SET NAMES utf8;
SET time_zone = '+00:00';
SET foreign_key_checks = 0;
SET sql_mode = 'NO_AUTO_VALUE_ON_ZERO';

SET NAMES utf8mb4;

--
-- Table structure for table `batch`
--

DROP TABLE IF EXISTS `batch`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `batch` (
  `bid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique batch ID.',
  `token` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'A string token generated against the current user''s session id and the batch id, used to ensure that only the user who submitted the batch can effectively access it.',
  `timestamp` int NOT NULL COMMENT 'A Unix timestamp indicating when this batch was submitted for processing. Stale batches are purged at cron time.',
  `batch` longblob COMMENT 'A serialized array containing the processing data for the batch.',
  PRIMARY KEY (`bid`),
  KEY `token` (`token`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores details about batches (processes that run in…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `batch`
--

LOCK TABLES `batch` WRITE;
/*!40000 ALTER TABLE `batch` DISABLE KEYS */;
/*!40000 ALTER TABLE `batch` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content`
--

DROP TABLE IF EXISTS `block_content`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `block_content_field__uuid__value` (`uuid`),
  UNIQUE KEY `block_content__revision_id` (`revision_id`),
  KEY `block_content_field__type__target_id` (`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for block_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content`
--

LOCK TABLES `block_content` WRITE;
/*!40000 ALTER TABLE `block_content` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content__body`
--

DROP TABLE IF EXISTS `block_content__body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content__body`
--

LOCK TABLES `block_content__body` WRITE;
/*!40000 ALTER TABLE `block_content__body` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content__body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content_field_data`
--

DROP TABLE IF EXISTS `block_content_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content_field_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `info` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `reusable` tinyint DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `block_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `block_content__revision_id` (`revision_id`),
  KEY `block_content_field__type__target_id` (`type`),
  KEY `block_content_field__reusable` (`reusable`),
  KEY `block_content__status_type` (`status`,`type`,`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for block_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content_field_data`
--

LOCK TABLES `block_content_field_data` WRITE;
/*!40000 ALTER TABLE `block_content_field_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content_field_revision`
--

DROP TABLE IF EXISTS `block_content_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content_field_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `info` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `block_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for block_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content_field_revision`
--

LOCK TABLES `block_content_field_revision` WRITE;
/*!40000 ALTER TABLE `block_content_field_revision` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content_revision`
--

DROP TABLE IF EXISTS `block_content_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `block_content__id` (`id`),
  KEY `block_content_field__revision_user__target_id` (`revision_user`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for block_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content_revision`
--

LOCK TABLES `block_content_revision` WRITE;
/*!40000 ALTER TABLE `block_content_revision` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `block_content_revision__body`
--

DROP TABLE IF EXISTS `block_content_revision__body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `block_content_revision__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `block_content_revision__body`
--

LOCK TABLES `block_content_revision__body` WRITE;
/*!40000 ALTER TABLE `block_content_revision__body` DISABLE KEYS */;
/*!40000 ALTER TABLE `block_content_revision__body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_access_policy`
--

DROP TABLE IF EXISTS `cache_access_policy`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_access_policy` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_access_policy`
--

LOCK TABLES `cache_access_policy` WRITE;
/*!40000 ALTER TABLE `cache_access_policy` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_access_policy` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_bootstrap`
--

DROP TABLE IF EXISTS `cache_bootstrap`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_bootstrap` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_bootstrap`
--

LOCK TABLES `cache_bootstrap` WRITE;
/*!40000 ALTER TABLE `cache_bootstrap` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_bootstrap` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_config`
--

DROP TABLE IF EXISTS `cache_config`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_config` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_config`
--

LOCK TABLES `cache_config` WRITE;
/*!40000 ALTER TABLE `cache_config` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_config` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_container`
--

DROP TABLE IF EXISTS `cache_container`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_container` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_container`
--

LOCK TABLES `cache_container` WRITE;
/*!40000 ALTER TABLE `cache_container` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_container` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_data`
--

DROP TABLE IF EXISTS `cache_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_data` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_data`
--

LOCK TABLES `cache_data` WRITE;
/*!40000 ALTER TABLE `cache_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_default`
--

DROP TABLE IF EXISTS `cache_default`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_default` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_default`
--

LOCK TABLES `cache_default` WRITE;
/*!40000 ALTER TABLE `cache_default` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_default` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_discovery`
--

DROP TABLE IF EXISTS `cache_discovery`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_discovery` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_discovery`
--

LOCK TABLES `cache_discovery` WRITE;
/*!40000 ALTER TABLE `cache_discovery` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_discovery` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_dynamic_page_cache`
--

DROP TABLE IF EXISTS `cache_dynamic_page_cache`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_dynamic_page_cache` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_dynamic_page_cache`
--

LOCK TABLES `cache_dynamic_page_cache` WRITE;
/*!40000 ALTER TABLE `cache_dynamic_page_cache` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_dynamic_page_cache` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_entity`
--

DROP TABLE IF EXISTS `cache_entity`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_entity` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_entity`
--

LOCK TABLES `cache_entity` WRITE;
/*!40000 ALTER TABLE `cache_entity` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_entity` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_file_mdm`
--

DROP TABLE IF EXISTS `cache_file_mdm`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_file_mdm` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_file_mdm`
--

LOCK TABLES `cache_file_mdm` WRITE;
/*!40000 ALTER TABLE `cache_file_mdm` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_file_mdm` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_menu`
--

DROP TABLE IF EXISTS `cache_menu`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_menu` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_menu`
--

LOCK TABLES `cache_menu` WRITE;
/*!40000 ALTER TABLE `cache_menu` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_menu` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_page`
--

DROP TABLE IF EXISTS `cache_page`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_page` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_page`
--

LOCK TABLES `cache_page` WRITE;
/*!40000 ALTER TABLE `cache_page` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_page` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_render`
--

DROP TABLE IF EXISTS `cache_render`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_render` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_render`
--

LOCK TABLES `cache_render` WRITE;
/*!40000 ALTER TABLE `cache_render` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_render` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cache_toolbar`
--

DROP TABLE IF EXISTS `cache_toolbar`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cache_toolbar` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cache_toolbar`
--

LOCK TABLES `cache_toolbar` WRITE;
/*!40000 ALTER TABLE `cache_toolbar` DISABLE KEYS */;
/*!40000 ALTER TABLE `cache_toolbar` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `cachetags`
--

DROP TABLE IF EXISTS `cachetags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `cachetags` (
  `tag` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Namespace-prefixed tag string.',
  `invalidations` int NOT NULL DEFAULT '0' COMMENT 'Number incremented when the tag is invalidated.',
  PRIMARY KEY (`tag`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Cache table for tracking cache tag invalidations.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `cachetags`
--

LOCK TABLES `cachetags` WRITE;
/*!40000 ALTER TABLE `cachetags` DISABLE KEYS */;
INSERT INTO `cachetags` VALUES ('4xx-response',224),('breakpoints',96),('config:action_list',1),('config:block.block.bootstrap_barrio_account_menu',2),('config:block.block.bootstrap_barrio_breadcrumbs',2),('config:block.block.bootstrap_barrio_content',2),('config:block.block.bootstrap_barrio_help',2),('config:block.block.bootstrap_barrio_main_menu',2),('config:block.block.bootstrap_barrio_messages',2),('config:block.block.bootstrap_barrio_page_title',2),('config:block.block.bootstrap_barrio_powered',2),('config:block.block.bootstrap_barrio_primary_admin_actions',2),('config:block.block.bootstrap_barrio_primary_local_tasks',2),('config:block.block.bootstrap_barrio_search_form_narrow',2),('config:block.block.bootstrap_barrio_search_form_wide',2),('config:block.block.bootstrap_barrio_secondary_local_tasks',2),('config:block.block.bootstrap_barrio_site_branding',2),('config:block.block.ept_light_account_menu',7),('config:block.block.ept_light_breadcrumbs',8),('config:block.block.ept_light_content',7),('config:block.block.ept_light_footer',3),('config:block.block.ept_light_help',7),('config:block.block.ept_light_main_menu',7),('config:block.block.ept_light_main_navigation',3),('config:block.block.ept_light_messages',7),('config:block.block.ept_light_page_title',10),('config:block.block.ept_light_powered',2),('config:block.block.ept_light_primary_admin_actions',7),('config:block.block.ept_light_primary_local_tasks',7),('config:block.block.ept_light_search_form_narrow',7),('config:block.block.ept_light_search_form_wide',7),('config:block.block.ept_light_secondary_local_tasks',7),('config:block.block.ept_light_site_branding',7),('config:block.block.ept_light_syndicate',2),('config:block.block.gin_breadcrumbs',1),('config:block.block.gin_content',1),('config:block.block.gin_help',1),('config:block.block.gin_local_actions',1),('config:block.block.gin_messages',1),('config:block.block.gin_page_title',1),('config:block.block.gin_primary_local_tasks',1),('config:block.block.gin_secondary_local_tasks',1),('config:block_list',19),('config:bootstrap_barrio.settings',1),('config:core.entity_form_display.node.article.default',1),('config:core.entity_form_display.node.page.default',2),('config:core.entity_view_display.node.article.default',1),('config:core.entity_view_display.node.article.rss',1),('config:core.entity_view_display.node.article.teaser',1),('config:core.entity_view_display.node.page.default',2),('config:core.entity_view_display.node.page.teaser',1),('config:core.entity_view_display.paragraph.ept_carousel.default',1),('config:core.entity_view_display.paragraph.ept_carousel_item.default',1),('config:core.entity_view_display.paragraph.ept_carousel_item.slider',1),('config:core.extension',76),('config:core.menu.static_menu_link_overrides',5),('config:editor.editor.full_html',3),('config:editor_list',3),('config:entity_form_display_list',28),('config:entity_form_mode_list',1),('config:entity_view_display_list',32),('config:entity_view_mode_list',7),('config:ept_light.settings',3),('config:field.field.node.article.comment',1),('config:field.field.paragraph.ept_block.field_ept_block_block',1),('config:field.storage.node.comment',1),('config:field.storage.paragraph.field_ept_block_block',1),('config:filter.format.basic_html',1),('config:filter.format.full_html',4),('config:filter.format.plain_text',1),('config:filter.format.restricted_html',1),('config:filter_format_list',4),('config:gin.settings',1),('config:image.style.ept_gallery_image',6),('config:image_style_list',11),('config:media_type_list',1),('config:menu_list',10),('config:node.settings',2),('config:node.type.article',1),('config:node_type_list',1),('config:paragraphs_type_list',23),('config:system.menu.account',94),('config:system.menu.admin',89),('config:system.menu.footer',95),('config:system.menu.main',104),('config:system.menu.tools',89),('config:system.performance',1),('config:system.site',1),('config:system.theme',5),('config:tb_megamenu.menu_config.main__ept_light',9),('config:tb_megamenu_list',10),('config:user.role.administrator',4),('config:user.role.anonymous',5),('config:user.role.authenticated',5),('config:user.role.content_editor',4),('config:user_role_list',5),('config:views.view.media',1),('config:views.view.media_library',1),('config:views.view.what_s_new',13),('config:view_list',10),('entity_bundles',38),('entity_field_info',243),('entity_types',107),('file:1',1),('file:10',2),('file:11',2),('file:12',2),('file:13',2),('file:14',2),('file:15',2),('file:16',2),('file:17',2),('file:18',2),('file:19',2),('file:20',2),('file:21',1),('file:22',2),('file:23',2),('file:24',2),('file:3',2),('file:4',2),('file:5',2),('file:6',2),('file:7',2),('file:8',2),('file:9',2),('file_list',47),('http_response',78),('library_info',72),('link_attributes',30),('local_task',116),('media:19',1),('media:4',2),('media:5',1),('media:6',1),('media:7',1),('media_list',28),('media_list:image',27),('media_list:remote_video',1),('media_view',5),('menu_link_content:1',5),('menu_link_content:11',2),('menu_link_content:12',2),('menu_link_content:13',6),('menu_link_content:14',1),('menu_link_content:2',2),('menu_link_content:3',2),('menu_link_content:4',3),('menu_link_content:5',2),('menu_link_content:7',1),('menu_link_content:9',1),('menu_link_content_list',33),('menu_link_content_list:menu_link_content',33),('node:1',44),('node:19',5),('node_list',68),('node_list:article',17),('node_list:page',51),('node_view',4),('paragraph:1',45),('paragraph:10',21),('paragraph:11',15),('paragraph:12',13),('paragraph:13',12),('paragraph:14',12),('paragraph:15',12),('paragraph:16',12),('paragraph:17',12),('paragraph:18',12),('paragraph:19',12),('paragraph:2',36),('paragraph:20',12),('paragraph:21',12),('paragraph:22',12),('paragraph:23',11),('paragraph:24',10),('paragraph:25',10),('paragraph:26',9),('paragraph:27',9),('paragraph:28',9),('paragraph:29',9),('paragraph:3',33),('paragraph:30',8),('paragraph:31',6),('paragraph:32',6),('paragraph:33',5),('paragraph:34',3),('paragraph:35',3),('paragraph:36',2),('paragraph:38',6),('paragraph:39',4),('paragraph:4',33),('paragraph:40',3),('paragraph:5',33),('paragraph:6',32),('paragraph:7',25),('paragraph:8',25),('paragraph:9',24),('paragraph_list',51),('paragraph_list:ept_accordion',3),('paragraph_list:ept_accordion_section',3),('paragraph_list:ept_block',5),('paragraph_list:ept_carousel',12),('paragraph_list:ept_carousel_item',12),('paragraph_list:ept_counter',10),('paragraph_list:ept_counter_item',10),('paragraph_list:ept_cta',16),('paragraph_list:ept_hero',49),('paragraph_list:ept_image_gallery',22),('paragraph_list:ept_quote',14),('paragraph_list:ept_slideshow',9),('paragraph_list:ept_slideshow_item',9),('paragraph_list:ept_stats',25),('paragraph_list:ept_stats_item',25),('paragraph_list:ept_tabs',6),('paragraph_list:ept_tabs_item',6),('paragraph_list:ept_text',37),('paragraph_list:ept_tiles',33),('paragraph_list:ept_tiles_item',33),('paragraph_list:ept_views',6),('paragraph_view',28),('rendered',12),('routes',78),('route_match',80),('search_index:help_search',10),('search_index:node_search',8),('views_data',27);
/*!40000 ALTER TABLE `cachetags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `comment`
--

DROP TABLE IF EXISTS `comment`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `comment` (
  `cid` int unsigned NOT NULL AUTO_INCREMENT,
  `comment_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`cid`),
  UNIQUE KEY `comment_field__uuid__value` (`uuid`),
  KEY `comment_field__comment_type__target_id` (`comment_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for comment entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `comment`
--

LOCK TABLES `comment` WRITE;
/*!40000 ALTER TABLE `comment` DISABLE KEYS */;
/*!40000 ALTER TABLE `comment` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `comment__comment_body`
--

DROP TABLE IF EXISTS `comment__comment_body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `comment__comment_body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `comment_body_value` longtext NOT NULL,
  `comment_body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `comment_body_format` (`comment_body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for comment field comment_body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `comment__comment_body`
--

LOCK TABLES `comment__comment_body` WRITE;
/*!40000 ALTER TABLE `comment__comment_body` DISABLE KEYS */;
/*!40000 ALTER TABLE `comment__comment_body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `comment_entity_statistics`
--

DROP TABLE IF EXISTS `comment_entity_statistics`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `comment_entity_statistics` (
  `entity_id` int unsigned NOT NULL DEFAULT '0' COMMENT 'The entity_id of the entity for which the statistics are compiled.',
  `entity_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT 'node' COMMENT 'The entity_type of the entity to which this comment is a reply.',
  `field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field_name of the field that was used to add this comment.',
  `cid` int NOT NULL DEFAULT '0' COMMENT 'The "comment".cid of the last comment.',
  `last_comment_timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp of the last comment that was posted within this node, from "comment".changed.',
  `last_comment_name` varchar(60) DEFAULT NULL COMMENT 'The name of the latest author to post a comment on this node, from "comment".name.',
  `last_comment_uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The user ID of the latest author to post a comment on this node, from "comment".uid.',
  `comment_count` int unsigned NOT NULL DEFAULT '0' COMMENT 'The total number of comments on this entity.',
  PRIMARY KEY (`entity_id`,`entity_type`,`field_name`),
  KEY `last_comment_timestamp` (`last_comment_timestamp`),
  KEY `comment_count` (`comment_count`),
  KEY `last_comment_uid` (`last_comment_uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maintains statistics of entity and comments posts to show …';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `comment_entity_statistics`
--

LOCK TABLES `comment_entity_statistics` WRITE;
/*!40000 ALTER TABLE `comment_entity_statistics` DISABLE KEYS */;
INSERT INTO `comment_entity_statistics` VALUES (2,'node','comment',0,1729063268,NULL,1,0);
/*!40000 ALTER TABLE `comment_entity_statistics` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `comment_field_data`
--

DROP TABLE IF EXISTS `comment_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `comment_field_data` (
  `cid` int unsigned NOT NULL,
  `comment_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `pid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `entity_id` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `subject` varchar(64) DEFAULT NULL,
  `name` varchar(60) DEFAULT NULL,
  `mail` varchar(254) DEFAULT NULL,
  `homepage` varchar(255) DEFAULT NULL,
  `hostname` varchar(128) DEFAULT NULL,
  `created` int NOT NULL,
  `changed` int DEFAULT NULL,
  `thread` varchar(255) NOT NULL,
  `entity_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`cid`,`langcode`),
  KEY `comment__id__default_langcode__langcode` (`cid`,`default_langcode`,`langcode`),
  KEY `comment_field__comment_type__target_id` (`comment_type`),
  KEY `comment_field__uid__target_id` (`uid`),
  KEY `comment_field__created` (`created`),
  KEY `comment__status_comment_type` (`status`,`comment_type`,`cid`),
  KEY `comment__status_pid` (`pid`,`status`),
  KEY `comment__num_new` (`entity_id`,`entity_type`,`comment_type`,`status`,`created`,`cid`,`thread`(191)),
  KEY `comment__entity_langcode` (`entity_id`,`entity_type`,`comment_type`,`default_langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for comment entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `comment_field_data`
--

LOCK TABLES `comment_field_data` WRITE;
/*!40000 ALTER TABLE `comment_field_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `comment_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `config`
--

DROP TABLE IF EXISTS `config`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `config` (
  `collection` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object collection.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object name.',
  `data` longblob COMMENT 'A serialized configuration object data.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for configuration data.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `config`
--

LOCK TABLES `config` WRITE;
/*!40000 ALTER TABLE `config` DISABLE KEYS */;
INSERT INTO `config` VALUES ('','admin_toolbar.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvTSppzcgH5wnzBhX5xnAExcp2I1CzkQ_aky65XNfYI\";}s:10:\"menu_depth\";i:4;}'),('','admin_toolbar_tools.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WgdZsrd_5w9jlmcHV4R9dD2tG9OZEkYo4I_O8h7Gq8Q\";}s:17:\"max_bundle_number\";i:20;s:25:\"hoverintent_functionality\";b:1;s:16:\"show_local_tasks\";b:0;}'),('','announcements_feed.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0G5pZBcxbg8ONYzNLd1RJIsvuFFewm9htnS4I-ABKJ8\";}s:7:\"max_age\";i:86400;s:13:\"cron_interval\";i:21600;s:5:\"limit\";i:10;}'),('','automated_cron.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fUksROt4FfkAU9BV4hV2XvhTBSS2nTNrZS4U7S-tKrs\";}s:8:\"interval\";i:10800;}'),('','block.block.claro_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"be976f48-8227-4e04-b46e-05849e446c76\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NjcxOBrPOiK5-38t56DwFBDVY4yer7YSlbRWXFuHe7A\";}s:2:\"id\";s:17:\"claro_breadcrumbs\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"ce83be5e-1fd7-4a0f-9b06-0a0d8710cb26\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a0Yyx1GeyKarZ4T_yXQBR_ZFKnXiFLtxAb6gWLd8nr0\";}s:2:\"id\";s:13:\"claro_content\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"d66baf8e-252f-4c79-acb6-b8b6d6b0a27a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jccFSSVqV0WCDb6NtML1VWAWTtDbZ-zn5YgTRMgMrIM\";}s:2:\"id\";s:10:\"claro_help\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_help_search',_binary 'a:13:{s:4:\"uuid\";s:36:\"05eb19c5-b411-47d2-b90a-e862156e9997\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"module\";a:2:{i:0;s:6:\"search\";i:1;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}s:8:\"enforced\";a:1:{s:6:\"config\";a:1:{i:0;s:23:\"search.page.help_search\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2ToeZLvlHKTeFY74gpgu1PejLoFyCECLO_gw6rAZwqw\";}s:2:\"id\";s:17:\"claro_help_search\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:11:\"Search help\";s:13:\"label_display\";s:7:\"visible\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:11:\"help_search\";}s:10:\"visibility\";a:1:{s:12:\"request_path\";a:4:{s:2:\"id\";s:12:\"request_path\";s:6:\"negate\";b:0;s:15:\"context_mapping\";a:0:{}s:5:\"pages\";s:11:\"/admin/help\";}}}'),('','block.block.claro_local_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"916365b2-7723-493b-8918-5f3ff7d57c7d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CdXfDmRgAvms7EQovxxWPdYi0GitxeRbVtScYK16ZH0\";}s:2:\"id\";s:19:\"claro_local_actions\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"3b00e68f-1ed0-4482-b8b1-e496f1da9936\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-Ac3ISpIT0PQ-whzD7_dw0SdKi6dAbRFNWdSjOiVDqg\";}s:2:\"id\";s:14:\"claro_messages\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"b76f1641-4f78-438e-a0fe-ce65bd7f9006\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNwDdW063tk_ktzSWzZVeQS9wzvLooVO280BQ9WrsIs\";}s:2:\"id\";s:16:\"claro_page_title\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"a8c9d41b-02e1-478d-85b3-fb3a1f815f49\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ACjBZI5shAMiiUpsz-inLYVXDqNNXRnSzAWV3kV_8Hw\";}s:2:\"id\";s:25:\"claro_primary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"bb1e9b33-93c2-4829-9613-e4ccc525f30b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2L0geP-ixCbCkEpW6BVF6H7vDUZN4ea07_Y9CociQm4\";}s:2:\"id\";s:27:\"claro_secondary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_account_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"f35c55e3-3d40-497f-9b7f-2896cbc2e345\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:19:\"system.menu.account\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU\";}s:2:\"id\";s:22:\"ept_light_account_menu\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:25:\"system_menu_block:account\";s:8:\"settings\";a:7:{s:2:\"id\";s:25:\"system_menu_block:account\";s:5:\"label\";s:17:\"User account menu\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:1;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"7010f57e-634e-4b97-8a69-97b80a011cb4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE\";}s:2:\"id\";s:21:\"ept_light_breadcrumbs\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:1:{s:12:\"request_path\";a:3:{s:2:\"id\";s:12:\"request_path\";s:6:\"negate\";b:1;s:5:\"pages\";s:10:\"/whats-new\";}}}'),('','block.block.ept_light_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"7b17ab28-0376-4ee3-91ee-5bd02432291e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk\";}s:2:\"id\";s:17:\"ept_light_content\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_footer',_binary 'a:12:{s:4:\"uuid\";s:36:\"a78731d9-6557-4805-9b50-71d93a910730\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:18:\"system.menu.footer\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:2:\"id\";s:16:\"ept_light_footer\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"footer\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:24:\"system_menu_block:footer\";s:8:\"settings\";a:7:{s:2:\"id\";s:24:\"system_menu_block:footer\";s:5:\"label\";s:24:\"Have a question or idea?\";s:13:\"label_display\";s:7:\"visible\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:0;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"8edfdbdd-cd33-4ebe-b1d4-74fb38d1039e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg\";}s:2:\"id\";s:14:\"ept_light_help\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_main_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"736d4519-e22a-419a-87cd-009a768a73b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE\";}s:2:\"id\";s:19:\"ept_light_main_menu\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:22:\"system_menu_block:main\";s:8:\"settings\";a:7:{s:2:\"id\";s:22:\"system_menu_block:main\";s:5:\"label\";s:15:\"Main navigation\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:2;s:16:\"expand_all_items\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"c8fc509e-9767-4eae-81f5-6cdbe64aa2b3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0\";}s:2:\"id\";s:18:\"ept_light_messages\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"f45a0a49-c001-47cb-b97e-767aac0f24f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y\";}s:2:\"id\";s:20:\"ept_light_page_title\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:1:{s:18:\"entity_bundle:node\";a:4:{s:2:\"id\";s:18:\"entity_bundle:node\";s:6:\"negate\";b:0;s:15:\"context_mapping\";a:1:{s:4:\"node\";s:29:\"@node.node_route_context:node\";}s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}}}'),('','block.block.ept_light_primary_admin_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"feb5ed42-838e-41fe-bce3-ac32e38425f9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U\";}s:2:\"id\";s:31:\"ept_light_primary_admin_actions\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"56ef6a64-122b-4123-89be-e28c850c9ab5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4\";}s:2:\"id\";s:29:\"ept_light_primary_local_tasks\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_search_form_narrow',_binary 'a:13:{s:4:\"uuid\";s:36:\"ac6db2d5-4bab-486d-9cbd-5a8bc4c56df9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yEBET0cqDbk8dkWzaJw-8CKft0961VBflsISoSR6Lj8\";}s:2:\"id\";s:28:\"ept_light_search_form_narrow\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"hidden\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:20:\"Search form (narrow)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_search_form_wide',_binary 'a:13:{s:4:\"uuid\";s:36:\"682b08d1-3f45-4c13-974e-95552426afcd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"imMyHD6LYci0gtXq56qr9ZKGHzbEG9uFydrN5EhKtSU\";}s:2:\"id\";s:26:\"ept_light_search_form_wide\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"hidden\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:18:\"Search form (wide)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"901eabdd-054d-4bcb-9773-45c7fd010fdf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI\";}s:2:\"id\";s:31:\"ept_light_secondary_local_tasks\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-3;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_site_branding',_binary 'a:13:{s:4:\"uuid\";s:36:\"91c1ee17-a1ad-4235-992c-274ff1022382\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM\";}s:2:\"id\";s:23:\"ept_light_site_branding\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_branding_block\";s:8:\"settings\";a:7:{s:2:\"id\";s:21:\"system_branding_block\";s:5:\"label\";s:13:\"Site branding\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:13:\"use_site_logo\";b:1;s:13:\"use_site_name\";b:1;s:15:\"use_site_slogan\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"906009a1-78bd-4b80-9f60-5260448561b2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"y9X3xgCsO59pQyzNLzY1D3SDJJxCHILLWkpPnmuTJ2E\";}s:2:\"id\";s:15:\"gin_breadcrumbs\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"38507368-0a7f-4498-a629-376fb4821455\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBHXB7hC05XU7pDYzETt-GUcpFlogK1gkjyAsg0Ym58\";}s:2:\"id\";s:11:\"gin_content\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"e3753ad7-7b76-4f93-add9-02296fe5a072\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8nOAry2oKqJOr0zbrlJ3sZHDFJLIO6j-0vT0K_TYca4\";}s:2:\"id\";s:8:\"gin_help\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_local_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"f127d369-8154-4de3-9366-638b32c1d495\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OQ9aJ-4qVwK1x00o9EOYK4eFDjQr_HLpbPiJaPSVZiQ\";}s:2:\"id\";s:17:\"gin_local_actions\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"302175a6-2514-4728-9834-feade3c1cb23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WvPhI8OwllG0gE69-F8qL3ai3nd5SbYD6JpmEuZcyok\";}s:2:\"id\";s:12:\"gin_messages\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"37f8f7d2-81b3-4c42-a9a4-84cb29380e2c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HLQY2xgby8K3vN_98hiOSasOhm9pdCsH234-s0duJ8Q\";}s:2:\"id\";s:14:\"gin_page_title\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"877e883f-c61a-49fd-bf14-7370c20fec8c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Hh01DLj9k7UnNdPpOQXHZHW7GHf2OPNDQyCJF7_R9ac\";}s:2:\"id\";s:23:\"gin_primary_local_tasks\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"11d088e1-eb0e-4d66-ac1d-c629d4c31759\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCWhood0xXFQYqxFgL1spXdb9KeIuXH1YvTdjIEedDg\";}s:2:\"id\";s:25:\"gin_secondary_local_tasks\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_account_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"360ce22f-fdb1-4a74-baf4-b253df6d8b6d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:19:\"system.menu.account\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU\";}s:2:\"id\";s:20:\"olivero_account_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:25:\"system_menu_block:account\";s:8:\"settings\";a:7:{s:2:\"id\";s:25:\"system_menu_block:account\";s:5:\"label\";s:17:\"User account menu\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:1;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"19cc65dc-0021-4f62-9692-28154e28e6d6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE\";}s:2:\"id\";s:19:\"olivero_breadcrumbs\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"45129ab9-c3af-46c1-b266-7caf3e552d05\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk\";}s:2:\"id\";s:15:\"olivero_content\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"1f0cb4e0-55ff-4097-a00c-015a0892bae5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg\";}s:2:\"id\";s:12:\"olivero_help\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_main_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"447aab50-0670-4a09-ad2b-204da3cad682\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE\";}s:2:\"id\";s:17:\"olivero_main_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:22:\"system_menu_block:main\";s:8:\"settings\";a:7:{s:2:\"id\";s:22:\"system_menu_block:main\";s:5:\"label\";s:15:\"Main navigation\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:2;s:16:\"expand_all_items\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"07cc9530-0745-41b8-a927-b15f94d11bfb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0\";}s:2:\"id\";s:16:\"olivero_messages\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"8ed1a440-61c0-42d9-af64-c0573a386802\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y\";}s:2:\"id\";s:18:\"olivero_page_title\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_powered',_binary 'a:13:{s:4:\"uuid\";s:36:\"4e19c95d-851d-48dd-8e91-3df3501787a3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYL19CLDyinGTWYQfBD1DswWzglEotE_kHnHx3AxTXM\";}s:2:\"id\";s:15:\"olivero_powered\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"footer_bottom\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_powered_by_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_powered_by_block\";s:5:\"label\";s:17:\"Powered by Drupal\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_primary_admin_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"2889853d-c6c8-46fb-8345-4f1161d60b42\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U\";}s:2:\"id\";s:29:\"olivero_primary_admin_actions\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"4a702f15-1477-4e9c-a8bf-5c98f5bff5f5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4\";}s:2:\"id\";s:27:\"olivero_primary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_search_form_narrow',_binary 'a:13:{s:4:\"uuid\";s:36:\"8eba635a-7f03-408c-a4a4-28e12ca89e20\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yEBET0cqDbk8dkWzaJw-8CKft0961VBflsISoSR6Lj8\";}s:2:\"id\";s:26:\"olivero_search_form_narrow\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:20:\"Search form (narrow)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_search_form_wide',_binary 'a:13:{s:4:\"uuid\";s:36:\"decd9477-39d6-4529-94a3-8a2d5f064f46\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"imMyHD6LYci0gtXq56qr9ZKGHzbEG9uFydrN5EhKtSU\";}s:2:\"id\";s:24:\"olivero_search_form_wide\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:18:\"Search form (wide)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"b7350fce-d849-4243-936a-283b164fea04\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI\";}s:2:\"id\";s:29:\"olivero_secondary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-2;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_site_branding',_binary 'a:13:{s:4:\"uuid\";s:36:\"5e004719-546a-4a9e-8ed6-bce3b1438316\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM\";}s:2:\"id\";s:21:\"olivero_site_branding\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_branding_block\";s:8:\"settings\";a:7:{s:2:\"id\";s:21:\"system_branding_block\";s:5:\"label\";s:13:\"Site branding\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:13:\"use_site_logo\";b:1;s:13:\"use_site_name\";b:1;s:15:\"use_site_slogan\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_syndicate',_binary 'a:13:{s:4:\"uuid\";s:36:\"b7ad69dc-b6ab-4ee3-ab50-2994b490c801\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0gq3VPg-_UM69FCCWurLFIrrnIjC2HLKhwo9iQNtcUo\";}s:2:\"id\";s:17:\"olivero_syndicate\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"social\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:20:\"node_syndicate_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:20:\"node_syndicate_block\";s:5:\"label\";s:8:\"RSS feed\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"node\";s:11:\"block_count\";i:10;}s:10:\"visibility\";a:0:{}}'),('','block_content.type.basic',_binary 'a:9:{s:4:\"uuid\";s:36:\"682f8d4b-7fbf-4b68-aeeb-78ff6ffa44c8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pQP5iQy4SdhAMVcjDUncCfkJmTofnHVtXrsMzx4k6Yk\";}s:2:\"id\";s:5:\"basic\";s:5:\"label\";s:11:\"Basic block\";s:8:\"revision\";b:0;s:11:\"description\";s:42:\"A basic block contains a title and a body.\";}'),('','ckeditor5_plugin_pack.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uAMHMIBA-fCvlzeeOYZ4vKwSBXvThlEytdEKK_Ur8nI\";}s:12:\"dll_location\";s:0:\"\";}'),('','claro.settings',_binary 'a:1:{s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}}'),('','comment.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YNUW2Ij5uE7a4oaXp3i_2lvaFdYM1zNKPPfnEjB0jEc\";}s:16:\"log_ip_addresses\";b:0;}'),('','comment.type.comment',_binary 'a:9:{s:4:\"uuid\";s:36:\"33c6c326-f5e0-4ece-8508-28b245963a92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bqZsN31T2n0UjcbyCpOPi9D2iO0sAOHR7FnEs9qMvaA\";}s:2:\"id\";s:7:\"comment\";s:5:\"label\";s:16:\"Default comments\";s:21:\"target_entity_type_id\";s:4:\"node\";s:11:\"description\";s:28:\"Allows commenting on content\";}'),('','contact.form.feedback',_binary 'a:12:{s:4:\"uuid\";s:36:\"d9d62dfa-bada-46f4-869f-64b74f835a2f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vymHlgJy26BuI5GGj9-IXjwR3dRC5C0tij4BpWJnoqw\";}s:2:\"id\";s:8:\"feedback\";s:5:\"label\";s:16:\"Website feedback\";s:10:\"recipients\";a:1:{i:0;s:17:\"admin@example.com\";}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),('','contact.form.personal',_binary 'a:12:{s:4:\"uuid\";s:36:\"3d45f5dc-8385-44e2-add9-10e58ad548b8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jonvgt3CkUM2eMLTFwWfHileWWDC4YtXCuIlCahTk_I\";}s:2:\"id\";s:8:\"personal\";s:5:\"label\";s:21:\"Personal contact form\";s:10:\"recipients\";a:0:{}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),('','contact.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U69DBeuvXuNVOC15rVNaBjDPK2fWFbo9v4takdYSSO8\";}s:12:\"default_form\";s:8:\"feedback\";s:5:\"flood\";a:2:{s:5:\"limit\";i:5;s:8:\"interval\";i:3600;}s:20:\"user_default_enabled\";b:1;}'),('','core.base_field_override.node.page.promote',_binary 'a:17:{s:4:\"uuid\";s:36:\"3818335f-a764-468f-ba14-8dbe325fa7f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:14:\"node.type.page\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fPUEnm4T5zfZRr3ttDUqq7yCDd2uW3clWD-pvos4tlQ\";}s:2:\"id\";s:17:\"node.page.promote\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:22:\"Promoted to front page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),('','core.date_format.fallback',_binary 'a:9:{s:4:\"uuid\";s:36:\"3d36a601-a518-4117-b489-72f027a4d007\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7klS5IWXrwzVaPpYZFAs6wcx8U2FF1X73OfrtTsvuvE\";}s:2:\"id\";s:8:\"fallback\";s:5:\"label\";s:20:\"Fallback date format\";s:6:\"locked\";b:1;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),('','core.date_format.html_date',_binary 'a:9:{s:4:\"uuid\";s:36:\"1e7ea1cc-62aa-4605-b6b6-e50e8e13c716\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EOQltUQPmgc6UQ2rcJ4Xi_leCEJj5ui0TR-12duS-Tk\";}s:2:\"id\";s:9:\"html_date\";s:5:\"label\";s:9:\"HTML Date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-m-d\";}'),('','core.date_format.html_datetime',_binary 'a:9:{s:4:\"uuid\";s:36:\"c34d2a68-a9e5-40c6-8224-8940032e30eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jxfClwZIRXIdcvMrE--WkcZxDGUVoOIE3Sm2NRZlFuE\";}s:2:\"id\";s:13:\"html_datetime\";s:5:\"label\";s:13:\"HTML Datetime\";s:6:\"locked\";b:1;s:7:\"pattern\";s:13:\"Y-m-d\\TH:i:sO\";}'),('','core.date_format.html_month',_binary 'a:9:{s:4:\"uuid\";s:36:\"1db472d5-aa8d-43d1-99f1-0718ae5620bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Z7KuCUwM_WdTNvLcoltuX3_8d-s-8FZkTN6KgNwF0eM\";}s:2:\"id\";s:10:\"html_month\";s:5:\"label\";s:10:\"HTML Month\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"Y-m\";}'),('','core.date_format.html_time',_binary 'a:9:{s:4:\"uuid\";s:36:\"504c65d8-2f56-4376-8b9b-e7ca5b007ba8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M7yqicYkU36hRy5p9drAaGBBihhUD1OyujFrAaQ93ZE\";}s:2:\"id\";s:9:\"html_time\";s:5:\"label\";s:9:\"HTML Time\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"H:i:s\";}'),('','core.date_format.html_week',_binary 'a:9:{s:4:\"uuid\";s:36:\"9c97ee83-74c2-4456-80d2-eb94e9ca333e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKD4WsoV_wFgv2vgI4mcAAFSIzrye17ykzdwrnApkfY\";}s:2:\"id\";s:9:\"html_week\";s:5:\"label\";s:9:\"HTML Week\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-\\WW\";}'),('','core.date_format.html_year',_binary 'a:9:{s:4:\"uuid\";s:36:\"045e5b96-3ec2-48a7-ba8c-c6cd6c3e6478\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjekiQuX9RbVQ2_8jOHBL94RgYLePqX7wpfNGgcQzrk\";}s:2:\"id\";s:9:\"html_year\";s:5:\"label\";s:9:\"HTML Year\";s:6:\"locked\";b:1;s:7:\"pattern\";s:1:\"Y\";}'),('','core.date_format.html_yearless_date',_binary 'a:9:{s:4:\"uuid\";s:36:\"ebd666ec-7725-4d54-8907-f69b8c4e48ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VpawMrKPEPCkoO4YpPa0TDFO2dgiIHfTziJtwlmUxc\";}s:2:\"id\";s:18:\"html_yearless_date\";s:5:\"label\";s:18:\"HTML Yearless date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"m-d\";}'),('','core.date_format.long',_binary 'a:9:{s:4:\"uuid\";s:36:\"26c2a255-dd57-40de-9edb-d3ecd4eafa69\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"og8sWXhBuHbLMw3CoiBEZjgqSyhFBFmcbUW_wLcfNbo\";}s:2:\"id\";s:4:\"long\";s:5:\"label\";s:17:\"Default long date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:15:\"l, F j, Y - H:i\";}'),('','core.date_format.medium',_binary 'a:9:{s:4:\"uuid\";s:36:\"b3b94f80-dd74-4a2f-b128-51de30c5e289\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nzL5d024NjXIX_8TlT6uFAu973lmfkmHklJC-2i9rAE\";}s:2:\"id\";s:6:\"medium\";s:5:\"label\";s:19:\"Default medium date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),('','core.date_format.olivero_medium',_binary 'a:9:{s:4:\"uuid\";s:36:\"f5992887-d80e-47c5-bcb3-28c304448abb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mt6cmxUbDZ9XxD6p25WQ8tj3_JcX8ylfcddwZc8gcAE\";}s:2:\"id\";s:14:\"olivero_medium\";s:5:\"label\";s:14:\"Olivero Medium\";s:6:\"locked\";b:0;s:7:\"pattern\";s:8:\"j  F,  Y\";}'),('','core.date_format.short',_binary 'a:9:{s:4:\"uuid\";s:36:\"c5c2ce9a-1442-4bf1-a654-b45e23c4b6e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AlzeyytA8InBgxIG9H2UDJYs3CG98Zj6yRsDKmlbZwA\";}s:2:\"id\";s:5:\"short\";s:5:\"label\";s:18:\"Default short date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:11:\"m/d/Y - H:i\";}'),('','core.entity_form_display.block_content.basic.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"21a9c7b6-423a-4c02-931a-6bb7c808ca5e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jAps3FCxvKecABS_tgExbhCZrBLQB3bNPWw18WjE3ss\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:-4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.comment.comment.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"46bc1cc1-610e-4909-9538-f9f08a6a24c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:40:\"field.field.comment.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I0Pa0aQvT_jawlPo9oz4FE3h_ickc55dYKTPl6gILes\";}s:2:\"id\";s:23:\"comment.comment.default\";s:16:\"targetEntityType\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:6:\"author\";a:2:{s:6:\"weight\";i:-2;s:6:\"region\";s:7:\"content\";}s:12:\"comment_body\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:11;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:7:\"subject\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.media.audio.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"1912a858-abb3-4ca8-aa94-e9265ace4567\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"G2_SKH3jmI9FQeXSUxo3KgQqiyF1hPDEkc7-3-rCSbc\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_audio_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.audio.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"4c160f87-d7c6-4dde-a9d2-878ce2336387\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:16:\"media.type.audio\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"28vwMIYtvyjPcD4RyciZXIztxtZgmuWRCNgYemr_SZE\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.document.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"c24b87ec-64f6-4fa0-aed7-1c3d86160e5e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aewrRkePgJzdD5kPOq8JeMcKHs6yat49nE7ZeCQzQZg\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_media_document\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.document.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"8323a260-ffc2-4476-8123-c40c72552a6e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:19:\"media.type.document\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dcpfpqyLXOSGpulacMAJW3H-G34_LeNsjdfxd1_oCfY\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.image.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f08ad847-8b1c-4396-9081-ca9a56f6b01a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:21:\"image.style.thumbnail\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JSY4-JPyNZBiYYo6imdRYF6_SdtWQexPndrLvn3-vw4\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.image.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"91fbcfb7-0a83-434f-99ac-c23c349657be\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BMLrK4zKp8-FFnMseBdT_6h6YipUsKRfbDf_3WUB5HA\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:5:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.remote_video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"97a32351-c013-445a-af13-08939389c3b1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pM8mGlwfpvfG_y5tZn0lGAXFLXz2_yKkL7MvWZsRqdA\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_media_oembed_video\";a:5:{s:4:\"type\";s:16:\"oembed_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.remote_video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"47cd5408-95d9-4b89-a9c5-7d8aedd625f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBgPW-uaXRaICBwLaVc16rXpRiLSknDIdF9q0XL7qso\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"7c5e18c3-3d08-4151-8d31-a9d9a597a5ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0kIIaDTt6dixXy8TZkat2MNGZJ6vkRG8TaBWTy3E1bM\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_video_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"3d683f4e-cbb1-4a0e-b1df-f9f9c87e4284\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:16:\"media.type.video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kGv8YsopqHvzTzb7QTINWcv0fnNa5ZDQyZxpOQR2vro\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.node.article.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"de67467e-664b-4fd4-b096-f4f20912ea91\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:35:\"field.field.node.article.field_tags\";i:3;s:21:\"image.style.thumbnail\";i:4;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"path\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ewbd6G2uX456-bgwseM2Q-KQG3RkASoyHmTh-XR3oLU\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:10:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:11:\"field_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:10:\"field_tags\";a:5:{s:4:\"type\";s:34:\"entity_reference_autocomplete_tags\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.node.page.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"c6ec1d38-d434-4a7d-be65-080873fd0aff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:26:\"field.field.node.page.body\";i:1;s:38:\"field.field.node.page.field_components\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:3:{i:0;s:17:\"layout_paragraphs\";i:1;s:4:\"path\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SfpLhPExzvR0MgFp0Wp7CrmgEnhcqQ-fXIWFhbf4ue0\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:9:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:31;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:16:\"field_components\";a:5:{s:4:\"type\";s:17:\"layout_paragraphs\";s:6:\"weight\";i:121;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.paragraph.ept_accordion.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"bcf372a8-c025-4ef1-bc1e-7467ead740ff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:55:\"field.field.paragraph.ept_accordion.field_ept_accordion\";i:1;s:54:\"field.field.paragraph.ept_accordion.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_accordion.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_accordion.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:4:{i:0;s:13:\"ept_accordion\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:19:\"field_ept_accordion\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0pJauu3QzSH4aBsmd_KTxzf59AWAoqGvmpFOuI3phow\";}s:2:\"id\";s:31:\"paragraph.ept_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:19:\"field_ept_accordion\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:22:\"ept_settings_accordion\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_accordion_section.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a18df3e8-1c60-449a-81fb-3d8f4dc347dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:68:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_text\";i:1;s:69:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_title\";i:2;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-D0_ofC0E9vG5JgJKn-KVVKS8EddSulFMva-vLSGBq4\";}s:2:\"id\";s:39:\"paragraph.ept_accordion_section.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ept_accordion_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_accordion_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_basic_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"3bbc19b5-b8d1-4737-93da-814614ad0da5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:66:\"field.field.paragraph.ept_basic_button.field_ept_basic_button_link\";i:1;s:57:\"field.field.paragraph.ept_basic_button.field_ept_settings\";i:2;s:53:\"field.field.paragraph.ept_basic_button.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_basic_button.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:3:{i:0;s:16:\"ept_basic_button\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BDM_dmNUeNyOV7_jEouKixGZvfGdfIYFnegSbt0TFUk\";}s:2:\"id\";s:34:\"paragraph.ept_basic_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:27:\"field_ept_basic_button_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:25:\"ept_settings_basic_button\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_block.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"063fafbf-a44a-44d9-b44e-e6b7f1c968f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_block.field_ept_block_block\";i:1;s:50:\"field.field.paragraph.ept_block.field_ept_settings\";i:2;s:46:\"field.field.paragraph.ept_block.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_block.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:4:{i:0;s:11:\"block_field\";i:1;s:8:\"ept_core\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:21:\"field_ept_block_block\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kf0CKi0lVMCHZKEFVJNSYNl5CpKFKRH7JLsGDr_mt24\";}s:2:\"id\";s:27:\"paragraph.ept_block.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:21:\"field_ept_block_block\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_bootstrap_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"39e1a15a-eab7-4dcc-af37-af10f81e96dd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:74:\"field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";i:1;s:61:\"field.field.paragraph.ept_bootstrap_button.field_ept_settings\";i:2;s:57:\"field.field.paragraph.ept_bootstrap_button.field_ept_text\";i:3;s:58:\"field.field.paragraph.ept_bootstrap_button.field_ept_title\";i:4;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:3:{i:0;s:20:\"ept_bootstrap_button\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WwkZbBHhL-k1BpcZgfCET2hj9ScPYC5rcs4an-tHYB4\";}s:2:\"id\";s:38:\"paragraph.ept_bootstrap_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:31:\"field_ept_bootstrap_button_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:29:\"ept_settings_bootstrap_button\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_carousel.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"3b42b32b-b440-4ab8-9a73-96284648f0b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_carousel.field_ept_carousel\";i:1;s:53:\"field.field.paragraph.ept_carousel.field_ept_settings\";i:2;s:49:\"field.field.paragraph.ept_carousel.field_ept_text\";i:3;s:50:\"field.field.paragraph.ept_carousel.field_ept_title\";i:4;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:4:{i:0;s:12:\"ept_carousel\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:18:\"field_ept_carousel\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:1;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9B69asgWfAo5TT1550-4nwxxD-NZ9b_eK0DwrqjPbAI\";}s:2:\"id\";s:30:\"paragraph.ept_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_carousel\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:21:\"ept_settings_carousel\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_carousel_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"209743da-7b46-410c-8256-e9acf9b4200b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";i:1;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";i:2;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0MubGNP7-aRTqqknjrXSWiyr6o87xC8YYQSjnFL1qMA\";}s:2:\"id\";s:35:\"paragraph.ept_carousel_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ept_carousel_caption\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ept_carousel_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_columns.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"4fadf498-bcbb-44d6-b829-6d1abdabf326\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:51:\"field.field.paragraph.ept_columns.field_ept_columns\";i:1;s:52:\"field.field.paragraph.ept_columns.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_columns.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_columns.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:4:{i:0;s:11:\"ept_columns\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:17:\"field_ept_columns\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MfVgHlmnR_bb8akzrozdi7R7KwnEOtq9cQ0OpHkngMs\";}s:2:\"id\";s:29:\"paragraph.ept_columns.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:17:\"field_ept_columns\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_columns\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_countdown.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"ed55009f-a01e-42ae-987d-b5ccc04e073b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ept_countdown.field_ept_countdown_date\";i:1;s:54:\"field.field.paragraph.ept_countdown.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_countdown.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_countdown.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:4:{i:0;s:8:\"datetime\";i:1;s:13:\"ept_countdown\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:24:\"field_ept_countdown_date\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZxcirB8U5v0ZYrJRdwsxmS_1WIhbNwZMbBqsAz988cQ\";}s:2:\"id\";s:31:\"paragraph.ept_countdown.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_countdown_date\";a:5:{s:4:\"type\";s:16:\"datetime_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:22:\"ept_settings_countdown\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_counter.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"6e0ad4c3-90f1-4e63-9ad2-e7c012a124d2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_counter.field_ept_counter_items\";i:1;s:52:\"field.field.paragraph.ept_counter.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_counter.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_counter.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:4:{i:0;s:11:\"ept_counter\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:23:\"field_ept_counter_items\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:9;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eaw1Ar6YTSIRF829Uy9SPd0v5CFQ_XobGxIEZV3aq_Q\";}s:2:\"id\";s:29:\"paragraph.ept_counter.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_counter_items\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_counter\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_counter_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8c95a60e-1c70-45a6-b8a2-c4d53b93ce5d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_counter_item.field_ept_counter_description\";i:1;s:61:\"field.field.paragraph.ept_counter_item.field_ept_counter_icon\";i:2;s:63:\"field.field.paragraph.ept_counter_item.field_ept_counter_number\";i:3;s:62:\"field.field.paragraph.ept_counter_item.field_ept_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HdOx-dFGYXleAxDzMra4AkSnLaUMOZ6Sgl69k93sJcg\";}s:2:\"id\";s:34:\"paragraph.ept_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ept_counter_description\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ept_counter_icon\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ept_counter_number\";a:5:{s:4:\"type\";s:6:\"number\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ept_counter_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_cta.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"8a29f047-88c0-4af9-8cd2-705177201f7a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:56:\"field.field.paragraph.ept_cta.field_ept_cta_column_image\";i:1;s:48:\"field.field.paragraph.ept_cta.field_ept_cta_link\";i:2;s:55:\"field.field.paragraph.ept_cta.field_ept_cta_second_link\";i:3;s:48:\"field.field.paragraph.ept_cta.field_ept_settings\";i:4;s:44:\"field.field.paragraph.ept_cta.field_ept_text\";i:5;s:45:\"field.field.paragraph.ept_cta.field_ept_title\";i:6;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:5:{i:0;s:7:\"ept_cta\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:5:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:26:\"field_ept_cta_column_image\";i:3;s:18:\"field_ept_cta_link\";i:4;s:25:\"field_ept_cta_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:1;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4FYtKN9WoslLXaZoBk3fkuVx6aDPk0YoM6rC8pnsieA\";}s:2:\"id\";s:25:\"paragraph.ept_cta.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:26:\"field_ept_cta_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_cta_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_cta_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:16:\"ept_settings_cta\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_hero.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"be53fd67-518c-4b3c-ac43-3b2c15a8d954\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_column_image\";i:1;s:50:\"field.field.paragraph.ept_hero.field_ept_hero_link\";i:2;s:57:\"field.field.paragraph.ept_hero.field_ept_hero_second_link\";i:3;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_title_prefix\";i:4;s:49:\"field.field.paragraph.ept_hero.field_ept_settings\";i:5;s:45:\"field.field.paragraph.ept_hero.field_ept_text\";i:6;s:46:\"field.field.paragraph.ept_hero.field_ept_title\";i:7;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:5:{i:0;s:8:\"ept_hero\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:6:{i:0;s:15:\"field_ept_title\";i:1;s:27:\"field_ept_hero_title_prefix\";i:2;s:14:\"field_ept_text\";i:3;s:27:\"field_ept_hero_column_image\";i:4;s:19:\"field_ept_hero_link\";i:5;s:26:\"field_ept_hero_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jU5fU7CphqYF6ZSn4c9q-QZ0_XHfDeFV936TKmTKPIM\";}s:2:\"id\";s:26:\"paragraph.ept_hero.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:27:\"field_ept_hero_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_hero_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ept_hero_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_hero_title_prefix\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:17:\"ept_settings_hero\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_image.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"a60ae7a6-353d-412e-81ca-b8eff5eb6f78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:47:\"field.field.paragraph.ept_image.field_ept_image\";i:1;s:55:\"field.field.paragraph.ept_image.field_ept_image_caption\";i:2;s:52:\"field.field.paragraph.ept_image.field_ept_image_link\";i:3;s:50:\"field.field.paragraph.ept_image.field_ept_settings\";i:4;s:46:\"field.field.paragraph.ept_image.field_ept_text\";i:5;s:47:\"field.field.paragraph.ept_image.field_ept_title\";i:6;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:5:{i:0;s:9:\"ept_image\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:5:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:15:\"field_ept_image\";i:3;s:23:\"field_ept_image_caption\";i:4;s:20:\"field_ept_image_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6-OjP-OV8uHyYxN_ycg0WCoPJRu34t3ix7LwCCNbTzE\";}s:2:\"id\";s:27:\"paragraph.ept_image.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:15:\"field_ept_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ept_image_caption\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_image_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_image\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_image_gallery.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"bd32a1a0-f63c-4e6b-b14f-7dfa6323a07a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_image_gallery.field_ept_image_gallery\";i:1;s:58:\"field.field.paragraph.ept_image_gallery.field_ept_settings\";i:2;s:54:\"field.field.paragraph.ept_image_gallery.field_ept_text\";i:3;s:55:\"field.field.paragraph.ept_image_gallery.field_ept_title\";i:4;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:4:{i:0;s:17:\"ept_image_gallery\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:23:\"field_ept_image_gallery\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9b_KN3kBrDhBERN17M7jxBYPF-IXaw1nLONpCw4Dtzo\";}s:2:\"id\";s:35:\"paragraph.ept_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_image_gallery\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:26:\"ept_settings_image_gallery\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_micromodal.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"c0e1ca3f-d656-43c4-a362-86c7cb0ac490\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_micromodal.field_ept_micromodal_title\";i:1;s:55:\"field.field.paragraph.ept_micromodal.field_ept_settings\";i:2;s:51:\"field.field.paragraph.ept_micromodal.field_ept_text\";i:3;s:52:\"field.field.paragraph.ept_micromodal.field_ept_title\";i:4;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:3:{i:0;s:14:\"ept_micromodal\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:14:\"group_settings\";i:1;s:13:\"group_content\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:26:\"field_ept_micromodal_title\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:6:\"hidden\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ynF9PLVVYG00_7Br42jxgJ02cMPPwmtf3jssH3Gx9T8\";}s:2:\"id\";s:32:\"paragraph.ept_micromodal.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_micromodal_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:23:\"ept_settings_micromodal\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_quote.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"62a89609-5a89-4eb4-a5a2-c3c58c93480d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:54:\"field.field.paragraph.ept_quote.field_ept_quote_author\";i:1;s:53:\"field.field.paragraph.ept_quote.field_ept_quote_image\";i:2;s:50:\"field.field.paragraph.ept_quote.field_ept_settings\";i:3;s:46:\"field.field.paragraph.ept_quote.field_ept_text\";i:4;s:47:\"field.field.paragraph.ept_quote.field_ept_title\";i:5;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_quote\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:4:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:22:\"field_ept_quote_author\";i:3;s:21:\"field_ept_quote_image\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:1;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rMIoq7ATvLm5GYUegulzLGA67l1jIqNeN1Vma_Calus\";}s:2:\"id\";s:27:\"paragraph.ept_quote.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:22:\"field_ept_quote_author\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_quote_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_quote\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slick_slider.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"6b2455af-c7c1-4faf-ae2f-5faf8b33c82d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_slick_slider.field_ept_settings\";i:1;s:61:\"field.field.paragraph.ept_slick_slider.field_ept_slick_slider\";i:2;s:53:\"field.field.paragraph.ept_slick_slider.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_slick_slider.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:4:{i:0;s:16:\"ept_slick_slider\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:22:\"field_ept_slick_slider\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hDbTWzuXu3VZtJk1OkYoVRSHUWjZQRwzNKl8MSfnHZo\";}s:2:\"id\";s:34:\"paragraph.ept_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:25:\"ept_settings_slick_slider\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ept_slick_slider\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slick_slider_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"0e9a2579-f110-4139-81b2-dc1025db5053\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:72:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";i:1;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";i:2;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";i:3;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CjC8L66tFduxz7PpSEZ_n5Vewr_T4E3BXo6iZw5cPjs\";}s:2:\"id\";s:39:\"paragraph.ept_slick_slider_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ept_slick_slider_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_slick_slider_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_slick_slider_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slideshow.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"1003a694-14ea-404d-bf58-34d4ad51a83c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:54:\"field.field.paragraph.ept_slideshow.field_ept_settings\";i:1;s:55:\"field.field.paragraph.ept_slideshow.field_ept_slideshow\";i:2;s:50:\"field.field.paragraph.ept_slideshow.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_slideshow.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:4:{i:0;s:13:\"ept_slideshow\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:19:\"field_ept_slideshow\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tILUBTEfzAAfH3RNpAfKLafcB4BQ1rEs4TXsefzXpz8\";}s:2:\"id\";s:31:\"paragraph.ept_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:22:\"ept_settings_slideshow\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_slideshow\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slideshow_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"483f7e15-2bcb-4ed9-952b-548c4960e622\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link\";i:1;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide\";i:2;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text\";i:3;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title\";i:4;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wXdtnml8iEI3B2hPt_jBFMcr9wunJPj97vsPtPVoSlI\";}s:2:\"id\";s:36:\"paragraph.ept_slideshow_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_slideshow_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_slideshow_slide\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ept_slideshow_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_slideshow_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_stats.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"a9e1d9c8-64cb-4c33-ae6e-7c4617fa82d4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_stats.field_ept_settings\";i:1;s:47:\"field.field.paragraph.ept_stats.field_ept_stats\";i:2;s:46:\"field.field.paragraph.ept_stats.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_stats.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_stats\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:15:\"field_ept_stats\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iULioKDpET9pDqjdWoX6RbIYNdzK6nuBHJbWBY8s8hw\";}s:2:\"id\";s:27:\"paragraph.ept_stats.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_stats\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_stats\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_stats_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"11f77720-51d3-4dc6-b653-b86d5771046b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_image\";i:1;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_link\";i:2;s:64:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_number\";i:3;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wF_mUJwfQr8bsVI-d3u1R2W8PUu9gazphbDkBAY2SEk\";}s:2:\"id\";s:32:\"paragraph.ept_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_stats_item_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_stats_item_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_stats_item_number\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_stats_item_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tabs.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"e1a6c8e5-95b1-4c04-8b08-798a42e3f990\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:49:\"field.field.paragraph.ept_tabs.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_tabs.field_ept_tabs\";i:2;s:45:\"field.field.paragraph.ept_tabs.field_ept_text\";i:3;s:46:\"field.field.paragraph.ept_tabs.field_ept_title\";i:4;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:4:{i:0;s:8:\"ept_tabs\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:14:\"field_ept_tabs\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qwxwo_7tJPCVoTpGT3EGZT8rcmOT-hnPcBxVGLjPG78\";}s:2:\"id\";s:26:\"paragraph.ept_tabs.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:17:\"ept_settings_tabs\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_tabs\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tabs_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2ba6d267-9074-4e3c-a4c5-e392e2e1b8ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_block\";i:1;s:57:\"field.field.paragraph.ept_tabs_item.field_ept_tab_content\";i:2;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_page\";i:3;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_text\";i:4;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_title\";i:5;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_views\";i:6;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oVvZoAPE_jk4D2dNYM8_LohZLLeaIQBnleftotvYd7o\";}s:2:\"id\";s:31:\"paragraph.ept_tabs_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:19:\"field_ept_tab_block\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_tab_content\";a:5:{s:4:\"type\";s:14:\"options_select\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_tab_page\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_tab_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_tab_title\";a:5:{s:4:\"type\";s:14:\"text_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_tab_views\";a:5:{s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_text.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"0a168361-abfe-403a-8922-8305dbbef7af\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:49:\"field.field.paragraph.ept_text.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_text.field_ept_text\";i:2;s:46:\"field.field.paragraph.ept_text.field_ept_title\";i:3;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:6:\"hidden\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"shyYm2rY3OjdKeiRCtoWJpvauXuaTQJb8xb0cyNYRM8\";}s:2:\"id\";s:26:\"paragraph.ept_text.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:21;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:23;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:22;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tiles.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"a5784c00-a16b-4f3b-91dd-568be1356d3a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_tiles.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_tiles.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_tiles.field_ept_tiles\";i:3;s:47:\"field.field.paragraph.ept_tiles.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_tiles\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:15:\"field_ept_tiles\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:11;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:12;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Fub48PSonCbwVzLnLvqqeYQk1wGzEf65HefNdP-qQaQ\";}s:2:\"id\";s:27:\"paragraph.ept_tiles.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_tiles\";s:6:\"weight\";i:11;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_tiles\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tiles_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"45b2e5a1-2031-4177-b3c2-580549849e46\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ept_tiles_item.field_ept_clickable_tile\";i:1;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_image\";i:2;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_link\";i:3;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_text\";i:4;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U9PXobBv4clQdnuyNB31xyZFAqJ5NgK_WHOSbnw6g98\";}s:2:\"id\";s:32:\"paragraph.ept_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ept_clickable_tile\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_tiles_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_tiles_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_tiles_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_tiles_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_video.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"fe1a956f-1eb5-49f4-8ccd-d852faeeea9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_video.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_video.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_video.field_ept_title\";i:3;s:47:\"field.field.paragraph.ept_video.field_ept_video\";i:4;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_video\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:15:\"field_ept_video\";i:2;s:14:\"field_ept_text\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uWfzDvi2652DPEZs_2EApToxb-ZwFGKVzEDZ3Jd27xU\";}s:2:\"id\";s:27:\"paragraph.ept_video.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_video\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_video\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_video_and_image_gallery.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"2a6ec3c5-051d-451f-bfa5-ae16ca4d9cc1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_settings\";i:1;s:64:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_text\";i:2;s:65:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_title\";i:3;s:77:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";i:4;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:4:{i:0;s:27:\"ept_video_and_image_gallery\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:27:\"field_ept_videos_and_images\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rOQ-MHiLNktgV1oHnzDodKFBNZKJGnpQ_jcoXGPWl3s\";}s:2:\"id\";s:45:\"paragraph.ept_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:36:\"ept_settings_video_and_image_gallery\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_videos_and_images\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_video_and_image_gallery_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"5a1fd1b5-9098-41dc-99e7-65246d6fe6da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:77:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";i:1;s:82:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";i:2;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-EpWxbfVxkolF4xO3v_gR4i7gLA_X1pxspQ3sm0jgQY\";}s:2:\"id\";s:50:\"paragraph.ept_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:22:\"field_ept_gallery_item\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_gallery_item_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_views.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"5f9fd1ed-53a9-4349-8202-c90230a11f12\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_views.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_views.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_views.field_ept_title\";i:3;s:52:\"field.field.paragraph.ept_views.field_ept_views_view\";i:4;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:4:{i:0;s:8:\"ept_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";i:3;s:14:\"viewsreference\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:20:\"field_ept_views_view\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_i5XjlBN7MBo2rHWjbgIick135me8C2QqOcKTkr7Sx0\";}s:2:\"id\";s:27:\"paragraph.ept_views.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_views_view\";a:5:{s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.user.user.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8eb5837f-793f-476b-8d5b-8eb1ea190520\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FaQ9Ptcpxpg30AtiqRDtl_8zbJArHP1LPfug_s59TOA\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"account\";a:2:{s:6:\"weight\";i:-10;s:6:\"region\";s:7:\"content\";}s:7:\"contact\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:8:\"language\";a:2:{s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:8:\"timezone\";a:2:{s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_mode.media.media_library',_binary 'a:10:{s:4:\"uuid\";s:36:\"94fd7791-9806-4755-a50f-91d35400a4cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_form_mode.user.register',_binary 'a:10:{s:4:\"uuid\";s:36:\"ef62034d-b624-4a32-9e4a-54a2baf7fa78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5pE_4hurqtIlZN3XDi7eTo5RG13BMG0Rh9HYlRI3h8U\";}s:2:\"id\";s:13:\"user.register\";s:5:\"label\";s:8:\"Register\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_display.block_content.basic.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"53a48e63-4272-4544-9051-7617915e3d41\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBNNDTFwakREOTa6GGMqN899Iyrii0hInwSJtQ7Kj30\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.comment.comment.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"da002566-b092-4563-9d08-c4b5c52593e5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:40:\"field.field.comment.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aBQUGsQ46M4048fIlFuTXwl2zV0j2cJX89CTUobh9hA\";}s:2:\"id\";s:23:\"comment.comment.default\";s:16:\"targetEntityType\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:12:\"comment_body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.media.audio.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"87bcc8b2-7f6c-4c74-800a-a87d1b94f5f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AS765MdDfNpK6K5eE7WVnBvpynClz_havy1R3bO3gVo\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_audio_file\";a:6:{s:4:\"type\";s:10:\"file_audio\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:4:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.audio.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"fd3c8ee0-7347-4825-a6ac-e712dc98946b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tcAUW1Xzq5Tjw5jomR6XKGSgfiXO7QiRAHJBF-n0akg\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.document.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"af3b0da5-5654-474f-b056-1b7fe53c1991\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XxUyhaTuM0OUUZpr8G6jdrFBEh5eag7auWxBKhm6cvY\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:20:\"field_media_document\";a:6:{s:4:\"type\";s:12:\"file_default\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.document.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"3027dd27-1f17-44e8-84f5-7366b5d87788\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:21:\"image.style.thumbnail\";i:3;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YcWqjhIlo-2RZUM5ogvRsrKB7M3voF2XB3lVLwgOlLU\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"19dfadc9-d9a4-4d4c-9953-240f406fe79c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:17:\"image.style.large\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"73xaTNkI5J6sfFcBmNYeuk070X3mQS_iwwWaPYyfG2M\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:5:\"large\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.ept_image_gallery',_binary 'a:11:{s:4:\"uuid\";s:36:\"4f8ec3e2-1797-492f-8b2d-8ce7545d59bc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:45:\"core.entity_view_mode.media.ept_image_gallery\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:29:\"image.style.ept_gallery_image\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n90nNuXho9mrkYYsIQ1XTO6AvAhpgl2KtPDCGCOnGhM\";}s:2:\"id\";s:29:\"media.image.ept_image_gallery\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:17:\"ept_image_gallery\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:17:\"ept_gallery_image\";s:26:\"glightbox_node_style_first\";s:0:\"\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:6:\"parent\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.ept_video_and_image_gallery_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"c47a77e8-55b1-49a2-adeb-dc69b79b24e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:60:\"core.entity_view_mode.media.ept_video_and_image_gallery_item\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:39:\"image.style.ept_video_and_image_gallery\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rH_qHt_lYqhJQjixn1J6qIQ6Nll3micOpoBEVEtJ4CA\";}s:2:\"id\";s:44:\"media.image.ept_video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:32:\"ept_video_and_image_gallery_item\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:27:\"ept_video_and_image_gallery\";s:26:\"glightbox_node_style_first\";s:0:\"\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"1053ac57-9af0-4e5b-ba2f-c5695c62ef08\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:18:\"image.style.medium\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ILLWu5KFvbsX6J7sh2Itd4w8-lBBRhR_H8ZrmQiN2yo\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:17:\"field_media_image\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"9ecc7509-3522-45c5-bda4-7ed77885a161\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZdPcl2hPxl5pgv3pI-07R7h51OjeUeKJTy-ab1NfM34\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:6:\"oembed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:9:\"max_width\";i:0;s:10:\"max_height\";i:0;s:7:\"loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.ept_video',_binary 'a:11:{s:4:\"uuid\";s:36:\"51e43f2e-4f69-45a1-95c7-5ecf07778894\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:37:\"core.entity_view_mode.media.ept_video\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1KlyRkRbqUbxJgk8eo1S40_quArKzT_wKaIMWWlaSoU\";}s:2:\"id\";s:28:\"media.remote_video.ept_video\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:9:\"ept_video\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:4:\"post\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.ept_video_and_image_gallery_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"72019611-98d6-4f86-81ec-768c71520e64\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:60:\"core.entity_view_mode.media.ept_video_and_image_gallery_item\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3xEp_ZELSvrqfzLRi2XtfPP7KVrHNdRe-XdyCYK3Jc8\";}s:2:\"id\";s:51:\"media.remote_video.ept_video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:32:\"ept_video_and_image_gallery_item\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:27:\"ept_video_and_image_gallery\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"b0bc3306-d88a-4581-af6c-2a1f29aac6ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:18:\"image.style.medium\";i:3;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PGGoP-hVkXe_S-GiJRAub4PHDu0KhMExylclrqjdJb4\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"63fe648a-c5c1-42b9-8b04-7bb9db119166\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SxvbuGh-6cQMxl9bBV27-hGI46u7ZvwlMm5ObaJMNnw\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_video_file\";a:6:{s:4:\"type\";s:10:\"file_video\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";s:5:\"muted\";b:0;s:5:\"width\";i:640;s:6:\"height\";i:480;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"5672ce5e-9fb4-4800-8c9d-3b15ca3f7fde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_fnkUKwQYHkXO1Ngmq9nE6FqWUNAmkddOxAH1h5aiKg\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.node.article.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"0f767bd2-1919-4166-8346-62c5fc895c81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:35:\"field.field.node.article.field_tags\";i:3;s:16:\"image.style.wide\";i:4;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"text\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"br6izr-iGEu--JvNbCJNtOBpRnxpFLXfoV5y61U9Nqc\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:4:\"wide\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.node.article.rss',_binary 'a:11:{s:4:\"uuid\";s:36:\"bad692de-34e5-483c-9717-c610a77e5be5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2rIr6K5Q0UQ9khg0zE_CK-PtJH76UL-BDDZcZnZzwCc\";}s:2:\"id\";s:16:\"node.article.rss\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:3:\"rss\";s:7:\"content\";a:1:{s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:3:{s:4:\"body\";b:1;s:11:\"field_image\";b:1;s:10:\"field_tags\";b:1;}}'),('','core.entity_view_display.node.article.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"b696c09e-d916-4b49-a1c2-566c781bf923\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:18:\"image.style.medium\";i:5;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"text\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"O8PxzfG8DOHHRu6M23kwR6TDPq_MNfYQ10Mp367ICUQ\";}s:2:\"id\";s:19:\"node.article.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:7:\"content\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.node.page.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"bc183acd-cdee-4366-86c4-4db46beceef3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:26:\"field.field.node.page.body\";i:1;s:38:\"field.field.node.page.field_components\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Y8L5tfmhx7DR143E05YyZSpvgil6VFvqcfBWykalg\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:16:\"field_components\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:4:\"body\";b:1;}}'),('','core.entity_view_display.node.page.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"b64bcaef-5bd0-446f-a6d5-7096df12851d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:26:\"field.field.node.page.body\";i:2;s:38:\"field.field.node.page.field_components\";i:3;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:4:\"text\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8BgdRtLbtQ0F__o0FHSH0Mx5fvXOra9tfT1GmNKbRYw\";}s:2:\"id\";s:16:\"node.page.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:16:\"field_components\";b:1;}}'),('','core.entity_view_display.paragraph.ept_accordion.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f60b271e-f09b-45a9-8e92-1ae341b267f5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:55:\"field.field.paragraph.ept_accordion.field_ept_accordion\";i:1;s:54:\"field.field.paragraph.ept_accordion.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_accordion.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_accordion.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PJi5yKQ_AuFiKp81hRO_aQKSuuwBJkStIGM6f0wBBX8\";}s:2:\"id\";s:31:\"paragraph.ept_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:19:\"field_ept_accordion\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_accordion_section.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"d4e6aedc-c8f3-451b-94d6-cd44fc4b6c11\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:68:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_text\";i:1;s:69:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_title\";i:2;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UjA4zXZ3oMZFxRvkNrsM94SAiqKznnxAtCPUVIC6MT0\";}s:2:\"id\";s:39:\"paragraph.ept_accordion_section.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ept_accordion_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_accordion_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_basic_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f4454fef-a659-4b88-9579-11ba22f32177\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:66:\"field.field.paragraph.ept_basic_button.field_ept_basic_button_link\";i:1;s:57:\"field.field.paragraph.ept_basic_button.field_ept_settings\";i:2;s:53:\"field.field.paragraph.ept_basic_button.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_basic_button.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4gJX4ZzysdJ_kzlqlJAB2uqXRXQJi3VjikD1N3iepgA\";}s:2:\"id\";s:34:\"paragraph.ept_basic_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:27:\"field_ept_basic_button_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_block.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"e7417c73-82e0-49a6-b66c-942b3596d612\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_block.field_ept_block_block\";i:1;s:50:\"field.field.paragraph.ept_block.field_ept_settings\";i:2;s:46:\"field.field.paragraph.ept_block.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_block.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BFcfVmJHF2899wHjHN2VFWpiUyRAjvacvce9Cfs79BY\";}s:2:\"id\";s:27:\"paragraph.ept_block.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:21:\"field_ept_block_block\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_bootstrap_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a806c6af-6b6a-4398-a270-06147cb09d21\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:74:\"field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";i:1;s:61:\"field.field.paragraph.ept_bootstrap_button.field_ept_settings\";i:2;s:57:\"field.field.paragraph.ept_bootstrap_button.field_ept_text\";i:3;s:58:\"field.field.paragraph.ept_bootstrap_button.field_ept_title\";i:4;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1s6HjRSAsva6N8IAwlMIIoLxlmMtVw7ygPp4U_Z7_1I\";}s:2:\"id\";s:38:\"paragraph.ept_bootstrap_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:31:\"field_ept_bootstrap_button_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_carousel.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a34b4adb-f67d-4569-90a5-e74b6a28bcdb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_carousel.field_ept_carousel\";i:1;s:53:\"field.field.paragraph.ept_carousel.field_ept_settings\";i:2;s:49:\"field.field.paragraph.ept_carousel.field_ept_text\";i:3;s:50:\"field.field.paragraph.ept_carousel.field_ept_title\";i:4;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hW53xnntQ786Y9Dng5tbHj61F_Xq405ejwkoK9cGxUg\";}s:2:\"id\";s:30:\"paragraph.ept_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_carousel\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_carousel_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"95f5dba7-e075-42d7-bb71-a987d5625124\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";i:1;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";i:2;s:18:\"image.style.medium\";i:3;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kypuOk2yxicxTkEhw3Xo0FLPQXZVoNvTgwtmyMtUUKk\";}s:2:\"id\";s:35:\"paragraph.ept_carousel_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ept_carousel_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_carousel_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_carousel_item.slider',_binary 'a:11:{s:4:\"uuid\";s:36:\"fa961609-f5ef-403a-8089-73f33b1e73f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:38:\"core.entity_view_mode.paragraph.slider\";i:1;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";i:2;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";i:3;s:18:\"image.style.medium\";i:4;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kypuOk2yxicxTkEhw3Xo0FLPQXZVoNvTgwtmyMtUUKk\";}s:2:\"id\";s:34:\"paragraph.ept_carousel_item.slider\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:4:\"mode\";s:6:\"slider\";s:7:\"content\";a:2:{s:26:\"field_ept_carousel_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_carousel_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_columns.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"83448cb5-91c5-4a34-a576-3ea914fa7d6b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:51:\"field.field.paragraph.ept_columns.field_ept_columns\";i:1;s:52:\"field.field.paragraph.ept_columns.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_columns.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_columns.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vOC7NP0p0aXc-869ZBnA91HhUz6DjvKa3lJQB7amMmo\";}s:2:\"id\";s:29:\"paragraph.ept_columns.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:17:\"field_ept_columns\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_countdown.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"08b2118c-18b9-4669-b9e4-0786d49af6ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ept_countdown.field_ept_countdown_date\";i:1;s:54:\"field.field.paragraph.ept_countdown.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_countdown.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_countdown.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:3:{i:0;s:8:\"datetime\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0tZvxTE9_SxYclV0-qXTYzgXSfZoC1elFCKHb9scTG4\";}s:2:\"id\";s:31:\"paragraph.ept_countdown.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_countdown_date\";a:6:{s:4:\"type\";s:16:\"datetime_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:17:\"timezone_override\";s:0:\"\";s:11:\"format_type\";s:6:\"medium\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_counter.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"ad408e08-db1a-47df-8098-0b2a61f16481\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_counter.field_ept_counter_items\";i:1;s:52:\"field.field.paragraph.ept_counter.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_counter.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_counter.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eZqA1TwH5tWY55LrWFHFJQ_5F6K3z2LZAXPoKY6znBw\";}s:2:\"id\";s:29:\"paragraph.ept_counter.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_counter_items\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_counter_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"077ee820-2041-4778-8135-0fc65cd20cb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_counter_item.field_ept_counter_description\";i:1;s:61:\"field.field.paragraph.ept_counter_item.field_ept_counter_icon\";i:2;s:63:\"field.field.paragraph.ept_counter_item.field_ept_counter_number\";i:3;s:62:\"field.field.paragraph.ept_counter_item.field_ept_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P7The1phmhJ8Ls_nSR64aLtEXudYALjs5Zzdf10AFuA\";}s:2:\"id\";s:34:\"paragraph.ept_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ept_counter_description\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:22:\"field_ept_counter_icon\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_counter_number\";a:6:{s:4:\"type\";s:14:\"number_integer\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:23:\"field_ept_counter_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_cta.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"4bf53171-20df-4e38-bb87-a451cfc4aa6c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:56:\"field.field.paragraph.ept_cta.field_ept_cta_column_image\";i:1;s:48:\"field.field.paragraph.ept_cta.field_ept_cta_link\";i:2;s:55:\"field.field.paragraph.ept_cta.field_ept_cta_second_link\";i:3;s:48:\"field.field.paragraph.ept_cta.field_ept_settings\";i:4;s:44:\"field.field.paragraph.ept_cta.field_ept_text\";i:5;s:45:\"field.field.paragraph.ept_cta.field_ept_title\";i:6;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LbUDjHCE5jPK-SF4gEbg6BwzdKjd1y4Wm5lHH77LQHE\";}s:2:\"id\";s:25:\"paragraph.ept_cta.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:26:\"field_ept_cta_column_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_cta_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_cta_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_hero.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2727e08a-658f-4ab5-b47b-287082974eca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_column_image\";i:1;s:50:\"field.field.paragraph.ept_hero.field_ept_hero_link\";i:2;s:57:\"field.field.paragraph.ept_hero.field_ept_hero_second_link\";i:3;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_title_prefix\";i:4;s:49:\"field.field.paragraph.ept_hero.field_ept_settings\";i:5;s:45:\"field.field.paragraph.ept_hero.field_ept_text\";i:6;s:46:\"field.field.paragraph.ept_hero.field_ept_title\";i:7;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RyJFBZtpPZyel78RpfsF1AiH8hwBQOOxLrAmCsQUA3E\";}s:2:\"id\";s:26:\"paragraph.ept_hero.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:27:\"field_ept_hero_column_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_hero_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:26:\"field_ept_hero_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_hero_title_prefix\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_image.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a5054ddd-1cf1-49bf-bb8f-790f40e08130\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:47:\"field.field.paragraph.ept_image.field_ept_image\";i:1;s:55:\"field.field.paragraph.ept_image.field_ept_image_caption\";i:2;s:52:\"field.field.paragraph.ept_image.field_ept_image_link\";i:3;s:50:\"field.field.paragraph.ept_image.field_ept_settings\";i:4;s:46:\"field.field.paragraph.ept_image.field_ept_text\";i:5;s:47:\"field.field.paragraph.ept_image.field_ept_title\";i:6;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:4:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:5:\"media\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DTOYjl8a1qPkDZ2tUSk7QmiHQ0xgbKAbv7qw0jY4LTE\";}s:2:\"id\";s:27:\"paragraph.ept_image.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:15:\"field_ept_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:23:\"field_ept_image_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_image_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_image_gallery.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"49052cac-09f9-471f-8cc0-d9c144baf2ff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_image_gallery.field_ept_image_gallery\";i:1;s:58:\"field.field.paragraph.ept_image_gallery.field_ept_settings\";i:2;s:54:\"field.field.paragraph.ept_image_gallery.field_ept_text\";i:3;s:55:\"field.field.paragraph.ept_image_gallery.field_ept_title\";i:4;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"baNfcT8hwfXqGdk9GFr_Uo5DAZw65OmnpJIPGu7rwLU\";}s:2:\"id\";s:35:\"paragraph.ept_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_image_gallery\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:17:\"ept_image_gallery\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_micromodal.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2b90284a-5b66-4a1f-8feb-f7da7fba402f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_micromodal.field_ept_micromodal_title\";i:1;s:55:\"field.field.paragraph.ept_micromodal.field_ept_settings\";i:2;s:51:\"field.field.paragraph.ept_micromodal.field_ept_text\";i:3;s:52:\"field.field.paragraph.ept_micromodal.field_ept_title\";i:4;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3RH7OegTiWFWXapSfExaq4iTqsXp0J-FoDgKn3BLvug\";}s:2:\"id\";s:32:\"paragraph.ept_micromodal.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_micromodal_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_quote.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"772993d5-eed2-4b18-a6f6-28eb39e116b4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:54:\"field.field.paragraph.ept_quote.field_ept_quote_author\";i:1;s:53:\"field.field.paragraph.ept_quote.field_ept_quote_image\";i:2;s:50:\"field.field.paragraph.ept_quote.field_ept_settings\";i:3;s:46:\"field.field.paragraph.ept_quote.field_ept_text\";i:4;s:47:\"field.field.paragraph.ept_quote.field_ept_title\";i:5;s:27:\"image.style.ept_quote_image\";i:6;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Ng1DAFgz9gNcE0pRgTjrcZTjwRmCqpVhuWZM-gi-D3o\";}s:2:\"id\";s:27:\"paragraph.ept_quote.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:22:\"field_ept_quote_author\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:21:\"field_ept_quote_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:15:\"ept_quote_image\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slick_slider.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"febc7649-4ada-4466-aea7-1872bc394145\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_slick_slider.field_ept_settings\";i:1;s:61:\"field.field.paragraph.ept_slick_slider.field_ept_slick_slider\";i:2;s:53:\"field.field.paragraph.ept_slick_slider.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_slick_slider.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"D6f-Fc2NAzWU9GdDBRkUKUZ-OufpE3B1nGAAJQhgO04\";}s:2:\"id\";s:34:\"paragraph.ept_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:22:\"field_ept_slick_slider\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slick_slider_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"e906e660-3e2c-436c-9fb5-1dc3aaa2d1a9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:72:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";i:1;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";i:2;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";i:3;s:33:\"image.style.ept_slick_slider_card\";i:4;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Yb25ejThf9Zw1K_1U4jgPEu6CXiu0AbCJlD9g9Lcjm0\";}s:2:\"id\";s:39:\"paragraph.ept_slick_slider_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ept_slick_slider_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:21:\"ept_slick_slider_card\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_slick_slider_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_slick_slider_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slideshow.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"113fc4a1-1a78-4da6-b222-3a4cd08a0def\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:54:\"field.field.paragraph.ept_slideshow.field_ept_settings\";i:1;s:55:\"field.field.paragraph.ept_slideshow.field_ept_slideshow\";i:2;s:50:\"field.field.paragraph.ept_slideshow.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_slideshow.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KtOxRXjaqWh0JTHfCOLP6aQSiruy6TgLL8zYom1n_L4\";}s:2:\"id\";s:31:\"paragraph.ept_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_slideshow\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slideshow_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"c452f408-f85b-4944-a31e-1bbef7fcda71\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link\";i:1;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide\";i:2;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text\";i:3;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title\";i:4;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zuevQDEEiEAdPhigrWbhLZc3nvEGuKwsXeWbIT6VtyM\";}s:2:\"id\";s:36:\"paragraph.ept_slideshow_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_slideshow_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_slideshow_slide\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_slideshow_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_slideshow_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_stats.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"ec282fce-d81d-4383-9a77-3fb87be08553\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_stats.field_ept_settings\";i:1;s:47:\"field.field.paragraph.ept_stats.field_ept_stats\";i:2;s:46:\"field.field.paragraph.ept_stats.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_stats.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-R8qIR4yTFENexKPFy8GHPre8URllz01mM6cb0sIz_0\";}s:2:\"id\";s:27:\"paragraph.ept_stats.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_stats\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_stats_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8e1a5df7-4ec6-40ba-b5be-4d5d2b6f489f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_image\";i:1;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_link\";i:2;s:64:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_number\";i:3;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vJgoosAvhgFcK-LHabcOoXx3QTmG9TF7iqpHAxeUkkc\";}s:2:\"id\";s:32:\"paragraph.ept_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_stats_item_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_stats_item_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_stats_item_number\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_stats_item_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tabs.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"7da9a817-79f8-4bec-add7-e39bb0ba78c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:49:\"field.field.paragraph.ept_tabs.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_tabs.field_ept_tabs\";i:2;s:45:\"field.field.paragraph.ept_tabs.field_ept_text\";i:3;s:46:\"field.field.paragraph.ept_tabs.field_ept_title\";i:4;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VYYeF4flc_QYohV2FJfKsdYisMArL-b2-hY7et7ry_M\";}s:2:\"id\";s:26:\"paragraph.ept_tabs.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_tabs\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tabs_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"b90a3de2-2933-49e5-8726-03f0e73085fa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_block\";i:1;s:57:\"field.field.paragraph.ept_tabs_item.field_ept_tab_content\";i:2;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_page\";i:3;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_text\";i:4;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_title\";i:5;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_views\";i:6;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vm2AN2TrjyhMIpH3DLfldicz1qb1mSF0ykCyMxw9bmE\";}s:2:\"id\";s:31:\"paragraph.ept_tabs_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:19:\"field_ept_tab_block\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_tab_page\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_tab_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_tab_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_tab_views\";a:6:{s:4:\"type\";s:24:\"viewsreference_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:1:{i:0;s:5:\"block\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:21:\"field_ept_tab_content\";b:1;}}'),('','core.entity_view_display.paragraph.ept_text.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"e06c8535-7973-44b5-8144-18baa167f488\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:49:\"field.field.paragraph.ept_text.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_text.field_ept_text\";i:2;s:46:\"field.field.paragraph.ept_text.field_ept_title\";i:3;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hzCv1OpNW04_O7sRxZPIlh1_rvwxOvMIGOWK43XgmKg\";}s:2:\"id\";s:26:\"paragraph.ept_text.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tiles.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"153a53c8-5121-4586-9a2d-42dbb61c9965\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_tiles.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_tiles.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_tiles.field_ept_tiles\";i:3;s:47:\"field.field.paragraph.ept_tiles.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VFAqZYQk4Jf5mJN7H6sw-zAemRX1LtPDXAfRw5U6hjM\";}s:2:\"id\";s:27:\"paragraph.ept_tiles.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_tiles\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tiles_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"1e04e293-6847-44fd-816b-d0cafeb9bfb1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ept_tiles_item.field_ept_clickable_tile\";i:1;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_image\";i:2;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_link\";i:3;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_text\";i:4;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sd_Fv-1q9ZOgwmZ0ePkn9oBIqVaWhe4K8YL6VyUVSfE\";}s:2:\"id\";s:32:\"paragraph.ept_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ept_clickable_tile\";a:6:{s:4:\"type\";s:7:\"boolean\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:6:\"format\";s:7:\"default\";s:19:\"format_custom_false\";s:0:\"\";s:18:\"format_custom_true\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:21:\"field_ept_tiles_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_tiles_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_tiles_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:21:\"field_ept_tiles_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"4c097cad-2585-405b-86e6-5effe6d6f443\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_video.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_video.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_video.field_ept_title\";i:3;s:47:\"field.field.paragraph.ept_video.field_ept_video\";i:4;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XvS78XJNKdR81VHVUzs1PUhNwNWlMocd77YwIDcgRH0\";}s:2:\"id\";s:27:\"paragraph.ept_video.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_video\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:9:\"ept_video\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_video_and_image_gallery.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"dfadbabc-626b-46a2-a063-3f65ad0c2b45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_settings\";i:1;s:64:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_text\";i:2;s:65:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_title\";i:3;s:77:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";i:4;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5dsKiTuP8c7klYOHnY_OBorbQ_YaHWXu4P_cKhDDKZE\";}s:2:\"id\";s:45:\"paragraph.ept_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_videos_and_images\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_video_and_image_gallery_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"273d4d81-bc41-43e6-bbfd-346c986e0c86\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:77:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";i:1;s:82:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";i:2;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PB75oeGkZ1ajIp-S4ceLC_lub5_nmn_WU0f_7wBeOag\";}s:2:\"id\";s:50:\"paragraph.ept_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:22:\"field_ept_gallery_item\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:32:\"ept_video_and_image_gallery_item\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_gallery_item_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_views.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"d0875a9d-cb50-4731-ac2a-fb25c1858dae\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_views.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_views.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_views.field_ept_title\";i:3;s:52:\"field.field.paragraph.ept_views.field_ept_views_view\";i:4;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HwJ8zDH-LTdrQbXrPD8P-vvx1n91p-8JocGN840XNUw\";}s:2:\"id\";s:27:\"paragraph.ept_views.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_views_view\";a:6:{s:4:\"type\";s:24:\"viewsreference_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:1:{i:0;s:5:\"block\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.user.user.compact',_binary 'a:11:{s:4:\"uuid\";s:36:\"fd378f17-2b7e-4025-89fa-c56cabc7bab2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:34:\"core.entity_view_mode.user.compact\";i:1;s:34:\"field.field.user.user.user_picture\";i:2;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"00zr_RBdTjPjBGITD3h4c1ESQZimjdVCcHGt1trLqIY\";}s:2:\"id\";s:17:\"user.user.compact\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"compact\";s:7:\"content\";a:1:{s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:10:\"member_for\";b:1;}}'),('','core.entity_view_display.user.user.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"afa0542b-6646-4a58-8063-b778fe6b3423\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mZLyuWM9CQx2ZJVqFGSbzgFnHzudVbHBYmdU256A5Wk\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:10:\"member_for\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_mode.block_content.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"3e515c12-bfb7-4a38-9360-e1bebd522e14\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q7yUUYeRLByl-MCGveKKF_KhAtNICLCMJuKWfugCvso\";}s:2:\"id\";s:18:\"block_content.full\";s:5:\"label\";s:4:\"Full\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.comment.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"aaef918d-7b8e-4ea0-822a-44703c28e61c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N4mUjXpPckUkVRY1PbKw4GGoL1i2ECU7PL3EreiKStk\";}s:2:\"id\";s:12:\"comment.full\";s:5:\"label\";s:12:\"Full comment\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:7:\"comment\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.ept_image_gallery',_binary 'a:10:{s:4:\"uuid\";s:36:\"c2742453-7e21-4da9-b647-07ef5aca9cf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hrWZ2by9y8V27Hv_3EBEgSBPp_2-kB9fizZj-DLVRcQ\";}s:2:\"id\";s:23:\"media.ept_image_gallery\";s:5:\"label\";s:17:\"EPT Image Gallery\";s:11:\"description\";N;s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.ept_video',_binary 'a:10:{s:4:\"uuid\";s:36:\"8ae8b19f-547b-42bd-9d8f-a88c05759d47\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0wiLx1gaRcymNOKRYsVEppFtOWUHrgVQsi6qUlIr_TM\";}s:2:\"id\";s:15:\"media.ept_video\";s:5:\"label\";s:9:\"EPT Video\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.ept_video_and_image_gallery_item',_binary 'a:10:{s:4:\"uuid\";s:36:\"56447995-bbf0-4a46-b361-7337f6962da6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QIGappKnnavEIRi1GzZ_dSeZaYoyiLSX-hOaXrOHbz8\";}s:2:\"id\";s:38:\"media.ept_video_and_image_gallery_item\";s:5:\"label\";s:32:\"EPT Video and Image gallery item\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"976815c3-f2f0-4a48-82b3-fb4ee2924c88\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dTfAUHooYV0uOVPO3saGpgv-c5PppJXDwxvwRTJOycM\";}s:2:\"id\";s:10:\"media.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.media_library',_binary 'a:10:{s:4:\"uuid\";s:36:\"4578cd26-ab79-41fc-b999-3224d7b96b78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"3096aebe-dabe-4849-b718-4be67ed1e0a2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QJ2aZ1xfVf59aq6Pz5X7fyUOa2HxuCoTwQ_RQjoulAU\";}s:2:\"id\";s:9:\"node.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.rss',_binary 'a:10:{s:4:\"uuid\";s:36:\"562fdf9e-431f-4436-87cc-5edcb21506bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l8fiAFE3Kng_6bhLlUDnVTkTDzXWxzYFrCWTrngVXEA\";}s:2:\"id\";s:8:\"node.rss\";s:5:\"label\";s:3:\"RSS\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.search_index',_binary 'a:10:{s:4:\"uuid\";s:36:\"edab19fa-a328-4f2e-a4a2-bce49808300d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r_A0T3aTqGDwLyvoH7wLps-0PM--RHlS8UsiJe_Ac64\";}s:2:\"id\";s:17:\"node.search_index\";s:5:\"label\";s:12:\"Search index\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.search_result',_binary 'a:10:{s:4:\"uuid\";s:36:\"ac6b99d6-0ed0-46ea-97e8-2b17a00adab0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d8wBEm7XvJ6H3S0IneDD9PfTBklPIH7GMpxElVemPf8\";}s:2:\"id\";s:18:\"node.search_result\";s:5:\"label\";s:32:\"Search result highlighting input\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.teaser',_binary 'a:10:{s:4:\"uuid\";s:36:\"5eb23a5d-001b-4f18-b772-c45ec412d4a1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KgGJDZFpMaz_8bTv6fN1bXS3Qi5LWmRJI9R53kEGsNQ\";}s:2:\"id\";s:11:\"node.teaser\";s:5:\"label\";s:6:\"Teaser\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.paragraph.preview',_binary 'a:10:{s:4:\"uuid\";s:36:\"298a8e9e-ea9f-462a-9e62-03ff202ebda4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"h3BeHVei4Lnyqbkao3YiF4KqoY-DhRvUNfEgKG8Rgjg\";}s:2:\"id\";s:17:\"paragraph.preview\";s:5:\"label\";s:7:\"Preview\";s:11:\"description\";N;s:16:\"targetEntityType\";s:9:\"paragraph\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.paragraph.slider',_binary 'a:9:{s:4:\"uuid\";s:36:\"f0967983-7199-4bf7-8047-72fb6a840ca0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:2:\"id\";s:16:\"paragraph.slider\";s:5:\"label\";s:6:\"slider\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.taxonomy_term.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"c1d7c975-f7cc-4e65-a0b5-d7a0b84e6fed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iukUENpf8CFvjZbGGacKX_Ges0-lU9z6zvsd32P6kbo\";}s:2:\"id\";s:18:\"taxonomy_term.full\";s:5:\"label\";s:18:\"Taxonomy term page\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.compact',_binary 'a:10:{s:4:\"uuid\";s:36:\"3267d362-0cde-4190-8a4e-f368fdab39d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TtD7OuGskOsQfoGyxXkrdtllBpR37J19d5BMQDZWJgA\";}s:2:\"id\";s:12:\"user.compact\";s:5:\"label\";s:7:\"Compact\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"18890f85-c8b4-4c37-a805-81e116c96c33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZbXunWS_xAvMZXFfinyvClDAb_RCVLt7gAzE3v16E-Q\";}s:2:\"id\";s:9:\"user.full\";s:5:\"label\";s:12:\"User account\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.extension',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GIX5Esnc_umpXUBj4IIocRX7Mt5fPhm4AgXfE3E56E\";}s:6:\"module\";a:108:{s:13:\"admin_toolbar\";i:0;s:19:\"admin_toolbar_tools\";i:0;s:18:\"announcements_feed\";i:0;s:14:\"automated_cron\";i:0;s:22:\"better_exposed_filters\";i:0;s:8:\"big_pipe\";i:0;s:5:\"block\";i:0;s:13:\"block_content\";i:0;s:11:\"block_field\";i:0;s:10:\"breakpoint\";i:0;s:9:\"ckeditor5\";i:0;s:21:\"ckeditor5_plugin_pack\";i:0;s:32:\"ckeditor5_plugin_pack_auto_image\";i:0;s:38:\"ckeditor5_plugin_pack_find_and_replace\";i:0;s:26:\"ckeditor5_plugin_pack_font\";i:0;s:31:\"ckeditor5_plugin_pack_highlight\";i:0;s:34:\"ckeditor5_plugin_pack_indent_block\";i:0;s:37:\"ckeditor5_plugin_pack_link_attributes\";i:0;s:32:\"ckeditor5_plugin_pack_page_break\";i:0;s:32:\"ckeditor5_plugin_pack_select_all\";i:0;s:31:\"ckeditor5_plugin_pack_templates\";i:0;s:41:\"ckeditor5_plugin_pack_text_transformation\";i:0;s:40:\"ckeditor5_plugin_pack_todo_document_list\";i:0;s:37:\"ckeditor5_premium_features_fullscreen\";i:0;s:7:\"comment\";i:0;s:6:\"config\";i:0;s:7:\"contact\";i:0;s:10:\"contextual\";i:0;s:8:\"datetime\";i:0;s:5:\"dblog\";i:0;s:18:\"dynamic_page_cache\";i:0;s:6:\"editor\";i:0;s:26:\"entity_reference_revisions\";i:0;s:13:\"ept_accordion\";i:0;s:16:\"ept_basic_button\";i:0;s:9:\"ept_block\";i:0;s:20:\"ept_bootstrap_button\";i:0;s:12:\"ept_carousel\";i:0;s:11:\"ept_columns\";i:0;s:8:\"ept_core\";i:0;s:19:\"ept_core_starterkit\";i:0;s:13:\"ept_countdown\";i:0;s:11:\"ept_counter\";i:0;s:7:\"ept_cta\";i:0;s:8:\"ept_hero\";i:0;s:9:\"ept_image\";i:0;s:17:\"ept_image_gallery\";i:0;s:14:\"ept_micromodal\";i:0;s:9:\"ept_quote\";i:0;s:16:\"ept_slick_slider\";i:0;s:13:\"ept_slideshow\";i:0;s:9:\"ept_stats\";i:0;s:8:\"ept_tabs\";i:0;s:8:\"ept_text\";i:0;s:9:\"ept_tiles\";i:0;s:9:\"ept_video\";i:0;s:27:\"ept_video_and_image_gallery\";i:0;s:9:\"ept_views\";i:0;s:5:\"field\";i:0;s:11:\"field_group\";i:0;s:8:\"field_ui\";i:0;s:4:\"file\";i:0;s:8:\"file_mdm\";i:0;s:13:\"file_mdm_exif\";i:0;s:13:\"file_mdm_font\";i:0;s:6:\"filter\";i:0;s:11:\"gin_toolbar\";i:0;s:9:\"glightbox\";i:0;s:21:\"glightbox_media_video\";i:0;s:4:\"help\";i:0;s:7:\"history\";i:0;s:5:\"image\";i:0;s:13:\"image_effects\";i:0;s:9:\"jquery_ui\";i:0;s:19:\"jquery_ui_accordion\";i:0;s:14:\"jquery_ui_tabs\";i:0;s:16:\"layout_discovery\";i:0;s:17:\"layout_paragraphs\";i:0;s:4:\"link\";i:0;s:15:\"link_attributes\";i:0;s:33:\"link_attributes_menu_link_content\";i:0;s:5:\"media\";i:0;s:13:\"media_library\";i:0;s:18:\"media_library_edit\";i:0;s:26:\"media_library_form_element\";i:0;s:17:\"menu_link_content\";i:0;s:7:\"menu_ui\";i:0;s:4:\"node\";i:0;s:7:\"options\";i:0;s:10:\"page_cache\";i:0;s:4:\"path\";i:0;s:10:\"path_alias\";i:0;s:6:\"search\";i:0;s:8:\"shortcut\";i:0;s:6:\"system\";i:0;s:8:\"taxonomy\";i:0;s:11:\"tb_megamenu\";i:0;s:4:\"text\";i:0;s:7:\"toolbar\";i:0;s:10:\"twig_tweak\";i:0;s:6:\"update\";i:0;s:4:\"user\";i:0;s:8:\"views_ui\";i:0;s:17:\"views_year_filter\";i:0;s:14:\"viewsreference\";i:0;s:5:\"views\";i:10;s:10:\"paragraphs\";i:11;s:4:\"fast\";i:1000;}s:5:\"theme\";a:5:{s:7:\"olivero\";i:0;s:5:\"claro\";i:0;s:3:\"gin\";i:0;s:7:\"stable9\";i:0;s:9:\"ept_light\";i:0;}s:7:\"profile\";s:4:\"fast\";}'),('','core.menu.static_menu_link_overrides',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CXhei_vpaZk-3f_Mj2cH0YmpK-ZpKHoSzVA3yZrDq0g\";}s:11:\"definitions\";a:4:{s:18:\"contact__site_page\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:6:\"footer\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:6:\"weight\";i:-50;}s:20:\"standard__front_page\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:6:\"weight\";i:-50;}s:10:\"user__page\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:7:\"account\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:6:\"weight\";i:-10;}s:12:\"user__logout\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:7:\"account\";s:6:\"parent\";s:0:\"\";s:6:\"weight\";i:10;s:8:\"expanded\";b:0;}}}'),('','dblog.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e883aGsrt1wFrsydlYU584PZONCSfRy0DtkZ9KzHb58\";}s:9:\"row_limit\";i:1000;}'),('','editor.editor.basic_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"de26b70d-0b5e-4129-a929-f1de8a455f1b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"filter.format.basic_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qi2tIe-L97EutlMmhEvhsNxZOpOoA-RH82c4BQb5n4A\";}s:6:\"format\";s:10:\"basic_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:15:{i:0;s:4:\"bold\";i:1;s:6:\"italic\";i:2;s:1:\"|\";i:3;s:4:\"link\";i:4;s:1:\"|\";i:5;s:12:\"bulletedList\";i:6;s:12:\"numberedList\";i:7;s:1:\"|\";i:8;s:10:\"blockQuote\";i:9;s:17:\"drupalInsertImage\";i:10;s:1:\"|\";i:11;s:7:\"heading\";i:12;s:4:\"code\";i:13;s:1:\"|\";i:14;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:4:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:0;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:13:{i:0;s:6:\"<cite>\";i:1;s:4:\"<dl>\";i:2;s:4:\"<dt>\";i:3;s:4:\"<dd>\";i:4;s:12:\"<a hreflang>\";i:5;s:17:\"<blockquote cite>\";i:6;s:9:\"<ul type>\";i:7;s:9:\"<ol type>\";i:8;s:7:\"<h2 id>\";i:9;s:7:\"<h3 id>\";i:10;s:7:\"<h4 id>\";i:11;s:7:\"<h5 id>\";i:12;s:7:\"<h6 id>\";}}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),('','editor.editor.full_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"5b65cbab-6e9a-450e-a54e-4c334c4ca75d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"filter.format.full_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lurcn8yf33g3Dkzdc55cTfJa9salGp9ytSYyG1s7QMI\";}s:6:\"format\";s:9:\"full_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:44:{i:0;s:4:\"undo\";i:1;s:4:\"redo\";i:2;s:4:\"bold\";i:3;s:6:\"italic\";i:4;s:13:\"strikethrough\";i:5;s:9:\"underline\";i:6;s:11:\"superscript\";i:7;s:9:\"subscript\";i:8;s:12:\"removeFormat\";i:9;s:1:\"|\";i:10;s:4:\"link\";i:11;s:1:\"|\";i:12;s:5:\"style\";i:13;s:9:\"fontColor\";i:14;s:19:\"fontBackgroundColor\";i:15;s:9:\"highlight\";i:16;s:10:\"fontFamily\";i:17;s:8:\"fontSize\";i:18;s:1:\"-\";i:19;s:12:\"bulletedList\";i:20;s:12:\"numberedList\";i:21;s:6:\"indent\";i:22;s:7:\"outdent\";i:23;s:9:\"alignment\";i:24;s:1:\"|\";i:25;s:14:\"insertTemplate\";i:26;s:4:\"code\";i:27;s:10:\"blockQuote\";i:28;s:17:\"drupalInsertImage\";i:29;s:11:\"drupalMedia\";i:30;s:11:\"insertTable\";i:31;s:14:\"horizontalLine\";i:32;s:1:\"|\";i:33;s:7:\"heading\";i:34;s:14:\"findAndReplace\";i:35;s:1:\"-\";i:36;s:10:\"showBlocks\";i:37;s:17:\"specialCharacters\";i:38;s:9:\"codeBlock\";i:39;s:13:\"sourceEditing\";i:40;s:1:\"|\";i:41;s:9:\"pageBreak\";i:42;s:9:\"selectAll\";i:43;s:10:\"fullScreen\";}}s:7:\"plugins\";a:17:{s:19:\"ckeditor5_alignment\";a:1:{s:18:\"enabled_alignments\";a:4:{i:0;s:6:\"center\";i:1;s:7:\"justify\";i:2;s:4:\"left\";i:3;s:5:\"right\";}}s:19:\"ckeditor5_codeBlock\";a:1:{s:9:\"languages\";a:14:{i:0;a:2:{s:5:\"label\";s:10:\"Plain text\";s:8:\"language\";s:9:\"plaintext\";}i:1;a:2:{s:5:\"label\";s:1:\"C\";s:8:\"language\";s:1:\"c\";}i:2;a:2:{s:5:\"label\";s:2:\"C#\";s:8:\"language\";s:2:\"cs\";}i:3;a:2:{s:5:\"label\";s:3:\"C++\";s:8:\"language\";s:3:\"cpp\";}i:4;a:2:{s:5:\"label\";s:3:\"CSS\";s:8:\"language\";s:3:\"css\";}i:5;a:2:{s:5:\"label\";s:4:\"Diff\";s:8:\"language\";s:4:\"diff\";}i:6;a:2:{s:5:\"label\";s:4:\"HTML\";s:8:\"language\";s:4:\"html\";}i:7;a:2:{s:5:\"label\";s:4:\"Java\";s:8:\"language\";s:4:\"java\";}i:8;a:2:{s:5:\"label\";s:10:\"JavaScript\";s:8:\"language\";s:10:\"javascript\";}i:9;a:2:{s:5:\"label\";s:3:\"PHP\";s:8:\"language\";s:3:\"php\";}i:10;a:2:{s:5:\"label\";s:6:\"Python\";s:8:\"language\";s:6:\"python\";}i:11;a:2:{s:5:\"label\";s:4:\"Ruby\";s:8:\"language\";s:4:\"ruby\";}i:12;a:2:{s:5:\"label\";s:10:\"TypeScript\";s:8:\"language\";s:10:\"typescript\";}i:13;a:2:{s:5:\"label\";s:3:\"XML\";s:8:\"language\";s:3:\"xml\";}}}s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:6:{i:0;s:8:\"heading1\";i:1;s:8:\"heading2\";i:2;s:8:\"heading3\";i:3;s:8:\"heading4\";i:4;s:8:\"heading5\";i:5;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:44:\"ckeditor5_plugin_pack_auto_image__auto_image\";a:1:{s:7:\"enabled\";b:0;}s:56:\"ckeditor5_plugin_pack_find_and_replace__find_and_replace\";a:1:{s:7:\"ui_type\";s:6:\"dialog\";}s:38:\"ckeditor5_plugin_pack_font__font_color\";a:2:{s:6:\"colors\";a:0:{}s:18:\"use_default_colors\";b:1;}s:39:\"ckeditor5_plugin_pack_font__font_family\";a:1:{s:7:\"options\";s:0:\"\";}s:37:\"ckeditor5_plugin_pack_font__font_size\";a:1:{s:7:\"options\";s:0:\"\";}s:42:\"ckeditor5_plugin_pack_highlight__highlight\";a:2:{s:7:\"options\";a:0:{}s:19:\"use_default_markers\";b:1;}s:48:\"ckeditor5_plugin_pack_indent_block__indent_block\";a:1:{s:7:\"enabled\";b:1;}s:54:\"ckeditor5_plugin_pack_link_attributes__link_attributes\";a:1:{s:10:\"attributes\";a:1:{i:0;a:2:{s:5:\"label\";s:15:\"Link Attributes\";s:10:\"attributes\";s:27:\"target|_blank\r\nrel|nofollow\";}}}s:62:\"ckeditor5_plugin_pack_text_transformation__text_transformation\";a:4:{s:7:\"enabled\";b:1;s:21:\"extra_transformations\";s:0:\"\";s:27:\"extra_regex_transformations\";a:0:{}s:6:\"groups\";a:5:{s:10:\"typography\";a:2:{s:15:\"transformations\";a:3:{s:8:\"ellipsis\";a:1:{s:7:\"enabled\";i:1;}s:6:\"enDash\";a:1:{s:7:\"enabled\";i:1;}s:6:\"emDash\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:6:\"quotes\";a:2:{s:15:\"transformations\";a:2:{s:13:\"quotesPrimary\";a:1:{s:7:\"enabled\";i:1;}s:15:\"quotesSecondary\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:7:\"symbols\";a:2:{s:15:\"transformations\";a:3:{s:9:\"trademark\";a:1:{s:7:\"enabled\";i:1;}s:19:\"registeredTrademark\";a:1:{s:7:\"enabled\";i:1;}s:9:\"copyright\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:12:\"mathematical\";a:2:{s:15:\"transformations\";a:10:{s:7:\"oneHalf\";a:1:{s:7:\"enabled\";i:1;}s:8:\"oneThird\";a:1:{s:7:\"enabled\";i:1;}s:9:\"twoThirds\";a:1:{s:7:\"enabled\";i:1;}s:9:\"oneFourth\";a:1:{s:7:\"enabled\";i:1;}s:13:\"threeQuarters\";a:1:{s:7:\"enabled\";i:1;}s:15:\"lessThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:18:\"greaterThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:8:\"notEqual\";a:1:{s:7:\"enabled\";i:1;}s:9:\"arrowLeft\";a:1:{s:7:\"enabled\";i:1;}s:10:\"arrowRight\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:4:\"misc\";a:2:{s:15:\"transformations\";a:4:{s:17:\"quotesPrimaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:19:\"quotesSecondaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:15:\"quotesPrimaryPl\";a:1:{s:7:\"enabled\";i:0;}s:17:\"quotesSecondaryPl\";a:1:{s:7:\"enabled\";i:0;}}s:7:\"enabled\";i:0;}}}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}s:15:\"ckeditor5_style\";a:1:{s:6:\"styles\";a:2:{i:0;a:2:{s:5:\"label\";s:12:\"Title prefix\";s:7:\"element\";s:27:\"<span class=\"title-prefix\">\";}i:1;a:2:{s:5:\"label\";s:10:\"White text\";s:7:\"element\";s:25:\"<span class=\"white-text\">\";}}}s:11:\"media_media\";a:1:{s:24:\"allow_view_mode_override\";b:0;}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),('','ept_core.settings',_binary 'a:12:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYlqpNn_5W04WVeLB4bYW404IYbkVrx7N9zxzBAJ-Io\";}s:26:\"ept_core_mobile_breakpoint\";s:3:\"640\";s:26:\"ept_core_tablet_breakpoint\";s:4:\"1020\";s:27:\"ept_core_desktop_breakpoint\";s:4:\"1320\";s:22:\"ept_core_xxsmall_width\";s:3:\"480\";s:21:\"ept_core_xsmall_width\";s:3:\"640\";s:20:\"ept_core_small_width\";s:3:\"768\";s:22:\"ept_core_default_width\";s:3:\"960\";s:20:\"ept_core_large_width\";s:4:\"1100\";s:21:\"ept_core_xlarge_width\";s:4:\"1320\";s:22:\"ept_core_xxlarge_width\";s:4:\"1600\";s:25:\"ept_core_background_color\";s:7:\"#0d77b5\";}'),('','field.field.block_content.basic.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"8fecb003-ae49-44e1-ac0e-aeaebabeca06\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j00Gfs9AFqwK4x9RIsISLbPO7vA12psPR4s60wOIwQo\";}s:2:\"id\";s:24:\"block_content.basic.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.comment.comment.comment_body',_binary 'a:17:{s:4:\"uuid\";s:36:\"2ea8eb6b-de2b-4de9-ac7c-5703ce8bc44f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:34:\"field.storage.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"62rlTOx3sPVrYhBnSBHZStXwiO02v1UpHSMrhWDsuG8\";}s:2:\"id\";s:28:\"comment.comment.comment_body\";s:10:\"field_name\";s:12:\"comment_body\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:5:\"label\";s:7:\"Comment\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.media.audio.field_media_audio_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"cccc3ad2-8bd3-4a0b-8777-2510ebee041b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UlZPIbHcLyNqGY5bvydCTijGcKDmwn4Fo8oYZT85wlk\";}s:2:\"id\";s:34:\"media.audio.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:5:\"label\";s:10:\"Audio file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:11:\"mp3 wav aac\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),('','field.field.media.document.field_media_document',_binary 'a:17:{s:4:\"uuid\";s:36:\"90b23d65-43c8-4f09-8924-c0be432e4510\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:40:\"field.storage.media.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DY5HtJTxUjFRGU_PaY6ifo2nhR-nAZ0y0s6kLmUbv5g\";}s:2:\"id\";s:35:\"media.document.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:96:\"txt rtf doc docx ppt pptx xls xlsx pdf odf odg odp ods odt fodt fods fodp fodg key numbers pages\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),('','field.field.media.image.field_media_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"410f42b6-e143-4eb8-9c88-c13fd9c4c17f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:37:\"field.storage.media.field_media_image\";i:1;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P7CkVOgjDXiN26Fm2hniNei-XPK3iuZTlcBGqreTbJ0\";}s:2:\"id\";s:29:\"media.image.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.field.media.remote_video.field_media_oembed_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"4ed02114-671f-4880-bd68-143fe1b70c33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.media.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Eo4HHenV5iZat_kEWgr_wydD3TgwURMCzwt-7qIEyoM\";}s:2:\"id\";s:43:\"media.remote_video.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:5:\"label\";s:9:\"Video URL\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:6:\"string\";}'),('','field.field.media.video.field_media_video_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"0b1a6314-b982-4d68-89cc-0362ac441239\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6kMMjmk2r_csGQ52qI9BUaO8r_oAzNLbxlclaj-JlDQ\";}s:2:\"id\";s:34:\"media.video.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:5:\"label\";s:10:\"Video file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:3:\"mp4\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),('','field.field.node.article.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"ac9343a5-d157-4641-93f9-1b5bd7d0980f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4Wxs1LseZ8JsNwD9uJVIbzZqG35yQXN8Eo1Hub6NMuI\";}s:2:\"id\";s:17:\"node.article.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.article.field_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"6c45f2f3-d271-4c13-b678-675fb9cbc261\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"field.storage.node.field_image\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j0riO_-77ZFWNLtj0iJ31HnohiNjdn8HUL86RueCF-M\";}s:2:\"id\";s:24:\"node.article.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.field.node.article.field_tags',_binary 'a:17:{s:4:\"uuid\";s:36:\"d3dcae7f-9494-4866-b051-d4817b208fd5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:29:\"field.storage.node.field_tags\";i:1;s:17:\"node.type.article\";i:2;s:24:\"taxonomy.vocabulary.tags\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QdUgf_beeoaPiyKorFv0q1fcJpWH_uZTqe_xoVJacrw\";}s:2:\"id\";s:23:\"node.article.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Tags\";s:11:\"description\";s:84:\"Enter a comma-separated list. For example: Amsterdam, Mexico City, \"Cleveland, Ohio\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:21:\"default:taxonomy_term\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:1;}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.node.page.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"c7106e91-0b1d-44f0-82fc-584be35a29c2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KHu9I-pR4FnP79crRJ5gVD_1mKGSZcJsdIm9bn64iFg\";}s:2:\"id\";s:14:\"node.page.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.page.field_components',_binary 'a:16:{s:4:\"uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:2:\"id\";s:26:\"node.page.field_components\";s:10:\"field_name\";s:16:\"field_components\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:10:\"Components\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_accordion.field_ept_accordion',_binary 'a:17:{s:4:\"uuid\";s:36:\"a6969ae3-e3c4-4adf-b115-07a5a0172b95\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:43:\"field.storage.paragraph.field_ept_accordion\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:2;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gyYZiR8Di3nPWs-p1SHNRU9nboJcW5hom8i6mSecVtc\";}s:2:\"id\";s:43:\"paragraph.ept_accordion.field_ept_accordion\";s:10:\"field_name\";s:19:\"field_ept_accordion\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:8:\"Sections\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:21:\"ept_accordion_section\";s:21:\"ept_accordion_section\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:23;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_accordion.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"71eb6510-d311-4704-9d7a-147c6ba1fca0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dFTek-2-VjYGV96ffjrJqRnc7cP8oR-xd4f0hA8JlyA\";}s:2:\"id\";s:42:\"paragraph.ept_accordion.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_accordion.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"38a67ca0-85d7-4dee-8871-eef6909b89f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7ILR55bNJzar89h8OPnJx-IpC8TrZBRKYFxLOI1p73c\";}s:2:\"id\";s:38:\"paragraph.ept_accordion.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_accordion.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"fa75defe-e7d5-4782-bedf-3d3107b3a40f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-fStMIM_IiXT6N43R2XfdUDoqFS_sK8AUA-WvSHfcwo\";}s:2:\"id\";s:39:\"paragraph.ept_accordion.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_accordion_section.field_ept_accordion_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"3f86759a-0926-49a9-a1b3-ebe22666f4d8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_accordion_text\";i:1;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3d4EpzZAObqkHVq5leB4wQ_vhii4h9OoUdsxw0lZgfg\";}s:2:\"id\";s:56:\"paragraph.ept_accordion_section.field_ept_accordion_text\";s:10:\"field_name\";s:24:\"field_ept_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:5:\"label\";s:13:\"Text / Answer\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_accordion_section.field_ept_accordion_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"5fd2a01d-4924-4824-af89-5638dcb01e07\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_accordion_title\";i:1;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1GJAw9hJcCS1kRz9iAwG1qqyJ5XL97F--Irgw6Ns0GY\";}s:2:\"id\";s:57:\"paragraph.ept_accordion_section.field_ept_accordion_title\";s:10:\"field_name\";s:25:\"field_ept_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:5:\"label\";s:16:\"Title / Question\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_basic_button.field_ept_basic_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"d95cc73b-b5b3-45bb-ab62-c70e8411b8e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_basic_button_link\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SCjKiIWEbPAkzMucyajmerVFBDbaKtjD3HukL942flo\";}s:2:\"id\";s:54:\"paragraph.ept_basic_button.field_ept_basic_button_link\";s:10:\"field_name\";s:27:\"field_ept_basic_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:11:\"Button Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_basic_button.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"0369fd76-8a03-4f51-98c8-2662289d77b1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JzXRiuHUYaRtlmk8K0WT_Yp1_iUpogPj6XDbLmZ_hVA\";}s:2:\"id\";s:45:\"paragraph.ept_basic_button.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:18:\"Paragraph settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_basic_button.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"484e5ed3-f463-4d7b-b27a-25b553c3a82b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U4JGLZ-4C6DwE5xpnkLU2Ckqm-NdvOTgwe9gAMlW_Ls\";}s:2:\"id\";s:41:\"paragraph.ept_basic_button.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_basic_button.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"d5f47d43-c851-4f4d-a9bf-282937a2eb88\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q6Cswt1AxNHLXzTfwWiWRP4dJwyasulFfWasATFZdrU\";}s:2:\"id\";s:42:\"paragraph.ept_basic_button.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_block.field_ept_block_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"9e49c287-a8e3-4673-b781-6db3e163c7f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ept_block_block\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Y5C1tDwIza9l7G1NAqWPtZndTwsI1uclqq7mOTUqmyg\";}s:2:\"id\";s:41:\"paragraph.ept_block.field_ept_block_block\";s:10:\"field_name\";s:21:\"field_ept_block_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:5:\"Block\";s:11:\"description\";s:25:\"Add existing Drupal Block\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:10:\"categories\";s:18:\"selection_settings\";a:1:{s:10:\"categories\";a:11:{s:5:\"Block\";s:5:\"Block\";s:4:\"core\";s:4:\"core\";s:5:\"Forms\";s:5:\"Forms\";s:4:\"Help\";s:4:\"Help\";s:13:\"Lists (Views)\";s:13:\"Lists (Views)\";s:5:\"Menus\";s:5:\"Menus\";s:6:\"System\";s:6:\"System\";s:4:\"User\";s:4:\"User\";s:5:\"Views\";s:5:\"Views\";s:13:\"Announcements\";s:1:\"0\";s:12:\"TB Mega Menu\";s:1:\"0\";}}}s:10:\"field_type\";s:11:\"block_field\";}'),('','field.field.paragraph.ept_block.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"2d995ad8-7b72-4241-8c5b-bfb64c7a936a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o3fZQjNNObe_TkbgxMWmav7VePiJKizuqf7wQm1RqgQ\";}s:2:\"id\";s:38:\"paragraph.ept_block.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_block.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"440982f1-1d49-45ce-856f-cb3b95954c65\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AhoRfTUTx6zdLkKC-tHQ_pZVKgtpGN452BRXc__PSgM\";}s:2:\"id\";s:34:\"paragraph.ept_block.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_block.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"b40d62dd-ee5a-44cf-9983-6bbbd7667b68\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LoHBLk0u3sVMSi5c2wsK0PWLWQ1aM4uvkXBsu3odiYk\";}s:2:\"id\";s:35:\"paragraph.ept_block.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"28952958-350e-4fa8-b1bf-0526c52b982e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.storage.paragraph.field_ept_bootstrap_button_link\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-csuiRgrTiYqGIjfvXfzBJvGlaY5drE5fp2a_BZjuo\";}s:2:\"id\";s:62:\"paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ept_bootstrap_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"97adadda-941e-43f5-8c16-c2a84adbb6a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9H_JnoEbVvGC1ew0GhZEnKhJOj78OfksYHFErUsrtVw\";}s:2:\"id\";s:49:\"paragraph.ept_bootstrap_button.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"9d80d485-b1e2-4fbf-ad86-60acbbdd3d92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YeaGECTvxFfymsGgUGC0AO8Uap3cVB1SFUvwKCEoP0c\";}s:2:\"id\";s:45:\"paragraph.ept_bootstrap_button.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:14:\"Paragraph Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"c9626d4b-c719-4c6c-bc96-f92de310cf2e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IbyiiWXl-WZPf_JAHHt9YHqt7GAEtb8FBXpeQ3OXG8c\";}s:2:\"id\";s:46:\"paragraph.ept_bootstrap_button.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:15:\"Paragraph Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel.field_ept_carousel',_binary 'a:17:{s:4:\"uuid\";s:36:\"d7d805e1-ee4a-4aeb-87d9-e74edbe4f1e7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:42:\"field.storage.paragraph.field_ept_carousel\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:2;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aXX70EioyFtKtGWUZXGbeNLyjZK-M_6xbjrznbKBxsQ\";}s:2:\"id\";s:41:\"paragraph.ept_carousel.field_ept_carousel\";s:10:\"field_name\";s:18:\"field_ept_carousel\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:8:\"Carousel\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:17:\"ept_carousel_item\";s:17:\"ept_carousel_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:31;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_carousel.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"9905b685-324b-4f6a-8423-5973b3364a40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_IVLsSToXRuYcAqksQE6q0UQCw5J0ys7z54fIX3Prcg\";}s:2:\"id\";s:41:\"paragraph.ept_carousel.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_carousel.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"e61c2ef3-bfa8-4a34-aa69-9a530904c063\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T9eYBrQXk7NZSU8LgCIvtf9ldAkjSDaUsIlMZK1m5ks\";}s:2:\"id\";s:37:\"paragraph.ept_carousel.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0f3cce54-16b4-433a-a3d8-f66dceadfb5e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NN8UIWMU2GbeEUny8ga4lRNGGKi0sRnscgZKNOBUJbU\";}s:2:\"id\";s:38:\"paragraph.ept_carousel.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel_item.field_ept_carousel_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"f1e8eab0-49cf-40c1-a0c3-1c7c52bbcf18\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ept_carousel_caption\";i:1;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2da0GoNsm_uJyuQNbeEacFu5K_me_-2I4TTM-UpRlLk\";}s:2:\"id\";s:54:\"paragraph.ept_carousel_item.field_ept_carousel_caption\";s:10:\"field_name\";s:26:\"field_ept_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:5:\"label\";s:13:\"Slide caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel_item.field_ept_carousel_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"8a07cecc-6fab-4d81-8cda-096df1dc73ab\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:48:\"field.storage.paragraph.field_ept_carousel_image\";i:1;s:16:\"media.type.image\";i:2;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1qmbDr08-JuyqmRroyYKRiBXHMWBHN8Q8K3o4KxjQW0\";}s:2:\"id\";s:52:\"paragraph.ept_carousel_item.field_ept_carousel_image\";s:10:\"field_name\";s:24:\"field_ept_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:5:\"label\";s:11:\"Slide image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_columns.field_ept_columns',_binary 'a:17:{s:4:\"uuid\";s:36:\"e3f4b834-b3d2-43cf-8914-8378ae9e9f82\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:41:\"field.storage.paragraph.field_ept_columns\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"R6rkX-mPMiS67Fz1NUwV172q4Get3igbZ_JqWTdWxKU\";}s:2:\"id\";s:39:\"paragraph.ept_columns.field_ept_columns\";s:10:\"field_name\";s:17:\"field_ept_columns\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:7:\"Columns\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:11:\"ept_columns\";s:11:\"ept_columns\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_columns.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"77e74bf9-008e-4d96-9381-dc809ff7b841\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"v6ug86IR2khsDICnCIAdzPfNfLXmkeVFT9UqUTRCd9s\";}s:2:\"id\";s:40:\"paragraph.ept_columns.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_columns.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f9935753-c052-4b7b-b23a-a14f2748a834\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"E5a_LPXp_bizIM-GzrOKjXX53p0mj01R_Ljy3UhbYmc\";}s:2:\"id\";s:36:\"paragraph.ept_columns.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_columns.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"3988d015-d4a9-4560-9665-3defb0bfead9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LCIv3BxeR6WGu8S2T4pGT69kr4zPkUTHJk0ehJJqVjs\";}s:2:\"id\";s:37:\"paragraph.ept_columns.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_countdown.field_ept_countdown_date',_binary 'a:17:{s:4:\"uuid\";s:36:\"51db6984-7e76-4d6a-be3b-8f052f3bae29\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_countdown_date\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:8:\"datetime\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Tpuj04Fr7uNZO039Nd8J5cv4Ya-znGKtwNYc5cXn1gc\";}s:2:\"id\";s:48:\"paragraph.ept_countdown.field_ept_countdown_date\";s:10:\"field_name\";s:24:\"field_ept_countdown_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:14:\"Countdown date\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:8:\"datetime\";}'),('','field.field.paragraph.ept_countdown.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"991df58b-c253-4036-a94c-16bf928672f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Ba5vspWY7pQHKiHMxUWsBgPe13kyadBUwXJG_mtVF04\";}s:2:\"id\";s:42:\"paragraph.ept_countdown.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:12:\"EPT Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_countdown.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"36557cf2-e64e-4835-ad8e-b5bbc8150e8e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jxnjRfw__e_lRLCA703BFzbVEExF3BkVWaY6sDGBfno\";}s:2:\"id\";s:38:\"paragraph.ept_countdown.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_countdown.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"ae2f7f13-51c7-4ea2-99c7-c5b6b22f7360\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hE1iEpJa-BGC9-RbtJz3GYEuzj1nOmJqKNp7bNq63v8\";}s:2:\"id\";s:39:\"paragraph.ept_countdown.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter.field_ept_counter_items',_binary 'a:17:{s:4:\"uuid\";s:36:\"53805c44-6771-4268-b091-a3f4f1269139\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:47:\"field.storage.paragraph.field_ept_counter_items\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:2;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1MfRaU5RDocEjlC7nyIwXtGJAd9zHFyzfmxMz3nhoL8\";}s:2:\"id\";s:45:\"paragraph.ept_counter.field_ept_counter_items\";s:10:\"field_name\";s:23:\"field_ept_counter_items\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:17:\"EPT Counter Items\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:16:\"ept_counter_item\";s:16:\"ept_counter_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_counter.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"153fe814-ed15-45dd-ac36-e3166140cf03\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MNeAeSI8Y2lhDp_9PO88OMzAgUex8QzA7U6mYPsqZh4\";}s:2:\"id\";s:40:\"paragraph.ept_counter.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:12:\"EPT Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_counter.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"b4f633fb-12be-4793-b294-21badb491880\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_WgiVxSXXCkXpPedeKEQqBdTrL2yAV-R5njXnnWvkyQ\";}s:2:\"id\";s:36:\"paragraph.ept_counter.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"44deba9e-6935-4553-9ef0-ecc889381ae8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_A9WA0oPqrE9hJAdrstmGGAwR1IetKm59q9podeyJaI\";}s:2:\"id\";s:37:\"paragraph.ept_counter.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_description',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad867234-0316-48d0-bba3-4dcafd6d6091\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:53:\"field.storage.paragraph.field_ept_counter_description\";i:1;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n4-1RuE5rL9TNgTiA2lw7thDEjBhXTw_XAZuWfN21qY\";}s:2:\"id\";s:56:\"paragraph.ept_counter_item.field_ept_counter_description\";s:10:\"field_name\";s:29:\"field_ept_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:11:\"Description\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_icon',_binary 'a:17:{s:4:\"uuid\";s:36:\"94fe1479-276a-47c8-a255-ba6fdb6b874f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_ept_counter_icon\";i:1;s:16:\"media.type.image\";i:2;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T7rXLcACaUML0NMksYsmdVF9_PA7XqFakcAdD0PuMKk\";}s:2:\"id\";s:49:\"paragraph.ept_counter_item.field_ept_counter_icon\";s:10:\"field_name\";s:22:\"field_ept_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:4:\"Icon\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"9857343f-763e-4b29-8143-ec3fb9d9963d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_counter_number\";i:1;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NLE9w7TbjN5CmAnSSj-gSDT5bGz-IIqdEs-myskjLxo\";}s:2:\"id\";s:51:\"paragraph.ept_counter_item.field_ept_counter_number\";s:10:\"field_name\";s:24:\"field_ept_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:6:\"Number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:4:{s:3:\"min\";i:1;s:3:\"max\";N;s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"field_type\";s:7:\"integer\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"9d669ec1-badd-49d6-82c8-4a8eba8ca7da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ept_counter_title\";i:1;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1YYXmvZIdinNPPgOBzpsoa5rCIzMayt9KFg5Gp6aGxI\";}s:2:\"id\";s:50:\"paragraph.ept_counter_item.field_ept_counter_title\";s:10:\"field_name\";s:23:\"field_ept_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_cta.field_ept_cta_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"40656cb2-323c-4502-b916-5613d935c06a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:50:\"field.storage.paragraph.field_ept_cta_column_image\";i:1;s:16:\"media.type.image\";i:2;s:34:\"paragraphs.paragraphs_type.ept_cta\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M6DPa4NxYRx2y48yZGbZgB9RXiUBCln4aFQ2BSQ1ZRo\";}s:2:\"id\";s:44:\"paragraph.ept_cta.field_ept_cta_column_image\";s:10:\"field_name\";s:26:\"field_ept_cta_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_cta.field_ept_cta_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"a4f2e656-d59b-4df7-833b-709b38ab9360\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_cta_link\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"663HkJoryKb6fkU2dIBK7JnS0-v_HHMirdYKZ97PPXI\";}s:2:\"id\";s:36:\"paragraph.ept_cta.field_ept_cta_link\";s:10:\"field_name\";s:18:\"field_ept_cta_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_cta.field_ept_cta_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"2eb61b2c-ee83-43b2-beb6-334f5562bc8c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_cta_second_link\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zqb9GkzwNjNvs2k4e9egdt1MT_D0YfyITXC4BVAQS3s\";}s:2:\"id\";s:43:\"paragraph.ept_cta.field_ept_cta_second_link\";s:10:\"field_name\";s:25:\"field_ept_cta_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:11:\"Second Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_cta.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"7a06dca5-73c0-4c47-a217-2f9d7f3b9d43\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CdThFhM93LECXPeiHekVQZst4pAyaZauFLBc6ZZ2HJ0\";}s:2:\"id\";s:36:\"paragraph.ept_cta.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:18:\"Paragraph settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_cta.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a054c663-7358-4e24-99c7-7caa63091265\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QN1QM2C6SY_OR_LyAWi1j0iKDvbeAcJCe6s806EaZDo\";}s:2:\"id\";s:32:\"paragraph.ept_cta.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_cta.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"e6f7cd85-741e-4d86-ae78-2eabee82b952\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r_MAbOMwe1u3jdwZjUjmDHaxwmjIU-JGVZUkIUziPiQ\";}s:2:\"id\";s:33:\"paragraph.ept_cta.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"b46ea217-84f7-4321-912a-7446b534bb92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:51:\"field.storage.paragraph.field_ept_hero_column_image\";i:1;s:16:\"media.type.image\";i:2;s:35:\"paragraphs.paragraphs_type.ept_hero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_3eydYXoFUtHpVqERbj-NUTxfjmRpY41GlotzDaiMHw\";}s:2:\"id\";s:46:\"paragraph.ept_hero.field_ept_hero_column_image\";s:10:\"field_name\";s:27:\"field_ept_hero_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"5dcc6a7e-0a0a-4b27-8ec1-fc41c3bb654a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_hero_link\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lxzpMFHK8I8nPXViJVyoXQFZitk8kttqyIRXSb9D1O0\";}s:2:\"id\";s:38:\"paragraph.ept_hero.field_ept_hero_link\";s:10:\"field_name\";s:19:\"field_ept_hero_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"93b358ac-f703-4792-a4cb-65cb87eb34aa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ept_hero_second_link\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"69BKIyb4s5Y9A2Ehq5ew6h-2_suAuoW3onibd8wyXpI\";}s:2:\"id\";s:45:\"paragraph.ept_hero.field_ept_hero_second_link\";s:10:\"field_name\";s:26:\"field_ept_hero_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:11:\"Second link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_title_prefix',_binary 'a:17:{s:4:\"uuid\";s:36:\"00840cc4-7392-4663-a414-47758f14db31\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_hero_title_prefix\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"veAof1VE_5yLVqcM55gO7131zQkIVF8H4zYSRsZft-U\";}s:2:\"id\";s:46:\"paragraph.ept_hero.field_ept_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ept_hero_title_prefix\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:12:\"Title prefix\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_hero.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"9610a78c-d4d5-4d29-9221-2b862f3b5c9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jlfCaG2VGA8ar8Pw_-7SqeS8qRs_HrOK0KBRLdRLQGw\";}s:2:\"id\";s:37:\"paragraph.ept_hero.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_hero.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"eda0ee86-a9c6-40a3-90a6-52025f859080\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d6uOb6beHqZsXuoLFCkZ9d-OTiK3Lfl7WLMId5Ynb1o\";}s:2:\"id\";s:33:\"paragraph.ept_hero.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_hero.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"9cd49d18-67b3-4776-ba0b-dda42289ac3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4ZRR07jQy0amtEk8dDsUh5TwD7BiPqLSfZ64qa1IkaE\";}s:2:\"id\";s:34:\"paragraph.ept_hero.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image.field_ept_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"123bb9be-f4f0-4e79-9c1f-5a74d1adc56a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_image\";i:1;s:16:\"media.type.image\";i:2;s:36:\"paragraphs.paragraphs_type.ept_image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jo3X0pnIHasz5kmaVrv_VxOnp5yor6wvZ68l7Hpg9nc\";}s:2:\"id\";s:35:\"paragraph.ept_image.field_ept_image\";s:10:\"field_name\";s:15:\"field_ept_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_image.field_ept_image_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"720ab2af-faa7-4459-84ec-84810093337c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ept_image_caption\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tA0YJl2CpERDaSbF2WLaH5CxWoJo4OUxxMw-Y_Z85KA\";}s:2:\"id\";s:43:\"paragraph.ept_image.field_ept_image_caption\";s:10:\"field_name\";s:23:\"field_ept_image_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:13:\"Image caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image.field_ept_image_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"e46eefbb-e77e-4dbb-b856-37283bfcbcf6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_image_link\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Dmezv08ITbH8uMIaLoQS0_rAIw2TDc-iXuD0VCZW5q0\";}s:2:\"id\";s:40:\"paragraph.ept_image.field_ept_image_link\";s:10:\"field_name\";s:20:\"field_ept_image_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:10:\"Image Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_image.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"99ba3548-2963-43fc-9439-5c4981283ee3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"35ALufHFT-74ORycJJBebQ8dzd9UMefuOloBcGo5VZ0\";}s:2:\"id\";s:38:\"paragraph.ept_image.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_image.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"ee4ec7f5-67b4-42d7-baf2-7aaee393847f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TQxr_NqYWOx6AZeW6vZ-pqzPYQhGvMxRwPcm_djydmY\";}s:2:\"id\";s:34:\"paragraph.ept_image.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"b25f97c8-ef2e-408c-b977-6254d1414afe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"js6jXfcyujmxNS5eOXM-fX2nbJp4VUCmm_wWeBR272c\";}s:2:\"id\";s:35:\"paragraph.ept_image.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_image_gallery',_binary 'a:17:{s:4:\"uuid\";s:36:\"dfb637af-23af-4aa3-8753-1c3c1b41f2a4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:47:\"field.storage.paragraph.field_ept_image_gallery\";i:1;s:16:\"media.type.image\";i:2;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-waCmECFpztaOjQ1zzHETTjcKsonmUGYLmUUBB3P_K4\";}s:2:\"id\";s:51:\"paragraph.ept_image_gallery.field_ept_image_gallery\";s:10:\"field_name\";s:23:\"field_ept_image_gallery\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:13:\"Image Gallery\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"84658343-fa44-4fe9-acaa-5c0c2ff5f1d0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"guMxbDDWmEkT_hzhYXnmY2fyGUJMEPxeJW9uZmuIh7s\";}s:2:\"id\";s:46:\"paragraph.ept_image_gallery.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"3d160c57-3e25-403d-8a51-0a0b3397f5eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u25lX345GD4zaFxqQqboxwsRa0S9GMlNcD3drpGc6wE\";}s:2:\"id\";s:42:\"paragraph.ept_image_gallery.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"bbd8f0a6-7c0d-47e5-a62d-a2c5aed60232\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eKE4hyL1K1LGrcOlvyUoYrmTVsVfgHxMAfCbRZf4f5A\";}s:2:\"id\";s:43:\"paragraph.ept_image_gallery.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_micromodal.field_ept_micromodal_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"1003b7da-189c-4687-89e9-fe627bd2f746\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ept_micromodal_title\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jDNhkuS0vb097p4tXdHxr-ydSAj5cLsbKHtJJ8CC8A0\";}s:2:\"id\";s:51:\"paragraph.ept_micromodal.field_ept_micromodal_title\";s:10:\"field_name\";s:26:\"field_ept_micromodal_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:16:\"Micromodal Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_micromodal.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"c3236ac3-dc6f-4f78-9199-3450f0c1f3b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nAJ_q4mUFfBF1PGkZwsvQdbCQKbSx6iW74pQQ8M2kaY\";}s:2:\"id\";s:43:\"paragraph.ept_micromodal.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_micromodal.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f9453349-a4b8-4f21-ad48-735cb6bb9eca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"L9_i6zE8UlUJcopkepORHiE8I3C69iY3aeKe3A1jKDg\";}s:2:\"id\";s:39:\"paragraph.ept_micromodal.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_micromodal.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"b6314b7b-d04b-4c21-b388-edad4a320f8e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GoRC0O7xqhZYbUT4g4Qv76pyVOo2S62CERLkOw5UcoU\";}s:2:\"id\";s:40:\"paragraph.ept_micromodal.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_quote.field_ept_quote_author',_binary 'a:17:{s:4:\"uuid\";s:36:\"819b216b-97f6-4f18-82b6-2074094a280f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.storage.paragraph.field_ept_quote_author\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oNI4JdVXun_FojU2-XZoJP9ztB3e4wWwPkZYgvGQGCg\";}s:2:\"id\";s:42:\"paragraph.ept_quote.field_ept_quote_author\";s:10:\"field_name\";s:22:\"field_ept_quote_author\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:12:\"Quote Author\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_quote.field_ept_quote_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"fe2fb5d1-bcf8-4e29-9e00-d600aab8954a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:45:\"field.storage.paragraph.field_ept_quote_image\";i:1;s:16:\"media.type.image\";i:2;s:36:\"paragraphs.paragraphs_type.ept_quote\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YjnCUtsj4uSblj8ujLf9XPYiUCvxUQCzn6Si7IvFez0\";}s:2:\"id\";s:41:\"paragraph.ept_quote.field_ept_quote_image\";s:10:\"field_name\";s:21:\"field_ept_quote_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:11:\"Quote Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_quote.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"c4e09c22-0835-4bec-a402-756220f2e9f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t7gxB3ZTgUm7Yk0DbVkmAjHW8mI8AmfMf32Oxs3QZcI\";}s:2:\"id\";s:38:\"paragraph.ept_quote.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_quote.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f701ef4d-7de9-46b4-88f4-6995981e11ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"daebO4BuA3YZb6pUdTzPsiqUuJH_LDMHLJkxdMWVZSo\";}s:2:\"id\";s:34:\"paragraph.ept_quote.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:5:\"Quote\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_quote.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"a08772a7-ac82-466b-918c-b39c7f16c309\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QGR28IMOBB-lAS8KMdPI2PxLFhQ8APHB11vjkOzEybM\";}s:2:\"id\";s:35:\"paragraph.ept_quote.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"9bf7105c-9c7f-493b-b93c-2ee846a91521\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"75Fj62yEPi_Tkndg_Fr-WT5Fn81YlgSw2oEee7jQnKg\";}s:2:\"id\";s:45:\"paragraph.ept_slick_slider.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_slick_slider',_binary 'a:17:{s:4:\"uuid\";s:36:\"c440db95-46b7-4316-8502-e20c900704c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_ept_slick_slider\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:2;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VMJlv4iCLXipe6DB9Nw7mRcvCegf6AlaUe9pD4sFZw4\";}s:2:\"id\";s:49:\"paragraph.ept_slick_slider.field_ept_slick_slider\";s:10:\"field_name\";s:22:\"field_ept_slick_slider\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:12:\"Slick Slider\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:21:\"ept_slick_slider_item\";s:21:\"ept_slick_slider_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"4bad9ad2-5f7d-40ee-92a6-547badbee525\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qgc2mLoZ4HsNUAYaZCNUYpblK1Qy_Grwx-FiIrrd3fo\";}s:2:\"id\";s:41:\"paragraph.ept_slick_slider.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0570de2b-d581-4073-a8b0-0729eacf75eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8znZ6dLr4j9QA4jZnTSyprUdnZL0N8ZENTLNXvgPaFo\";}s:2:\"id\";s:42:\"paragraph.ept_slick_slider.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"1b1a1524-2e19-47c4-af5c-c693044a59e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:52:\"field.storage.paragraph.field_ept_slick_slider_image\";i:1;s:16:\"media.type.image\";i:2;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XlD11lUQ6pjHnXyA9Z5Z_lyj35bmUgn2C_2xUYcE2wI\";}s:2:\"id\";s:60:\"paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ept_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"6d566515-d2a4-4ce3-96e1-678ae2feea9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_slick_slider_link\";i:1;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"f47xjCX2OUOsteSKP2-Rqy9EJ1ZQWtGr2EmizJ0jwsQ\";}s:2:\"id\";s:59:\"paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"532449b1-8d51-4c87-ad35-6a4555565967\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_slick_slider_text\";i:1;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dP7Z_3Sp9p8yprgyoPMwzTnDckg7oXVPKeGBpWi5yHs\";}s:2:\"id\";s:59:\"paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"a98491aa-0091-4a36-af08-7e4f9e2a3554\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wDLAk6apIKl_k-WeYvw2Sx7NuPQrdbmVpPi_pcf6Ank\";}s:2:\"id\";s:42:\"paragraph.ept_slideshow.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_slideshow.field_ept_slideshow',_binary 'a:17:{s:4:\"uuid\";s:36:\"929dd04a-655a-436e-b9ec-8b400a26f596\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:43:\"field.storage.paragraph.field_ept_slideshow\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:2;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sl3hYGCV99Y8zdhisWkqHtWAR4cKtwAzRiAC8g8O_3w\";}s:2:\"id\";s:43:\"paragraph.ept_slideshow.field_ept_slideshow\";s:10:\"field_name\";s:19:\"field_ept_slideshow\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:9:\"Slideshow\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:18:\"ept_slideshow_item\";s:18:\"ept_slideshow_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_slideshow.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"04f2459a-8250-49b8-9c26-a1bc5f23b1ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eFgq1F96D8Kk_yB-LhiHcUiv0NDGHiiESnrxKVotJ8M\";}s:2:\"id\";s:38:\"paragraph.ept_slideshow.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0a76e0e6-37a2-4e5e-a2ca-41101da17e1e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MaSZwNYeloEyTip3_uq3aYWI21fdjStPLv72a0OyAs0\";}s:2:\"id\";s:39:\"paragraph.ept_slideshow.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"6671231f-f98f-4ea0-a6ab-9bfe42290292\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_slideshow_link\";i:1;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sj-aXmpz4XSqjlnaG36lSUzZ8k1NxnbVupC-3jXoTh4\";}s:2:\"id\";s:53:\"paragraph.ept_slideshow_item.field_ept_slideshow_link\";s:10:\"field_name\";s:24:\"field_ept_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide',_binary 'a:17:{s:4:\"uuid\";s:36:\"6483f62f-11d2-44ea-bf5b-d0db486d3689\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:49:\"field.storage.paragraph.field_ept_slideshow_slide\";i:1;s:16:\"media.type.image\";i:2;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a66BmJCI3SYkj4hLc0icKJq37QzM84zA3q3tcAMeAqA\";}s:2:\"id\";s:54:\"paragraph.ept_slideshow_item.field_ept_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ept_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad96e4c6-579a-4465-ba2d-117890a7bff3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_slideshow_text\";i:1;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JIuZsvq1IySXyy86tHyxkIPZnRhYgEKfm5uNfN4Qgi8\";}s:2:\"id\";s:53:\"paragraph.ept_slideshow_item.field_ept_slideshow_text\";s:10:\"field_name\";s:24:\"field_ept_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"84bea7b4-b9e4-4cf4-8ec9-389dd6b02c10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_slideshow_title\";i:1;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"of2_NLVXcX_Tqy_oCPxWCKkqkVV1GMoDc32IPKj-uAs\";}s:2:\"id\";s:54:\"paragraph.ept_slideshow_item.field_ept_slideshow_title\";s:10:\"field_name\";s:25:\"field_ept_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:11:\"Slide Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"f00824ef-dc9b-4ba7-81ad-8e7910f662a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"w6dTziASV3O9e_SoQSGcA7y3KjBRRRFKEmxbhx_eOPY\";}s:2:\"id\";s:38:\"paragraph.ept_stats.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_stats.field_ept_stats',_binary 'a:17:{s:4:\"uuid\";s:36:\"cfaf7cc4-f386-4397-8876-cdcee33b93b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_stats\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:2;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ixjxb8WmNFSxd8n64WYGee4M8gw_ihsOSTkxejxBK7I\";}s:2:\"id\";s:35:\"paragraph.ept_stats.field_ept_stats\";s:10:\"field_name\";s:15:\"field_ept_stats\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:9:\"EPT Stats\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ept_stats_item\";s:14:\"ept_stats_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_stats.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a8fb2e31-9a7a-45bb-84f7-84bce2a8e256\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5DBGJho8oBlSjoM127v2kkKEhKXLsn2dYpC1Gj4wep8\";}s:2:\"id\";s:34:\"paragraph.ept_stats.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"1c882037-c7e3-42e4-9707-af10c5015ef2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T8Ioj6BqDtO5y16e6qpTBdiluC90CXivuhVNCfIlff8\";}s:2:\"id\";s:35:\"paragraph.ept_stats.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"48e0dea0-fc4d-4a86-8ed4-203f0efe3a52\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:50:\"field.storage.paragraph.field_ept_stats_item_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gQ-WN8Z7uMhqF7m3PcgLkMbssZvUuoZDru39piaWdaY\";}s:2:\"id\";s:51:\"paragraph.ept_stats_item.field_ept_stats_item_image\";s:10:\"field_name\";s:26:\"field_ept_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:16:\"Stats item image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"64aa7603-d2f0-4050-a82f-35b5ef3b978f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_stats_item_link\";i:1;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MnXt19dK8rTz4x1hRigyeVWiXn1o6VumcHTMqrFFk74\";}s:2:\"id\";s:50:\"paragraph.ept_stats_item.field_ept_stats_item_link\";s:10:\"field_name\";s:25:\"field_ept_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:15:\"Stats item link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"4be87c8b-a691-4546-9b46-8104a7920252\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_stats_item_number\";i:1;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7DMKiTrisc5ETf4YO_Rg2a1hxbtze1sV29AulzJK_mo\";}s:2:\"id\";s:52:\"paragraph.ept_stats_item.field_ept_stats_item_number\";s:10:\"field_name\";s:27:\"field_ept_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:17:\"Stats item number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"7ab22f13-220c-400f-9f56-3043d91300ed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_stats_item_text\";i:1;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"syABtrl4XuopN2UmpGpkCfjm8LZlB4zLjgHycG4AUww\";}s:2:\"id\";s:50:\"paragraph.ept_stats_item.field_ept_stats_item_text\";s:10:\"field_name\";s:25:\"field_ept_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:15:\"Stats item text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"bcee11b6-9de3-4ea7-ab28-783aaf52a980\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7WAUPeogPEpndKAuLbuwHXSQX1_x1zQ1DkQgZ0xSJl8\";}s:2:\"id\";s:37:\"paragraph.ept_tabs.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_tabs.field_ept_tabs',_binary 'a:17:{s:4:\"uuid\";s:36:\"f3ed6271-02a1-49ae-87a5-dcbb0788200c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:38:\"field.storage.paragraph.field_ept_tabs\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:2;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oxGvFEmPYXx97wLochArKKDYG1lhbF0L77Sp4ki0K1I\";}s:2:\"id\";s:33:\"paragraph.ept_tabs.field_ept_tabs\";s:10:\"field_name\";s:14:\"field_ept_tabs\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:8:\"EPT Tabs\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_tabs.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"5d8d9518-713c-4c54-a1b1-e9255a1064cf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SxiqJRauMgF0Qzud0cz2Wj4-oLnMJ3Cr-bXZe_fdGC0\";}s:2:\"id\";s:33:\"paragraph.ept_tabs.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"3b694b0c-21b1-40f1-aab1-5f8f6b508006\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DehWRcrin5XDNZhAMoyHl3b5Vtw4Tpdijx5u8vCQ75Q\";}s:2:\"id\";s:34:\"paragraph.ept_tabs.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"c3f52d5a-54bd-4606-8b04-4a6c1e456a0b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_block\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Djebt4QCWYRzCydiBvhKgj0bMyEaWAKfY-YBAf7OX4Y\";}s:2:\"id\";s:43:\"paragraph.ept_tabs_item.field_ept_tab_block\";s:10:\"field_name\";s:19:\"field_ept_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:9:\"Tab Block\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:6:\"blocks\";s:18:\"selection_settings\";a:1:{s:10:\"plugin_ids\";a:0:{}}}s:10:\"field_type\";s:11:\"block_field\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_content',_binary 'a:17:{s:4:\"uuid\";s:36:\"8bd0ca98-8e9c-4dba-b1cf-ae98a043504f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ept_tab_content\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:7:\"options\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FHi-QeaCukjELTWL55S3DmUxMPC5qvpjm7YoUXlN2_k\";}s:2:\"id\";s:45:\"paragraph.ept_tabs_item.field_ept_tab_content\";s:10:\"field_name\";s:21:\"field_ept_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:11:\"Tab content\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:11:\"list_string\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_page',_binary 'a:17:{s:4:\"uuid\";s:36:\"15235fd9-9fad-4092-b19c-8e011debebfb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:42:\"field.storage.paragraph.field_ept_tab_page\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lSW-pbI_Dd3D3Pmk9Ey9S92Si1kgRJBouroj9i9FcxI\";}s:2:\"id\";s:42:\"paragraph.ept_tabs_item.field_ept_tab_page\";s:10:\"field_name\";s:18:\"field_ept_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:8:\"Tab page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:12:\"default:node\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:4:\"page\";s:4:\"page\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a059a1dc-b8c7-41a3-a0ba-57ef2b7c3ef2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_tab_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UhI0Db-BZ8kkyso5fdxGaK2SLKXQOo3Tz91NfllT_zE\";}s:2:\"id\";s:42:\"paragraph.ept_tabs_item.field_ept_tab_text\";s:10:\"field_name\";s:18:\"field_ept_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:8:\"Tab text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0c7eb82c-6093-4901-bd0b-fd48f6eedcb2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"evBpqQnLlVSI7JzfhV_sYlfl4Xj_FMH8yjfAXa3TuNo\";}s:2:\"id\";s:43:\"paragraph.ept_tabs_item.field_ept_tab_title\";s:10:\"field_name\";s:19:\"field_ept_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:9:\"Tab title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:4:\"text\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_views',_binary 'a:17:{s:4:\"uuid\";s:36:\"efd74810-b803-4db6-b891-9ea3905eb31d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_views\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I_C7XUVcXIbh_wxTumKceK8yBCxb_QVNvaycgNmZB20\";}s:2:\"id\";s:43:\"paragraph.ept_tabs_item.field_ept_tab_views\";s:10:\"field_name\";s:19:\"field_ept_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:9:\"Tab views\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";i:0;}s:12:\"plugin_types\";a:5:{s:5:\"block\";s:5:\"block\";s:7:\"default\";i:0;s:4:\"page\";i:0;s:4:\"feed\";i:0;s:5:\"embed\";i:0;}s:15:\"preselect_views\";a:15:{s:13:\"block_content\";i:0;s:7:\"comment\";i:0;s:15:\"comments_recent\";i:0;s:7:\"content\";i:0;s:14:\"content_recent\";i:0;s:5:\"files\";i:0;s:9:\"frontpage\";i:0;s:5:\"media\";i:0;s:13:\"media_library\";i:0;s:13:\"taxonomy_term\";i:0;s:17:\"user_admin_people\";i:0;s:8:\"watchdog\";i:0;s:19:\"webform_submissions\";i:0;s:9:\"who_s_new\";i:0;s:12:\"who_s_online\";i:0;}s:16:\"enabled_settings\";a:5:{s:8:\"argument\";i:0;s:5:\"limit\";i:0;s:6:\"offset\";i:0;s:5:\"pager\";i:0;s:5:\"title\";i:0;}}s:10:\"field_type\";s:14:\"viewsreference\";}'),('','field.field.paragraph.ept_text.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"dd24c6a8-a5d2-434a-90d0-3a97c829c794\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zlnMwIZoq976NUR8ObTPmCmOG2YwYTmjc1fQpFhCzWs\";}s:2:\"id\";s:37:\"paragraph.ept_text.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:5:\"label\";s:18:\"field_ept_settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_text.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"406dd338-600c-4eb2-841a-df635188cfb3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yIzbNDHidtMFArQQv6qO6cTkFBTnI6e02KK-xT8FOIM\";}s:2:\"id\";s:33:\"paragraph.ept_text.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_text.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"6902be14-683f-4f5a-8d50-8543bbf0aca5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DZTXvQuYpXkQt9q004RnVKvKTocT9hurW7VYy0As9Is\";}s:2:\"id\";s:34:\"paragraph.ept_text.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"ac698185-3f8a-4519-a9b7-29609da24892\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d-eKpx0qmCR-PZ85K0IfmM1LKHFjcx9xUcNT5mMFMuA\";}s:2:\"id\";s:38:\"paragraph.ept_tiles.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_tiles.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"7f39ca00-ae38-46ac-a2f2-ce0b4f545f9f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uGM6CpdmK0GJ5mrS4WHYG6QnXJLHx0fiEbs3D7e_iqE\";}s:2:\"id\";s:34:\"paragraph.ept_tiles.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles.field_ept_tiles',_binary 'a:17:{s:4:\"uuid\";s:36:\"254d23bc-cd9a-4186-b124-2f3fa923fc05\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_tiles\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:2;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Lii17sKUYm4ZAvrf-OKM8IF0auj5DIQWCMBUkdzT4BM\";}s:2:\"id\";s:35:\"paragraph.ept_tiles.field_ept_tiles\";s:10:\"field_name\";s:15:\"field_ept_tiles\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:5:\"Tiles\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:75;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_tiles.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"efadba67-9ef3-474a-8246-0e5a51d74660\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e58JwGJ1lDz1CUji4qvDlK_7WEadqaihU0jG6u0_10E\";}s:2:\"id\";s:35:\"paragraph.ept_tiles.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_clickable_tile',_binary 'a:17:{s:4:\"uuid\";s:36:\"29c56f04-456b-4f6f-87b5-6352ddaa6a51\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_clickable_tile\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BVIyqIinPodc30VYfLCsYHnMbl1U6L7LpKffkLNM6RY\";}s:2:\"id\";s:49:\"paragraph.ept_tiles_item.field_ept_clickable_tile\";s:10:\"field_name\";s:24:\"field_ept_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:14:\"Clickable Tile\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"af24502d-ca80-4229-bc11-8b9d175d53f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:45:\"field.storage.paragraph.field_ept_tiles_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AnFN9yAGXXY3wn6XD_DMYj4H1UfZR6gt3lITV4L2Jy4\";}s:2:\"id\";s:46:\"paragraph.ept_tiles_item.field_ept_tiles_image\";s:10:\"field_name\";s:21:\"field_ept_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"77a71623-7050-467d-bbb6-f7e2b8e10f9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_tiles_link\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"c5x2tFCR-aDLFMCY5a0CDVK8OLjI-eH92z0w6wsbq7I\";}s:2:\"id\";s:45:\"paragraph.ept_tiles_item.field_ept_tiles_link\";s:10:\"field_name\";s:20:\"field_ept_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a96f802e-f6f6-415b-a00b-47d8e483f3c2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_tiles_text\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zLtl1oCO1H3AjX05GApCKNVIuZj-sWnEjN2TFBhgTpk\";}s:2:\"id\";s:45:\"paragraph.ept_tiles_item.field_ept_tiles_text\";s:10:\"field_name\";s:20:\"field_ept_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"60166fc5-cd70-42a2-ab4a-021bef6afcf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ept_tiles_title\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-RWZYOv7kMNcT6h0h3wa0LE8w3is_5A7gNJGRvk2Xh8\";}s:2:\"id\";s:46:\"paragraph.ept_tiles_item.field_ept_tiles_title\";s:10:\"field_name\";s:21:\"field_ept_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"65e27c50-82c3-46dd-ad6d-c95805dd83bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jKYz3Azrp1BbteF4w3ARDoD11HGUjD6Y1-Pi3j5bMMA\";}s:2:\"id\";s:38:\"paragraph.ept_video.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_video.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"de00022b-0652-4a4f-a13f-6d001b19f4c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rOcKKlFTqbEyP9jZpIA7FgAeEZVpAzkLMwyL7Ocl7ZA\";}s:2:\"id\";s:34:\"paragraph.ept_video.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"68fe7948-f81f-4f36-8ce6-3a736d2696be\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"liOGejMkGS8WchkLMEwnO9OEFeI2CuDopa6y4ARi6R4\";}s:2:\"id\";s:35:\"paragraph.ept_video.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video.field_ept_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"5fbf0b1d-881b-44e3-9225-31e307913827\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_video\";i:1;s:23:\"media.type.remote_video\";i:2;s:36:\"paragraphs.paragraphs_type.ept_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"B2uO316aHzKE6mwH_4CehW7np6-M8ImTN-8E4ZUIOz4\";}s:2:\"id\";s:35:\"paragraph.ept_video.field_ept_video\";s:10:\"field_name\";s:15:\"field_ept_video\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:12:\"remote_video\";s:12:\"remote_video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"8b147c97-e78e-4773-a7dd-fbdd3db585a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A0AtClTrQ3Abbg6jEI-itnCAjYSI69l8ZIU5n6wGu-k\";}s:2:\"id\";s:56:\"paragraph.ept_video_and_image_gallery.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"5c1e6fab-0fe9-4952-a3c8-991a0f293a80\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iohq2efRKb05xjfjet4Iqszn41WFrfgfSMpBRl9I8EQ\";}s:2:\"id\";s:52:\"paragraph.ept_video_and_image_gallery.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"2bdd8485-4125-400d-b6ef-feffe57ca0b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nYAF3MHEVZhy6EJ7hiHDE82BlOyi6F94s9AtJa31HxY\";}s:2:\"id\";s:53:\"paragraph.ept_video_and_image_gallery.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images',_binary 'a:17:{s:4:\"uuid\";s:36:\"c9a94fcc-b813-47ed-9b68-5780ad0e270c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:51:\"field.storage.paragraph.field_ept_videos_and_images\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:2;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Md5TJXPOSzIMO3hzpok2uncR4UY-8oOvihBYAwl1UTE\";}s:2:\"id\";s:65:\"paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";s:10:\"field_name\";s:27:\"field_ept_videos_and_images\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:17:\"Videos and Images\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:32:\"ept_video_and_image_gallery_item\";s:32:\"ept_video_and_image_gallery_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:82;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item',_binary 'a:17:{s:4:\"uuid\";s:36:\"8e45972c-1dc7-444f-9475-a98aa5a83a12\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:4:{i:0;s:46:\"field.storage.paragraph.field_ept_gallery_item\";i:1;s:16:\"media.type.image\";i:2;s:23:\"media.type.remote_video\";i:3;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pIblYcf3rZ3cLp4a87dabiYrK0YFYOLsXZ8PPx7JD2w\";}s:2:\"id\";s:65:\"paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";s:10:\"field_name\";s:22:\"field_ept_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:5:\"label\";s:12:\"Gallery Item\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:2:{s:5:\"image\";s:5:\"image\";s:12:\"remote_video\";s:12:\"remote_video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:5:\"image\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"9302769a-011f-4ea8-8a1a-82c6399fc628\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_gallery_item_text\";i:1;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rHN5K2dhzZ2JBJLK9KNsBbDp_D8-ug9T0oRgKfs_L_8\";}s:2:\"id\";s:70:\"paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";s:10:\"field_name\";s:27:\"field_ept_gallery_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:5:\"label\";s:17:\"Gallery item text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_views.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"0cd4c4a7-feca-4fb7-9e8b-02984559941b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qvGJxPRaclSHVbrfz5Je86o0KNtcIYQhWoZtkWbYOeY\";}s:2:\"id\";s:38:\"paragraph.ept_views.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_views.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f9ef68e5-ed23-45fb-a5d1-bac433eeb379\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yroYplh-3xAoBiIIaPAFqecCgnt--hr4wQOE6pydZiw\";}s:2:\"id\";s:34:\"paragraph.ept_views.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_views.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0d3eae73-ae6d-4601-b1d4-4df1d7d62c53\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YN4Np9dhEdu3560d9b81PqIY6VAamYuCUEeaTR7MeA4\";}s:2:\"id\";s:35:\"paragraph.ept_views.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_views.field_ept_views_view',_binary 'a:17:{s:4:\"uuid\";s:36:\"ef74c15e-0e9f-4f8c-82b1-f7cec4763c50\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_views_view\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qezCi3E0L14u6YMFPeJ3FisM_AyqNacTs3hFkLyN-Bk\";}s:2:\"id\";s:40:\"paragraph.ept_views.field_ept_views_view\";s:10:\"field_name\";s:20:\"field_ept_views_view\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:4:\"View\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}s:12:\"plugin_types\";a:1:{s:5:\"block\";s:5:\"block\";}s:15:\"preselect_views\";a:0:{}s:16:\"enabled_settings\";a:0:{}}s:10:\"field_type\";s:14:\"viewsreference\";}'),('','field.field.user.user.user_picture',_binary 'a:17:{s:4:\"uuid\";s:36:\"27323f57-acfd-4aff-a508-544c6c8bdf3d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:31:\"field.storage.user.user_picture\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TE3gYVzd6g0deXqUl8SEu2azHwVG-SdXm3kwbrz0kHw\";}s:2:\"id\";s:22:\"user.user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:5:\"label\";s:7:\"Picture\";s:11:\"description\";s:29:\"Your virtual face or picture.\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:40:\"pictures/[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:0;s:18:\"alt_field_required\";b:0;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nJk0TAQBzlNo52ehiHI7bIEPLGi0BYqZvPdEn7Chfu0\";}s:16:\"purge_batch_size\";i:50;}'),('','field.storage.block_content.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"05e5fd5b-7ad6-434e-99a8-8635a8fa97cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc\";}s:2:\"id\";s:18:\"block_content.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.comment.comment_body',_binary 'a:17:{s:4:\"uuid\";s:36:\"4a613783-5795-48bc-bd8e-e3fe3a00ea51\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swYoCch_hY8QO5uwr4FURplfnUCUlpPB4idF8WGVCpw\";}s:2:\"id\";s:20:\"comment.comment_body\";s:10:\"field_name\";s:12:\"comment_body\";s:11:\"entity_type\";s:7:\"comment\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_audio_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"1295648c-a917-438e-a846-fd85d14ae8a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JCHoh95CpUeBx9ch24Tmi6ru0nwmNz8xWVH4Qs7RnTg\";}s:2:\"id\";s:28:\"media.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_document',_binary 'a:17:{s:4:\"uuid\";s:36:\"6b41e063-a182-4108-9b56-c0f4bb265180\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BdkTx7IL59MCw5a_fOZprPTOGM_wcjz-Fm8g7HV3vFk\";}s:2:\"id\";s:26:\"media.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"ae1f0138-a2f5-4881-bf90-0ade773b59b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0N0KSFk57p6qsq3qM4lYVGSuROvzXK-tSsdwByqUh3g\";}s:2:\"id\";s:23:\"media.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_oembed_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"b471db54-e924-4e9f-b6d7-c7e32f497206\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cNf_852Dq-fNnSaMI4LxL-J6N7bLkHuDbD9EUqOn4_U\";}s:2:\"id\";s:30:\"media.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:0;s:8:\"is_ascii\";b:0;}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_video_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"1567fe07-a329-492a-bc5f-d82e3865bd57\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z5mgbn1PIVZ5TNMByBmivqo_u3Rdk58UIzpyN4ypTeM\";}s:2:\"id\";s:28:\"media.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"26a81385-82de-46f0-8582-8c93b0fbcb01\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY\";}s:2:\"id\";s:9:\"node.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_components',_binary 'a:16:{s:4:\"uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:2:\"id\";s:21:\"node.field_components\";s:10:\"field_name\";s:16:\"field_components\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"d9aff85c-3ad9-418b-b47e-58f08b64180e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE\";}s:2:\"id\";s:16:\"node.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_tags',_binary 'a:17:{s:4:\"uuid\";s:36:\"81f6ea79-133f-4e53-bb0a-4169a69c4472\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs\";}s:2:\"id\";s:15:\"node.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:13:\"taxonomy_term\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_accordion',_binary 'a:17:{s:4:\"uuid\";s:36:\"c9282b5e-9cbb-4d37-84d7-b405cf59a041\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"99EX18edsQlLBda3J37pHASAxF4OUjSVJ4_nSq1pW94\";}s:2:\"id\";s:29:\"paragraph.field_ept_accordion\";s:10:\"field_name\";s:19:\"field_ept_accordion\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_accordion_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"177e4cd0-bbd1-44cd-9d3f-5b5dd4378ed4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l5c0DoOjgcErJEjFGkUqN_upYgubdHpE_MiwbMK2YRI\";}s:2:\"id\";s:34:\"paragraph.field_ept_accordion_text\";s:10:\"field_name\";s:24:\"field_ept_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_accordion_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"012f2184-9082-4983-9239-7dac48864d9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6S4PB05UjgSgHEDSalqgqkJHWyCcYsdkgPKTvGC2c8s\";}s:2:\"id\";s:35:\"paragraph.field_ept_accordion_title\";s:10:\"field_name\";s:25:\"field_ept_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_basic_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"360bef36-b4f7-492b-9677-6170eebdf2bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Tj1qQArNpaPeg2XmPed8WY2JiAk8p21-R1HVn28zVoY\";}s:2:\"id\";s:37:\"paragraph.field_ept_basic_button_link\";s:10:\"field_name\";s:27:\"field_ept_basic_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_block_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"58c5cc3e-9949-4686-882a-a56b59c60ea8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hAESsXJ5KZsWYKr-KB5wJoHNBdcOTlIFJUomBW8VxoU\";}s:2:\"id\";s:31:\"paragraph.field_ept_block_block\";s:10:\"field_name\";s:21:\"field_ept_block_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_bootstrap_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"bceb6f2f-b114-41f5-8b07-0ce990d0087a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BweaoyqqEqOIBPWV2qKw_2N4R6oBSudk91cCNPtz_iY\";}s:2:\"id\";s:41:\"paragraph.field_ept_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ept_bootstrap_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_carousel',_binary 'a:17:{s:4:\"uuid\";s:36:\"fbb51140-67d8-4112-868c-19dd46c31b98\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RbALd0Xz78o-CtP2iD8j7s8h1scHn1lSdm-_EQqZyrY\";}s:2:\"id\";s:28:\"paragraph.field_ept_carousel\";s:10:\"field_name\";s:18:\"field_ept_carousel\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_carousel_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"4bdff313-152c-4ea9-ba49-6f433c48203a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HeWBlq69mptI0nGWU0dliRAS9rVOa2HzuJbUbzsJg4M\";}s:2:\"id\";s:36:\"paragraph.field_ept_carousel_caption\";s:10:\"field_name\";s:26:\"field_ept_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_carousel_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"1da3ad04-a3d6-45a2-8a2e-100f0d629948\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ViB2NrYfe_RWvrvvb9X_U6kuX0eI47m5Wpa6hCFqZWE\";}s:2:\"id\";s:34:\"paragraph.field_ept_carousel_image\";s:10:\"field_name\";s:24:\"field_ept_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_clickable_tile',_binary 'a:17:{s:4:\"uuid\";s:36:\"776f5eb1-0740-473f-b278-4678ab1e0a4e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKnQMenIUygu6qoP8n4_EzChFXMkjnwf78bFFBWCN0w\";}s:2:\"id\";s:34:\"paragraph.field_ept_clickable_tile\";s:10:\"field_name\";s:24:\"field_ept_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_columns',_binary 'a:17:{s:4:\"uuid\";s:36:\"7518ddce-1000-4e47-8c93-f8230ca40081\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lIenGVJ8vS3WAEr1xteI9sDUdCoc-UNgbf7xDipU4_s\";}s:2:\"id\";s:27:\"paragraph.field_ept_columns\";s:10:\"field_name\";s:17:\"field_ept_columns\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_countdown_date',_binary 'a:17:{s:4:\"uuid\";s:36:\"5741fa83-8e57-4e60-99ce-6e8bd5bf8b78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:8:\"datetime\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SWGbKy8XYRkCxbrmDvY2UYyxzAKxcSL7ouH4CljiXbY\";}s:2:\"id\";s:34:\"paragraph.field_ept_countdown_date\";s:10:\"field_name\";s:24:\"field_ept_countdown_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:8:\"datetime\";s:8:\"settings\";a:1:{s:13:\"datetime_type\";s:8:\"datetime\";}s:6:\"module\";s:8:\"datetime\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_description',_binary 'a:17:{s:4:\"uuid\";s:36:\"385056ad-483b-468c-8fc7-fa477f32138c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Vb_uSodiEH1YHgcoZFitK_cSCdO65_4U1fUOrl-0G-0\";}s:2:\"id\";s:39:\"paragraph.field_ept_counter_description\";s:10:\"field_name\";s:29:\"field_ept_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_icon',_binary 'a:17:{s:4:\"uuid\";s:36:\"bd174355-0ad0-4843-9909-9069e6e2eac2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I0JA4V_sLzmSUMXzEuZ7m6J_MFEw5Nrb7bG9XU34Ucc\";}s:2:\"id\";s:32:\"paragraph.field_ept_counter_icon\";s:10:\"field_name\";s:22:\"field_ept_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_items',_binary 'a:17:{s:4:\"uuid\";s:36:\"fa2205d7-3b05-4d76-a029-30510c45d952\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vFwfw4KEUwjCwBs2-7ay4ctFQ2ObvCZYU16zxuQC5HM\";}s:2:\"id\";s:33:\"paragraph.field_ept_counter_items\";s:10:\"field_name\";s:23:\"field_ept_counter_items\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"072a57f4-9c76-4a9a-a3f4-f13ef03b81be\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MzVJsn5k9Si1YXppdAIDnZzJ1W16U44-V2RnkeyaeyI\";}s:2:\"id\";s:34:\"paragraph.field_ept_counter_number\";s:10:\"field_name\";s:24:\"field_ept_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"integer\";s:8:\"settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"a62c9e27-ad8b-430d-85ce-9db276ada8eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CTuSHda2RHGJciX7ZF12J7Y9A3TK_RrRj7CRxyKyNGA\";}s:2:\"id\";s:33:\"paragraph.field_ept_counter_title\";s:10:\"field_name\";s:23:\"field_ept_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_cta_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"2545ccb9-b7f9-49f1-a002-1aa70a099849\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BVZIBdZwlh9CG5xDwjnekBIIuVdEEtKvFPci5rwGdA0\";}s:2:\"id\";s:36:\"paragraph.field_ept_cta_column_image\";s:10:\"field_name\";s:26:\"field_ept_cta_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_cta_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"ef4b1edf-7e44-4fd4-9484-139b43615d23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LvryVrIdU5CC3UNEhpU7Vej6X8Y4RKKDsOdhseGGUVg\";}s:2:\"id\";s:28:\"paragraph.field_ept_cta_link\";s:10:\"field_name\";s:18:\"field_ept_cta_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_cta_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"e5ac8a81-1f96-4b7d-b8e0-6d9b2c08fcbd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DHvUvJxjsMX4y4-L8sAyVpFvA0pptpqcHZ8p_EMBBdU\";}s:2:\"id\";s:35:\"paragraph.field_ept_cta_second_link\";s:10:\"field_name\";s:25:\"field_ept_cta_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_gallery_item',_binary 'a:17:{s:4:\"uuid\";s:36:\"a1361495-0a6d-4f18-8570-b713e198ddf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8JLKZdRZR-OD6hbmGc3VHufx5PLi683tbf4QM_K4ZAU\";}s:2:\"id\";s:32:\"paragraph.field_ept_gallery_item\";s:10:\"field_name\";s:22:\"field_ept_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_gallery_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"ceb57be4-05e2-49c4-afad-48cb1341e682\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cWuIwOJOPOwoJ4OA0TCSko2wR73oMOOVlyC7clefebo\";}s:2:\"id\";s:37:\"paragraph.field_ept_gallery_item_text\";s:10:\"field_name\";s:27:\"field_ept_gallery_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"0bd5b0b1-4d3b-472e-ac51-086416f9360a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"knr6QfLVidPHSzwjlRdOZ6PqAiVNnXT73--qFC4pZqo\";}s:2:\"id\";s:37:\"paragraph.field_ept_hero_column_image\";s:10:\"field_name\";s:27:\"field_ept_hero_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"89e38776-3ba0-4f79-9023-af5e40b20171\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XgZuheOtVwvMdFAli6FX9XwC6jCtmfQsa4Y--V6AWLk\";}s:2:\"id\";s:29:\"paragraph.field_ept_hero_link\";s:10:\"field_name\";s:19:\"field_ept_hero_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"a51e7805-3dcf-415a-b08c-6e41b660115d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_LEdcxkwVZPMeBjAfFM_DTcqJxHu-SXmfvkzYA16OTE\";}s:2:\"id\";s:36:\"paragraph.field_ept_hero_second_link\";s:10:\"field_name\";s:26:\"field_ept_hero_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_title_prefix',_binary 'a:17:{s:4:\"uuid\";s:36:\"be93c2a2-2803-47c8-8cbb-88ab3561ae6c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HgeEpS7HHbPsoLeKHrpRrax2ttxvlJADvMU3R-HwVf4\";}s:2:\"id\";s:37:\"paragraph.field_ept_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ept_hero_title_prefix\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"a3a4414c-7488-42d9-ad4e-706dbb16b1da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t2q8Lh-nuJZ2Ozh8PR1_zVbozcHAD18kLOnsz0e4oxY\";}s:2:\"id\";s:25:\"paragraph.field_ept_image\";s:10:\"field_name\";s:15:\"field_ept_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"d90ba792-7242-4c28-a755-2203bfbd33dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-2PNM_k1cGXc-Q0fAWwWKl0WSoTksX8UcJ3-t0wUn1s\";}s:2:\"id\";s:33:\"paragraph.field_ept_image_caption\";s:10:\"field_name\";s:23:\"field_ept_image_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image_gallery',_binary 'a:17:{s:4:\"uuid\";s:36:\"a25a51c6-fb73-441d-bfe4-baf60db380f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"42vUEff48hmnJOtdaZMLlF0wtf_QYb_mBJO5EVMCKBk\";}s:2:\"id\";s:33:\"paragraph.field_ept_image_gallery\";s:10:\"field_name\";s:23:\"field_ept_image_gallery\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"389f5e03-e7e9-4fb0-bdb5-618f4ada2579\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VKNAP2cuu9mjHYh_BiZTS3nC4gx2nPLjvdAFIHAhJs\";}s:2:\"id\";s:30:\"paragraph.field_ept_image_link\";s:10:\"field_name\";s:20:\"field_ept_image_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_micromodal_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"58a0c8d3-2aaa-43a3-af29-df451a7410e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9wlDgbRXeLI7j3BoH97N3phJfeK2l1E2osqZh_FRkh4\";}s:2:\"id\";s:36:\"paragraph.field_ept_micromodal_title\";s:10:\"field_name\";s:26:\"field_ept_micromodal_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_quote_author',_binary 'a:17:{s:4:\"uuid\";s:36:\"f68b8da9-803f-4c9b-8f4c-4fc24f899205\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yN0vOPqU28gSDN6dC5uNd2vwbTDVhm0njE_mJ2k_rCk\";}s:2:\"id\";s:32:\"paragraph.field_ept_quote_author\";s:10:\"field_name\";s:22:\"field_ept_quote_author\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_quote_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"39b9627d-fdb9-4ed9-afc4-0c4d133a92c6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tQ8LcsYTu_fXhMAvx5We58I0EB2mrFc9tC42tO2YpQ4\";}s:2:\"id\";s:31:\"paragraph.field_ept_quote_image\";s:10:\"field_name\";s:21:\"field_ept_quote_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"aed153c8-a66a-428a-be76-0d9ff9c57e30\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HvKMBmRf1ancerUpnNjtwfTeY-R4_vPBnsqEe9j-ovs\";}s:2:\"id\";s:28:\"paragraph.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:12:\"ept_settings\";s:8:\"settings\";a:0:{}s:6:\"module\";s:8:\"ept_core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider',_binary 'a:17:{s:4:\"uuid\";s:36:\"467150cb-7feb-412a-9426-4b2a3f4a1caa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"p4cFkBoz3tkJW1Ep5zM4g_f4mQ-XFHh3pShn7qHErpU\";}s:2:\"id\";s:32:\"paragraph.field_ept_slick_slider\";s:10:\"field_name\";s:22:\"field_ept_slick_slider\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"d985b37a-8f1d-4d3c-8d92-09cb8326cf66\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LzVCCy3JB_QNYYe-TIA7NOSStFsPdMhJRj2kRx6xp48\";}s:2:\"id\";s:38:\"paragraph.field_ept_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ept_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"3adc57b0-490d-4760-8c68-b19c339fedb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"urQvYyrbemmSrIdbqn5B3hiHO3OGBgCpwmTx0L9ipCM\";}s:2:\"id\";s:37:\"paragraph.field_ept_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"d8e5d125-f4f7-4c1d-ac26-f7468f91d3b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9lgsbO7ntDggj0S64_Kj04ysNSAJqsLLVWCg1sASI7o\";}s:2:\"id\";s:37:\"paragraph.field_ept_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow',_binary 'a:17:{s:4:\"uuid\";s:36:\"1a9f268a-efba-464e-854e-f46e7e1341e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNz95cfhiI0VPQ9jlgmyexwx_snf3hcYXB3N76R6FEg\";}s:2:\"id\";s:29:\"paragraph.field_ept_slideshow\";s:10:\"field_name\";s:19:\"field_ept_slideshow\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"08a96db8-eb88-4875-8250-d218a934e839\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j3IfmwQ3lYIJp87Put31sIn-_9bc3uFqZWFLa_w_9hk\";}s:2:\"id\";s:34:\"paragraph.field_ept_slideshow_link\";s:10:\"field_name\";s:24:\"field_ept_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_slide',_binary 'a:17:{s:4:\"uuid\";s:36:\"d704c8d4-b783-49b6-af10-1f4524374151\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qxeflsuOm7AVY0acEDYWC8RbV1WUHCbVdEWrV-i8xCU\";}s:2:\"id\";s:35:\"paragraph.field_ept_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ept_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"8f6db9bb-d214-4b8e-a41e-8e68af02013e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hf7ieZizeOOo0vAYdXIuWovA7ihSiu5RQ6PQD9LV27c\";}s:2:\"id\";s:34:\"paragraph.field_ept_slideshow_text\";s:10:\"field_name\";s:24:\"field_ept_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"c605bbbd-911f-4bca-9f1d-7575ba23063c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tyAlxAEOc2ScLxGA0DPp-lg0u4x8VXHrFuotd44B_SE\";}s:2:\"id\";s:35:\"paragraph.field_ept_slideshow_title\";s:10:\"field_name\";s:25:\"field_ept_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats',_binary 'a:17:{s:4:\"uuid\";s:36:\"54f29aab-0b38-45f1-bef4-33ea7848198c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A2WIvrY8Lq2oUgdXcZ6AeYNUvyM4mmPAuE7W3ZK_2Wc\";}s:2:\"id\";s:25:\"paragraph.field_ept_stats\";s:10:\"field_name\";s:15:\"field_ept_stats\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"32ff7444-1fb2-4c29-97a3-9e9f53ec491a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UoI74uzcaxvNAutge4YEMTgWFuRMeasXrgpq3PK1sVs\";}s:2:\"id\";s:36:\"paragraph.field_ept_stats_item_image\";s:10:\"field_name\";s:26:\"field_ept_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"48fc10e7-9c7a-4b33-8f60-3ce608c713c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r9tIHirJngA0lU8nZzF4zo3Sk3sZoNMDm7tn4Q8f6nU\";}s:2:\"id\";s:35:\"paragraph.field_ept_stats_item_link\";s:10:\"field_name\";s:25:\"field_ept_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"e0b4af62-c275-4029-b2a7-59ffabd9c786\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HhOT5HnntE62swJxbAxEUWcqiYJnPIfz8wawWbRbXDs\";}s:2:\"id\";s:37:\"paragraph.field_ept_stats_item_number\";s:10:\"field_name\";s:27:\"field_ept_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"9bab1d24-d574-48e2-8d0e-4ab68fb47d98\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IMNMgfxAACwo5FdbEzobs2cmUZRx-IryVkWAVFd6jPc\";}s:2:\"id\";s:35:\"paragraph.field_ept_stats_item_text\";s:10:\"field_name\";s:25:\"field_ept_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tabs',_binary 'a:17:{s:4:\"uuid\";s:36:\"79fcf2b8-c7f0-45ad-b0c1-f2032eef3896\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NMqcA7Fqw60GbpdVeUtmztxo2zdXkrGvZx8twbTDDeU\";}s:2:\"id\";s:24:\"paragraph.field_ept_tabs\";s:10:\"field_name\";s:14:\"field_ept_tabs\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"14901660-c7de-459b-8e6b-6065e1894829\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mkRqIh2Wq5dPyqwbNdS4O7366xpiXfnEqoCKO_Dxil8\";}s:2:\"id\";s:29:\"paragraph.field_ept_tab_block\";s:10:\"field_name\";s:19:\"field_ept_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_content',_binary 'a:17:{s:4:\"uuid\";s:36:\"87c56ad4-62d6-4644-86c1-680e4755ff8b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"options\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fKb1I7aWTTDXPpSXxFasd3Do_zu03KEABHYH6l26zZU\";}s:2:\"id\";s:31:\"paragraph.field_ept_tab_content\";s:10:\"field_name\";s:21:\"field_ept_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"list_string\";s:8:\"settings\";a:2:{s:14:\"allowed_values\";a:4:{i:0;a:2:{s:5:\"value\";s:4:\"text\";s:5:\"label\";s:4:\"Text\";}i:1;a:2:{s:5:\"value\";s:4:\"page\";s:5:\"label\";s:4:\"Page\";}i:2;a:2:{s:5:\"value\";s:5:\"block\";s:5:\"label\";s:5:\"Block\";}i:3;a:2:{s:5:\"value\";s:5:\"views\";s:5:\"label\";s:5:\"Views\";}}s:23:\"allowed_values_function\";s:0:\"\";}s:6:\"module\";s:7:\"options\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_page',_binary 'a:17:{s:4:\"uuid\";s:36:\"dd8a6a77-dce1-4167-81fc-78b560cda129\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HG0HGpRQXhX56PVuj3x5C5jDc-vtEneALavRoeN1CvM\";}s:2:\"id\";s:28:\"paragraph.field_ept_tab_page\";s:10:\"field_name\";s:18:\"field_ept_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"node\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"843571d5-1f13-41be-91d6-4a2cdc24036d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-LqQ-u0-ZIOFFNbSXCCLceO2nHJcofY3jorF2Bo_oOs\";}s:2:\"id\";s:28:\"paragraph.field_ept_tab_text\";s:10:\"field_name\";s:18:\"field_ept_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"75781815-4f60-47eb-bdc4-255e273d1add\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jmZoEFoCrYRXWTQoBNH-lk2Jtzlrk1QgYJW-ZwiojjU\";}s:2:\"id\";s:29:\"paragraph.field_ept_tab_title\";s:10:\"field_name\";s:19:\"field_ept_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"text\";s:8:\"settings\";a:1:{s:10:\"max_length\";i:255;}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_views',_binary 'a:17:{s:4:\"uuid\";s:36:\"0210aa9b-f809-485d-9dc9-01d5b19a7a97\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yuhCLkHFy1lOVHdkbi-9gSbiwW6Cz9cKfJdJaYwK_Pk\";}s:2:\"id\";s:29:\"paragraph.field_ept_tab_views\";s:10:\"field_name\";s:19:\"field_ept_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"e76f4c36-a02a-4c1e-b34f-cecbd30657dd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7r3ygKhgvLH2hBQgQ6uizJgLea8q4TUMhKv9AysHhVw\";}s:2:\"id\";s:24:\"paragraph.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad3c2c1b-78c7-400a-a114-8f5a64daf409\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XenLJeS9-3QAxnei6iPwJsGOprgjG7bUCwDd60onVWw\";}s:2:\"id\";s:25:\"paragraph.field_ept_tiles\";s:10:\"field_name\";s:15:\"field_ept_tiles\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"c84089e9-ca27-4ede-81db-501ab243fe10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LTIRUfdCjzSopVuoQqk229l5haSvo7JDJ2W9r1MheDo\";}s:2:\"id\";s:31:\"paragraph.field_ept_tiles_image\";s:10:\"field_name\";s:21:\"field_ept_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"62135f80-efc0-4ec3-883a-ce4ccfe66aaa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ca5c5aWMZPNjvFUQqM813ltjPOGiBvCBP1o5N8IrcOM\";}s:2:\"id\";s:30:\"paragraph.field_ept_tiles_link\";s:10:\"field_name\";s:20:\"field_ept_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"095f6e1d-c38c-4e36-824d-929e502f2c16\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"K1TV7SR5GOPQTJv3GF_zAIsJciKLKB5xd_eo3WUc5HA\";}s:2:\"id\";s:30:\"paragraph.field_ept_tiles_text\";s:10:\"field_name\";s:20:\"field_ept_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"a21fa265-c368-46f8-b0bf-ccd4251290bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fWLTZKbXw0jB-UFCqh6l4jRNvxOPFhGWVUKUjcIHfEg\";}s:2:\"id\";s:31:\"paragraph.field_ept_tiles_title\";s:10:\"field_name\";s:21:\"field_ept_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"d142f67c-eb14-402b-8d63-83e817038f33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjnRL-vwDWFKmoYTCU9jkwjIlui_gNnOJnIwnLo9m2k\";}s:2:\"id\";s:25:\"paragraph.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"30383ff9-015d-4872-a3cb-3c814a4683f6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WUq7ljAeKbQ5WQGxUm1FFT157H56wcSHSihAGR-RPhc\";}s:2:\"id\";s:25:\"paragraph.field_ept_video\";s:10:\"field_name\";s:15:\"field_ept_video\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_videos_and_images',_binary 'a:17:{s:4:\"uuid\";s:36:\"fb3b02a6-684b-4508-8b49-e87fa4e916c1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P8bQebl9F2OCnDtVw7LFuwUlmGfUGA7HLJaYolmUgpU\";}s:2:\"id\";s:37:\"paragraph.field_ept_videos_and_images\";s:10:\"field_name\";s:27:\"field_ept_videos_and_images\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_views_view',_binary 'a:17:{s:4:\"uuid\";s:36:\"8622c9ec-6687-4349-af19-885f22d99285\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GjkDxormsrh0OTX-iAPBLiJLIDg3h8b7yPlpgyt-kM\";}s:2:\"id\";s:30:\"paragraph.field_ept_views_view\";s:10:\"field_name\";s:20:\"field_ept_views_view\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.user.user_picture',_binary 'a:17:{s:4:\"uuid\";s:36:\"233edf85-6a6a-473c-933a-1a6a9015993a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E\";}s:2:\"id\";s:17:\"user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field_ui.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q1nMi90W6YQxKzZAgJQw7Ag9U4JrsEUwkomF0lhvbIM\";}s:12:\"field_prefix\";s:6:\"field_\";}'),('','file.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2bwjZB1IjEYbppgZT3g7YW_5h_LDZYNa3DaDEfWX82U\";}s:11:\"description\";a:2:{s:4:\"type\";s:9:\"textfield\";s:6:\"length\";i:128;}s:4:\"icon\";a:1:{s:9:\"directory\";s:23:\"core/modules/file/icons\";}s:35:\"make_unused_managed_files_temporary\";b:0;s:21:\"filename_sanitization\";a:6:{s:13:\"transliterate\";b:0;s:18:\"replace_whitespace\";b:0;s:24:\"replace_non_alphanumeric\";b:0;s:22:\"deduplicate_separators\";b:0;s:9:\"lowercase\";b:0;s:21:\"replacement_character\";s:1:\"-\";}}'),('','file_mdm.file_metadata_plugin.getimagesize',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o53U_2I-21Es-9iqxeUMDRcRxN0spL1OiHuAVQhh2oI\";}s:13:\"configuration\";a:1:{s:5:\"cache\";a:2:{s:8:\"override\";b:0;s:8:\"settings\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}}}}'),('','file_mdm.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fOx6TBj_84WfX_a6JhuWiPQ-twAjHykvYsTvJAKbZsE\";}s:14:\"metadata_cache\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}s:22:\"missing_file_log_level\";i:3;}'),('','file_mdm_exif.file_metadata_plugin.exif',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u0ZqkNrnyVSnHXGBP0zlKY9dP1ZARzJZ9VSovzU_eDg\";}s:7:\"ifd_map\";a:5:{i:0;a:2:{s:4:\"type\";i:0;s:7:\"aliases\";a:3:{i:0;s:1:\"0\";i:1;s:4:\"IFD0\";i:2;s:4:\"Main\";}}i:1;a:2:{s:4:\"type\";i:1;s:7:\"aliases\";a:3:{i:0;s:1:\"1\";i:1;s:4:\"IFD1\";i:2;s:9:\"Thumbnail\";}}s:4:\"Exif\";a:2:{s:4:\"type\";i:2;s:7:\"aliases\";a:1:{i:0;s:4:\"Exif\";}}s:3:\"GPS\";a:2:{s:4:\"type\";i:3;s:7:\"aliases\";a:1:{i:0;s:3:\"GPS\";}}s:16:\"Interoperability\";a:2:{s:4:\"type\";i:4;s:7:\"aliases\";a:2:{i:0;s:16:\"Interoperability\";i:1;s:7:\"Interop\";}}}s:13:\"configuration\";a:1:{s:5:\"cache\";a:2:{s:8:\"override\";b:0;s:8:\"settings\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}}}}'),('','file_mdm_font.file_metadata_plugin.font',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o53U_2I-21Es-9iqxeUMDRcRxN0spL1OiHuAVQhh2oI\";}s:13:\"configuration\";a:1:{s:5:\"cache\";a:2:{s:8:\"override\";b:0;s:8:\"settings\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}}}}'),('','filter.format.basic_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"9ffd8de5-5d95-4675-941e-b6205d96c828\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:6:\"editor\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mclCbTlJwWJORez4Y1eX2MqA0aGjSMAoJb3TaBABcK8\";}s:4:\"name\";s:10:\"Basic HTML\";s:6:\"format\";s:10:\"basic_html\";s:6:\"weight\";i:-9;s:7:\"filters\";a:6:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:7;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:243:\"<br> <p> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id> <cite> <dl> <dt> <dd> <a hreflang href> <blockquote cite> <ul type> <ol start type> <strong> <em> <code> <li> <img src alt data-entity-uuid data-entity-type height width data-caption data-align>\";s:16:\"filter_html_help\";b:0;s:20:\"filter_html_nofollow\";b:0;}}s:24:\"filter_html_image_secure\";a:5:{s:2:\"id\";s:24:\"filter_html_image_secure\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}}}'),('','filter.format.full_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"5837f230-16d1-4857-8f42-39560aa7f6bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:32:\"core.entity_view_mode.media.full\";}s:6:\"module\";a:2:{i:0;s:6:\"editor\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpZysv3RHJjhYzq7O_q5q8mVlHdrSzKELmXyiX6RtV0\";}s:4:\"name\";s:9:\"Full HTML\";s:6:\"format\";s:9:\"full_html\";s:6:\"weight\";i:-10;s:7:\"filters\";a:7:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:0;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:38:\"<span class=\"title-prefix white-text\">\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:20:\"filter_htmlcorrector\";a:5:{s:2:\"id\";s:20:\"filter_htmlcorrector\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:10;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}s:11:\"media_embed\";a:5:{s:2:\"id\";s:11:\"media_embed\";s:8:\"provider\";s:5:\"media\";s:6:\"status\";b:1;s:6:\"weight\";i:100;s:8:\"settings\";a:3:{s:17:\"default_view_mode\";s:7:\"default\";s:18:\"allowed_view_modes\";a:2:{s:7:\"default\";s:7:\"default\";s:4:\"full\";s:4:\"full\";}s:19:\"allowed_media_types\";a:3:{s:5:\"image\";s:5:\"image\";s:12:\"remote_video\";s:12:\"remote_video\";s:5:\"video\";s:5:\"video\";}}}}}'),('','filter.format.plain_text',_binary 'a:9:{s:4:\"uuid\";s:36:\"e7b49ea5-e3d9-43a7-9355-811016606856\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JLMwODO0epnA_H-jFlH9ezVfa5YBJniRv3MmLqYNl_Q\";}s:4:\"name\";s:10:\"Plain text\";s:6:\"format\";s:10:\"plain_text\";s:6:\"weight\";i:-7;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:18:\"filter_html_escape\";a:5:{s:2:\"id\";s:18:\"filter_html_escape\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:0:{}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),('','filter.format.restricted_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"b26630f8-bc66-410b-9271-2fd35673a39c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QiKqQS_YGAT3Qr4vaAgZICJknm-MGCzt_xBAMqg-tRM\";}s:4:\"name\";s:15:\"Restricted HTML\";s:6:\"format\";s:15:\"restricted_html\";s:6:\"weight\";i:-8;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:149:\"<a href hreflang> <em> <strong> <cite> <blockquote cite> <code> <ul type> <ol start type> <li> <dl> <dt> <dd> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id>\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),('','filter.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FiPjM3WdB__ruFA7B6TLwni_UcZbmek5G4b2dxQItxA\";}s:15:\"fallback_format\";s:10:\"plain_text\";s:27:\"always_show_fallback_choice\";b:0;}'),('','gin.settings',_binary 'a:17:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ug4-rUG_KE9H5v1RaDLLpkSZsu70E9HnJp6sqFfjvHk\";}s:7:\"favicon\";a:1:{s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:1;}s:4:\"logo\";a:1:{s:11:\"use_default\";b:1;}s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}s:19:\"preset_accent_color\";s:4:\"blue\";s:18:\"preset_focus_color\";s:3:\"gin\";s:15:\"enable_darkmode\";s:1:\"0\";s:15:\"classic_toolbar\";s:7:\"classic\";s:26:\"secondary_toolbar_frontend\";b:1;s:18:\"high_contrast_mode\";b:0;s:12:\"accent_color\";s:0:\"\";s:11:\"focus_color\";s:0:\"\";s:14:\"layout_density\";s:7:\"default\";s:23:\"show_description_toggle\";b:0;s:24:\"show_user_theme_settings\";b:0;s:21:\"sticky_action_buttons\";b:0;}'),('','glightbox.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5G059LQS_7DV7oGUpxVTPM0aWtunW7bvDpRkgeb0KtE\";}s:6:\"custom\";a:17:{s:8:\"activate\";i:0;s:11:\"open_effect\";s:4:\"zoom\";s:12:\"close_effect\";s:4:\"zoom\";s:12:\"slide_effect\";s:5:\"slide\";s:5:\"width\";s:3:\"98%\";s:6:\"height\";s:3:\"98%\";s:11:\"videosWidth\";s:5:\"960px\";s:22:\"close_on_outside_click\";b:1;s:9:\"more_text\";s:8:\"See more\";s:11:\"more_length\";i:60;s:13:\"desc_position\";s:6:\"bottom\";s:4:\"loop\";b:0;s:8:\"zoomable\";b:1;s:9:\"draggable\";b:1;s:7:\"preload\";b:1;s:15:\"autoplay_videos\";b:1;s:16:\"autofocus_videos\";b:0;}s:8:\"advanced\";a:2:{s:12:\"unique_token\";i:0;s:16:\"compression_type\";s:8:\"minified\";}}'),('','image.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-yDFHbqNfpe-Srg4sdCSqaosCl2D8uwyEY5esF8gEw\";}s:13:\"preview_image\";s:29:\"core/modules/image/sample.png\";s:26:\"allow_insecure_derivatives\";b:0;s:20:\"suppress_itok_output\";b:0;}'),('','image.style.ept_gallery_image',_binary 'a:8:{s:4:\"uuid\";s:36:\"96327273-04cd-4db7-9889-976db88ae72b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"image_effects\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1Q9XGhzUPbe1wp53fxzN8EbXYFVVXfNTiWQshZB1x-o\";}s:4:\"name\";s:17:\"ept_gallery_image\";s:5:\"label\";s:17:\"EPT Gallery Image\";s:7:\"effects\";a:2:{s:36:\"5a3cbdd5-32d1-49cd-a00f-bbc716cc09ef\";a:4:{s:4:\"uuid\";s:36:\"5a3cbdd5-32d1-49cd-a00f-bbc716cc09ef\";s:2:\"id\";s:24:\"image_effects_set_canvas\";s:6:\"weight\";i:-8;s:4:\"data\";a:4:{s:11:\"canvas_size\";s:5:\"exact\";s:12:\"canvas_color\";s:9:\"#FFFFFFFF\";s:5:\"exact\";a:5:{s:5:\"width\";s:3:\"365\";s:6:\"height\";s:3:\"265\";s:9:\"placement\";s:13:\"center-center\";s:8:\"x_offset\";i:0;s:8:\"y_offset\";i:0;}s:8:\"relative\";a:4:{s:4:\"left\";i:0;s:5:\"right\";i:0;s:3:\"top\";i:0;s:6:\"bottom\";i:0;}}}s:36:\"7237f375-b695-4dca-8e1a-88b52b0437ea\";a:4:{s:4:\"uuid\";s:36:\"7237f375-b695-4dca-8e1a-88b52b0437ea\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:-9;s:4:\"data\";a:3:{s:5:\"width\";i:365;s:6:\"height\";i:265;s:7:\"upscale\";b:0;}}}}'),('','image.style.ept_quote_image',_binary 'a:8:{s:4:\"uuid\";s:36:\"8ad0f8e1-bf91-4861-b98d-bd4757ce19fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"R8OkUD1v3lvqA1ihlprDbuQcs3MJp_s2N37cfrJuul8\";}s:4:\"name\";s:15:\"ept_quote_image\";s:5:\"label\";s:15:\"EPT Quote Image\";s:7:\"effects\";a:1:{s:36:\"c7e1a3e5-c5e1-4f6b-92f2-525a6f9ca013\";a:4:{s:4:\"uuid\";s:36:\"c7e1a3e5-c5e1-4f6b-92f2-525a6f9ca013\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:530;s:6:\"height\";N;s:7:\"upscale\";b:1;}}}}'),('','image.style.ept_slick_slider_card',_binary 'a:8:{s:4:\"uuid\";s:36:\"d5e3c8ee-d135-4d9b-87f8-3983d8804dd0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TLssjGEnnOFSTHjAehxDElobDdWsdzT8XjjY2Ru_ZTQ\";}s:4:\"name\";s:21:\"ept_slick_slider_card\";s:5:\"label\";s:21:\"EPT Slick Slider card\";s:7:\"effects\";a:1:{s:36:\"55a5d05a-911b-44f6-8154-26bf4d5f89a2\";a:4:{s:4:\"uuid\";s:36:\"55a5d05a-911b-44f6-8154-26bf4d5f89a2\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:400;s:6:\"height\";i:300;s:6:\"anchor\";s:13:\"center-center\";}}}}'),('','image.style.ept_video_and_image_gallery',_binary 'a:8:{s:4:\"uuid\";s:36:\"c7167138-d49d-4235-8671-ee7f0d2d2b21\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VijhP4To3EdFocRuOjCdr8vV8fPomTYloLASZEYa0pc\";}s:4:\"name\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:27:\"EPT Video and Image gallery\";s:7:\"effects\";a:1:{s:36:\"dd219b2f-d95b-480c-83e9-b9b81fe45c90\";a:4:{s:4:\"uuid\";s:36:\"dd219b2f-d95b-480c-83e9-b9b81fe45c90\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:360;s:6:\"anchor\";s:13:\"center-center\";}}}}'),('','image.style.large',_binary 'a:8:{s:4:\"uuid\";s:36:\"1d081002-40ce-4508-b331-45087f55f851\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rDR2BOewa2UFH9yG4tVvrGxEVv8U7LQo-RLkJhFpERs\";}s:4:\"name\";s:5:\"large\";s:5:\"label\";s:16:\"Large (480×480)\";s:7:\"effects\";a:2:{s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";a:4:{s:4:\"uuid\";s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:480;s:7:\"upscale\";b:0;}}s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";a:4:{s:4:\"uuid\";s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.media_library',_binary 'a:8:{s:4:\"uuid\";s:36:\"dce163df-e6d0-4a19-be9f-835d8fb9ad19\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FxMdscEA4aDH0KPM73HIZtVn3zIAgC1kQ3CkBw26HYs\";}s:4:\"name\";s:13:\"media_library\";s:5:\"label\";s:34:\"Media Library thumbnail (220×220)\";s:7:\"effects\";a:2:{s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";a:4:{s:4:\"uuid\";s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";a:4:{s:4:\"uuid\";s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.medium',_binary 'a:8:{s:4:\"uuid\";s:36:\"cc99d86c-9cb9-4913-9000-8ea5ef978940\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dlar76VBuGj5iMGTruB_uMZX8VbivXt9_QLemaG2q4E\";}s:4:\"name\";s:6:\"medium\";s:5:\"label\";s:17:\"Medium (220×220)\";s:7:\"effects\";a:2:{s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";a:4:{s:4:\"uuid\";s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";a:4:{s:4:\"uuid\";s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.thumbnail',_binary 'a:8:{s:4:\"uuid\";s:36:\"45c23df0-c353-4723-86c7-ddfc29333553\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BgeBV-xOFINMsz-y2thm45EGesj6bRM6DTLZ6ce3V9I\";}s:4:\"name\";s:9:\"thumbnail\";s:5:\"label\";s:20:\"Thumbnail (100×100)\";s:7:\"effects\";a:2:{s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";a:4:{s:4:\"uuid\";s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:100;s:6:\"height\";i:100;s:7:\"upscale\";b:0;}}s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";a:4:{s:4:\"uuid\";s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.wide',_binary 'a:8:{s:4:\"uuid\";s:36:\"7407b366-d102-42ad-8d9b-28fc84ce386e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XHh3ATMH7z4ljwmzdndM47qNMkgLnoYsP98rGxVgCOw\";}s:4:\"name\";s:4:\"wide\";s:5:\"label\";s:11:\"Wide (1090)\";s:7:\"effects\";a:2:{s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";a:4:{s:4:\"uuid\";s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:1090;s:6:\"height\";N;s:7:\"upscale\";b:0;}}s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";a:4:{s:4:\"uuid\";s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image_effects.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eaXmaPSud65p-XhTwMIL9vKETD9zR3qNOMMa5EUuoNw\";}s:14:\"color_selector\";a:2:{s:9:\"plugin_id\";s:10:\"html_color\";s:15:\"plugin_settings\";a:1:{s:10:\"html_color\";a:0:{}}}s:14:\"image_selector\";a:2:{s:9:\"plugin_id\";s:5:\"basic\";s:15:\"plugin_settings\";a:1:{s:5:\"basic\";a:0:{}}}s:13:\"font_selector\";a:2:{s:9:\"plugin_id\";s:5:\"basic\";s:15:\"plugin_settings\";a:1:{s:5:\"basic\";a:0:{}}}}'),('','layout_paragraphs.modal_settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z9zmTNfo1bY0sbqYp1OAvqSynu_DXDRdJoZhi7oiS0I\";}s:5:\"width\";s:3:\"90%\";s:6:\"height\";s:4:\"auto\";s:10:\"autoresize\";b:1;}'),('','layout_paragraphs.settings',_binary 'a:6:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HBy2Jf-2HHsgvIjldhAl07r9vuy879dsx6Cm_LpbPrw\";}s:21:\"show_paragraph_labels\";i:0;s:18:\"show_layout_labels\";i:0;s:25:\"paragraph_behaviors_label\";s:9:\"Behaviors\";s:28:\"paragraph_behaviors_position\";i:-99;s:13:\"empty_message\";s:21:\"No components to add.\";}'),('','media.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WCFqLQAxMw1weToDJEhfnW1Z-iOF7cqMdL8X7YTFxBA\";}s:13:\"icon_base_uri\";s:28:\"public://media-icons/generic\";s:13:\"iframe_domain\";N;s:20:\"oembed_providers_url\";s:33:\"https://oembed.com/providers.json\";s:14:\"standalone_url\";b:0;}'),('','media.type.audio',_binary 'a:13:{s:4:\"uuid\";s:36:\"6a011382-b41c-428b-bec3-c2acb1a0b347\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJw8n6Tk2tO3ZysuEeGR1gZa1yRffaZzR4t0Q7iNurs\";}s:2:\"id\";s:5:\"audio\";s:5:\"label\";s:5:\"Audio\";s:11:\"description\";s:28:\"A locally hosted audio file.\";s:6:\"source\";s:10:\"audio_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_audio_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media.type.document',_binary 'a:13:{s:4:\"uuid\";s:36:\"f7d4d4ed-07f1-4c0e-add0-5205dca6bb2d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_D9q3XSnP6ik9we9UuoTvZsQKPuYNp_G9PfwVtWzgnQ\";}s:2:\"id\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:44:\"An uploaded file or document, such as a PDF.\";s:6:\"source\";s:4:\"file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:20:\"field_media_document\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media.type.image',_binary 'a:13:{s:4:\"uuid\";s:36:\"0bf0a6ff-42d0-4443-95d9-32bb21b3d878\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6Qope5wG7HUpV0tPOBMtDI_GZkHFcF1Xj4hgD9Cu_hM\";}s:2:\"id\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:36:\"Use local images for reusable media.\";s:6:\"source\";s:5:\"image\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:17:\"field_media_image\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media.type.remote_video',_binary 'a:13:{s:4:\"uuid\";s:36:\"d833ee62-0e66-41f9-bc64-0ee184be48b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hIBTnDGgDKnCiP6HUZm1m7600DHUEpC6FN3LQ4sUgZ4\";}s:2:\"id\";s:12:\"remote_video\";s:5:\"label\";s:12:\"Remote video\";s:11:\"description\";s:46:\"A remotely hosted video from YouTube or Vimeo.\";s:6:\"source\";s:12:\"oembed:video\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:3:{s:12:\"source_field\";s:24:\"field_media_oembed_video\";s:20:\"thumbnails_directory\";s:44:\"public://oembed_thumbnails/[date:custom:Y-m]\";s:9:\"providers\";a:2:{i:0;s:7:\"YouTube\";i:1;s:5:\"Vimeo\";}}s:9:\"field_map\";a:1:{s:5:\"title\";s:4:\"name\";}}'),('','media.type.video',_binary 'a:13:{s:4:\"uuid\";s:36:\"f37b6fcf-a1f5-41c8-ad6b-ab36d7822130\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hzgvcRgZHltqWf8hBmttoWh95tCJoPL25lPq9YSIRsY\";}s:2:\"id\";s:5:\"video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:28:\"A locally hosted video file.\";s:6:\"source\";s:10:\"video_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_video_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media_library.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_3gQsCnZELUjUUqHk8SSh8bXnx7TZwN95vctAeVJG60\";}s:11:\"advanced_ui\";b:0;}'),('','menu_ui.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SqMarzIjxC3F8dZo9FEOxfqDKD_sdW1tbcFTV1BA2zU\";}s:24:\"override_parent_selector\";b:0;}'),('','node.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W0cgFPhPJ3gAdqm06-az48BLf5MVcoZVS0HdByoofi0\";}s:15:\"use_admin_theme\";b:1;}'),('','node.type.article',_binary 'a:13:{s:4:\"uuid\";s:36:\"9597cbd8-ec71-47b6-98f5-c2eeebffff0e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"menu_ui\";}}s:20:\"third_party_settings\";a:1:{s:7:\"menu_ui\";a:2:{s:15:\"available_menus\";a:1:{i:0;s:4:\"main\";}s:6:\"parent\";s:5:\"main:\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Fe3N1uqaAyyKJbVkqT-btXy3t98puW8GCRD822xjl10\";}s:4:\"name\";s:7:\"Article\";s:4:\"type\";s:7:\"article\";s:11:\"description\";s:89:\"Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:0;}'),('','node.type.page',_binary 'a:12:{s:4:\"uuid\";s:36:\"e24a8178-cabf-4c12-8439-99829f4ce10e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"i0snV8Wj--OkRW12UdachUiYiz3FbeMwHu_pZYfzKLc\";}s:4:\"name\";s:10:\"Basic page\";s:4:\"type\";s:4:\"page\";s:11:\"description\";s:77:\"Use <em>basic pages</em> for your static content, such as an \'About us\' page.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:0;}'),('','olivero.settings',_binary 'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1TswGK46jyu77aIM7Z-0JVQs5bxHmo-gtgrvrQGMXxc\";}s:7:\"favicon\";a:1:{s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:0;}s:4:\"logo\";a:1:{s:11:\"use_default\";b:0;}s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}s:22:\"mobile_menu_all_widths\";i:0;s:22:\"site_branding_bg_color\";s:7:\"default\";s:18:\"base_primary_color\";s:7:\"#1b9ae4\";}'),('','paragraphs.paragraphs_type.ept_accordion',_binary 'a:11:{s:4:\"uuid\";s:36:\"3252260c-9d6c-4095-8836-d9e0aaa25dc6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7pqqqPfYwBkkvx32K8x5QoezX6vxHdseC3YV0ajDLEI\";}s:2:\"id\";s:13:\"ept_accordion\";s:5:\"label\";s:17:\"EPT Accordion/FAQ\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:41:\"Extra Paragraph Type (EPT): Accordion/FAQ\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_accordion_section',_binary 'a:11:{s:4:\"uuid\";s:36:\"4290efa9-ba8f-4d75-8ae5-02743a3c35f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fmkcpDXAJK73b4nzzBnj4rVGpuHiDLrUxBK6rbvbQMY\";}s:2:\"id\";s:21:\"ept_accordion_section\";s:5:\"label\";s:35:\"EPT Accordion section / FAQ section\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:46:\"Accordion or FAQ section for EPT Accordion/FAQ\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_basic_button',_binary 'a:11:{s:4:\"uuid\";s:36:\"29db5768-3c25-444b-84f5-1a0ab0ba6377\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gzUQpZ2WLaq6cYbIJG9au02yBTA2Hi4xUPtwlz0CRhU\";}s:2:\"id\";s:16:\"ept_basic_button\";s:5:\"label\";s:16:\"EPT Basic Button\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:39:\"Extra Paragraph Type (EPT) Basic Button\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_block',_binary 'a:11:{s:4:\"uuid\";s:36:\"698fe7c4-0789-4365-b3ce-d8bbd2d7d879\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hSup62OW-6glALkcPyijfub_HXz0FNzEQuWRhyhtdXk\";}s:2:\"id\";s:9:\"ept_block\";s:5:\"label\";s:9:\"EPT Block\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Block\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_bootstrap_button',_binary 'a:11:{s:4:\"uuid\";s:36:\"ffeadf94-a846-4eeb-af7e-504e5b867d19\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4txRVN0PevwIGZwVEjxCxQoHq3fJGXNtgncbg5k5JDA\";}s:2:\"id\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:20:\"EPT Bootstrap Button\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:44:\"Extra Paragraph Type (EPT): Bootstrap Button\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_carousel',_binary 'a:11:{s:4:\"uuid\";s:36:\"0f8caf80-346b-4e13-bb09-4c47aafab045\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"E7xdcbl_-Um-sC9AVRpej77V2ILldHA3_zXTVVCz1sY\";}s:2:\"id\";s:12:\"ept_carousel\";s:5:\"label\";s:12:\"EPT Carousel\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:36:\"Extra Paragraph Type (EPT): Carousel\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_carousel_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"07a0dbc7-10e5-4ae6-897e-e0a112e89e81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YtKbftJ20RlhAbMlxwbbttKpDr7oOd_NrNquqRUyXK8\";}s:2:\"id\";s:17:\"ept_carousel_item\";s:5:\"label\";s:17:\"EPT Carousel Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:30:\"Carousel item for EPT Carousel\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_columns',_binary 'a:11:{s:4:\"uuid\";s:36:\"e359103e-fb7d-4814-b51e-5b6eb0bf50cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fmkytBjjMOfcRpE_qi-piB3B8O6AiLkllwZyK_sI7Gw\";}s:2:\"id\";s:11:\"ept_columns\";s:5:\"label\";s:23:\"EPT Columns / Container\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:48:\"Extra Paragraph Types (EPT): Columns / Container\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_countdown',_binary 'a:11:{s:4:\"uuid\";s:36:\"d468b305-ccc4-4dd1-827a-5ac37883f188\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BqPVlvdHbcXEIez6BBufo--6hdhOwAkO8rjIkAK5jq4\";}s:2:\"id\";s:13:\"ept_countdown\";s:5:\"label\";s:13:\"EPT Countdown\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:37:\"Extra Paragraph Type (EPT): Countdown\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_counter',_binary 'a:11:{s:4:\"uuid\";s:36:\"fb9a64bf-58bb-4e29-a23f-83bc70d9958c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Seed1ZP-O7N7haFpWM63DgrcW90m0L3mwRpNqOVCvms\";}s:2:\"id\";s:11:\"ept_counter\";s:5:\"label\";s:11:\"EPT Counter\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:66:\"Adds Counter with coffee cups, projects, case studies number, etc.\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_counter_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"8fca0905-ad07-4e5a-b80e-a842bece8ab5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1DUe53zhmyI3hSvz4PGQ9EcXk8A47wdqyIrDi3aJmo8\";}s:2:\"id\";s:16:\"ept_counter_item\";s:5:\"label\";s:16:\"EPT Counter Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:64:\"Counter Items to be used inside of Paragraph Type: \"EPT Counter\"\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_cta',_binary 'a:11:{s:4:\"uuid\";s:36:\"5a3625a2-f528-429b-8415-b0b1eface1d4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-6Ujd6Cr-x8TD472fJ9SX66k2Pn7_uw07fVQWq1DXQk\";}s:2:\"id\";s:7:\"ept_cta\";s:5:\"label\";s:24:\"EPT Call to Action (CTA)\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:48:\"Extra Paragraph Type (EPT): Call to Action (CTA)\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_hero',_binary 'a:11:{s:4:\"uuid\";s:36:\"ced6180f-b154-47b8-a7b7-61647c71db48\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kps1UJbRPEF2GuSjDQDJFWWG5EZ6qTHII92BJxLlwTk\";}s:2:\"id\";s:8:\"ept_hero\";s:5:\"label\";s:8:\"EPT Hero\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:36:\"Extra Paragraph Type (EPT): EPT Hero\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_image',_binary 'a:11:{s:4:\"uuid\";s:36:\"f1d6ed2b-6a40-4f21-930f-5cd318945855\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GEIZEGHO5Mf_kO9Yek21HvRO-j_2fbPepBSsr35U_zY\";}s:2:\"id\";s:9:\"ept_image\";s:5:\"label\";s:9:\"EPT Image\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Image\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_image_gallery',_binary 'a:11:{s:4:\"uuid\";s:36:\"ec405efa-b146-4a07-abc8-d507909706f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fQ2CW1Vm9f_8Xi0V4exsAGpv8RdV6Ptm-cjffg9lPyM\";}s:2:\"id\";s:17:\"ept_image_gallery\";s:5:\"label\";s:17:\"EPT Image Gallery\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:41:\"Extra Paragraph Type (EPT): Image Gallery\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_micromodal',_binary 'a:11:{s:4:\"uuid\";s:36:\"3188911c-48a1-42f6-8342-f2b8eb94edff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OvFmHRYOT8js98yougS_zy_ICFqOce54ziNcxoCbTq8\";}s:2:\"id\";s:14:\"ept_micromodal\";s:5:\"label\";s:14:\"EPT Micromodal\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:38:\"Extra Paragraph Type (EPT): Micromodal\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_quote',_binary 'a:11:{s:4:\"uuid\";s:36:\"e7cc4707-218e-4bb9-bcbe-65d47620375d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zd4SMxSGtEMXFqSse2TdY999VhcjYnraQj7qnFhHo6Q\";}s:2:\"id\";s:9:\"ept_quote\";s:5:\"label\";s:9:\"EPT Quote\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Quote\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slick_slider',_binary 'a:11:{s:4:\"uuid\";s:36:\"d1c90790-b1df-488f-a53e-bc8c9bbe2e9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kF1ktW9usSGMpm4KK6xObCSXk1ZU-mWLNc7N1B5IN3A\";}s:2:\"id\";s:16:\"ept_slick_slider\";s:5:\"label\";s:16:\"EPT Slick Slider\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:40:\"Extra Paragraph Type (EPT): Slick Slider\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slick_slider_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"41cd1373-cca3-46dc-87a0-714c7a1489bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JzEHRSTeS_5k9aQaMIQiZssckNv0akkT0UHkl8qu8TE\";}s:2:\"id\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:21:\"EPT Slick Slider Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:0:\"\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slideshow',_binary 'a:11:{s:4:\"uuid\";s:36:\"b702ec4e-c33c-4331-beff-6b5b7107cc9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KeaY7LvgW90UqWSbJG60DfX1q0Up4566bgG8p85U12U\";}s:2:\"id\";s:13:\"ept_slideshow\";s:5:\"label\";s:13:\"EPT Slideshow\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:37:\"Extra Paragraph Type (EPT): Slideshow\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slideshow_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"9953b7d8-252b-4d78-9b63-08418e206990\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yz4xVMckzLbuIuqcq5CLDr2LZyc6GPHhiCkw_ygR1cM\";}s:2:\"id\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:18:\"EPT Slideshow Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:35:\"Slideshow section for EPT Slideshow\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_stats',_binary 'a:11:{s:4:\"uuid\";s:36:\"6838ec7f-c8a4-4325-97a7-1021f1dfe5d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KAQ05Ri6j17FmntgY7SCHOgGFRtUqdJWrNKlBxVsBsI\";}s:2:\"id\";s:9:\"ept_stats\";s:5:\"label\";s:9:\"EPT Stats\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Stats\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_stats_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"1f202608-b028-44b4-99c0-312ebcadcb47\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Be2-EmGyo2-KDBpxotaDl8GmJCgv5EKdsZNMXdWrM10\";}s:2:\"id\";s:14:\"ept_stats_item\";s:5:\"label\";s:14:\"EPT Stats Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:34:\"Stats Item for EPT Stats paragraph\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tabs',_binary 'a:11:{s:4:\"uuid\";s:36:\"d64be736-43ad-47c5-a174-0a5e19f4b24a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zt6Y01DpCpOfI3LIolOc9xk6SptdAkHJlZkEp2KhkRQ\";}s:2:\"id\";s:8:\"ept_tabs\";s:5:\"label\";s:8:\"EPT Tabs\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:32:\"Extra Paragraph Type (EPT): Tabs\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tabs_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"9e15e91a-5c5e-4c79-9e75-1386629a7208\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VixuGFI2mBIwt085I9X7vz9dq9H8dh0Bb20u-pT90X8\";}s:2:\"id\";s:13:\"ept_tabs_item\";s:5:\"label\";s:13:\"EPT Tabs Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:31:\"Tab item for EPT Tabs paragraph\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_text',_binary 'a:11:{s:4:\"uuid\";s:36:\"c76a9833-ec98-4fe9-9268-c55ecc6606f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fSKAEY0p1DQvC6AE_TEi0RWHmjahL13tHQTb3WVaVik\";}s:2:\"id\";s:8:\"ept_text\";s:5:\"label\";s:8:\"EPT Text\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:31:\"Extra Paragraph Type (EPT) Text\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tiles',_binary 'a:11:{s:4:\"uuid\";s:36:\"e1accd8b-a614-4659-8cf0-f0563effdfeb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AHyDurvHt3xm3keCp8kZSod4iM7Y1JlF1O0xivGQ7As\";}s:2:\"id\";s:9:\"ept_tiles\";s:5:\"label\";s:9:\"EPT Tiles\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Tiles\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tiles_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"ae747fa8-05f4-441a-92bd-76441012dd9b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q4wQLWgQpxsrvWKawlFVZnqSn8qCCPj4IOKPpn7O8Po\";}s:2:\"id\";s:14:\"ept_tiles_item\";s:5:\"label\";s:14:\"EPT Tiles Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:21:\"Section for EPT Tiles\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_video',_binary 'a:11:{s:4:\"uuid\";s:36:\"e50ad18b-eff8-48a4-9102-1709c8e0bb40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FU0WTLBDpLuC53lMEuAJGnwlX6sqt0SutW7q0c-btWQ\";}s:2:\"id\";s:9:\"ept_video\";s:5:\"label\";s:9:\"EPT Video\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Video\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_video_and_image_gallery',_binary 'a:11:{s:4:\"uuid\";s:36:\"dee3b2de-c5f8-4d3f-8564-0f6f24943f59\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z1YuWpAuPdJe7k9v-67rALbAapgyfzwTi2cQLvreLbo\";}s:2:\"id\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:27:\"EPT Video and Image Gallery\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:51:\"Extra Paragraph Type (EPT): Video and Image Gallery\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_video_and_image_gallery_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"1a4319ac-f841-4112-85c5-2a1ab06cb4d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OrMDgoP5KHK7xLNhKOohBVVuqmo2J4D3YWH3a3Od1Dw\";}s:2:\"id\";s:32:\"ept_video_and_image_gallery_item\";s:5:\"label\";s:32:\"EPT Video and Image gallery item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:62:\"Video and Image item for EPT Video and Image Gallery paragraph\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_views',_binary 'a:11:{s:4:\"uuid\";s:36:\"7ac88ec9-7da9-488c-ac70-492b5bcfde08\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JfY6zZuA9cpemb4U-YVMX2rzmT1pm_Pr1YpT7xaSxeA\";}s:2:\"id\";s:9:\"ept_views\";s:5:\"label\";s:9:\"EPT Views\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Views\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7eR0sk71Eol86r_A7BMqn5_46wzenh5J1O5vZRCGKv8\";}s:16:\"show_unpublished\";b:1;}'),('','search.page.help_search',_binary 'a:11:{s:4:\"uuid\";s:36:\"98a9a1a8-dfbe-4b36-a295-131fa324015e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RZ-bcSekNSsAbIPLW7Gmyd3uUjIOSrPvnb8RCCZYJm8\";}s:2:\"id\";s:11:\"help_search\";s:5:\"label\";s:4:\"Help\";s:4:\"path\";s:4:\"help\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"help_search\";s:13:\"configuration\";a:0:{}}'),('','search.page.node_search',_binary 'a:11:{s:4:\"uuid\";s:36:\"be4dce05-236d-43ce-aa4d-b829b5c9d8a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"97tvtzGOa8_flb22CzSjgtm_YkiGMHvEBO-6q2K9V_U\";}s:2:\"id\";s:11:\"node_search\";s:5:\"label\";s:7:\"Content\";s:4:\"path\";s:4:\"node\";s:6:\"weight\";i:-10;s:6:\"plugin\";s:11:\"node_search\";s:13:\"configuration\";a:1:{s:8:\"rankings\";a:0:{}}}'),('','search.page.user_search',_binary 'a:11:{s:4:\"uuid\";s:36:\"02f73622-4ae8-479b-bddb-6b507d943c7b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k3aUaZXGDuhkek2TZIee0PApOPTvYZLadziekdyHA5A\";}s:2:\"id\";s:11:\"user_search\";s:5:\"label\";s:5:\"Users\";s:4:\"path\";s:4:\"user\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"user_search\";s:13:\"configuration\";a:0:{}}'),('','search.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hvVxL1G-ZCxaq32IZws0YsfuhvaDiQE_np-0g35KjUk\";}s:12:\"and_or_limit\";i:7;s:12:\"default_page\";s:11:\"node_search\";s:5:\"index\";a:4:{s:10:\"cron_limit\";i:100;s:11:\"overlap_cjk\";b:1;s:17:\"minimum_word_size\";i:3;s:11:\"tag_weights\";a:12:{s:2:\"h1\";i:25;s:2:\"h2\";i:18;s:2:\"h3\";i:15;s:2:\"h4\";i:14;s:2:\"h5\";i:9;s:2:\"h6\";i:6;s:1:\"u\";i:3;s:1:\"b\";i:3;s:1:\"i\";i:3;s:6:\"strong\";i:3;s:2:\"em\";i:3;s:1:\"a\";i:10;}}s:7:\"logging\";b:0;}'),('','shortcut.set.default',_binary 'a:7:{s:4:\"uuid\";s:36:\"2b149d5c-a926-4de8-aae7-b7f45081ccab\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U5VlGjd_SfV0Qm_EfnaynOfc549cNscFAx48JfYoMRI\";}s:2:\"id\";s:7:\"default\";s:5:\"label\";s:7:\"Default\";}'),('','system.action.comment_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"6f753574-2b6f-4e3a-87fd-04f281182309\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpBH8OmL4sdesCdeZLsW8KOutB5gkbreWJbfjhfFKaQ\";}s:2:\"id\";s:21:\"comment_delete_action\";s:5:\"label\";s:14:\"Delete comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:28:\"entity:delete_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"c8e0fba3-a9ea-40bc-9886-42d52bf69615\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C00dyL_W_5M0nFlgUB3lWUTUs96jn51Jw1MLHVEHZD0\";}s:2:\"id\";s:22:\"comment_publish_action\";s:5:\"label\";s:15:\"Publish comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:29:\"entity:publish_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f2a7400a-fd44-4225-906e-c04f6f5f8944\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lfyE_snmvfg_EQ3VDyhUtGAXgmqtEiqa46I3bTMg8DU\";}s:2:\"id\";s:19:\"comment_save_action\";s:5:\"label\";s:12:\"Save comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:26:\"entity:save_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"a09349ec-38d9-4ee0-b772-074a9b406491\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tWOIjSMobEWOFZddMkNqb9JySbOVwE1diC6NRqcfLTk\";}s:2:\"id\";s:24:\"comment_unpublish_action\";s:5:\"label\";s:17:\"Unpublish comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:31:\"entity:unpublish_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f8932ff6-cc40-43b7-9cd8-7fefb06c44cf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FrZy1tmuXJcOxhXlBoI1Hsnen5TT-9OCC1iolWH84go\";}s:2:\"id\";s:19:\"media_delete_action\";s:5:\"label\";s:12:\"Delete media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:26:\"entity:delete_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"5ee77a15-afb1-4e0c-bd3b-3e462abe568d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nh83qNNrmWE-CDdHz2MdFOAk60T9mzv3R-MaKfZR2jw\";}s:2:\"id\";s:20:\"media_publish_action\";s:5:\"label\";s:13:\"Publish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:27:\"entity:publish_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"9b97ffc0-0ba9-48fc-9e78-a23777ef7ff4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VVyUA6PIaVeGtcIbgEWqJ6SYDiJdReBeojFswURFpKs\";}s:2:\"id\";s:17:\"media_save_action\";s:5:\"label\";s:10:\"Save media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:24:\"entity:save_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"59cad6a4-a038-45d4-98e9-6ace07f80050\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CsK6TseQ2DatEbZgbd30swOlZ28_HHwAESU2LvEnWq0\";}s:2:\"id\";s:22:\"media_unpublish_action\";s:5:\"label\";s:15:\"Unpublish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:29:\"entity:unpublish_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"455e72bb-d5c2-4233-8fae-fe874a5aecde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t43OqwzP3CTbcAagSsWKNy6KwMm_zShXo3c4-So6rQg\";}s:2:\"id\";s:18:\"node_delete_action\";s:5:\"label\";s:14:\"Delete content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"entity:delete_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_make_sticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"2003aeb9-8fd3-4006-8c7f-9129bef1a808\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sOb26JSy3fGpWkvR0WYN6_hMqj_6d1rvbvrkzp1yya0\";}s:2:\"id\";s:23:\"node_make_sticky_action\";s:5:\"label\";s:19:\"Make content sticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"node_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_make_unsticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"0640984c-3787-4c25-8abe-073f6ff633cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lDM9mvIGAu8Sw8rt-uCO4Sr7yX5VPrDPxYcawkbKd6k\";}s:2:\"id\";s:25:\"node_make_unsticky_action\";s:5:\"label\";s:21:\"Make content unsticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"node_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_promote_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"93459360-b66a-4249-92eb-59a0d4b9e585\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N0RDBTqiK4dKoN4p4oW2j0SGWycdHyALUe9M-Ofp89U\";}s:2:\"id\";s:19:\"node_promote_action\";s:5:\"label\";s:29:\"Promote content to front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:19:\"node_promote_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"6e3d2ae5-f68b-4adb-8345-78fe6e53c835\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2B9uF8NL5gutNKSdPRAhhAsDWFZZG1PJOBmx0aBGd_0\";}s:2:\"id\";s:19:\"node_publish_action\";s:5:\"label\";s:15:\"Publish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:26:\"entity:publish_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"7ff39d45-7ef9-4e69-a87b-aa71ae0d4343\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LhdsoZPL_pFas2fjaAWue4zvrQ_tEVofLYtcNec-JGM\";}s:2:\"id\";s:16:\"node_save_action\";s:5:\"label\";s:12:\"Save content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"entity:save_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_unpromote_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"29499598-fb70-43f6-a160-d2522304d4e7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JBptjnfuOMtsdKygklXxoOgeOCTMtQxlkymjnnj-cC0\";}s:2:\"id\";s:21:\"node_unpromote_action\";s:5:\"label\";s:30:\"Remove content from front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"node_unpromote_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"34872d09-0b48-4090-a401-75dc2bd3358d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C7X8h9FWlwkQ9y5mnU2JzgaZICAdc6HFbPVbhvjlAYE\";}s:2:\"id\";s:21:\"node_unpublish_action\";s:5:\"label\";s:17:\"Unpublish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:28:\"entity:unpublish_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.taxonomy_term_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"8509e01a-1fe0-4d2b-80fe-6292c7281beb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DoVt_VGgVLcDD4XmVbSFzr0K17SJy9imFiYusKkJBgY\";}s:2:\"id\";s:28:\"taxonomy_term_publish_action\";s:5:\"label\";s:21:\"Publish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:35:\"entity:publish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),('','system.action.taxonomy_term_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"07d84567-f6ce-480c-94fe-71f48ce157b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z2sNRM3ECa7FPCGnSNje_9SmZJQgwhD_6fG_L4Mr8zI\";}s:2:\"id\";s:30:\"taxonomy_term_unpublish_action\";s:5:\"label\";s:23:\"Unpublish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:37:\"entity:unpublish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_add_role_action.administrator',_binary 'a:9:{s:4:\"uuid\";s:36:\"080a7d5c-2fda-47ed-b9aa-be9cb07b6d2e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:34:\"user_add_role_action.administrator\";s:5:\"label\";s:50:\"Add the Administrator role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),('','system.action.user_add_role_action.content_editor',_binary 'a:9:{s:4:\"uuid\";s:36:\"e33f0ef8-e9df-400f-b24b-60c0f3497768\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"user.role.content_editor\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:35:\"user_add_role_action.content_editor\";s:5:\"label\";s:51:\"Add the Content editor role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:14:\"content_editor\";}}'),('','system.action.user_block_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"ec45edef-e3ef-44f8-87d8-428346ac0579\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DyypzTfThX10FFQw-399qPfEbLLyrhXgQrKPVsmAoJ4\";}s:2:\"id\";s:22:\"user_block_user_action\";s:5:\"label\";s:26:\"Block the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:22:\"user_block_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_cancel_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"7317c388-dffd-422a-b041-7ef8597810b4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nvrL9bFilzBvm2bjO9rQnFDpBA7dBBUjShSSt6NS-DU\";}s:2:\"id\";s:23:\"user_cancel_user_action\";s:5:\"label\";s:35:\"Cancel the selected user account(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_cancel_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_remove_role_action.administrator',_binary 'a:9:{s:4:\"uuid\";s:36:\"a3ac7eaa-5ae2-4c20-abbb-79b198424e39\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:37:\"user_remove_role_action.administrator\";s:5:\"label\";s:55:\"Remove the Administrator role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),('','system.action.user_remove_role_action.content_editor',_binary 'a:9:{s:4:\"uuid\";s:36:\"daca732c-22a4-42c1-a3c8-d54dae2a458c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"user.role.content_editor\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:38:\"user_remove_role_action.content_editor\";s:5:\"label\";s:56:\"Remove the Content editor role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:14:\"content_editor\";}}'),('','system.action.user_unblock_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"879c5dbe-c854-4240-b44b-cc9946b7e95b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SPsUXsR3Rc8d1y3gewzaAKWa1ncea_ywXX3f7LTn7k0\";}s:2:\"id\";s:24:\"user_unblock_user_action\";s:5:\"label\";s:28:\"Unblock the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:24:\"user_unblock_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.advisories',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"x0FuQ_7Cg81mSDQwG028_Z0CjH3R9ib5IDlHeV2BbAo\";}s:7:\"enabled\";b:1;s:14:\"interval_hours\";i:6;}'),('','system.cron',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"f3yToH8v8EaBZU0NFFw2qR8ogSCuWVmQaN0hpYR1BD8\";}s:9:\"threshold\";a:2:{s:20:\"requirements_warning\";i:172800;s:18:\"requirements_error\";i:1209600;}s:7:\"logging\";b:1;}'),('','system.date',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IVsFTD1mvR2NGBP_1myt9kFIFmGepH4PyaN5aQBYpno\";}s:9:\"first_day\";i:0;s:7:\"country\";a:1:{s:7:\"default\";N;}s:8:\"timezone\";a:2:{s:7:\"default\";s:15:\"Europe/Belgrade\";s:4:\"user\";a:3:{s:12:\"configurable\";b:1;s:7:\"default\";i:0;s:4:\"warn\";b:0;}}}'),('','system.diff',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1WanmaEhxW_vM8_5Ktsdntj8MaO9UBHXg0lN603PsWM\";}s:7:\"context\";a:2:{s:13:\"lines_leading\";i:2;s:14:\"lines_trailing\";i:2;}}'),('','system.feature_flags',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYyVj1FtPGV40Cf65YDVTUIc7YgLH6trXlotuevfs2I\";}s:16:\"linkset_endpoint\";b:0;}'),('','system.file',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mguGHCYb9Dw5EcpfjwoShGV1Vjkbz3QuPRCLfxiye-g\";}s:22:\"allow_insecure_uploads\";b:0;s:14:\"default_scheme\";s:6:\"public\";s:21:\"temporary_maximum_age\";i:21600;}'),('','system.image',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"durWHaKeBaq4d9Wpi4RqwADj1OufDepcnJuhVLmKN24\";}s:7:\"toolkit\";s:2:\"gd\";}'),('','system.image.gd',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eNXaHfkJJUThHeF0nvkoXyPLRrKYGxgHRjORvT4F5rQ\";}s:12:\"jpeg_quality\";i:75;}'),('','system.logging',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u3-njszl92FaxjrCMiq0yDcjAfcdx72w1zT1O9dx6aA\";}s:11:\"error_level\";s:4:\"hide\";}'),('','system.mail',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5PvD9swkqWUeHkabdvbJ2SQqdhrzjkCT21wtD4BLfk4\";}s:9:\"interface\";a:1:{s:7:\"default\";s:8:\"php_mail\";}s:10:\"mailer_dsn\";a:6:{s:6:\"scheme\";s:8:\"sendmail\";s:4:\"host\";s:7:\"default\";s:4:\"user\";N;s:8:\"password\";N;s:4:\"port\";N;s:7:\"options\";a:0:{}}}'),('','system.maintenance',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1SNdA25INsV5YjlgAJtfC-6AM8VcWe_00xneMLb2yFg\";}s:8:\"langcode\";s:2:\"en\";s:7:\"message\";s:93:\"@site is currently under maintenance. We should be back shortly. Thank you for your patience.\";}'),('','system.menu.account',_binary 'a:9:{s:4:\"uuid\";s:36:\"37d50e8a-b786-4ff3-a41f-5e41d67f88b1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Bh81osDyUQ4wV0GgU_NdBNqkzM87sLxjaCdFj9mnw\";}s:2:\"id\";s:7:\"account\";s:5:\"label\";s:17:\"User account menu\";s:11:\"description\";s:40:\"Links related to the active user account\";s:6:\"locked\";b:1;}'),('','system.menu.admin',_binary 'a:9:{s:4:\"uuid\";s:36:\"cf474897-e948-4315-a183-5878deecdaf0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sapEi2YDGoI9yQIT_WgIV2vUdQ6DScH0V3fAyTadAL0\";}s:2:\"id\";s:5:\"admin\";s:5:\"label\";s:14:\"Administration\";s:11:\"description\";s:25:\"Administrative task links\";s:6:\"locked\";b:1;}'),('','system.menu.footer',_binary 'a:9:{s:4:\"uuid\";s:36:\"d761cbba-9ebe-4d52-96fc-79063bff0783\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7yrlW5z9zdg2eBucB2GPqXKSMQfH9lSRSO4DbWF7AFc\";}s:2:\"id\";s:6:\"footer\";s:5:\"label\";s:6:\"Footer\";s:11:\"description\";s:22:\"Site information links\";s:6:\"locked\";b:1;}'),('','system.menu.main',_binary 'a:9:{s:4:\"uuid\";s:36:\"4108c568-d39d-4283-8af4-4ce0601c49ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q2Ra3jfoIVk0f3SjxJX61byRQFVBAbpzYDQOiY-kno8\";}s:2:\"id\";s:4:\"main\";s:5:\"label\";s:15:\"Main navigation\";s:11:\"description\";s:18:\"Site section links\";s:6:\"locked\";b:1;}'),('','system.menu.tools',_binary 'a:9:{s:4:\"uuid\";s:36:\"6e91308b-4a52-440d-824d-e3b9fb3941e2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCM-vV1zzRaLHN18dqAR_CuGOj8AFJvTx7BKl_8Gcxc\";}s:2:\"id\";s:5:\"tools\";s:5:\"label\";s:5:\"Tools\";s:11:\"description\";s:39:\"User tool links, often added by modules\";s:6:\"locked\";b:1;}'),('','system.performance',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jtno5biznHZbrIgKwzq-ze-7XaQxLCGe6PeUOR7bRiQ\";}s:5:\"cache\";a:1:{s:4:\"page\";a:1:{s:7:\"max_age\";i:0;}}s:3:\"css\";a:2:{s:10:\"preprocess\";b:0;s:4:\"gzip\";b:1;}s:8:\"fast_404\";a:4:{s:7:\"enabled\";b:1;s:5:\"paths\";s:69:\"/\\.(?:txt|png|gif|jpe?g|css|js|ico|swf|flv|cgi|bat|pl|dll|exe|asp)$/i\";s:13:\"exclude_paths\";s:27:\"/\\/(?:styles|imagecache)\\//\";s:4:\"html\";s:162:\"<!DOCTYPE html><html><head><title>404 Not Found</title></head><body><h1>Not Found</h1><p>The requested URL \"@path\" was not found on this server.</p></body></html>\";}s:2:\"js\";a:2:{s:10:\"preprocess\";b:0;s:4:\"gzip\";b:1;}}'),('','system.rss',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MIpNzlG4gPunfS7vTCwUPum6QH3GUsEBMj-qS631Jw0\";}s:5:\"items\";a:1:{s:9:\"view_mode\";s:3:\"rss\";}}'),('','system.site',_binary 'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ijfbzDTN4CbE7Sr-6ubWzy_t1vH4OtU1doNCLssVz-4\";}s:8:\"langcode\";s:2:\"en\";s:4:\"uuid\";s:36:\"78d4512f-043a-4ffe-b38d-c79b75c64b27\";s:4:\"name\";s:23:\"EPT Page Builder - Demo\";s:4:\"mail\";s:17:\"admin@example.com\";s:6:\"slogan\";s:0:\"\";s:4:\"page\";a:3:{i:403;s:0:\"\";i:404;s:0:\"\";s:5:\"front\";s:7:\"/node/1\";}s:18:\"admin_compact_mode\";b:0;s:17:\"weight_select_max\";i:100;s:16:\"default_langcode\";s:2:\"en\";s:17:\"mail_notification\";N;}'),('','system.theme',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJ529VM1gSIA_vgTy2PdiDvJuG0xhSxfQjCyl5WKlv4\";}s:5:\"admin\";s:3:\"gin\";s:7:\"default\";s:9:\"ept_light\";}'),('','system.theme.global',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KZiV2LB312xgJBphfq5BTjmp16xiR5KM8InBJ-pff7Y\";}s:7:\"favicon\";a:4:{s:8:\"mimetype\";s:24:\"image/vnd.microsoft.icon\";s:4:\"path\";s:0:\"\";s:3:\"url\";s:0:\"\";s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:1;}s:4:\"logo\";a:3:{s:4:\"path\";s:0:\"\";s:3:\"url\";N;s:11:\"use_default\";b:1;}}'),('','taxonomy.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zKpaWT6cJc1tVQQaTqatGELaCqU_oyRym6zTl27Yias\";}s:20:\"maintain_index_table\";b:1;s:17:\"override_selector\";b:0;s:20:\"terms_per_page_admin\";i:100;}'),('','taxonomy.vocabulary.tags',_binary 'a:10:{s:4:\"uuid\";s:36:\"368fd9b7-ee40-4b51-8ac1-60f818b9f9f6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iTEzwrEQ_4JIb-OYGiqzyF2TmMgWyWayresXcWgwGWM\";}s:4:\"name\";s:4:\"Tags\";s:3:\"vid\";s:4:\"tags\";s:11:\"description\";s:61:\"Use tags to group articles on similar topics into categories.\";s:6:\"weight\";i:0;s:12:\"new_revision\";b:0;}'),('','tb_megamenu.menu_config.main__ept_light',_binary 'a:9:{s:4:\"uuid\";s:36:\"9a71f48f-4fa9-44ad-996b-21fe7ea77565\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}s:4:\"menu\";a:1:{i:0;s:4:\"main\";}}s:2:\"id\";s:15:\"main__ept_light\";s:4:\"menu\";s:4:\"main\";s:5:\"theme\";s:9:\"ept_light\";s:12:\"block_config\";s:120:\"{\"animation\":\"none\",\"duration\":400,\"delay\":200,\"style\":\"\",\"auto-arrow\":\"1\",\"always-show-submenu\":\"0\",\"number-columns\":1}\";s:11:\"menu_config\";s:707:\"{\"standard.front_page\":{\"rows_content\":[],\"submenu_config\":{\"width\":\"\",\"class\":\"\",\"group\":\"0\"},\"item_config\":{\"class\":\"\",\"xicon\":\"\",\"caption\":\"\",\"alignsub\":\"\",\"group\":\"0\",\"hidewcol\":\"0\",\"hidesub\":\"0\",\"label\":\"\"}},\"menu_link_content:d5043c53-9961-4a60-bb2a-a37bbaaa3961\":{\"rows_content\":[],\"submenu_config\":{\"width\":\"\",\"class\":\"\",\"group\":\"0\"},\"item_config\":{\"class\":\"\",\"xicon\":\"\",\"caption\":\"\",\"alignsub\":\"\",\"group\":\"0\",\"hidewcol\":\"0\",\"hidesub\":\"0\",\"label\":\"\"}},\"menu_link_content:addff990-0222-4099-9e61-5f98566f7f94\":{\"rows_content\":[],\"submenu_config\":{\"width\":\"\",\"class\":\"\",\"group\":\"0\"},\"item_config\":{\"class\":\"\",\"xicon\":\"\",\"caption\":\"\",\"alignsub\":\"\",\"group\":\"0\",\"hidewcol\":\"0\",\"hidesub\":\"0\",\"label\":\"\"}}}\";}'),('','text.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Bkewb77RBOK3_aXMPsp8p87gbc03NvmC5gBLzPl7hVA\";}s:22:\"default_summary_length\";i:600;}'),('','update.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xbYr66-g0FjNgVBkGypCuN46vBI2XHntXN1URawq1s4\";}s:5:\"check\";a:2:{s:19:\"disabled_extensions\";b:0;s:13:\"interval_days\";i:1;}s:5:\"fetch\";a:3:{s:3:\"url\";N;s:12:\"max_attempts\";i:2;s:7:\"timeout\";i:30;}s:12:\"notification\";a:2:{s:6:\"emails\";a:1:{i:0;s:17:\"admin@example.com\";}s:9:\"threshold\";s:3:\"all\";}}'),('','user.flood',_binary 'a:6:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UYfMzeP1S8jKm9PSvxf7nQNe8DsNS-3bc2WSNNXBQWs\";}s:8:\"uid_only\";b:0;s:8:\"ip_limit\";i:50;s:9:\"ip_window\";i:3600;s:10:\"user_limit\";i:5;s:11:\"user_window\";i:21600;}'),('','user.mail',_binary 'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6CZIzFifRq3qbdq3n3nDpEOO4hWIQtKOAQNPvGNGKeM\";}s:8:\"langcode\";s:2:\"en\";s:14:\"cancel_confirm\";a:2:{s:7:\"subject\";s:67:\"Account cancellation request for [user:display-name] at [site:name]\";s:4:\"body\";s:376:\"[user:display-name]\n\nA request to cancel your account has been made at [site:name].\n\nYou may now cancel your account on [site:url-brief] by clicking this link or copying and pasting it into your browser:\n\n[user:cancel-url]\n\nNOTE: The cancellation of your account is not reversible.\n\nThis link expires in one day and nothing will happen if it is not used.\n\n--  [site:name] team\";}s:14:\"password_reset\";a:2:{s:7:\"subject\";s:68:\"Replacement login information for [user:display-name] at [site:name]\";s:4:\"body\";s:407:\"[user:display-name],\n\nA request to reset the password for your account has been made at [site:name].\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password. It expires after one day and nothing will happen if it\'s not used.\n\n--  [site:name] team\";}s:22:\"register_admin_created\";a:2:{s:7:\"subject\";s:58:\"An administrator created an account for you at [site:name]\";s:4:\"body\";s:473:\"[user:display-name],\n\nA site administrator at [site:name] has created an account for you. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:29:\"register_no_approval_required\";a:2:{s:7:\"subject\";s:54:\"Account details for [user:display-name] at [site:name]\";s:4:\"body\";s:447:\"[user:display-name],\n\nThank you for registering at [site:name]. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:25:\"register_pending_approval\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:288:\"[user:display-name],\n\nThank you for registering at [site:name]. Your application for an account is currently pending approval. Once it has been approved, you will receive another email containing information about how to log in, set your password, and other details.\n\n--  [site:name] team\";}s:31:\"register_pending_approval_admin\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:64:\"[user:display-name] has applied for an account.\n\n[user:edit-url]\";}s:16:\"status_activated\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (approved)\";s:4:\"body\";s:462:\"[user:display-name],\n\nYour account at [site:name] has been activated.\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:account-name]\npassword: Your password\n\n--  [site:name] team\";}s:14:\"status_blocked\";a:2:{s:7:\"subject\";s:64:\"Account details for [user:display-name] at [site:name] (blocked)\";s:4:\"body\";s:89:\"[user:display-name],\n\nYour account on [site:name] has been blocked.\n\n--  [site:name] team\";}s:15:\"status_canceled\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (canceled)\";s:4:\"body\";s:90:\"[user:display-name],\n\nYour account on [site:name] has been canceled.\n\n--  [site:name] team\";}}'),('','user.role.administrator',_binary 'a:10:{s:4:\"uuid\";s:36:\"5f4748db-4b8a-4105-a888-23753782d022\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OeKGIkmZA_c-t6QLH81WNQx8gDCc1MRmxaTuQgxBByU\";}s:2:\"id\";s:13:\"administrator\";s:5:\"label\";s:13:\"Administrator\";s:6:\"weight\";i:3;s:8:\"is_admin\";b:1;s:11:\"permissions\";a:0:{}}'),('','user.role.anonymous',_binary 'a:10:{s:4:\"uuid\";s:36:\"eda565bf-dc62-4fa8-b48c-329d2d6fc492\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.restricted_html\";}s:6:\"module\";a:6:{i:0;s:7:\"comment\";i:1;s:7:\"contact\";i:2;s:6:\"filter\";i:3;s:5:\"media\";i:4;s:6:\"search\";i:5;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6WavjUYXIegP9AAg2zXGx54MWIVoomC3SZhNiqe-Dyk\";}s:2:\"id\";s:9:\"anonymous\";s:5:\"label\";s:14:\"Anonymous user\";s:6:\"weight\";i:0;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:6:{i:0;s:15:\"access comments\";i:1;s:14:\"access content\";i:2;s:29:\"access site-wide contact form\";i:3;s:14:\"search content\";i:4;s:31:\"use text format restricted_html\";i:5;s:10:\"view media\";}}'),('','user.role.authenticated',_binary 'a:10:{s:4:\"uuid\";s:36:\"369ad726-b0da-4331-8cb0-56ab9af109d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"filter.format.basic_html\";}s:6:\"module\";a:8:{i:0;s:7:\"comment\";i:1;s:7:\"contact\";i:2;s:4:\"file\";i:3;s:6:\"filter\";i:4;s:5:\"media\";i:5;s:6:\"search\";i:6;s:8:\"shortcut\";i:7;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFrlqjtkTfvY3RGccjJkPf1SGIfJ942IrxTLWAO4mgA\";}s:2:\"id\";s:13:\"authenticated\";s:5:\"label\";s:18:\"Authenticated user\";s:6:\"weight\";i:1;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:10:{i:0;s:15:\"access comments\";i:1;s:14:\"access content\";i:2;s:16:\"access shortcuts\";i:3;s:29:\"access site-wide contact form\";i:4;s:16:\"delete own files\";i:5;s:13:\"post comments\";i:6;s:14:\"search content\";i:7;s:21:\"skip comment approval\";i:8;s:26:\"use text format basic_html\";i:9;s:10:\"view media\";}}'),('','user.role.content_editor',_binary 'a:10:{s:4:\"uuid\";s:36:\"e916801a-5024-47c1-b402-bb0bb1592d19\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:17:\"node.type.article\";i:1;s:14:\"node.type.page\";i:2;s:24:\"taxonomy.vocabulary.tags\";}s:6:\"module\";a:9:{i:0;s:7:\"comment\";i:1;s:10:\"contextual\";i:2;s:4:\"file\";i:3;s:4:\"node\";i:4;s:4:\"path\";i:5;s:6:\"system\";i:6;s:8:\"taxonomy\";i:7;s:11:\"tb_megamenu\";i:8;s:7:\"toolbar\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e_wG1u7SrGaJbY2-Szgbgl-c8T3kdirU3uTNq2c_QJQ\";}s:2:\"id\";s:14:\"content_editor\";s:5:\"label\";s:14:\"Content editor\";s:6:\"weight\";i:2;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:24:{i:0;s:27:\"access administration pages\";i:1;s:23:\"access content overview\";i:2;s:23:\"access contextual links\";i:3;s:21:\"access files overview\";i:4;s:14:\"access toolbar\";i:5;s:22:\"administer tb_megamenu\";i:6;s:22:\"administer url aliases\";i:7;s:22:\"create article content\";i:8;s:19:\"create page content\";i:9;s:20:\"create terms in tags\";i:10;s:18:\"create url aliases\";i:11;s:24:\"delete article revisions\";i:12;s:26:\"delete own article content\";i:13;s:16:\"delete own files\";i:14;s:23:\"delete own page content\";i:15;s:21:\"delete page revisions\";i:16;s:24:\"edit own article content\";i:17;s:17:\"edit own comments\";i:18;s:21:\"edit own page content\";i:19;s:18:\"edit terms in tags\";i:20;s:20:\"revert all revisions\";i:21;s:18:\"view all revisions\";i:22;s:28:\"view own unpublished content\";i:23;s:29:\"view the administration theme\";}}'),('','user.settings',_binary 'a:9:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-htDFWUv1S4OlJMzta2nhFl4QbhJvu0D9xsJ-clxo-M\";}s:8:\"langcode\";s:2:\"en\";s:9:\"anonymous\";s:9:\"Anonymous\";s:11:\"verify_mail\";b:1;s:6:\"notify\";a:8:{s:14:\"cancel_confirm\";b:1;s:14:\"password_reset\";b:1;s:16:\"status_activated\";b:1;s:14:\"status_blocked\";b:0;s:15:\"status_canceled\";b:0;s:22:\"register_admin_created\";b:1;s:29:\"register_no_approval_required\";b:1;s:25:\"register_pending_approval\";b:1;}s:8:\"register\";s:23:\"visitors_admin_approval\";s:13:\"cancel_method\";s:17:\"user_cancel_block\";s:22:\"password_reset_timeout\";i:86400;s:17:\"password_strength\";b:1;}'),('','views.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8oDr9oPVb_ostrNnVV6V7VdphwoH_u-NqTS0u7SE7qc\";}s:17:\"display_extenders\";a:0:{}s:13:\"sql_signature\";b:0;s:2:\"ui\";a:3:{s:4:\"show\";a:7:{s:18:\"additional_queries\";b:0;s:15:\"advanced_column\";b:0;s:15:\"default_display\";b:0;s:22:\"performance_statistics\";b:0;s:19:\"preview_information\";b:1;s:9:\"sql_query\";a:2:{s:7:\"enabled\";b:0;s:5:\"where\";s:5:\"above\";}s:13:\"display_embed\";b:0;}s:19:\"always_live_preview\";b:1;s:24:\"exposed_filter_any_label\";s:7:\"old_any\";}s:22:\"field_rewrite_elements\";a:29:{s:3:\"div\";s:3:\"DIV\";s:4:\"span\";s:4:\"SPAN\";s:2:\"h1\";s:2:\"H1\";s:2:\"h2\";s:2:\"H2\";s:2:\"h3\";s:2:\"H3\";s:2:\"h4\";s:2:\"H4\";s:2:\"h5\";s:2:\"H5\";s:2:\"h6\";s:2:\"H6\";s:1:\"p\";s:1:\"P\";s:6:\"header\";s:6:\"HEADER\";s:6:\"footer\";s:6:\"FOOTER\";s:7:\"article\";s:7:\"ARTICLE\";s:7:\"section\";s:7:\"SECTION\";s:5:\"aside\";s:5:\"ASIDE\";s:7:\"details\";s:7:\"DETAILS\";s:10:\"blockquote\";s:10:\"BLOCKQUOTE\";s:6:\"figure\";s:6:\"FIGURE\";s:7:\"address\";s:7:\"ADDRESS\";s:4:\"code\";s:4:\"CODE\";s:3:\"pre\";s:3:\"PRE\";s:3:\"var\";s:3:\"VAR\";s:4:\"samp\";s:4:\"SAMP\";s:3:\"kbd\";s:3:\"KBD\";s:6:\"strong\";s:6:\"STRONG\";s:2:\"em\";s:2:\"EM\";s:3:\"del\";s:3:\"DEL\";s:3:\"ins\";s:3:\"INS\";s:1:\"q\";s:1:\"Q\";s:1:\"s\";s:1:\"S\";}}'),('','views.view.archive',_binary 'a:13:{s:4:\"uuid\";s:36:\"f33400de-a3e8-4128-b4b9-8f10fc897a3f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"exIF08PTvYSK6tJCsAzBqMEKUBKIptPorMn74SVhevc\";}s:2:\"id\";s:7:\"archive\";s:5:\"label\";s:7:\"Archive\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:22:\"All content, by month.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:15:\"Monthly archive\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:2:{s:8:\"override\";b:1;s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:2:{s:10:\"sort_order\";s:4:\"desc\";s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:0;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:1:{s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"archive\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.block_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"f0a4d615-99cd-438c-a7fe-c2d84a594ee3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HfvTcWhiVuvxchoh4DjIkXhKkj9ow2TGgHkLHSvRLq8\";}s:2:\"id\";s:13:\"block_content\";s:5:\"label\";s:14:\"Content blocks\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:31:\"Find and manage content blocks.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:24:\"block_content_field_data\";s:10:\"base_field\";s:2:\"id\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:14:\"Content blocks\";s:6:\"fields\";a:4:{s:4:\"info\";a:37:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";N;s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:17:\"Block description\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Block type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access block library\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:2:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:38:\"There are no content blocks available.\";s:8:\"tokenize\";b:0;}s:27:\"block_content_listing_empty\";a:10:{s:2:\"id\";s:27:\"block_content_listing_empty\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:27:\"block_content_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:27:\"block_content_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:4:\"info\";a:16:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"info_op\";s:5:\"label\";s:17:\"Block description\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"info_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"info\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:10:\"Block type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"reusable\";a:16:{s:2:\"id\";s:8:\"reusable\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:8:\"reusable\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:8:\"reusable\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:4:\"info\";s:4:\"info\";s:4:\"type\";s:4:\"type\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:4:{s:4:\"info\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/block\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:6:\"Blocks\";s:11:\"description\";s:31:\"Create and edit content blocks.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:20:\"system.admin_content\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.comment',_binary 'a:13:{s:4:\"uuid\";s:36:\"e6cd565b-768b-47a9-b906-fe031ec4047e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"H6JHGXl97yOKmVaV62SoY1ki1tWVdyD44fgOkdmVyRM\";}s:2:\"id\";s:7:\"comment\";s:5:\"label\";s:8:\"Comments\";s:6:\"module\";s:7:\"comment\";s:11:\"description\";s:25:\"Find and manage comments.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:18:\"comment_field_data\";s:10:\"base_field\";s:3:\"cid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:26:{s:5:\"title\";s:8:\"Comments\";s:6:\"fields\";a:8:{s:17:\"comment_bulk_form\";a:26:{s:2:\"id\";s:17:\"comment_bulk_form\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:17:\"comment_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"comment_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:2:{i:0;s:21:\"comment_delete_action\";i:1;s:24:\"comment_unpublish_action\";}}s:7:\"subject\";a:37:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Subject\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:17:\"comment_permalink\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:9:\"{{ uid }}\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:16:\"comment_username\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:9:\"entity_id\";a:37:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:9:\"entity_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:16:\"commented_entity\";s:5:\"label\";s:9:\"Posted in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:6:\"name_1\";a:37:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"next ›\";s:8:\"previous\";s:12:\"‹ previous\";s:5:\"first\";s:8:\"« first\";s:4:\"last\";s:7:\"last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"administer comments\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:22:\"No comments available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:4:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"subject\";a:16:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"subject_op\";s:5:\"label\";s:7:\"Subject\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"subject_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"subject\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:11:\"Author name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:11:\"author_name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:6:\"name_1\";s:6:\"name_1\";}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:6:{s:17:\"comment_bulk_form\";s:17:\"comment_bulk_form\";s:7:\"subject\";s:7:\"subject\";s:3:\"uid\";s:3:\"uid\";s:9:\"entity_id\";s:9:\"entity_id\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:6:{s:17:\"comment_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"subject\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"uid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"entity_id\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:1;s:13:\"use_more_text\";s:4:\"more\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}s:14:\"page_published\";a:6:{s:2:\"id\";s:14:\"page_published\";s:13:\"display_title\";s:18:\"Published comments\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:19:\"display_description\";s:30:\"The approved comments listing.\";s:15:\"display_comment\";s:0:\"\";s:13:\"exposed_block\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:21:\"admin/content/comment\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:8:\"Comments\";s:11:\"description\";s:18:\"Comments published\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}s:15:\"page_unapproved\";a:6:{s:2:\"id\";s:15:\"page_unapproved\";s:13:\"display_title\";s:19:\"Unapproved comments\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:8:{s:6:\"fields\";a:8:{s:17:\"comment_bulk_form\";a:26:{s:2:\"id\";s:17:\"comment_bulk_form\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:17:\"comment_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"comment_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:2:{i:0;s:21:\"comment_delete_action\";i:1;s:22:\"comment_publish_action\";}}s:7:\"subject\";a:37:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Subject\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:17:\"comment_permalink\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:9:\"{{ uid }}\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:16:\"comment_username\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:9:\"entity_id\";a:37:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:9:\"entity_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:16:\"commented_entity\";s:5:\"label\";s:9:\"Posted in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:6:\"name_1\";a:37:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:7:\"filters\";a:4:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"subject\";a:16:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"subject_op\";s:5:\"label\";s:7:\"Subject\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"subject_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"subject\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:11:\"Author Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:11:\"author_name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:6:\"name_1\";s:6:\"name_1\";}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:8:\"defaults\";a:3:{s:6:\"fields\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:19:\"display_description\";s:32:\"The unapproved comments listing.\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:30:\"admin/content/comment/approval\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:19:\"Unapproved comments\";s:11:\"description\";s:19:\"Comments unapproved\";s:6:\"weight\";i:1;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}}}'),('','views.view.comments_recent',_binary 'a:13:{s:4:\"uuid\";s:36:\"b85b83ea-7ca6-4445-91d4-33ba3dff6403\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:7:\"comment\";i:1;s:4:\"node\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFOucxH8PAXDQ2kViCcAHgK-JMCcxVkpIMzD56EfpZo\";}s:2:\"id\";s:15:\"comments_recent\";s:5:\"label\";s:15:\"Recent comments\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:16:\"Recent comments.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:18:\"comment_field_data\";s:10:\"base_field\";s:3:\"cid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:14:{s:5:\"title\";s:15:\"Recent comments\";s:6:\"fields\";a:2:{s:7:\"subject\";a:26:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:1:{s:4:\"type\";s:5:\"basic\";}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:15:\"access comments\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:22:\"No comments available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:2:{s:7:\"created\";a:12:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;}s:3:\"cid\";a:12:{s:2:\"id\";s:3:\"cid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"cid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"cid\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"cid\";}s:7:\"exposed\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:11:\"status_node\";a:10:{s:2:\"id\";s:11:\"status_node\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"node\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:2:{s:22:\"default_field_elements\";b:1;s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:4:\"node\";a:5:{s:2:\"id\";s:4:\"node\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"node\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:15:\"Recent comments\";s:14:\"block_category\";s:13:\"Lists (Views)\";s:5:\"allow\";a:1:{s:14:\"items_per_page\";b:1;}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.content',_binary 'a:13:{s:4:\"uuid\";s:36:\"db9f543b-a00c-4765-a8dd-36dc8ebd091c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d7p-wwJZ_Wmz1gnvla9jDtRsjOaWAhPoIoW9w3vo4R4\";}s:2:\"id\";s:7:\"content\";s:5:\"label\";s:7:\"Content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:24:\"Find and manage content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:7:\"Content\";s:6:\"fields\";a:8:{s:14:\"node_bulk_form\";a:14:{s:2:\"id\";s:14:\"node_bulk_form\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:14:\"node_bulk_form\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:14:\"node_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"title\";a:17:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Content type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:17:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:17:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}}s:7:\"changed\";a:17:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:8:\"langcode\";a:37:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:14:\"field_language\";s:5:\"label\";s:8:\"Language\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:8:\"language\";s:8:\"settings\";a:2:{s:14:\"link_to_entity\";b:0;s:15:\"native_language\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:23:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:3:{s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:23:\"access content overview\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:5:\"title\";a:16:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:8:\"title_op\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:8:\"title_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:5:\"title\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:12:\"Content type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:12:\"status_extra\";a:9:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:6:\"expose\";a:2:{s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:10:{s:14:\"node_bulk_form\";s:14:\"node_bulk_form\";s:5:\"title\";s:5:\"title\";s:4:\"type\";s:4:\"type\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:7:\"changed\";s:7:\"changed\";s:9:\"edit_node\";s:9:\"edit_node\";s:11:\"delete_node\";s:11:\"delete_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";s:9:\"timestamp\";s:5:\"title\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:10:{s:14:\"node_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"title\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"delete_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:18:\"admin/content/node\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:23:\"Find and manage content\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.content_recent',_binary 'a:13:{s:4:\"uuid\";s:36:\"9dd1c55e-db52-4c19-aa0d-4c122baa71f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YqZN5rc7XDQcFcInc8wkzuaHJmC5YvirhTmDcrarT6M\";}s:2:\"id\";s:14:\"content_recent\";s:5:\"label\";s:14:\"Recent content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:15:\"Recent content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:22:{s:5:\"title\";s:14:\"Recent content\";s:6:\"fields\";a:2:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"More\";s:12:\"link_display\";s:1:\"0\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:1:{s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.files',_binary 'a:13:{s:4:\"uuid\";s:36:\"36db1296-d05c-4dd7-bda9-64d0981e2f85\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"blP1XdpU4RqVoA_8po7qnIokIbHB6DJt0lpilgY5ovM\";}s:2:\"id\";s:5:\"files\";s:5:\"label\";s:5:\"Files\";s:6:\"module\";s:4:\"file\";s:11:\"description\";s:22:\"Find and manage files.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:12:\"file_managed\";s:10:\"base_field\";s:3:\"fid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:5:\"Files\";s:6:\"fields\";a:9:{s:3:\"fid\";a:24:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:3:\"Fid\";s:7:\"exclude\";b:1;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"filename\";a:36:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"file_link\";s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:8:\"filemime\";a:25:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"MIME type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"file_filemime\";}s:8:\"filesize\";a:25:{s:2:\"id\";s:8:\"filesize\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filesize\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filesize\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Size\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"file_size\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:9:\"Temporary\";s:18:\"format_custom_true\";s:9:\"Permanent\";}}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Upload date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Changed date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:3:\"fid\";s:10:\"group_type\";s:3:\"sum\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:7:\"Used in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/content/files/usage/{{ fid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:1;s:20:\"format_plural_string\";s:21:\"1 place@count places\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access files overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No files available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:8:\"filename\";a:16:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:8:\"Filename\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filename_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filename\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"filemime\";a:16:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:9:\"MIME type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filemime_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filemime\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:11:\"file_status\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"status_op\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:3:\"fid\";s:3:\"fid\";s:8:\"filename\";s:8:\"filename\";s:8:\"filemime\";s:8:\"filemime\";s:8:\"filesize\";s:8:\"filesize\";s:6:\"status\";s:6:\"status\";s:7:\"created\";s:7:\"created\";s:7:\"changed\";s:7:\"changed\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:8:{s:3:\"fid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filename\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filemime\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:8:\"filesize\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:1;s:16:\"show_admin_links\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:14:\"Files overview\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:2:{s:5:\"pager\";b:1;s:13:\"relationships\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:0;}}s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/files\";s:4:\"menu\";a:6:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Files\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_2\";a:6:{s:2:\"id\";s:6:\"page_2\";s:13:\"display_title\";s:10:\"File usage\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:15:{s:5:\"title\";s:10:\"File usage\";s:6:\"fields\";a:4:{s:12:\"entity_label\";a:23:{s:2:\"id\";s:12:\"entity_label\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:12:\"entity_label\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"entity_label\";s:5:\"label\";s:6:\"Entity\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:14:\"link_to_entity\";b:1;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:11:\"Entity type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:6:\"module\";a:22:{s:2:\"id\";s:6:\"module\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:6:\"module\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:18:\"Registering module\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:9:\"Use count\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:0;s:20:\"format_plural_string\";s:8:\"1@count\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:5:\"empty\";a:0:{}s:9:\"arguments\";a:1:{s:3:\"fid\";a:22:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:8:\"file_fid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:46:\"File usage information for {{ arguments.fid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;}}s:7:\"filters\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:12:\"entity_label\";s:12:\"entity_label\";s:4:\"type\";s:4:\"type\";s:6:\"module\";s:6:\"module\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:12:\"entity_label\";s:4:\"info\";a:4:{s:12:\"entity_label\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:6:\"module\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:11:{s:5:\"empty\";b:0;s:5:\"title\";b:0;s:5:\"pager\";b:0;s:8:\"group_by\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:13:\"relationships\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:0;s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:27:\"admin/content/files/usage/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.frontpage',_binary 'a:13:{s:4:\"uuid\";s:36:\"899f634a-224d-4abf-ae01-81a9b3031896\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OEEnRQIjfIaCFRsz8U3VqDrE82ltQKlo8wNbQJRZXu0\";}s:2:\"id\";s:9:\"frontpage\";s:5:\"label\";s:9:\"Frontpage\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:39:\"All content promoted to the front page.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:0:\"\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:3:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:181:\"No front page content has been created yet.<br/>Follow the <a target=\"_blank\" href=\"https://www.drupal.org/docs/user_guide/en/index.html\">User Guide</a> to start building your site.\";s:8:\"tokenize\";b:0;}s:18:\"node_listing_empty\";a:10:{s:2:\"id\";s:18:\"node_listing_empty\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:18:\"node_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:18:\"node_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}s:5:\"title\";a:10:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"title\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:5:\"title\";s:8:\"Welcome!\";}}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:12:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:7:\"promote\";a:16:{s:2:\"id\";s:7:\"promote\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"promote\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"promote\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:3:\"rss\";}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"rss.xml\";s:14:\"sitename_title\";b:1;s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:28:\"languages:language_interface\";i:1;s:21:\"user.node_grants:view\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:4:\"node\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.glossary',_binary 'a:13:{s:4:\"uuid\";s:36:\"9a843b37-02d2-45c5-84e0-2cd85511ce42\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r-klgGeO4haVHqAwxW1HXZLzdzLSMUVC08OuTBrRh58\";}s:2:\"id\";s:8:\"glossary\";s:5:\"label\";s:8:\"Glossary\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:23:\"All content, by letter.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:6:\"fields\";a:3:{s:5:\"title\";a:24:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:36;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"default\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:0:{}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;s:7:\"columns\";a:3:{s:5:\"title\";s:5:\"title\";s:4:\"name\";s:4:\"name\";s:7:\"changed\";s:7:\"changed\";}s:7:\"default\";s:5:\"title\";s:4:\"info\";a:3:{s:5:\"title\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:4:\"name\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:7:\"changed\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:5:\"order\";s:3:\"asc\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"attachment_1\";a:6:{s:2:\"id\";s:12:\"attachment_1\";s:13:\"display_title\";s:10:\"Attachment\";s:14:\"display_plugin\";s:10:\"attachment\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:0;}}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:3:{s:14:\"items_per_page\";i:25;s:6:\"inline\";b:1;s:9:\"separator\";s:3:\" | \";}s:7:\"summary\";a:1:{s:6:\"format\";s:19:\"unformatted_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}s:8:\"displays\";a:2:{s:7:\"default\";s:7:\"default\";s:6:\"page_1\";s:6:\"page_1\";}s:17:\"inherit_arguments\";b:0;}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:8:\"glossary\";s:4:\"menu\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:8:\"Glossary\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.media',_binary 'a:13:{s:4:\"uuid\";s:36:\"7c06b5e5-ebff-4822-8688-54ce69b5a404\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kOTUk5XWeupgBOJuRRarCiDcFKVZcvaW-FT5MTzrML8\";}s:2:\"id\";s:5:\"media\";s:5:\"label\";s:5:\"Media\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:8:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:20:\"thumbnail__target_id\";a:37:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:9:\"thumbnail\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:12:\"group_column\";s:0:\"\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:5:\"media\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Media name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"bundle\";a:37:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"status\";a:37:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:10:\"Media name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:4:\"True\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:6:{s:4:\"name\";s:4:\"name\";s:6:\"bundle\";s:6:\"bundle\";s:7:\"changed\";s:7:\"changed\";s:3:\"uid\";s:3:\"uid\";s:6:\"status\";s:6:\"status\";s:20:\"thumbnail__target_id\";s:20:\"thumbnail__target_id\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:6:{s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"bundle\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"uid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:15:\"media_page_list\";a:6:{s:2:\"id\";s:15:\"media_page_list\";s:13:\"display_title\";s:5:\"Media\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/media\";s:4:\"menu\";a:8:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Media\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:8:\"expanded\";b:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.media_library',_binary 'a:13:{s:4:\"uuid\";s:36:\"74d36492-489a-4ac8-ab15-1c22af9e302b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:25:\"image.style.media_library\";}s:6:\"module\";a:4:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:13:\"media_library\";i:3;s:4:\"user\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9u9hwW-Q0-uQJz1vgenJTQhZGYN0FBZoOogwPD6kgkQ\";}s:2:\"id\";s:13:\"media_library\";s:5:\"label\";s:13:\"Media library\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:4:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:2:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:24;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"6, 12, 24, 48\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:13:\"Apply filters\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:3:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:12:\"Newest first\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:1;s:11:\"granularity\";s:6:\"second\";}s:4:\"name\";a:12:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:3:\"ASC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (A-Z)\";s:16:\"field_identifier\";s:4:\"name\";}s:7:\"exposed\";b:1;}s:6:\"name_1\";a:12:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (Z-A)\";s:16:\"field_identifier\";s:6:\"name_1\";}s:7:\"exposed\";b:1;}}s:7:\"filters\";a:5:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:17:\"Publishing status\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:9:\"Published\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:10:\"Media type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:10:\"Media type\";s:11:\"description\";N;s:10:\"identifier\";s:6:\"bundle\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:3:{i:1;a:0:{}i:2;a:0:{}i:3;a:0:{}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:6:\"fields\";a:5:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"edit_media\";a:26:{s:2:\"id\";s:10:\"edit_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"edit_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:15:\"Edit {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:15:\"Edit {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"Edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:12:\"delete_media\";a:26:{s:2:\"id\";s:12:\"delete_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:12:\"delete_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:18:\"entity_link_delete\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:17:\"Delete {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:17:\"Delete {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:6:\"Delete\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:8:\"defaults\";a:1:{s:6:\"fields\";b:0;}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:24:\"admin/content/media-grid\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:22:\"url.query_args:sort_by\";i:5;s:4:\"user\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"widget\";a:6:{s:2:\"id\";s:6:\"widget\";s:13:\"display_title\";s:6:\"Widget\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:12:{s:6:\"fields\";a:2:{s:25:\"media_library_select_form\";a:23:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:8:\"defaults\";a:7:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:19:\"display_description\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:26:\"admin/content/media-widget\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"widget_table\";a:6:{s:2:\"id\";s:12:\"widget_table\";s:13:\"display_title\";s:14:\"Widget (table)\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:3;s:15:\"display_options\";a:13:{s:6:\"fields\";a:5:{s:25:\"media_library_select_form\";a:9:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:10:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:13:\"media_library\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}}}s:4:\"name\";a:10:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}}s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:20:\"media_field_revision\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}}s:7:\"changed\";a:10:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:2:{s:9:\"row_class\";s:85:\"media-library-item media-library-item--table js-media-library-item js-click-to-select\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:8:\"defaults\";a:9:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:32:\"admin/content/media-widget-table\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.taxonomy_term',_binary 'a:13:{s:4:\"uuid\";s:36:\"56651306-efed-4808-bbdc-d9cf02cff348\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:3:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KejdxDJQmx8SaO-t83OVekLw6ar4ldjmsJMGcotGxnQ\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:6:\"module\";s:8:\"taxonomy\";s:11:\"description\";s:45:\"Content belonging to a certain taxonomy term.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:10:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:11:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:3:\"tid\";a:22:{s:2:\"id\";s:3:\"tid\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:3:\"tid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:18:\"taxonomy_index_tid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:0:\"\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:19:\"{{ arguments.tid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:4:{s:7:\"bundles\";a:0:{}s:6:\"access\";b:1;s:9:\"operation\";s:4:\"view\";s:8:\"multiple\";i:0;}s:12:\"break_phrase\";b:0;s:9:\"add_table\";b:0;s:13:\"require_value\";b:0;s:17:\"reduce_duplicates\";b:0;}}s:7:\"filters\";a:2:{s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:14:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:1:{s:20:\"entity_taxonomy_term\";a:12:{s:2:\"id\";s:20:\"entity_taxonomy_term\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:20:\"entity_taxonomy_term\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"entity\";s:5:\"empty\";b:1;s:6:\"target\";s:23:\"{{ raw_arguments.tid }}\";s:9:\"view_mode\";s:4:\"full\";s:8:\"tokenize\";b:1;s:13:\"bypass_access\";b:0;}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:7:\"default\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:20:\"taxonomy/term/%/feed\";s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:15:\"taxonomy/term/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.user_admin_people',_binary 'a:13:{s:4:\"uuid\";s:36:\"66ac1092-d560-4cf9-a5d3-b1941a3311d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FFLg74mnzRE10lgg5fspPCZWLnIEcvCnJMlNzj8OEtw\";}s:2:\"id\";s:17:\"user_admin_people\";s:5:\"label\";s:6:\"People\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:25:{s:5:\"title\";s:6:\"People\";s:6:\"fields\";a:8:{s:14:\"user_bulk_form\";a:23:{s:2:\"id\";s:14:\"user_bulk_form\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:14:\"user_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:14:\"user_bulk_form\";s:5:\"label\";s:11:\"Bulk update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:8:\"Username\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:7:\"Blocked\";s:18:\"format_custom_true\";s:6:\"Active\";}}s:15:\"roles_target_id\";a:24:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:5:\"label\";s:5:\"Roles\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:2:\"ul\";s:9:\"separator\";s:2:\", \";}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Member for\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:9:\"@interval\";s:11:\"past_format\";s:9:\"@interval\";s:11:\"granularity\";i:2;}}s:6:\"access\";a:26:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last access\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:4:\"mail\";a:37:{s:2:\"id\";s:4:\"mail\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"mail\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"mail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:12:\"basic_string\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:16:\"administer users\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:20:\"No people available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:7:\"filters\";a:6:{s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:22:\"Name or email contains\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"user\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:4:\"mail\";s:4:\"mail\";}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:6:\"Active\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:7:\"Blocked\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:15:\"roles_target_id\";a:15:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:18:\"roles_target_id_op\";s:5:\"label\";s:4:\"Role\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:18:\"roles_target_id_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"role\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:10:\"permission\";a:15:{s:2:\"id\";s:10:\"permission\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:10:\"permission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"user_permissions\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:13:\"permission_op\";s:5:\"label\";s:10:\"Permission\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:13:\"permission_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:10:\"permission\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"uid_raw\";a:15:{s:2:\"id\";s:7:\"uid_raw\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"uid_raw\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:7:\"numeric\";s:8:\"operator\";s:2:\"!=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:1:\"0\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:10:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:14:\"user_bulk_form\";s:14:\"user_bulk_form\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:3:\"rid\";s:3:\"rid\";s:7:\"created\";s:7:\"created\";s:6:\"access\";s:6:\"access\";s:9:\"edit_node\";s:9:\"edit_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";}s:7:\"default\";s:7:\"created\";s:4:\"info\";a:8:{s:14:\"user_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:3:\"rid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"access\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"more\";s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:15:\"display_comment\";s:0:\"\";s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:1:{s:16:\"show_admin_links\";b:0;}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:17:\"admin/people/list\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:4:\"List\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:6:\"People\";s:11:\"description\";s:45:\"Manage user accounts, roles, and permissions.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.watchdog',_binary 'a:13:{s:4:\"uuid\";s:36:\"25587939-259b-48aa-8c6c-dbd04aa5d800\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"dblog\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SR5P89f0vUTPC7WY2YpLAffkDx8-Ar8LKFfowVXeqNU\";}s:2:\"id\";s:8:\"watchdog\";s:5:\"label\";s:8:\"Watchdog\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:19:\"Recent log messages\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"watchdog\";s:10:\"base_field\";s:3:\"wid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:19:\"Recent log messages\";s:6:\"fields\";a:8:{s:7:\"nothing\";a:22:{s:2:\"id\";s:7:\"nothing\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"nothing\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"Icon\";s:9:\"plugin_id\";s:6:\"custom\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:4:\"icon\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:0;}s:3:\"wid\";a:22:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:3:\"WID\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"severity\";a:23:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"machine_name\";s:5:\"label\";s:8:\"Severity\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"machine_name\";b:0;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:9:\"timestamp\";a:25:{s:2:\"id\";s:9:\"timestamp\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:9:\"timestamp\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"label\";s:4:\"Date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:7:\"message\";a:23:{s:2:\"id\";s:7:\"message\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:7:\"message\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:13:\"dblog_message\";s:5:\"label\";s:7:\"Message\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/reports/dblog/event/{{ wid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:13:\"{{ message }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:56;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:1;s:4:\"trim\";b:1;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:1;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"replace_variables\";b:1;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"User\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"link\";a:22:{s:2:\"id\";s:4:\"link\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"link\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"dblog_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"access site reports\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:4:\"area\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:26:\"No log messages available.\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:26:\"No log messages available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:3:\"wid\";a:10:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"wid\";}s:7:\"exposed\";b:0;}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:4:\"type\";a:14:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"dblog_types\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"severity\";a:14:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"in_operator\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"severity_op\";s:5:\"label\";s:8:\"Severity\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"severity_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"severity\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:25:\"{{ type }} {{ severity }}\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:7:\"nothing\";s:7:\"nothing\";s:3:\"wid\";s:3:\"wid\";s:8:\"severity\";s:8:\"severity\";s:4:\"type\";s:4:\"type\";s:9:\"timestamp\";s:9:\"timestamp\";s:7:\"message\";s:7:\"message\";s:4:\"name\";s:4:\"name\";s:4:\"link\";s:4:\"link\";}s:7:\"default\";s:3:\"wid\";s:4:\"info\";a:8:{s:7:\"nothing\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:3:\"wid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:8:\"severity\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"message\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:4:\"link\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:0;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"User\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:11:\"admin-dblog\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/reports/dblog\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.what_s_new',_binary 'a:12:{s:4:\"uuid\";s:36:\"e1df6ee8-b831-49f1-9777-12d640e99636\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:4:{i:0;s:22:\"better_exposed_filters\";i:1;s:4:\"node\";i:2;s:4:\"text\";i:3;s:4:\"user\";}}s:2:\"id\";s:10:\"what_s_new\";s:5:\"label\";s:10:\"What\'s New\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:0:\"\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:5:\"title\";s:10:\"What\'s New\";s:6:\"fields\";a:2:{s:5:\"title\";a:35:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:20:\"<h3>{{ title }}</h3>\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"body\";a:35:{s:2:\"id\";s:4:\"body\";s:5:\"table\";s:10:\"node__body\";s:5:\"field\";s:4:\"body\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:12:\"text_default\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:3:\"bef\";s:7:\"options\";a:10:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";s:19:\"text_input_required\";s:51:\"Select any filter and click on Apply to see results\";s:26:\"text_input_required_format\";s:9:\"full_html\";s:3:\"bef\";a:2:{s:7:\"general\";a:10:{s:10:\"autosubmit\";b:1;s:28:\"autosubmit_exclude_textfield\";b:0;s:26:\"autosubmit_textfield_delay\";i:500;s:35:\"autosubmit_textfield_minimum_length\";i:3;s:15:\"autosubmit_hide\";b:0;s:14:\"input_required\";b:0;s:15:\"allow_secondary\";b:0;s:15:\"secondary_label\";s:16:\"Advanced options\";s:14:\"secondary_open\";b:0;s:24:\"reset_button_always_show\";b:0;}s:6:\"filter\";a:1:{s:7:\"created\";a:2:{s:9:\"plugin_id\";s:7:\"default\";s:8:\"advanced\";a:6:{s:16:\"placeholder_text\";s:0:\"\";s:7:\"rewrite\";a:2:{s:21:\"filter_rewrite_values\";s:0:\"\";s:25:\"filter_rewrite_values_key\";b:0;}s:11:\"collapsible\";b:0;s:34:\"collapsible_disable_automatic_open\";b:0;s:12:\"is_secondary\";b:0;s:10:\"hide_label\";b:0;}}}}}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:0:\"\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:1:{s:8:\"operator\";s:0:\"\";}}s:4:\"type\";a:7:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:5:\"value\";a:1:{s:7:\"article\";s:7:\"article\";}}s:7:\"created\";a:16:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:0:\"\";s:4:\"type\";s:9:\"date_year\";}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:15:{s:11:\"operator_id\";s:10:\"created_op\";s:5:\"label\";s:11:\"Authored on\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"created_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"created\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:14:\"content_editor\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:15:\"min_placeholder\";s:0:\"\";s:15:\"max_placeholder\";s:0:\"\";s:11:\"placeholder\";s:0:\"\";}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:5:\"Year \";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:7:\"created\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:3:{i:1;a:3:{s:5:\"title\";s:4:\"2024\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:4:\"2024\";s:4:\"type\";s:9:\"date_year\";}}i:2;a:3:{s:5:\"title\";s:4:\"2023\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:4:\"2023\";s:4:\"type\";s:9:\"date_year\";}}i:3;a:3:{s:5:\"title\";s:4:\"2022\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:4:\"2022\";s:4:\"type\";s:9:\"date_year\";}}}}}}s:5:\"style\";a:1:{s:4:\"type\";s:7:\"default\";}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:1:{i:0;s:30:\"config:field.storage.node.body\";}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:13:\"exposed_block\";b:1;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:1:{i:0;s:30:\"config:field.storage.node.body\";}}}}}'),('','views.view.who_s_new',_binary 'a:13:{s:4:\"uuid\";s:36:\"d9b64673-64f0-48bb-8588-e15e4bdacdbf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zji0_13MyVGK7Bn1lUMDeZyyOIZedWvqpYUeM_SioPI\";}s:2:\"id\";s:9:\"who_s_new\";s:5:\"label\";s:9:\"Who\'s new\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:53:\"Shows a list of the newest user accounts on the site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:9:\"Who\'s new\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:5;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:1:\">\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:10:\"1970-01-01\";s:4:\"type\";s:4:\"date\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:1:{s:4:\"type\";s:9:\"html_list\";}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:9:\"Who\'s new\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:19:\"A list of new users\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:9:\"Who\'s new\";s:14:\"block_category\";s:4:\"User\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.who_s_online',_binary 'a:13:{s:4:\"uuid\";s:36:\"267c96ad-120e-49d6-9273-b49f1a603f01\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"suDsVMgawXoQt4rfmdfpr05EVX3z3KyfDDTYgeSM898\";}s:2:\"id\";s:12:\"who_s_online\";s:5:\"label\";s:18:\"Who\'s online block\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:93:\"Shows the user names of the most recently active users, and the total number of active users.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:12:\"Who\'s online\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access user profiles\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:35:\"There are currently 0 users online.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:6:\"access\";a:13:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"access\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:2:\">=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:11:\"-15 minutes\";s:4:\"type\";s:6:\"offset\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:9:\"access_op\";s:5:\"label\";s:11:\"Last access\";s:11:\"description\";s:77:\"A user is considered online for this long after they have last viewed a page.\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"access_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"access\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"result\";s:5:\"empty\";b:0;s:7:\"content\";s:40:\"There are currently @total users online.\";}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:18:\"who_s_online_block\";a:6:{s:2:\"id\";s:18:\"who_s_online_block\";s:13:\"display_title\";s:12:\"Who\'s online\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:19:\"display_description\";s:45:\"A list of users that are currently logged in.\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:12:\"Who\'s online\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}');
/*!40000 ALTER TABLE `config` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `config_export`
--

DROP TABLE IF EXISTS `config_export`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `config_export` (
  `collection` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object collection.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object name.',
  `data` longblob COMMENT 'A serialized configuration object data.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for configuration data.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `config_export`
--

LOCK TABLES `config_export` WRITE;
/*!40000 ALTER TABLE `config_export` DISABLE KEYS */;
INSERT INTO `config_export` VALUES ('','admin_toolbar.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvTSppzcgH5wnzBhX5xnAExcp2I1CzkQ_aky65XNfYI\";}s:10:\"menu_depth\";i:4;}'),('','admin_toolbar_tools.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WgdZsrd_5w9jlmcHV4R9dD2tG9OZEkYo4I_O8h7Gq8Q\";}s:17:\"max_bundle_number\";i:20;s:25:\"hoverintent_functionality\";b:1;s:16:\"show_local_tasks\";b:0;}'),('','announcements_feed.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0G5pZBcxbg8ONYzNLd1RJIsvuFFewm9htnS4I-ABKJ8\";}s:7:\"max_age\";i:86400;s:13:\"cron_interval\";i:21600;s:5:\"limit\";i:10;}'),('','automated_cron.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fUksROt4FfkAU9BV4hV2XvhTBSS2nTNrZS4U7S-tKrs\";}s:8:\"interval\";i:10800;}'),('','block.block.claro_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"be976f48-8227-4e04-b46e-05849e446c76\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NjcxOBrPOiK5-38t56DwFBDVY4yer7YSlbRWXFuHe7A\";}s:2:\"id\";s:17:\"claro_breadcrumbs\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"ce83be5e-1fd7-4a0f-9b06-0a0d8710cb26\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a0Yyx1GeyKarZ4T_yXQBR_ZFKnXiFLtxAb6gWLd8nr0\";}s:2:\"id\";s:13:\"claro_content\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"d66baf8e-252f-4c79-acb6-b8b6d6b0a27a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jccFSSVqV0WCDb6NtML1VWAWTtDbZ-zn5YgTRMgMrIM\";}s:2:\"id\";s:10:\"claro_help\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_help_search',_binary 'a:13:{s:4:\"uuid\";s:36:\"05eb19c5-b411-47d2-b90a-e862156e9997\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"module\";a:2:{i:0;s:6:\"search\";i:1;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}s:8:\"enforced\";a:1:{s:6:\"config\";a:1:{i:0;s:23:\"search.page.help_search\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2ToeZLvlHKTeFY74gpgu1PejLoFyCECLO_gw6rAZwqw\";}s:2:\"id\";s:17:\"claro_help_search\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:11:\"Search help\";s:13:\"label_display\";s:7:\"visible\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:11:\"help_search\";}s:10:\"visibility\";a:1:{s:12:\"request_path\";a:4:{s:2:\"id\";s:12:\"request_path\";s:6:\"negate\";b:0;s:15:\"context_mapping\";a:0:{}s:5:\"pages\";s:11:\"/admin/help\";}}}'),('','block.block.claro_local_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"916365b2-7723-493b-8918-5f3ff7d57c7d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CdXfDmRgAvms7EQovxxWPdYi0GitxeRbVtScYK16ZH0\";}s:2:\"id\";s:19:\"claro_local_actions\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"3b00e68f-1ed0-4482-b8b1-e496f1da9936\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-Ac3ISpIT0PQ-whzD7_dw0SdKi6dAbRFNWdSjOiVDqg\";}s:2:\"id\";s:14:\"claro_messages\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"b76f1641-4f78-438e-a0fe-ce65bd7f9006\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNwDdW063tk_ktzSWzZVeQS9wzvLooVO280BQ9WrsIs\";}s:2:\"id\";s:16:\"claro_page_title\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"a8c9d41b-02e1-478d-85b3-fb3a1f815f49\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ACjBZI5shAMiiUpsz-inLYVXDqNNXRnSzAWV3kV_8Hw\";}s:2:\"id\";s:25:\"claro_primary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.claro_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"bb1e9b33-93c2-4829-9613-e4ccc525f30b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2L0geP-ixCbCkEpW6BVF6H7vDUZN4ea07_Y9CociQm4\";}s:2:\"id\";s:27:\"claro_secondary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_account_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"f35c55e3-3d40-497f-9b7f-2896cbc2e345\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:19:\"system.menu.account\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU\";}s:2:\"id\";s:22:\"ept_light_account_menu\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:25:\"system_menu_block:account\";s:8:\"settings\";a:7:{s:2:\"id\";s:25:\"system_menu_block:account\";s:5:\"label\";s:17:\"User account menu\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:1;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"7010f57e-634e-4b97-8a69-97b80a011cb4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE\";}s:2:\"id\";s:21:\"ept_light_breadcrumbs\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:1:{s:12:\"request_path\";a:3:{s:2:\"id\";s:12:\"request_path\";s:6:\"negate\";b:1;s:5:\"pages\";s:10:\"/whats-new\";}}}'),('','block.block.ept_light_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"7b17ab28-0376-4ee3-91ee-5bd02432291e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk\";}s:2:\"id\";s:17:\"ept_light_content\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_footer',_binary 'a:12:{s:4:\"uuid\";s:36:\"a78731d9-6557-4805-9b50-71d93a910730\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:18:\"system.menu.footer\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:2:\"id\";s:16:\"ept_light_footer\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"footer\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:24:\"system_menu_block:footer\";s:8:\"settings\";a:7:{s:2:\"id\";s:24:\"system_menu_block:footer\";s:5:\"label\";s:24:\"Have a question or idea?\";s:13:\"label_display\";s:7:\"visible\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:0;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"8edfdbdd-cd33-4ebe-b1d4-74fb38d1039e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg\";}s:2:\"id\";s:14:\"ept_light_help\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_main_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"736d4519-e22a-419a-87cd-009a768a73b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE\";}s:2:\"id\";s:19:\"ept_light_main_menu\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:22:\"system_menu_block:main\";s:8:\"settings\";a:7:{s:2:\"id\";s:22:\"system_menu_block:main\";s:5:\"label\";s:15:\"Main navigation\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:2;s:16:\"expand_all_items\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"c8fc509e-9767-4eae-81f5-6cdbe64aa2b3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0\";}s:2:\"id\";s:18:\"ept_light_messages\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"f45a0a49-c001-47cb-b97e-767aac0f24f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y\";}s:2:\"id\";s:20:\"ept_light_page_title\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:1:{s:18:\"entity_bundle:node\";a:4:{s:2:\"id\";s:18:\"entity_bundle:node\";s:6:\"negate\";b:0;s:15:\"context_mapping\";a:1:{s:4:\"node\";s:29:\"@node.node_route_context:node\";}s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}}}'),('','block.block.ept_light_primary_admin_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"feb5ed42-838e-41fe-bce3-ac32e38425f9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U\";}s:2:\"id\";s:31:\"ept_light_primary_admin_actions\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"56ef6a64-122b-4123-89be-e28c850c9ab5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4\";}s:2:\"id\";s:29:\"ept_light_primary_local_tasks\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_search_form_narrow',_binary 'a:13:{s:4:\"uuid\";s:36:\"ac6db2d5-4bab-486d-9cbd-5a8bc4c56df9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yEBET0cqDbk8dkWzaJw-8CKft0961VBflsISoSR6Lj8\";}s:2:\"id\";s:28:\"ept_light_search_form_narrow\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"hidden\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:20:\"Search form (narrow)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_search_form_wide',_binary 'a:13:{s:4:\"uuid\";s:36:\"682b08d1-3f45-4c13-974e-95552426afcd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"imMyHD6LYci0gtXq56qr9ZKGHzbEG9uFydrN5EhKtSU\";}s:2:\"id\";s:26:\"ept_light_search_form_wide\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"hidden\";s:6:\"weight\";i:-6;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:18:\"Search form (wide)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"901eabdd-054d-4bcb-9773-45c7fd010fdf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI\";}s:2:\"id\";s:31:\"ept_light_secondary_local_tasks\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-3;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.ept_light_site_branding',_binary 'a:13:{s:4:\"uuid\";s:36:\"91c1ee17-a1ad-4235-992c-274ff1022382\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM\";}s:2:\"id\";s:23:\"ept_light_site_branding\";s:5:\"theme\";s:9:\"ept_light\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_branding_block\";s:8:\"settings\";a:7:{s:2:\"id\";s:21:\"system_branding_block\";s:5:\"label\";s:13:\"Site branding\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:13:\"use_site_logo\";b:1;s:13:\"use_site_name\";b:1;s:15:\"use_site_slogan\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"906009a1-78bd-4b80-9f60-5260448561b2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"y9X3xgCsO59pQyzNLzY1D3SDJJxCHILLWkpPnmuTJ2E\";}s:2:\"id\";s:15:\"gin_breadcrumbs\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"38507368-0a7f-4498-a629-376fb4821455\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBHXB7hC05XU7pDYzETt-GUcpFlogK1gkjyAsg0Ym58\";}s:2:\"id\";s:11:\"gin_content\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"e3753ad7-7b76-4f93-add9-02296fe5a072\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8nOAry2oKqJOr0zbrlJ3sZHDFJLIO6j-0vT0K_TYca4\";}s:2:\"id\";s:8:\"gin_help\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_local_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"f127d369-8154-4de3-9366-638b32c1d495\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OQ9aJ-4qVwK1x00o9EOYK4eFDjQr_HLpbPiJaPSVZiQ\";}s:2:\"id\";s:17:\"gin_local_actions\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"302175a6-2514-4728-9834-feade3c1cb23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WvPhI8OwllG0gE69-F8qL3ai3nd5SbYD6JpmEuZcyok\";}s:2:\"id\";s:12:\"gin_messages\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"37f8f7d2-81b3-4c42-a9a4-84cb29380e2c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HLQY2xgby8K3vN_98hiOSasOhm9pdCsH234-s0duJ8Q\";}s:2:\"id\";s:14:\"gin_page_title\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"877e883f-c61a-49fd-bf14-7370c20fec8c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Hh01DLj9k7UnNdPpOQXHZHW7GHf2OPNDQyCJF7_R9ac\";}s:2:\"id\";s:23:\"gin_primary_local_tasks\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.gin_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"11d088e1-eb0e-4d66-ac1d-c629d4c31759\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:3:\"gin\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCWhood0xXFQYqxFgL1spXdb9KeIuXH1YvTdjIEedDg\";}s:2:\"id\";s:25:\"gin_secondary_local_tasks\";s:5:\"theme\";s:3:\"gin\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_account_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"360ce22f-fdb1-4a74-baf4-b253df6d8b6d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:19:\"system.menu.account\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU\";}s:2:\"id\";s:20:\"olivero_account_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:25:\"system_menu_block:account\";s:8:\"settings\";a:7:{s:2:\"id\";s:25:\"system_menu_block:account\";s:5:\"label\";s:17:\"User account menu\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:1;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_breadcrumbs',_binary 'a:13:{s:4:\"uuid\";s:36:\"19cc65dc-0021-4f62-9692-28154e28e6d6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE\";}s:2:\"id\";s:19:\"olivero_breadcrumbs\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"45129ab9-c3af-46c1-b266-7caf3e552d05\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk\";}s:2:\"id\";s:15:\"olivero_content\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_help',_binary 'a:13:{s:4:\"uuid\";s:36:\"1f0cb4e0-55ff-4097-a00c-015a0892bae5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg\";}s:2:\"id\";s:12:\"olivero_help\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_main_menu',_binary 'a:13:{s:4:\"uuid\";s:36:\"447aab50-0670-4a09-ad2b-204da3cad682\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE\";}s:2:\"id\";s:17:\"olivero_main_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:22:\"system_menu_block:main\";s:8:\"settings\";a:7:{s:2:\"id\";s:22:\"system_menu_block:main\";s:5:\"label\";s:15:\"Main navigation\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:2;s:16:\"expand_all_items\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_messages',_binary 'a:13:{s:4:\"uuid\";s:36:\"07cc9530-0745-41b8-a927-b15f94d11bfb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0\";}s:2:\"id\";s:16:\"olivero_messages\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_page_title',_binary 'a:13:{s:4:\"uuid\";s:36:\"8ed1a440-61c0-42d9-af64-c0573a386802\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y\";}s:2:\"id\";s:18:\"olivero_page_title\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_powered',_binary 'a:13:{s:4:\"uuid\";s:36:\"4e19c95d-851d-48dd-8e91-3df3501787a3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYL19CLDyinGTWYQfBD1DswWzglEotE_kHnHx3AxTXM\";}s:2:\"id\";s:15:\"olivero_powered\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"footer_bottom\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_powered_by_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_powered_by_block\";s:5:\"label\";s:17:\"Powered by Drupal\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_primary_admin_actions',_binary 'a:13:{s:4:\"uuid\";s:36:\"2889853d-c6c8-46fb-8345-4f1161d60b42\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U\";}s:2:\"id\";s:29:\"olivero_primary_admin_actions\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_primary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"4a702f15-1477-4e9c-a8bf-5c98f5bff5f5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4\";}s:2:\"id\";s:27:\"olivero_primary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_search_form_narrow',_binary 'a:13:{s:4:\"uuid\";s:36:\"8eba635a-7f03-408c-a4a4-28e12ca89e20\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yEBET0cqDbk8dkWzaJw-8CKft0961VBflsISoSR6Lj8\";}s:2:\"id\";s:26:\"olivero_search_form_narrow\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:20:\"Search form (narrow)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_search_form_wide',_binary 'a:13:{s:4:\"uuid\";s:36:\"decd9477-39d6-4529-94a3-8a2d5f064f46\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"imMyHD6LYci0gtXq56qr9ZKGHzbEG9uFydrN5EhKtSU\";}s:2:\"id\";s:24:\"olivero_search_form_wide\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:18:\"Search form (wide)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_secondary_local_tasks',_binary 'a:13:{s:4:\"uuid\";s:36:\"b7350fce-d849-4243-936a-283b164fea04\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI\";}s:2:\"id\";s:29:\"olivero_secondary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-2;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_site_branding',_binary 'a:13:{s:4:\"uuid\";s:36:\"5e004719-546a-4a9e-8ed6-bce3b1438316\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM\";}s:2:\"id\";s:21:\"olivero_site_branding\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_branding_block\";s:8:\"settings\";a:7:{s:2:\"id\";s:21:\"system_branding_block\";s:5:\"label\";s:13:\"Site branding\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:13:\"use_site_logo\";b:1;s:13:\"use_site_name\";b:1;s:15:\"use_site_slogan\";b:0;}s:10:\"visibility\";a:0:{}}'),('','block.block.olivero_syndicate',_binary 'a:13:{s:4:\"uuid\";s:36:\"b7ad69dc-b6ab-4ee3-ab50-2994b490c801\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0gq3VPg-_UM69FCCWurLFIrrnIjC2HLKhwo9iQNtcUo\";}s:2:\"id\";s:17:\"olivero_syndicate\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"social\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:20:\"node_syndicate_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:20:\"node_syndicate_block\";s:5:\"label\";s:8:\"RSS feed\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"node\";s:11:\"block_count\";i:10;}s:10:\"visibility\";a:0:{}}'),('','block_content.type.basic',_binary 'a:9:{s:4:\"uuid\";s:36:\"682f8d4b-7fbf-4b68-aeeb-78ff6ffa44c8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pQP5iQy4SdhAMVcjDUncCfkJmTofnHVtXrsMzx4k6Yk\";}s:2:\"id\";s:5:\"basic\";s:5:\"label\";s:11:\"Basic block\";s:8:\"revision\";b:0;s:11:\"description\";s:42:\"A basic block contains a title and a body.\";}'),('','ckeditor5_plugin_pack.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uAMHMIBA-fCvlzeeOYZ4vKwSBXvThlEytdEKK_Ur8nI\";}s:12:\"dll_location\";s:0:\"\";}'),('','claro.settings',_binary 'a:1:{s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}}'),('','comment.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YNUW2Ij5uE7a4oaXp3i_2lvaFdYM1zNKPPfnEjB0jEc\";}s:16:\"log_ip_addresses\";b:0;}'),('','comment.type.comment',_binary 'a:9:{s:4:\"uuid\";s:36:\"33c6c326-f5e0-4ece-8508-28b245963a92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bqZsN31T2n0UjcbyCpOPi9D2iO0sAOHR7FnEs9qMvaA\";}s:2:\"id\";s:7:\"comment\";s:5:\"label\";s:16:\"Default comments\";s:21:\"target_entity_type_id\";s:4:\"node\";s:11:\"description\";s:28:\"Allows commenting on content\";}'),('','contact.form.feedback',_binary 'a:12:{s:4:\"uuid\";s:36:\"d9d62dfa-bada-46f4-869f-64b74f835a2f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vymHlgJy26BuI5GGj9-IXjwR3dRC5C0tij4BpWJnoqw\";}s:2:\"id\";s:8:\"feedback\";s:5:\"label\";s:16:\"Website feedback\";s:10:\"recipients\";a:1:{i:0;s:17:\"admin@example.com\";}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),('','contact.form.personal',_binary 'a:12:{s:4:\"uuid\";s:36:\"3d45f5dc-8385-44e2-add9-10e58ad548b8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jonvgt3CkUM2eMLTFwWfHileWWDC4YtXCuIlCahTk_I\";}s:2:\"id\";s:8:\"personal\";s:5:\"label\";s:21:\"Personal contact form\";s:10:\"recipients\";a:0:{}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),('','contact.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U69DBeuvXuNVOC15rVNaBjDPK2fWFbo9v4takdYSSO8\";}s:12:\"default_form\";s:8:\"feedback\";s:5:\"flood\";a:2:{s:5:\"limit\";i:5;s:8:\"interval\";i:3600;}s:20:\"user_default_enabled\";b:1;}'),('','core.base_field_override.node.page.promote',_binary 'a:17:{s:4:\"uuid\";s:36:\"3818335f-a764-468f-ba14-8dbe325fa7f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:14:\"node.type.page\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fPUEnm4T5zfZRr3ttDUqq7yCDd2uW3clWD-pvos4tlQ\";}s:2:\"id\";s:17:\"node.page.promote\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:22:\"Promoted to front page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),('','core.date_format.fallback',_binary 'a:9:{s:4:\"uuid\";s:36:\"3d36a601-a518-4117-b489-72f027a4d007\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7klS5IWXrwzVaPpYZFAs6wcx8U2FF1X73OfrtTsvuvE\";}s:2:\"id\";s:8:\"fallback\";s:5:\"label\";s:20:\"Fallback date format\";s:6:\"locked\";b:1;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),('','core.date_format.html_date',_binary 'a:9:{s:4:\"uuid\";s:36:\"1e7ea1cc-62aa-4605-b6b6-e50e8e13c716\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EOQltUQPmgc6UQ2rcJ4Xi_leCEJj5ui0TR-12duS-Tk\";}s:2:\"id\";s:9:\"html_date\";s:5:\"label\";s:9:\"HTML Date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-m-d\";}'),('','core.date_format.html_datetime',_binary 'a:9:{s:4:\"uuid\";s:36:\"c34d2a68-a9e5-40c6-8224-8940032e30eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jxfClwZIRXIdcvMrE--WkcZxDGUVoOIE3Sm2NRZlFuE\";}s:2:\"id\";s:13:\"html_datetime\";s:5:\"label\";s:13:\"HTML Datetime\";s:6:\"locked\";b:1;s:7:\"pattern\";s:13:\"Y-m-d\\TH:i:sO\";}'),('','core.date_format.html_month',_binary 'a:9:{s:4:\"uuid\";s:36:\"1db472d5-aa8d-43d1-99f1-0718ae5620bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Z7KuCUwM_WdTNvLcoltuX3_8d-s-8FZkTN6KgNwF0eM\";}s:2:\"id\";s:10:\"html_month\";s:5:\"label\";s:10:\"HTML Month\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"Y-m\";}'),('','core.date_format.html_time',_binary 'a:9:{s:4:\"uuid\";s:36:\"504c65d8-2f56-4376-8b9b-e7ca5b007ba8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M7yqicYkU36hRy5p9drAaGBBihhUD1OyujFrAaQ93ZE\";}s:2:\"id\";s:9:\"html_time\";s:5:\"label\";s:9:\"HTML Time\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"H:i:s\";}'),('','core.date_format.html_week',_binary 'a:9:{s:4:\"uuid\";s:36:\"9c97ee83-74c2-4456-80d2-eb94e9ca333e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKD4WsoV_wFgv2vgI4mcAAFSIzrye17ykzdwrnApkfY\";}s:2:\"id\";s:9:\"html_week\";s:5:\"label\";s:9:\"HTML Week\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-\\WW\";}'),('','core.date_format.html_year',_binary 'a:9:{s:4:\"uuid\";s:36:\"045e5b96-3ec2-48a7-ba8c-c6cd6c3e6478\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjekiQuX9RbVQ2_8jOHBL94RgYLePqX7wpfNGgcQzrk\";}s:2:\"id\";s:9:\"html_year\";s:5:\"label\";s:9:\"HTML Year\";s:6:\"locked\";b:1;s:7:\"pattern\";s:1:\"Y\";}'),('','core.date_format.html_yearless_date',_binary 'a:9:{s:4:\"uuid\";s:36:\"ebd666ec-7725-4d54-8907-f69b8c4e48ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VpawMrKPEPCkoO4YpPa0TDFO2dgiIHfTziJtwlmUxc\";}s:2:\"id\";s:18:\"html_yearless_date\";s:5:\"label\";s:18:\"HTML Yearless date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"m-d\";}'),('','core.date_format.long',_binary 'a:9:{s:4:\"uuid\";s:36:\"26c2a255-dd57-40de-9edb-d3ecd4eafa69\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"og8sWXhBuHbLMw3CoiBEZjgqSyhFBFmcbUW_wLcfNbo\";}s:2:\"id\";s:4:\"long\";s:5:\"label\";s:17:\"Default long date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:15:\"l, F j, Y - H:i\";}'),('','core.date_format.medium',_binary 'a:9:{s:4:\"uuid\";s:36:\"b3b94f80-dd74-4a2f-b128-51de30c5e289\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nzL5d024NjXIX_8TlT6uFAu973lmfkmHklJC-2i9rAE\";}s:2:\"id\";s:6:\"medium\";s:5:\"label\";s:19:\"Default medium date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),('','core.date_format.olivero_medium',_binary 'a:9:{s:4:\"uuid\";s:36:\"f5992887-d80e-47c5-bcb3-28c304448abb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mt6cmxUbDZ9XxD6p25WQ8tj3_JcX8ylfcddwZc8gcAE\";}s:2:\"id\";s:14:\"olivero_medium\";s:5:\"label\";s:14:\"Olivero Medium\";s:6:\"locked\";b:0;s:7:\"pattern\";s:8:\"j  F,  Y\";}'),('','core.date_format.short',_binary 'a:9:{s:4:\"uuid\";s:36:\"c5c2ce9a-1442-4bf1-a654-b45e23c4b6e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AlzeyytA8InBgxIG9H2UDJYs3CG98Zj6yRsDKmlbZwA\";}s:2:\"id\";s:5:\"short\";s:5:\"label\";s:18:\"Default short date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:11:\"m/d/Y - H:i\";}'),('','core.entity_form_display.block_content.basic.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"21a9c7b6-423a-4c02-931a-6bb7c808ca5e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jAps3FCxvKecABS_tgExbhCZrBLQB3bNPWw18WjE3ss\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:-4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.comment.comment.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"46bc1cc1-610e-4909-9538-f9f08a6a24c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:40:\"field.field.comment.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I0Pa0aQvT_jawlPo9oz4FE3h_ickc55dYKTPl6gILes\";}s:2:\"id\";s:23:\"comment.comment.default\";s:16:\"targetEntityType\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:6:\"author\";a:2:{s:6:\"weight\";i:-2;s:6:\"region\";s:7:\"content\";}s:12:\"comment_body\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:11;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:7:\"subject\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.media.audio.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"1912a858-abb3-4ca8-aa94-e9265ace4567\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"G2_SKH3jmI9FQeXSUxo3KgQqiyF1hPDEkc7-3-rCSbc\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_audio_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.audio.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"4c160f87-d7c6-4dde-a9d2-878ce2336387\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:16:\"media.type.audio\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"28vwMIYtvyjPcD4RyciZXIztxtZgmuWRCNgYemr_SZE\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.document.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"c24b87ec-64f6-4fa0-aed7-1c3d86160e5e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aewrRkePgJzdD5kPOq8JeMcKHs6yat49nE7ZeCQzQZg\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_media_document\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.document.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"8323a260-ffc2-4476-8123-c40c72552a6e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:19:\"media.type.document\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dcpfpqyLXOSGpulacMAJW3H-G34_LeNsjdfxd1_oCfY\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.image.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f08ad847-8b1c-4396-9081-ca9a56f6b01a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:21:\"image.style.thumbnail\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JSY4-JPyNZBiYYo6imdRYF6_SdtWQexPndrLvn3-vw4\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.image.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"91fbcfb7-0a83-434f-99ac-c23c349657be\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BMLrK4zKp8-FFnMseBdT_6h6YipUsKRfbDf_3WUB5HA\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:5:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.remote_video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"97a32351-c013-445a-af13-08939389c3b1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pM8mGlwfpvfG_y5tZn0lGAXFLXz2_yKkL7MvWZsRqdA\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_media_oembed_video\";a:5:{s:4:\"type\";s:16:\"oembed_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.remote_video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"47cd5408-95d9-4b89-a9c5-7d8aedd625f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBgPW-uaXRaICBwLaVc16rXpRiLSknDIdF9q0XL7qso\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.media.video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"7c5e18c3-3d08-4151-8d31-a9d9a597a5ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0kIIaDTt6dixXy8TZkat2MNGZJ6vkRG8TaBWTy3E1bM\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_video_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),('','core.entity_form_display.media.video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"3d683f4e-cbb1-4a0e-b1df-f9f9c87e4284\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:16:\"media.type.video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kGv8YsopqHvzTzb7QTINWcv0fnNa5ZDQyZxpOQR2vro\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_form_display.node.article.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"de67467e-664b-4fd4-b096-f4f20912ea91\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:35:\"field.field.node.article.field_tags\";i:3;s:21:\"image.style.thumbnail\";i:4;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"path\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ewbd6G2uX456-bgwseM2Q-KQG3RkASoyHmTh-XR3oLU\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:10:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:11:\"field_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:10:\"field_tags\";a:5:{s:4:\"type\";s:34:\"entity_reference_autocomplete_tags\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.node.page.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"c6ec1d38-d434-4a7d-be65-080873fd0aff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:26:\"field.field.node.page.body\";i:1;s:38:\"field.field.node.page.field_components\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:3:{i:0;s:17:\"layout_paragraphs\";i:1;s:4:\"path\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SfpLhPExzvR0MgFp0Wp7CrmgEnhcqQ-fXIWFhbf4ue0\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:9:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:31;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:16:\"field_components\";a:5:{s:4:\"type\";s:17:\"layout_paragraphs\";s:6:\"weight\";i:121;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_display.paragraph.ept_accordion.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"bcf372a8-c025-4ef1-bc1e-7467ead740ff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:55:\"field.field.paragraph.ept_accordion.field_ept_accordion\";i:1;s:54:\"field.field.paragraph.ept_accordion.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_accordion.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_accordion.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:4:{i:0;s:13:\"ept_accordion\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:19:\"field_ept_accordion\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0pJauu3QzSH4aBsmd_KTxzf59AWAoqGvmpFOuI3phow\";}s:2:\"id\";s:31:\"paragraph.ept_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:19:\"field_ept_accordion\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:22:\"ept_settings_accordion\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_accordion_section.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a18df3e8-1c60-449a-81fb-3d8f4dc347dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:68:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_text\";i:1;s:69:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_title\";i:2;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-D0_ofC0E9vG5JgJKn-KVVKS8EddSulFMva-vLSGBq4\";}s:2:\"id\";s:39:\"paragraph.ept_accordion_section.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ept_accordion_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_accordion_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_basic_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"3bbc19b5-b8d1-4737-93da-814614ad0da5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:66:\"field.field.paragraph.ept_basic_button.field_ept_basic_button_link\";i:1;s:57:\"field.field.paragraph.ept_basic_button.field_ept_settings\";i:2;s:53:\"field.field.paragraph.ept_basic_button.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_basic_button.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:3:{i:0;s:16:\"ept_basic_button\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BDM_dmNUeNyOV7_jEouKixGZvfGdfIYFnegSbt0TFUk\";}s:2:\"id\";s:34:\"paragraph.ept_basic_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:27:\"field_ept_basic_button_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:25:\"ept_settings_basic_button\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_block.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"063fafbf-a44a-44d9-b44e-e6b7f1c968f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_block.field_ept_block_block\";i:1;s:50:\"field.field.paragraph.ept_block.field_ept_settings\";i:2;s:46:\"field.field.paragraph.ept_block.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_block.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:4:{i:0;s:11:\"block_field\";i:1;s:8:\"ept_core\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:21:\"field_ept_block_block\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kf0CKi0lVMCHZKEFVJNSYNl5CpKFKRH7JLsGDr_mt24\";}s:2:\"id\";s:27:\"paragraph.ept_block.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:21:\"field_ept_block_block\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_bootstrap_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"39e1a15a-eab7-4dcc-af37-af10f81e96dd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:74:\"field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";i:1;s:61:\"field.field.paragraph.ept_bootstrap_button.field_ept_settings\";i:2;s:57:\"field.field.paragraph.ept_bootstrap_button.field_ept_text\";i:3;s:58:\"field.field.paragraph.ept_bootstrap_button.field_ept_title\";i:4;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:3:{i:0;s:20:\"ept_bootstrap_button\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WwkZbBHhL-k1BpcZgfCET2hj9ScPYC5rcs4an-tHYB4\";}s:2:\"id\";s:38:\"paragraph.ept_bootstrap_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:31:\"field_ept_bootstrap_button_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:29:\"ept_settings_bootstrap_button\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_carousel.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"3b42b32b-b440-4ab8-9a73-96284648f0b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_carousel.field_ept_carousel\";i:1;s:53:\"field.field.paragraph.ept_carousel.field_ept_settings\";i:2;s:49:\"field.field.paragraph.ept_carousel.field_ept_text\";i:3;s:50:\"field.field.paragraph.ept_carousel.field_ept_title\";i:4;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:4:{i:0;s:12:\"ept_carousel\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:18:\"field_ept_carousel\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:1;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9B69asgWfAo5TT1550-4nwxxD-NZ9b_eK0DwrqjPbAI\";}s:2:\"id\";s:30:\"paragraph.ept_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_carousel\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:21:\"ept_settings_carousel\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_carousel_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"209743da-7b46-410c-8256-e9acf9b4200b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";i:1;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";i:2;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0MubGNP7-aRTqqknjrXSWiyr6o87xC8YYQSjnFL1qMA\";}s:2:\"id\";s:35:\"paragraph.ept_carousel_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ept_carousel_caption\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ept_carousel_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_columns.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"4fadf498-bcbb-44d6-b829-6d1abdabf326\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:51:\"field.field.paragraph.ept_columns.field_ept_columns\";i:1;s:52:\"field.field.paragraph.ept_columns.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_columns.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_columns.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:4:{i:0;s:11:\"ept_columns\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:17:\"field_ept_columns\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MfVgHlmnR_bb8akzrozdi7R7KwnEOtq9cQ0OpHkngMs\";}s:2:\"id\";s:29:\"paragraph.ept_columns.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:17:\"field_ept_columns\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_columns\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_countdown.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"ed55009f-a01e-42ae-987d-b5ccc04e073b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ept_countdown.field_ept_countdown_date\";i:1;s:54:\"field.field.paragraph.ept_countdown.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_countdown.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_countdown.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:4:{i:0;s:8:\"datetime\";i:1;s:13:\"ept_countdown\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:24:\"field_ept_countdown_date\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZxcirB8U5v0ZYrJRdwsxmS_1WIhbNwZMbBqsAz988cQ\";}s:2:\"id\";s:31:\"paragraph.ept_countdown.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_countdown_date\";a:5:{s:4:\"type\";s:16:\"datetime_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:22:\"ept_settings_countdown\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_counter.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"6e0ad4c3-90f1-4e63-9ad2-e7c012a124d2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_counter.field_ept_counter_items\";i:1;s:52:\"field.field.paragraph.ept_counter.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_counter.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_counter.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:4:{i:0;s:11:\"ept_counter\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:23:\"field_ept_counter_items\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:9;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eaw1Ar6YTSIRF829Uy9SPd0v5CFQ_XobGxIEZV3aq_Q\";}s:2:\"id\";s:29:\"paragraph.ept_counter.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_counter_items\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_counter\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_counter_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8c95a60e-1c70-45a6-b8a2-c4d53b93ce5d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_counter_item.field_ept_counter_description\";i:1;s:61:\"field.field.paragraph.ept_counter_item.field_ept_counter_icon\";i:2;s:63:\"field.field.paragraph.ept_counter_item.field_ept_counter_number\";i:3;s:62:\"field.field.paragraph.ept_counter_item.field_ept_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HdOx-dFGYXleAxDzMra4AkSnLaUMOZ6Sgl69k93sJcg\";}s:2:\"id\";s:34:\"paragraph.ept_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ept_counter_description\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ept_counter_icon\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ept_counter_number\";a:5:{s:4:\"type\";s:6:\"number\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ept_counter_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_cta.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"8a29f047-88c0-4af9-8cd2-705177201f7a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:56:\"field.field.paragraph.ept_cta.field_ept_cta_column_image\";i:1;s:48:\"field.field.paragraph.ept_cta.field_ept_cta_link\";i:2;s:55:\"field.field.paragraph.ept_cta.field_ept_cta_second_link\";i:3;s:48:\"field.field.paragraph.ept_cta.field_ept_settings\";i:4;s:44:\"field.field.paragraph.ept_cta.field_ept_text\";i:5;s:45:\"field.field.paragraph.ept_cta.field_ept_title\";i:6;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:5:{i:0;s:7:\"ept_cta\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:5:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:26:\"field_ept_cta_column_image\";i:3;s:18:\"field_ept_cta_link\";i:4;s:25:\"field_ept_cta_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:1;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4FYtKN9WoslLXaZoBk3fkuVx6aDPk0YoM6rC8pnsieA\";}s:2:\"id\";s:25:\"paragraph.ept_cta.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:26:\"field_ept_cta_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_cta_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_cta_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:16:\"ept_settings_cta\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_hero.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"be53fd67-518c-4b3c-ac43-3b2c15a8d954\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_column_image\";i:1;s:50:\"field.field.paragraph.ept_hero.field_ept_hero_link\";i:2;s:57:\"field.field.paragraph.ept_hero.field_ept_hero_second_link\";i:3;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_title_prefix\";i:4;s:49:\"field.field.paragraph.ept_hero.field_ept_settings\";i:5;s:45:\"field.field.paragraph.ept_hero.field_ept_text\";i:6;s:46:\"field.field.paragraph.ept_hero.field_ept_title\";i:7;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:5:{i:0;s:8:\"ept_hero\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:6:{i:0;s:15:\"field_ept_title\";i:1;s:27:\"field_ept_hero_title_prefix\";i:2;s:14:\"field_ept_text\";i:3;s:27:\"field_ept_hero_column_image\";i:4;s:19:\"field_ept_hero_link\";i:5;s:26:\"field_ept_hero_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jU5fU7CphqYF6ZSn4c9q-QZ0_XHfDeFV936TKmTKPIM\";}s:2:\"id\";s:26:\"paragraph.ept_hero.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:27:\"field_ept_hero_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_hero_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ept_hero_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_hero_title_prefix\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:17:\"ept_settings_hero\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_image.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"a60ae7a6-353d-412e-81ca-b8eff5eb6f78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:47:\"field.field.paragraph.ept_image.field_ept_image\";i:1;s:55:\"field.field.paragraph.ept_image.field_ept_image_caption\";i:2;s:52:\"field.field.paragraph.ept_image.field_ept_image_link\";i:3;s:50:\"field.field.paragraph.ept_image.field_ept_settings\";i:4;s:46:\"field.field.paragraph.ept_image.field_ept_text\";i:5;s:47:\"field.field.paragraph.ept_image.field_ept_title\";i:6;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:5:{i:0;s:9:\"ept_image\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:5:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:15:\"field_ept_image\";i:3;s:23:\"field_ept_image_caption\";i:4;s:20:\"field_ept_image_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6-OjP-OV8uHyYxN_ycg0WCoPJRu34t3ix7LwCCNbTzE\";}s:2:\"id\";s:27:\"paragraph.ept_image.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:15:\"field_ept_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ept_image_caption\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_image_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_image\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_image_gallery.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"bd32a1a0-f63c-4e6b-b14f-7dfa6323a07a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_image_gallery.field_ept_image_gallery\";i:1;s:58:\"field.field.paragraph.ept_image_gallery.field_ept_settings\";i:2;s:54:\"field.field.paragraph.ept_image_gallery.field_ept_text\";i:3;s:55:\"field.field.paragraph.ept_image_gallery.field_ept_title\";i:4;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:4:{i:0;s:17:\"ept_image_gallery\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:23:\"field_ept_image_gallery\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9b_KN3kBrDhBERN17M7jxBYPF-IXaw1nLONpCw4Dtzo\";}s:2:\"id\";s:35:\"paragraph.ept_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_image_gallery\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:26:\"ept_settings_image_gallery\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_micromodal.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"c0e1ca3f-d656-43c4-a362-86c7cb0ac490\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_micromodal.field_ept_micromodal_title\";i:1;s:55:\"field.field.paragraph.ept_micromodal.field_ept_settings\";i:2;s:51:\"field.field.paragraph.ept_micromodal.field_ept_text\";i:3;s:52:\"field.field.paragraph.ept_micromodal.field_ept_title\";i:4;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:3:{i:0;s:14:\"ept_micromodal\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:14:\"group_settings\";i:1;s:13:\"group_content\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:26:\"field_ept_micromodal_title\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:6:\"hidden\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ynF9PLVVYG00_7Br42jxgJ02cMPPwmtf3jssH3Gx9T8\";}s:2:\"id\";s:32:\"paragraph.ept_micromodal.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_micromodal_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:23:\"ept_settings_micromodal\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_quote.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"62a89609-5a89-4eb4-a5a2-c3c58c93480d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:54:\"field.field.paragraph.ept_quote.field_ept_quote_author\";i:1;s:53:\"field.field.paragraph.ept_quote.field_ept_quote_image\";i:2;s:50:\"field.field.paragraph.ept_quote.field_ept_settings\";i:3;s:46:\"field.field.paragraph.ept_quote.field_ept_text\";i:4;s:47:\"field.field.paragraph.ept_quote.field_ept_title\";i:5;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_quote\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:4:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:22:\"field_ept_quote_author\";i:3;s:21:\"field_ept_quote_image\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:1;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rMIoq7ATvLm5GYUegulzLGA67l1jIqNeN1Vma_Calus\";}s:2:\"id\";s:27:\"paragraph.ept_quote.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:22:\"field_ept_quote_author\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_quote_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_quote\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slick_slider.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"6b2455af-c7c1-4faf-ae2f-5faf8b33c82d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_slick_slider.field_ept_settings\";i:1;s:61:\"field.field.paragraph.ept_slick_slider.field_ept_slick_slider\";i:2;s:53:\"field.field.paragraph.ept_slick_slider.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_slick_slider.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:4:{i:0;s:16:\"ept_slick_slider\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:22:\"field_ept_slick_slider\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hDbTWzuXu3VZtJk1OkYoVRSHUWjZQRwzNKl8MSfnHZo\";}s:2:\"id\";s:34:\"paragraph.ept_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:25:\"ept_settings_slick_slider\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ept_slick_slider\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slick_slider_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"0e9a2579-f110-4139-81b2-dc1025db5053\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:72:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";i:1;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";i:2;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";i:3;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CjC8L66tFduxz7PpSEZ_n5Vewr_T4E3BXo6iZw5cPjs\";}s:2:\"id\";s:39:\"paragraph.ept_slick_slider_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ept_slick_slider_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_slick_slider_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_slick_slider_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slideshow.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"1003a694-14ea-404d-bf58-34d4ad51a83c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:54:\"field.field.paragraph.ept_slideshow.field_ept_settings\";i:1;s:55:\"field.field.paragraph.ept_slideshow.field_ept_slideshow\";i:2;s:50:\"field.field.paragraph.ept_slideshow.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_slideshow.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:4:{i:0;s:13:\"ept_slideshow\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:19:\"field_ept_slideshow\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tILUBTEfzAAfH3RNpAfKLafcB4BQ1rEs4TXsefzXpz8\";}s:2:\"id\";s:31:\"paragraph.ept_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:22:\"ept_settings_slideshow\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_slideshow\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_slideshow_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"483f7e15-2bcb-4ed9-952b-548c4960e622\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link\";i:1;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide\";i:2;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text\";i:3;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title\";i:4;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wXdtnml8iEI3B2hPt_jBFMcr9wunJPj97vsPtPVoSlI\";}s:2:\"id\";s:36:\"paragraph.ept_slideshow_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_slideshow_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_slideshow_slide\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ept_slideshow_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_slideshow_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_stats.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"a9e1d9c8-64cb-4c33-ae6e-7c4617fa82d4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_stats.field_ept_settings\";i:1;s:47:\"field.field.paragraph.ept_stats.field_ept_stats\";i:2;s:46:\"field.field.paragraph.ept_stats.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_stats.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_stats\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:15:\"field_ept_stats\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iULioKDpET9pDqjdWoX6RbIYNdzK6nuBHJbWBY8s8hw\";}s:2:\"id\";s:27:\"paragraph.ept_stats.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_stats\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_stats\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_stats_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"11f77720-51d3-4dc6-b653-b86d5771046b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_image\";i:1;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_link\";i:2;s:64:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_number\";i:3;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wF_mUJwfQr8bsVI-d3u1R2W8PUu9gazphbDkBAY2SEk\";}s:2:\"id\";s:32:\"paragraph.ept_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_stats_item_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_stats_item_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_stats_item_number\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ept_stats_item_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tabs.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"e1a6c8e5-95b1-4c04-8b08-798a42e3f990\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:49:\"field.field.paragraph.ept_tabs.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_tabs.field_ept_tabs\";i:2;s:45:\"field.field.paragraph.ept_tabs.field_ept_text\";i:3;s:46:\"field.field.paragraph.ept_tabs.field_ept_title\";i:4;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:4:{i:0;s:8:\"ept_tabs\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:14:\"field_ept_tabs\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qwxwo_7tJPCVoTpGT3EGZT8rcmOT-hnPcBxVGLjPG78\";}s:2:\"id\";s:26:\"paragraph.ept_tabs.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:17:\"ept_settings_tabs\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_tabs\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tabs_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2ba6d267-9074-4e3c-a4c5-e392e2e1b8ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_block\";i:1;s:57:\"field.field.paragraph.ept_tabs_item.field_ept_tab_content\";i:2;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_page\";i:3;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_text\";i:4;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_title\";i:5;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_views\";i:6;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oVvZoAPE_jk4D2dNYM8_LohZLLeaIQBnleftotvYd7o\";}s:2:\"id\";s:31:\"paragraph.ept_tabs_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:19:\"field_ept_tab_block\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_tab_content\";a:5:{s:4:\"type\";s:14:\"options_select\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_tab_page\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_tab_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_tab_title\";a:5:{s:4:\"type\";s:14:\"text_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_tab_views\";a:5:{s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_text.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"0a168361-abfe-403a-8922-8305dbbef7af\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:49:\"field.field.paragraph.ept_text.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_text.field_ept_text\";i:2;s:46:\"field.field.paragraph.ept_text.field_ept_title\";i:3;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:6:\"hidden\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"shyYm2rY3OjdKeiRCtoWJpvauXuaTQJb8xb0cyNYRM8\";}s:2:\"id\";s:26:\"paragraph.ept_text.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:21;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:23;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:22;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tiles.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"a5784c00-a16b-4f3b-91dd-568be1356d3a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_tiles.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_tiles.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_tiles.field_ept_tiles\";i:3;s:47:\"field.field.paragraph.ept_tiles.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_tiles\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:15:\"field_ept_tiles\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:11;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:12;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Fub48PSonCbwVzLnLvqqeYQk1wGzEf65HefNdP-qQaQ\";}s:2:\"id\";s:27:\"paragraph.ept_tiles.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_tiles\";s:6:\"weight\";i:11;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_tiles\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_tiles_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"45b2e5a1-2031-4177-b3c2-580549849e46\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ept_tiles_item.field_ept_clickable_tile\";i:1;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_image\";i:2;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_link\";i:3;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_text\";i:4;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U9PXobBv4clQdnuyNB31xyZFAqJ5NgK_WHOSbnw6g98\";}s:2:\"id\";s:32:\"paragraph.ept_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ept_clickable_tile\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_tiles_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_tiles_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_tiles_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ept_tiles_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_video.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"fe1a956f-1eb5-49f4-8ccd-d852faeeea9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_video.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_video.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_video.field_ept_title\";i:3;s:47:\"field.field.paragraph.ept_video.field_ept_video\";i:4;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:4:{i:0;s:9:\"ept_video\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:15:\"field_ept_video\";i:2;s:14:\"field_ept_text\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uWfzDvi2652DPEZs_2EApToxb-ZwFGKVzEDZ3Jd27xU\";}s:2:\"id\";s:27:\"paragraph.ept_video.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:18:\"ept_settings_video\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_video\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_video_and_image_gallery.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"2a6ec3c5-051d-451f-bfa5-ae16ca4d9cc1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_settings\";i:1;s:64:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_text\";i:2;s:65:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_title\";i:3;s:77:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";i:4;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:4:{i:0;s:27:\"ept_video_and_image_gallery\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:27:\"field_ept_videos_and_images\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rOQ-MHiLNktgV1oHnzDodKFBNZKJGnpQ_jcoXGPWl3s\";}s:2:\"id\";s:45:\"paragraph.ept_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:36:\"ept_settings_video_and_image_gallery\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_videos_and_images\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_video_and_image_gallery_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"5a1fd1b5-9098-41dc-99e7-65246d6fe6da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:77:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";i:1;s:82:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";i:2;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-EpWxbfVxkolF4xO3v_gR4i7gLA_X1pxspQ3sm0jgQY\";}s:2:\"id\";s:50:\"paragraph.ept_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:22:\"field_ept_gallery_item\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_gallery_item_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.paragraph.ept_views.default',_binary 'a:12:{s:4:\"uuid\";s:36:\"5f9fd1ed-53a9-4349-8202-c90230a11f12\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_views.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_views.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_views.field_ept_title\";i:3;s:52:\"field.field.paragraph.ept_views.field_ept_views_view\";i:4;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:4:{i:0;s:8:\"ept_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";i:3;s:14:\"viewsreference\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:20:\"field_ept_views_view\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_i5XjlBN7MBo2rHWjbgIick135me8C2QqOcKTkr7Sx0\";}s:2:\"id\";s:27:\"paragraph.ept_views.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_views_view\";a:5:{s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),('','core.entity_form_display.user.user.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8eb5837f-793f-476b-8d5b-8eb1ea190520\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FaQ9Ptcpxpg30AtiqRDtl_8zbJArHP1LPfug_s59TOA\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"account\";a:2:{s:6:\"weight\";i:-10;s:6:\"region\";s:7:\"content\";}s:7:\"contact\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:8:\"language\";a:2:{s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:8:\"timezone\";a:2:{s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),('','core.entity_form_mode.media.media_library',_binary 'a:10:{s:4:\"uuid\";s:36:\"94fd7791-9806-4755-a50f-91d35400a4cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_form_mode.user.register',_binary 'a:10:{s:4:\"uuid\";s:36:\"ef62034d-b624-4a32-9e4a-54a2baf7fa78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5pE_4hurqtIlZN3XDi7eTo5RG13BMG0Rh9HYlRI3h8U\";}s:2:\"id\";s:13:\"user.register\";s:5:\"label\";s:8:\"Register\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_display.block_content.basic.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"53a48e63-4272-4544-9051-7617915e3d41\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBNNDTFwakREOTa6GGMqN899Iyrii0hInwSJtQ7Kj30\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.comment.comment.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"da002566-b092-4563-9d08-c4b5c52593e5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:40:\"field.field.comment.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aBQUGsQ46M4048fIlFuTXwl2zV0j2cJX89CTUobh9hA\";}s:2:\"id\";s:23:\"comment.comment.default\";s:16:\"targetEntityType\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:12:\"comment_body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.media.audio.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"87bcc8b2-7f6c-4c74-800a-a87d1b94f5f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AS765MdDfNpK6K5eE7WVnBvpynClz_havy1R3bO3gVo\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_audio_file\";a:6:{s:4:\"type\";s:10:\"file_audio\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:4:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.audio.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"fd3c8ee0-7347-4825-a6ac-e712dc98946b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tcAUW1Xzq5Tjw5jomR6XKGSgfiXO7QiRAHJBF-n0akg\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.document.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"af3b0da5-5654-474f-b056-1b7fe53c1991\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XxUyhaTuM0OUUZpr8G6jdrFBEh5eag7auWxBKhm6cvY\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:20:\"field_media_document\";a:6:{s:4:\"type\";s:12:\"file_default\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.document.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"3027dd27-1f17-44e8-84f5-7366b5d87788\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:21:\"image.style.thumbnail\";i:3;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YcWqjhIlo-2RZUM5ogvRsrKB7M3voF2XB3lVLwgOlLU\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"19dfadc9-d9a4-4d4c-9953-240f406fe79c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:17:\"image.style.large\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"73xaTNkI5J6sfFcBmNYeuk070X3mQS_iwwWaPYyfG2M\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:5:\"large\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.ept_image_gallery',_binary 'a:11:{s:4:\"uuid\";s:36:\"4f8ec3e2-1797-492f-8b2d-8ce7545d59bc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:45:\"core.entity_view_mode.media.ept_image_gallery\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:29:\"image.style.ept_gallery_image\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n90nNuXho9mrkYYsIQ1XTO6AvAhpgl2KtPDCGCOnGhM\";}s:2:\"id\";s:29:\"media.image.ept_image_gallery\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:17:\"ept_image_gallery\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:17:\"ept_gallery_image\";s:26:\"glightbox_node_style_first\";s:0:\"\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:6:\"parent\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.ept_video_and_image_gallery_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"c47a77e8-55b1-49a2-adeb-dc69b79b24e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:60:\"core.entity_view_mode.media.ept_video_and_image_gallery_item\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:39:\"image.style.ept_video_and_image_gallery\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rH_qHt_lYqhJQjixn1J6qIQ6Nll3micOpoBEVEtJ4CA\";}s:2:\"id\";s:44:\"media.image.ept_video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:32:\"ept_video_and_image_gallery_item\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:27:\"ept_video_and_image_gallery\";s:26:\"glightbox_node_style_first\";s:0:\"\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.image.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"1053ac57-9af0-4e5b-ba2f-c5695c62ef08\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:18:\"image.style.medium\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ILLWu5KFvbsX6J7sh2Itd4w8-lBBRhR_H8ZrmQiN2yo\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:17:\"field_media_image\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"9ecc7509-3522-45c5-bda4-7ed77885a161\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZdPcl2hPxl5pgv3pI-07R7h51OjeUeKJTy-ab1NfM34\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:6:\"oembed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:9:\"max_width\";i:0;s:10:\"max_height\";i:0;s:7:\"loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.ept_video',_binary 'a:11:{s:4:\"uuid\";s:36:\"51e43f2e-4f69-45a1-95c7-5ecf07778894\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:37:\"core.entity_view_mode.media.ept_video\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1KlyRkRbqUbxJgk8eo1S40_quArKzT_wKaIMWWlaSoU\";}s:2:\"id\";s:28:\"media.remote_video.ept_video\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:9:\"ept_video\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:4:\"post\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.ept_video_and_image_gallery_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"72019611-98d6-4f86-81ec-768c71520e64\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:60:\"core.entity_view_mode.media.ept_video_and_image_gallery_item\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3xEp_ZELSvrqfzLRi2XtfPP7KVrHNdRe-XdyCYK3Jc8\";}s:2:\"id\";s:51:\"media.remote_video.ept_video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:32:\"ept_video_and_image_gallery_item\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:27:\"ept_video_and_image_gallery\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.remote_video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"b0bc3306-d88a-4581-af6c-2a1f29aac6ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:18:\"image.style.medium\";i:3;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PGGoP-hVkXe_S-GiJRAub4PHDu0KhMExylclrqjdJb4\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"63fe648a-c5c1-42b9-8b04-7bb9db119166\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SxvbuGh-6cQMxl9bBV27-hGI46u7ZvwlMm5ObaJMNnw\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_video_file\";a:6:{s:4:\"type\";s:10:\"file_video\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";s:5:\"muted\";b:0;s:5:\"width\";i:640;s:6:\"height\";i:480;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.media.video.media_library',_binary 'a:11:{s:4:\"uuid\";s:36:\"5672ce5e-9fb4-4800-8c9d-3b15ca3f7fde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_fnkUKwQYHkXO1Ngmq9nE6FqWUNAmkddOxAH1h5aiKg\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),('','core.entity_view_display.node.article.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"0f767bd2-1919-4166-8346-62c5fc895c81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:35:\"field.field.node.article.field_tags\";i:3;s:16:\"image.style.wide\";i:4;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"text\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"br6izr-iGEu--JvNbCJNtOBpRnxpFLXfoV5y61U9Nqc\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:4:\"wide\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.node.article.rss',_binary 'a:11:{s:4:\"uuid\";s:36:\"bad692de-34e5-483c-9717-c610a77e5be5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2rIr6K5Q0UQ9khg0zE_CK-PtJH76UL-BDDZcZnZzwCc\";}s:2:\"id\";s:16:\"node.article.rss\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:3:\"rss\";s:7:\"content\";a:1:{s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:3:{s:4:\"body\";b:1;s:11:\"field_image\";b:1;s:10:\"field_tags\";b:1;}}'),('','core.entity_view_display.node.article.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"b696c09e-d916-4b49-a1c2-566c781bf923\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:18:\"image.style.medium\";i:5;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:4:\"text\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"O8PxzfG8DOHHRu6M23kwR6TDPq_MNfYQ10Mp367ICUQ\";}s:2:\"id\";s:19:\"node.article.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:7:\"content\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.node.page.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"bc183acd-cdee-4366-86c4-4db46beceef3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:26:\"field.field.node.page.body\";i:1;s:38:\"field.field.node.page.field_components\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Y8L5tfmhx7DR143E05YyZSpvgil6VFvqcfBWykalg\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:16:\"field_components\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:4:\"body\";b:1;}}'),('','core.entity_view_display.node.page.teaser',_binary 'a:11:{s:4:\"uuid\";s:36:\"b64bcaef-5bd0-446f-a6d5-7096df12851d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:26:\"field.field.node.page.body\";i:2;s:38:\"field.field.node.page.field_components\";i:3;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:4:\"text\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8BgdRtLbtQ0F__o0FHSH0Mx5fvXOra9tfT1GmNKbRYw\";}s:2:\"id\";s:16:\"node.page.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:16:\"field_components\";b:1;}}'),('','core.entity_view_display.paragraph.ept_accordion.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f60b271e-f09b-45a9-8e92-1ae341b267f5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:55:\"field.field.paragraph.ept_accordion.field_ept_accordion\";i:1;s:54:\"field.field.paragraph.ept_accordion.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_accordion.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_accordion.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PJi5yKQ_AuFiKp81hRO_aQKSuuwBJkStIGM6f0wBBX8\";}s:2:\"id\";s:31:\"paragraph.ept_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:19:\"field_ept_accordion\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_accordion_section.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"d4e6aedc-c8f3-451b-94d6-cd44fc4b6c11\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:68:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_text\";i:1;s:69:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_title\";i:2;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UjA4zXZ3oMZFxRvkNrsM94SAiqKznnxAtCPUVIC6MT0\";}s:2:\"id\";s:39:\"paragraph.ept_accordion_section.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ept_accordion_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_accordion_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_basic_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"f4454fef-a659-4b88-9579-11ba22f32177\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:66:\"field.field.paragraph.ept_basic_button.field_ept_basic_button_link\";i:1;s:57:\"field.field.paragraph.ept_basic_button.field_ept_settings\";i:2;s:53:\"field.field.paragraph.ept_basic_button.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_basic_button.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4gJX4ZzysdJ_kzlqlJAB2uqXRXQJi3VjikD1N3iepgA\";}s:2:\"id\";s:34:\"paragraph.ept_basic_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:27:\"field_ept_basic_button_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_block.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"e7417c73-82e0-49a6-b66c-942b3596d612\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_block.field_ept_block_block\";i:1;s:50:\"field.field.paragraph.ept_block.field_ept_settings\";i:2;s:46:\"field.field.paragraph.ept_block.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_block.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BFcfVmJHF2899wHjHN2VFWpiUyRAjvacvce9Cfs79BY\";}s:2:\"id\";s:27:\"paragraph.ept_block.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:21:\"field_ept_block_block\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_bootstrap_button.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a806c6af-6b6a-4398-a270-06147cb09d21\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:74:\"field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";i:1;s:61:\"field.field.paragraph.ept_bootstrap_button.field_ept_settings\";i:2;s:57:\"field.field.paragraph.ept_bootstrap_button.field_ept_text\";i:3;s:58:\"field.field.paragraph.ept_bootstrap_button.field_ept_title\";i:4;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1s6HjRSAsva6N8IAwlMIIoLxlmMtVw7ygPp4U_Z7_1I\";}s:2:\"id\";s:38:\"paragraph.ept_bootstrap_button.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:31:\"field_ept_bootstrap_button_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_carousel.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a34b4adb-f67d-4569-90a5-e74b6a28bcdb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_carousel.field_ept_carousel\";i:1;s:53:\"field.field.paragraph.ept_carousel.field_ept_settings\";i:2;s:49:\"field.field.paragraph.ept_carousel.field_ept_text\";i:3;s:50:\"field.field.paragraph.ept_carousel.field_ept_title\";i:4;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hW53xnntQ786Y9Dng5tbHj61F_Xq405ejwkoK9cGxUg\";}s:2:\"id\";s:30:\"paragraph.ept_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_carousel\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_carousel_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"95f5dba7-e075-42d7-bb71-a987d5625124\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";i:1;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";i:2;s:18:\"image.style.medium\";i:3;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kypuOk2yxicxTkEhw3Xo0FLPQXZVoNvTgwtmyMtUUKk\";}s:2:\"id\";s:35:\"paragraph.ept_carousel_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ept_carousel_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_carousel_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_carousel_item.slider',_binary 'a:11:{s:4:\"uuid\";s:36:\"fa961609-f5ef-403a-8089-73f33b1e73f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:38:\"core.entity_view_mode.paragraph.slider\";i:1;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";i:2;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";i:3;s:18:\"image.style.medium\";i:4;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kypuOk2yxicxTkEhw3Xo0FLPQXZVoNvTgwtmyMtUUKk\";}s:2:\"id\";s:34:\"paragraph.ept_carousel_item.slider\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:4:\"mode\";s:6:\"slider\";s:7:\"content\";a:2:{s:26:\"field_ept_carousel_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_carousel_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_columns.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"83448cb5-91c5-4a34-a576-3ea914fa7d6b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:51:\"field.field.paragraph.ept_columns.field_ept_columns\";i:1;s:52:\"field.field.paragraph.ept_columns.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_columns.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_columns.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vOC7NP0p0aXc-869ZBnA91HhUz6DjvKa3lJQB7amMmo\";}s:2:\"id\";s:29:\"paragraph.ept_columns.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:17:\"field_ept_columns\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_countdown.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"08b2118c-18b9-4669-b9e4-0786d49af6ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ept_countdown.field_ept_countdown_date\";i:1;s:54:\"field.field.paragraph.ept_countdown.field_ept_settings\";i:2;s:50:\"field.field.paragraph.ept_countdown.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_countdown.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:3:{i:0;s:8:\"datetime\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0tZvxTE9_SxYclV0-qXTYzgXSfZoC1elFCKHb9scTG4\";}s:2:\"id\";s:31:\"paragraph.ept_countdown.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_countdown_date\";a:6:{s:4:\"type\";s:16:\"datetime_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:17:\"timezone_override\";s:0:\"\";s:11:\"format_type\";s:6:\"medium\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_counter.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"ad408e08-db1a-47df-8098-0b2a61f16481\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_counter.field_ept_counter_items\";i:1;s:52:\"field.field.paragraph.ept_counter.field_ept_settings\";i:2;s:48:\"field.field.paragraph.ept_counter.field_ept_text\";i:3;s:49:\"field.field.paragraph.ept_counter.field_ept_title\";i:4;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eZqA1TwH5tWY55LrWFHFJQ_5F6K3z2LZAXPoKY6znBw\";}s:2:\"id\";s:29:\"paragraph.ept_counter.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_counter_items\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_counter_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"077ee820-2041-4778-8135-0fc65cd20cb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_counter_item.field_ept_counter_description\";i:1;s:61:\"field.field.paragraph.ept_counter_item.field_ept_counter_icon\";i:2;s:63:\"field.field.paragraph.ept_counter_item.field_ept_counter_number\";i:3;s:62:\"field.field.paragraph.ept_counter_item.field_ept_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P7The1phmhJ8Ls_nSR64aLtEXudYALjs5Zzdf10AFuA\";}s:2:\"id\";s:34:\"paragraph.ept_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ept_counter_description\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:22:\"field_ept_counter_icon\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_counter_number\";a:6:{s:4:\"type\";s:14:\"number_integer\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:23:\"field_ept_counter_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_cta.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"4bf53171-20df-4e38-bb87-a451cfc4aa6c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:56:\"field.field.paragraph.ept_cta.field_ept_cta_column_image\";i:1;s:48:\"field.field.paragraph.ept_cta.field_ept_cta_link\";i:2;s:55:\"field.field.paragraph.ept_cta.field_ept_cta_second_link\";i:3;s:48:\"field.field.paragraph.ept_cta.field_ept_settings\";i:4;s:44:\"field.field.paragraph.ept_cta.field_ept_text\";i:5;s:45:\"field.field.paragraph.ept_cta.field_ept_title\";i:6;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LbUDjHCE5jPK-SF4gEbg6BwzdKjd1y4Wm5lHH77LQHE\";}s:2:\"id\";s:25:\"paragraph.ept_cta.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:26:\"field_ept_cta_column_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_cta_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_cta_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_hero.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2727e08a-658f-4ab5-b47b-287082974eca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_column_image\";i:1;s:50:\"field.field.paragraph.ept_hero.field_ept_hero_link\";i:2;s:57:\"field.field.paragraph.ept_hero.field_ept_hero_second_link\";i:3;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_title_prefix\";i:4;s:49:\"field.field.paragraph.ept_hero.field_ept_settings\";i:5;s:45:\"field.field.paragraph.ept_hero.field_ept_text\";i:6;s:46:\"field.field.paragraph.ept_hero.field_ept_title\";i:7;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RyJFBZtpPZyel78RpfsF1AiH8hwBQOOxLrAmCsQUA3E\";}s:2:\"id\";s:26:\"paragraph.ept_hero.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:27:\"field_ept_hero_column_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_hero_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:26:\"field_ept_hero_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_hero_title_prefix\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_image.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"a5054ddd-1cf1-49bf-bb8f-790f40e08130\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:47:\"field.field.paragraph.ept_image.field_ept_image\";i:1;s:55:\"field.field.paragraph.ept_image.field_ept_image_caption\";i:2;s:52:\"field.field.paragraph.ept_image.field_ept_image_link\";i:3;s:50:\"field.field.paragraph.ept_image.field_ept_settings\";i:4;s:46:\"field.field.paragraph.ept_image.field_ept_text\";i:5;s:47:\"field.field.paragraph.ept_image.field_ept_title\";i:6;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:4:{i:0;s:8:\"ept_core\";i:1;s:4:\"link\";i:2;s:5:\"media\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DTOYjl8a1qPkDZ2tUSk7QmiHQ0xgbKAbv7qw0jY4LTE\";}s:2:\"id\";s:27:\"paragraph.ept_image.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:15:\"field_ept_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:23:\"field_ept_image_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_image_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_image_gallery.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"49052cac-09f9-471f-8cc0-d9c144baf2ff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_image_gallery.field_ept_image_gallery\";i:1;s:58:\"field.field.paragraph.ept_image_gallery.field_ept_settings\";i:2;s:54:\"field.field.paragraph.ept_image_gallery.field_ept_text\";i:3;s:55:\"field.field.paragraph.ept_image_gallery.field_ept_title\";i:4;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"baNfcT8hwfXqGdk9GFr_Uo5DAZw65OmnpJIPGu7rwLU\";}s:2:\"id\";s:35:\"paragraph.ept_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:23:\"field_ept_image_gallery\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:17:\"ept_image_gallery\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_micromodal.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"2b90284a-5b66-4a1f-8feb-f7da7fba402f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_micromodal.field_ept_micromodal_title\";i:1;s:55:\"field.field.paragraph.ept_micromodal.field_ept_settings\";i:2;s:51:\"field.field.paragraph.ept_micromodal.field_ept_text\";i:3;s:52:\"field.field.paragraph.ept_micromodal.field_ept_title\";i:4;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3RH7OegTiWFWXapSfExaq4iTqsXp0J-FoDgKn3BLvug\";}s:2:\"id\";s:32:\"paragraph.ept_micromodal.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_micromodal_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_quote.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"772993d5-eed2-4b18-a6f6-28eb39e116b4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:54:\"field.field.paragraph.ept_quote.field_ept_quote_author\";i:1;s:53:\"field.field.paragraph.ept_quote.field_ept_quote_image\";i:2;s:50:\"field.field.paragraph.ept_quote.field_ept_settings\";i:3;s:46:\"field.field.paragraph.ept_quote.field_ept_text\";i:4;s:47:\"field.field.paragraph.ept_quote.field_ept_title\";i:5;s:27:\"image.style.ept_quote_image\";i:6;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Ng1DAFgz9gNcE0pRgTjrcZTjwRmCqpVhuWZM-gi-D3o\";}s:2:\"id\";s:27:\"paragraph.ept_quote.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:22:\"field_ept_quote_author\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:21:\"field_ept_quote_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:15:\"ept_quote_image\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slick_slider.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"febc7649-4ada-4466-aea7-1872bc394145\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:57:\"field.field.paragraph.ept_slick_slider.field_ept_settings\";i:1;s:61:\"field.field.paragraph.ept_slick_slider.field_ept_slick_slider\";i:2;s:53:\"field.field.paragraph.ept_slick_slider.field_ept_text\";i:3;s:54:\"field.field.paragraph.ept_slick_slider.field_ept_title\";i:4;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"D6f-Fc2NAzWU9GdDBRkUKUZ-OufpE3B1nGAAJQhgO04\";}s:2:\"id\";s:34:\"paragraph.ept_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:22:\"field_ept_slick_slider\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slick_slider_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"e906e660-3e2c-436c-9fb5-1dc3aaa2d1a9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:72:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";i:1;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";i:2;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";i:3;s:33:\"image.style.ept_slick_slider_card\";i:4;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Yb25ejThf9Zw1K_1U4jgPEu6CXiu0AbCJlD9g9Lcjm0\";}s:2:\"id\";s:39:\"paragraph.ept_slick_slider_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ept_slick_slider_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:21:\"ept_slick_slider_card\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_slick_slider_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_slick_slider_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slideshow.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"113fc4a1-1a78-4da6-b222-3a4cd08a0def\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:54:\"field.field.paragraph.ept_slideshow.field_ept_settings\";i:1;s:55:\"field.field.paragraph.ept_slideshow.field_ept_slideshow\";i:2;s:50:\"field.field.paragraph.ept_slideshow.field_ept_text\";i:3;s:51:\"field.field.paragraph.ept_slideshow.field_ept_title\";i:4;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KtOxRXjaqWh0JTHfCOLP6aQSiruy6TgLL8zYom1n_L4\";}s:2:\"id\";s:31:\"paragraph.ept_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_slideshow\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_slideshow_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"c452f408-f85b-4944-a31e-1bbef7fcda71\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link\";i:1;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide\";i:2;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text\";i:3;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title\";i:4;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zuevQDEEiEAdPhigrWbhLZc3nvEGuKwsXeWbIT6VtyM\";}s:2:\"id\";s:36:\"paragraph.ept_slideshow_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ept_slideshow_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_slideshow_slide\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ept_slideshow_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_slideshow_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_stats.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"ec282fce-d81d-4383-9a77-3fb87be08553\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_stats.field_ept_settings\";i:1;s:47:\"field.field.paragraph.ept_stats.field_ept_stats\";i:2;s:46:\"field.field.paragraph.ept_stats.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_stats.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-R8qIR4yTFENexKPFy8GHPre8URllz01mM6cb0sIz_0\";}s:2:\"id\";s:27:\"paragraph.ept_stats.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_stats\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_stats_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"8e1a5df7-4ec6-40ba-b5be-4d5d2b6f489f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:63:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_image\";i:1;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_link\";i:2;s:64:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_number\";i:3;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vJgoosAvhgFcK-LHabcOoXx3QTmG9TF7iqpHAxeUkkc\";}s:2:\"id\";s:32:\"paragraph.ept_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:26:\"field_ept_stats_item_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_stats_item_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_stats_item_number\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:25:\"field_ept_stats_item_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tabs.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"7da9a817-79f8-4bec-add7-e39bb0ba78c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:49:\"field.field.paragraph.ept_tabs.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_tabs.field_ept_tabs\";i:2;s:45:\"field.field.paragraph.ept_tabs.field_ept_text\";i:3;s:46:\"field.field.paragraph.ept_tabs.field_ept_title\";i:4;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VYYeF4flc_QYohV2FJfKsdYisMArL-b2-hY7et7ry_M\";}s:2:\"id\";s:26:\"paragraph.ept_tabs.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_tabs\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tabs_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"b90a3de2-2933-49e5-8726-03f0e73085fa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_block\";i:1;s:57:\"field.field.paragraph.ept_tabs_item.field_ept_tab_content\";i:2;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_page\";i:3;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_text\";i:4;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_title\";i:5;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_views\";i:6;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vm2AN2TrjyhMIpH3DLfldicz1qb1mSF0ykCyMxw9bmE\";}s:2:\"id\";s:31:\"paragraph.ept_tabs_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:19:\"field_ept_tab_block\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_tab_page\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ept_tab_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_tab_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:19:\"field_ept_tab_views\";a:6:{s:4:\"type\";s:24:\"viewsreference_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:1:{i:0;s:5:\"block\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:21:\"field_ept_tab_content\";b:1;}}'),('','core.entity_view_display.paragraph.ept_text.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"e06c8535-7973-44b5-8144-18baa167f488\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:49:\"field.field.paragraph.ept_text.field_ept_settings\";i:1;s:45:\"field.field.paragraph.ept_text.field_ept_text\";i:2;s:46:\"field.field.paragraph.ept_text.field_ept_title\";i:3;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hzCv1OpNW04_O7sRxZPIlh1_rvwxOvMIGOWK43XgmKg\";}s:2:\"id\";s:26:\"paragraph.ept_text.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tiles.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"153a53c8-5121-4586-9a2d-42dbb61c9965\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_tiles.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_tiles.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_tiles.field_ept_tiles\";i:3;s:47:\"field.field.paragraph.ept_tiles.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VFAqZYQk4Jf5mJN7H6sw-zAemRX1LtPDXAfRw5U6hjM\";}s:2:\"id\";s:27:\"paragraph.ept_tiles.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_tiles\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_tiles_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"1e04e293-6847-44fd-816b-d0cafeb9bfb1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ept_tiles_item.field_ept_clickable_tile\";i:1;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_image\";i:2;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_link\";i:3;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_text\";i:4;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sd_Fv-1q9ZOgwmZ0ePkn9oBIqVaWhe4K8YL6VyUVSfE\";}s:2:\"id\";s:32:\"paragraph.ept_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ept_clickable_tile\";a:6:{s:4:\"type\";s:7:\"boolean\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:6:\"format\";s:7:\"default\";s:19:\"format_custom_false\";s:0:\"\";s:18:\"format_custom_true\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:21:\"field_ept_tiles_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_tiles_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_tiles_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:21:\"field_ept_tiles_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_video.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"4c097cad-2585-405b-86e6-5effe6d6f443\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_video.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_video.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_video.field_ept_title\";i:3;s:47:\"field.field.paragraph.ept_video.field_ept_video\";i:4;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XvS78XJNKdR81VHVUzs1PUhNwNWlMocd77YwIDcgRH0\";}s:2:\"id\";s:27:\"paragraph.ept_video.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_video\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:9:\"ept_video\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_video_and_image_gallery.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"dfadbabc-626b-46a2-a063-3f65ad0c2b45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_settings\";i:1;s:64:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_text\";i:2;s:65:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_title\";i:3;s:77:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";i:4;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:8:\"ept_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5dsKiTuP8c7klYOHnY_OBorbQ_YaHWXu4P_cKhDDKZE\";}s:2:\"id\";s:45:\"paragraph.ept_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_videos_and_images\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_video_and_image_gallery_item.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"273d4d81-bc41-43e6-bbfd-346c986e0c86\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:77:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";i:1;s:82:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";i:2;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PB75oeGkZ1ajIp-S4ceLC_lub5_nmn_WU0f_7wBeOag\";}s:2:\"id\";s:50:\"paragraph.ept_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:22:\"field_ept_gallery_item\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:32:\"ept_video_and_image_gallery_item\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ept_gallery_item_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.paragraph.ept_views.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"d0875a9d-cb50-4731-ac2a-fb25c1858dae\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_views.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_views.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_views.field_ept_title\";i:3;s:52:\"field.field.paragraph.ept_views.field_ept_views_view\";i:4;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:3:{i:0;s:8:\"ept_core\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HwJ8zDH-LTdrQbXrPD8P-vvx1n91p-8JocGN840XNUw\";}s:2:\"id\";s:27:\"paragraph.ept_views.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:18:\"field_ept_settings\";a:6:{s:4:\"type\";s:20:\"ept_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:14:\"field_ept_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ept_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:20:\"field_ept_views_view\";a:6:{s:4:\"type\";s:24:\"viewsreference_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:1:{i:0;s:5:\"block\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_display.user.user.compact',_binary 'a:11:{s:4:\"uuid\";s:36:\"fd378f17-2b7e-4025-89fa-c56cabc7bab2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:34:\"core.entity_view_mode.user.compact\";i:1;s:34:\"field.field.user.user.user_picture\";i:2;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"00zr_RBdTjPjBGITD3h4c1ESQZimjdVCcHGt1trLqIY\";}s:2:\"id\";s:17:\"user.user.compact\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"compact\";s:7:\"content\";a:1:{s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:10:\"member_for\";b:1;}}'),('','core.entity_view_display.user.user.default',_binary 'a:11:{s:4:\"uuid\";s:36:\"afa0542b-6646-4a58-8063-b778fe6b3423\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mZLyuWM9CQx2ZJVqFGSbzgFnHzudVbHBYmdU256A5Wk\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:10:\"member_for\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),('','core.entity_view_mode.block_content.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"3e515c12-bfb7-4a38-9360-e1bebd522e14\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q7yUUYeRLByl-MCGveKKF_KhAtNICLCMJuKWfugCvso\";}s:2:\"id\";s:18:\"block_content.full\";s:5:\"label\";s:4:\"Full\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.comment.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"aaef918d-7b8e-4ea0-822a-44703c28e61c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N4mUjXpPckUkVRY1PbKw4GGoL1i2ECU7PL3EreiKStk\";}s:2:\"id\";s:12:\"comment.full\";s:5:\"label\";s:12:\"Full comment\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:7:\"comment\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.ept_image_gallery',_binary 'a:10:{s:4:\"uuid\";s:36:\"c2742453-7e21-4da9-b647-07ef5aca9cf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hrWZ2by9y8V27Hv_3EBEgSBPp_2-kB9fizZj-DLVRcQ\";}s:2:\"id\";s:23:\"media.ept_image_gallery\";s:5:\"label\";s:17:\"EPT Image Gallery\";s:11:\"description\";N;s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.ept_video',_binary 'a:10:{s:4:\"uuid\";s:36:\"8ae8b19f-547b-42bd-9d8f-a88c05759d47\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0wiLx1gaRcymNOKRYsVEppFtOWUHrgVQsi6qUlIr_TM\";}s:2:\"id\";s:15:\"media.ept_video\";s:5:\"label\";s:9:\"EPT Video\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.ept_video_and_image_gallery_item',_binary 'a:10:{s:4:\"uuid\";s:36:\"56447995-bbf0-4a46-b361-7337f6962da6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QIGappKnnavEIRi1GzZ_dSeZaYoyiLSX-hOaXrOHbz8\";}s:2:\"id\";s:38:\"media.ept_video_and_image_gallery_item\";s:5:\"label\";s:32:\"EPT Video and Image gallery item\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"976815c3-f2f0-4a48-82b3-fb4ee2924c88\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dTfAUHooYV0uOVPO3saGpgv-c5PppJXDwxvwRTJOycM\";}s:2:\"id\";s:10:\"media.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.media.media_library',_binary 'a:10:{s:4:\"uuid\";s:36:\"4578cd26-ab79-41fc-b999-3224d7b96b78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"3096aebe-dabe-4849-b718-4be67ed1e0a2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QJ2aZ1xfVf59aq6Pz5X7fyUOa2HxuCoTwQ_RQjoulAU\";}s:2:\"id\";s:9:\"node.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.rss',_binary 'a:10:{s:4:\"uuid\";s:36:\"562fdf9e-431f-4436-87cc-5edcb21506bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l8fiAFE3Kng_6bhLlUDnVTkTDzXWxzYFrCWTrngVXEA\";}s:2:\"id\";s:8:\"node.rss\";s:5:\"label\";s:3:\"RSS\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.search_index',_binary 'a:10:{s:4:\"uuid\";s:36:\"edab19fa-a328-4f2e-a4a2-bce49808300d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r_A0T3aTqGDwLyvoH7wLps-0PM--RHlS8UsiJe_Ac64\";}s:2:\"id\";s:17:\"node.search_index\";s:5:\"label\";s:12:\"Search index\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.search_result',_binary 'a:10:{s:4:\"uuid\";s:36:\"ac6b99d6-0ed0-46ea-97e8-2b17a00adab0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d8wBEm7XvJ6H3S0IneDD9PfTBklPIH7GMpxElVemPf8\";}s:2:\"id\";s:18:\"node.search_result\";s:5:\"label\";s:32:\"Search result highlighting input\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.node.teaser',_binary 'a:10:{s:4:\"uuid\";s:36:\"5eb23a5d-001b-4f18-b772-c45ec412d4a1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KgGJDZFpMaz_8bTv6fN1bXS3Qi5LWmRJI9R53kEGsNQ\";}s:2:\"id\";s:11:\"node.teaser\";s:5:\"label\";s:6:\"Teaser\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.paragraph.preview',_binary 'a:10:{s:4:\"uuid\";s:36:\"298a8e9e-ea9f-462a-9e62-03ff202ebda4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"h3BeHVei4Lnyqbkao3YiF4KqoY-DhRvUNfEgKG8Rgjg\";}s:2:\"id\";s:17:\"paragraph.preview\";s:5:\"label\";s:7:\"Preview\";s:11:\"description\";N;s:16:\"targetEntityType\";s:9:\"paragraph\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.paragraph.slider',_binary 'a:9:{s:4:\"uuid\";s:36:\"f0967983-7199-4bf7-8047-72fb6a840ca0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:2:\"id\";s:16:\"paragraph.slider\";s:5:\"label\";s:6:\"slider\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.taxonomy_term.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"c1d7c975-f7cc-4e65-a0b5-d7a0b84e6fed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iukUENpf8CFvjZbGGacKX_Ges0-lU9z6zvsd32P6kbo\";}s:2:\"id\";s:18:\"taxonomy_term.full\";s:5:\"label\";s:18:\"Taxonomy term page\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.compact',_binary 'a:10:{s:4:\"uuid\";s:36:\"3267d362-0cde-4190-8a4e-f368fdab39d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TtD7OuGskOsQfoGyxXkrdtllBpR37J19d5BMQDZWJgA\";}s:2:\"id\";s:12:\"user.compact\";s:5:\"label\";s:7:\"Compact\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.entity_view_mode.user.full',_binary 'a:10:{s:4:\"uuid\";s:36:\"18890f85-c8b4-4c37-a805-81e116c96c33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZbXunWS_xAvMZXFfinyvClDAb_RCVLt7gAzE3v16E-Q\";}s:2:\"id\";s:9:\"user.full\";s:5:\"label\";s:12:\"User account\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),('','core.extension',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GIX5Esnc_umpXUBj4IIocRX7Mt5fPhm4AgXfE3E56E\";}s:6:\"module\";a:109:{s:13:\"admin_toolbar\";i:0;s:19:\"admin_toolbar_tools\";i:0;s:18:\"announcements_feed\";i:0;s:14:\"automated_cron\";i:0;s:22:\"better_exposed_filters\";i:0;s:8:\"big_pipe\";i:0;s:5:\"block\";i:0;s:13:\"block_content\";i:0;s:11:\"block_field\";i:0;s:10:\"breakpoint\";i:0;s:9:\"ckeditor5\";i:0;s:21:\"ckeditor5_plugin_pack\";i:0;s:32:\"ckeditor5_plugin_pack_auto_image\";i:0;s:38:\"ckeditor5_plugin_pack_find_and_replace\";i:0;s:26:\"ckeditor5_plugin_pack_font\";i:0;s:31:\"ckeditor5_plugin_pack_highlight\";i:0;s:34:\"ckeditor5_plugin_pack_indent_block\";i:0;s:37:\"ckeditor5_plugin_pack_link_attributes\";i:0;s:32:\"ckeditor5_plugin_pack_page_break\";i:0;s:32:\"ckeditor5_plugin_pack_select_all\";i:0;s:31:\"ckeditor5_plugin_pack_templates\";i:0;s:41:\"ckeditor5_plugin_pack_text_transformation\";i:0;s:40:\"ckeditor5_plugin_pack_todo_document_list\";i:0;s:37:\"ckeditor5_premium_features_fullscreen\";i:0;s:7:\"comment\";i:0;s:6:\"config\";i:0;s:7:\"contact\";i:0;s:10:\"contextual\";i:0;s:8:\"datetime\";i:0;s:5:\"dblog\";i:0;s:18:\"dynamic_page_cache\";i:0;s:6:\"editor\";i:0;s:26:\"entity_reference_revisions\";i:0;s:13:\"ept_accordion\";i:0;s:16:\"ept_basic_button\";i:0;s:9:\"ept_block\";i:0;s:20:\"ept_bootstrap_button\";i:0;s:12:\"ept_carousel\";i:0;s:11:\"ept_columns\";i:0;s:8:\"ept_core\";i:0;s:19:\"ept_core_starterkit\";i:0;s:13:\"ept_countdown\";i:0;s:11:\"ept_counter\";i:0;s:7:\"ept_cta\";i:0;s:8:\"ept_hero\";i:0;s:9:\"ept_image\";i:0;s:17:\"ept_image_gallery\";i:0;s:14:\"ept_micromodal\";i:0;s:9:\"ept_quote\";i:0;s:16:\"ept_slick_slider\";i:0;s:13:\"ept_slideshow\";i:0;s:9:\"ept_stats\";i:0;s:8:\"ept_tabs\";i:0;s:8:\"ept_text\";i:0;s:9:\"ept_tiles\";i:0;s:9:\"ept_video\";i:0;s:27:\"ept_video_and_image_gallery\";i:0;s:9:\"ept_views\";i:0;s:5:\"field\";i:0;s:11:\"field_group\";i:0;s:8:\"field_ui\";i:0;s:4:\"file\";i:0;s:8:\"file_mdm\";i:0;s:13:\"file_mdm_exif\";i:0;s:13:\"file_mdm_font\";i:0;s:6:\"filter\";i:0;s:11:\"gin_toolbar\";i:0;s:9:\"glightbox\";i:0;s:21:\"glightbox_media_video\";i:0;s:4:\"help\";i:0;s:7:\"history\";i:0;s:5:\"image\";i:0;s:13:\"image_effects\";i:0;s:9:\"jquery_ui\";i:0;s:19:\"jquery_ui_accordion\";i:0;s:14:\"jquery_ui_tabs\";i:0;s:16:\"layout_discovery\";i:0;s:17:\"layout_paragraphs\";i:0;s:4:\"link\";i:0;s:15:\"link_attributes\";i:0;s:33:\"link_attributes_menu_link_content\";i:0;s:5:\"media\";i:0;s:13:\"media_library\";i:0;s:18:\"media_library_edit\";i:0;s:26:\"media_library_form_element\";i:0;s:17:\"menu_link_content\";i:0;s:7:\"menu_ui\";i:0;s:4:\"node\";i:0;s:7:\"options\";i:0;s:10:\"page_cache\";i:0;s:4:\"path\";i:0;s:10:\"path_alias\";i:0;s:16:\"profile_switcher\";i:0;s:6:\"search\";i:0;s:8:\"shortcut\";i:0;s:6:\"system\";i:0;s:8:\"taxonomy\";i:0;s:11:\"tb_megamenu\";i:0;s:4:\"text\";i:0;s:7:\"toolbar\";i:0;s:10:\"twig_tweak\";i:0;s:6:\"update\";i:0;s:4:\"user\";i:0;s:8:\"views_ui\";i:0;s:17:\"views_year_filter\";i:0;s:14:\"viewsreference\";i:0;s:5:\"views\";i:10;s:10:\"paragraphs\";i:11;s:4:\"fast\";i:1000;}s:5:\"theme\";a:5:{s:7:\"olivero\";i:0;s:5:\"claro\";i:0;s:3:\"gin\";i:0;s:7:\"stable9\";i:0;s:9:\"ept_light\";i:0;}s:7:\"profile\";s:4:\"fast\";}'),('','core.menu.static_menu_link_overrides',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CXhei_vpaZk-3f_Mj2cH0YmpK-ZpKHoSzVA3yZrDq0g\";}s:11:\"definitions\";a:4:{s:18:\"contact__site_page\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:6:\"footer\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:6:\"weight\";i:-50;}s:20:\"standard__front_page\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:6:\"weight\";i:-50;}s:10:\"user__page\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:7:\"account\";s:6:\"parent\";s:0:\"\";s:8:\"expanded\";b:0;s:6:\"weight\";i:-10;}s:12:\"user__logout\";a:5:{s:7:\"enabled\";b:0;s:9:\"menu_name\";s:7:\"account\";s:6:\"parent\";s:0:\"\";s:6:\"weight\";i:10;s:8:\"expanded\";b:0;}}}'),('','dblog.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e883aGsrt1wFrsydlYU584PZONCSfRy0DtkZ9KzHb58\";}s:9:\"row_limit\";i:1000;}'),('','editor.editor.basic_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"de26b70d-0b5e-4129-a929-f1de8a455f1b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"filter.format.basic_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qi2tIe-L97EutlMmhEvhsNxZOpOoA-RH82c4BQb5n4A\";}s:6:\"format\";s:10:\"basic_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:15:{i:0;s:4:\"bold\";i:1;s:6:\"italic\";i:2;s:1:\"|\";i:3;s:4:\"link\";i:4;s:1:\"|\";i:5;s:12:\"bulletedList\";i:6;s:12:\"numberedList\";i:7;s:1:\"|\";i:8;s:10:\"blockQuote\";i:9;s:17:\"drupalInsertImage\";i:10;s:1:\"|\";i:11;s:7:\"heading\";i:12;s:4:\"code\";i:13;s:1:\"|\";i:14;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:4:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:0;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:13:{i:0;s:6:\"<cite>\";i:1;s:4:\"<dl>\";i:2;s:4:\"<dt>\";i:3;s:4:\"<dd>\";i:4;s:12:\"<a hreflang>\";i:5;s:17:\"<blockquote cite>\";i:6;s:9:\"<ul type>\";i:7;s:9:\"<ol type>\";i:8;s:7:\"<h2 id>\";i:9;s:7:\"<h3 id>\";i:10;s:7:\"<h4 id>\";i:11;s:7:\"<h5 id>\";i:12;s:7:\"<h6 id>\";}}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),('','editor.editor.full_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"5b65cbab-6e9a-450e-a54e-4c334c4ca75d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"filter.format.full_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lurcn8yf33g3Dkzdc55cTfJa9salGp9ytSYyG1s7QMI\";}s:6:\"format\";s:9:\"full_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:44:{i:0;s:4:\"undo\";i:1;s:4:\"redo\";i:2;s:4:\"bold\";i:3;s:6:\"italic\";i:4;s:13:\"strikethrough\";i:5;s:9:\"underline\";i:6;s:11:\"superscript\";i:7;s:9:\"subscript\";i:8;s:12:\"removeFormat\";i:9;s:1:\"|\";i:10;s:4:\"link\";i:11;s:1:\"|\";i:12;s:5:\"style\";i:13;s:9:\"fontColor\";i:14;s:19:\"fontBackgroundColor\";i:15;s:9:\"highlight\";i:16;s:10:\"fontFamily\";i:17;s:8:\"fontSize\";i:18;s:1:\"-\";i:19;s:12:\"bulletedList\";i:20;s:12:\"numberedList\";i:21;s:6:\"indent\";i:22;s:7:\"outdent\";i:23;s:9:\"alignment\";i:24;s:1:\"|\";i:25;s:14:\"insertTemplate\";i:26;s:4:\"code\";i:27;s:10:\"blockQuote\";i:28;s:17:\"drupalInsertImage\";i:29;s:11:\"drupalMedia\";i:30;s:11:\"insertTable\";i:31;s:14:\"horizontalLine\";i:32;s:1:\"|\";i:33;s:7:\"heading\";i:34;s:14:\"findAndReplace\";i:35;s:1:\"-\";i:36;s:10:\"showBlocks\";i:37;s:17:\"specialCharacters\";i:38;s:9:\"codeBlock\";i:39;s:13:\"sourceEditing\";i:40;s:1:\"|\";i:41;s:9:\"pageBreak\";i:42;s:9:\"selectAll\";i:43;s:10:\"fullScreen\";}}s:7:\"plugins\";a:17:{s:19:\"ckeditor5_alignment\";a:1:{s:18:\"enabled_alignments\";a:4:{i:0;s:6:\"center\";i:1;s:7:\"justify\";i:2;s:4:\"left\";i:3;s:5:\"right\";}}s:19:\"ckeditor5_codeBlock\";a:1:{s:9:\"languages\";a:14:{i:0;a:2:{s:5:\"label\";s:10:\"Plain text\";s:8:\"language\";s:9:\"plaintext\";}i:1;a:2:{s:5:\"label\";s:1:\"C\";s:8:\"language\";s:1:\"c\";}i:2;a:2:{s:5:\"label\";s:2:\"C#\";s:8:\"language\";s:2:\"cs\";}i:3;a:2:{s:5:\"label\";s:3:\"C++\";s:8:\"language\";s:3:\"cpp\";}i:4;a:2:{s:5:\"label\";s:3:\"CSS\";s:8:\"language\";s:3:\"css\";}i:5;a:2:{s:5:\"label\";s:4:\"Diff\";s:8:\"language\";s:4:\"diff\";}i:6;a:2:{s:5:\"label\";s:4:\"HTML\";s:8:\"language\";s:4:\"html\";}i:7;a:2:{s:5:\"label\";s:4:\"Java\";s:8:\"language\";s:4:\"java\";}i:8;a:2:{s:5:\"label\";s:10:\"JavaScript\";s:8:\"language\";s:10:\"javascript\";}i:9;a:2:{s:5:\"label\";s:3:\"PHP\";s:8:\"language\";s:3:\"php\";}i:10;a:2:{s:5:\"label\";s:6:\"Python\";s:8:\"language\";s:6:\"python\";}i:11;a:2:{s:5:\"label\";s:4:\"Ruby\";s:8:\"language\";s:4:\"ruby\";}i:12;a:2:{s:5:\"label\";s:10:\"TypeScript\";s:8:\"language\";s:10:\"typescript\";}i:13;a:2:{s:5:\"label\";s:3:\"XML\";s:8:\"language\";s:3:\"xml\";}}}s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:6:{i:0;s:8:\"heading1\";i:1;s:8:\"heading2\";i:2;s:8:\"heading3\";i:3;s:8:\"heading4\";i:4;s:8:\"heading5\";i:5;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:44:\"ckeditor5_plugin_pack_auto_image__auto_image\";a:1:{s:7:\"enabled\";b:0;}s:56:\"ckeditor5_plugin_pack_find_and_replace__find_and_replace\";a:1:{s:7:\"ui_type\";s:6:\"dialog\";}s:38:\"ckeditor5_plugin_pack_font__font_color\";a:2:{s:6:\"colors\";a:0:{}s:18:\"use_default_colors\";b:1;}s:39:\"ckeditor5_plugin_pack_font__font_family\";a:1:{s:7:\"options\";s:0:\"\";}s:37:\"ckeditor5_plugin_pack_font__font_size\";a:1:{s:7:\"options\";s:0:\"\";}s:42:\"ckeditor5_plugin_pack_highlight__highlight\";a:2:{s:7:\"options\";a:0:{}s:19:\"use_default_markers\";b:1;}s:48:\"ckeditor5_plugin_pack_indent_block__indent_block\";a:1:{s:7:\"enabled\";b:1;}s:54:\"ckeditor5_plugin_pack_link_attributes__link_attributes\";a:1:{s:10:\"attributes\";a:1:{i:0;a:2:{s:5:\"label\";s:15:\"Link Attributes\";s:10:\"attributes\";s:27:\"target|_blank\r\nrel|nofollow\";}}}s:62:\"ckeditor5_plugin_pack_text_transformation__text_transformation\";a:4:{s:7:\"enabled\";b:1;s:21:\"extra_transformations\";s:0:\"\";s:27:\"extra_regex_transformations\";a:0:{}s:6:\"groups\";a:5:{s:10:\"typography\";a:2:{s:15:\"transformations\";a:3:{s:8:\"ellipsis\";a:1:{s:7:\"enabled\";i:1;}s:6:\"enDash\";a:1:{s:7:\"enabled\";i:1;}s:6:\"emDash\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:6:\"quotes\";a:2:{s:15:\"transformations\";a:2:{s:13:\"quotesPrimary\";a:1:{s:7:\"enabled\";i:1;}s:15:\"quotesSecondary\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:7:\"symbols\";a:2:{s:15:\"transformations\";a:3:{s:9:\"trademark\";a:1:{s:7:\"enabled\";i:1;}s:19:\"registeredTrademark\";a:1:{s:7:\"enabled\";i:1;}s:9:\"copyright\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:12:\"mathematical\";a:2:{s:15:\"transformations\";a:10:{s:7:\"oneHalf\";a:1:{s:7:\"enabled\";i:1;}s:8:\"oneThird\";a:1:{s:7:\"enabled\";i:1;}s:9:\"twoThirds\";a:1:{s:7:\"enabled\";i:1;}s:9:\"oneFourth\";a:1:{s:7:\"enabled\";i:1;}s:13:\"threeQuarters\";a:1:{s:7:\"enabled\";i:1;}s:15:\"lessThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:18:\"greaterThanOrEqual\";a:1:{s:7:\"enabled\";i:1;}s:8:\"notEqual\";a:1:{s:7:\"enabled\";i:1;}s:9:\"arrowLeft\";a:1:{s:7:\"enabled\";i:1;}s:10:\"arrowRight\";a:1:{s:7:\"enabled\";i:1;}}s:7:\"enabled\";i:1;}s:4:\"misc\";a:2:{s:15:\"transformations\";a:4:{s:17:\"quotesPrimaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:19:\"quotesSecondaryEnGb\";a:1:{s:7:\"enabled\";i:0;}s:15:\"quotesPrimaryPl\";a:1:{s:7:\"enabled\";i:0;}s:17:\"quotesSecondaryPl\";a:1:{s:7:\"enabled\";i:0;}}s:7:\"enabled\";i:0;}}}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}s:15:\"ckeditor5_style\";a:1:{s:6:\"styles\";a:2:{i:0;a:2:{s:5:\"label\";s:12:\"Title prefix\";s:7:\"element\";s:27:\"<span class=\"title-prefix\">\";}i:1;a:2:{s:5:\"label\";s:10:\"White text\";s:7:\"element\";s:25:\"<span class=\"white-text\">\";}}}s:11:\"media_media\";a:1:{s:24:\"allow_view_mode_override\";b:0;}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),('','ept_core.settings',_binary 'a:12:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYlqpNn_5W04WVeLB4bYW404IYbkVrx7N9zxzBAJ-Io\";}s:26:\"ept_core_mobile_breakpoint\";s:3:\"640\";s:26:\"ept_core_tablet_breakpoint\";s:4:\"1020\";s:27:\"ept_core_desktop_breakpoint\";s:4:\"1320\";s:22:\"ept_core_xxsmall_width\";s:3:\"480\";s:21:\"ept_core_xsmall_width\";s:3:\"640\";s:20:\"ept_core_small_width\";s:3:\"768\";s:22:\"ept_core_default_width\";s:3:\"960\";s:20:\"ept_core_large_width\";s:4:\"1100\";s:21:\"ept_core_xlarge_width\";s:4:\"1320\";s:22:\"ept_core_xxlarge_width\";s:4:\"1600\";s:25:\"ept_core_background_color\";s:7:\"#0d77b5\";}'),('','field.field.block_content.basic.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"8fecb003-ae49-44e1-ac0e-aeaebabeca06\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j00Gfs9AFqwK4x9RIsISLbPO7vA12psPR4s60wOIwQo\";}s:2:\"id\";s:24:\"block_content.basic.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.comment.comment.comment_body',_binary 'a:17:{s:4:\"uuid\";s:36:\"2ea8eb6b-de2b-4de9-ac7c-5703ce8bc44f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:20:\"comment.type.comment\";i:1;s:34:\"field.storage.comment.comment_body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"62rlTOx3sPVrYhBnSBHZStXwiO02v1UpHSMrhWDsuG8\";}s:2:\"id\";s:28:\"comment.comment.comment_body\";s:10:\"field_name\";s:12:\"comment_body\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";s:7:\"comment\";s:5:\"label\";s:7:\"Comment\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.media.audio.field_media_audio_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"cccc3ad2-8bd3-4a0b-8777-2510ebee041b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UlZPIbHcLyNqGY5bvydCTijGcKDmwn4Fo8oYZT85wlk\";}s:2:\"id\";s:34:\"media.audio.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:5:\"label\";s:10:\"Audio file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:11:\"mp3 wav aac\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),('','field.field.media.document.field_media_document',_binary 'a:17:{s:4:\"uuid\";s:36:\"90b23d65-43c8-4f09-8924-c0be432e4510\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:40:\"field.storage.media.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DY5HtJTxUjFRGU_PaY6ifo2nhR-nAZ0y0s6kLmUbv5g\";}s:2:\"id\";s:35:\"media.document.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:96:\"txt rtf doc docx ppt pptx xls xlsx pdf odf odg odp ods odt fodt fods fodp fodg key numbers pages\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),('','field.field.media.image.field_media_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"410f42b6-e143-4eb8-9c88-c13fd9c4c17f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:37:\"field.storage.media.field_media_image\";i:1;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P7CkVOgjDXiN26Fm2hniNei-XPK3iuZTlcBGqreTbJ0\";}s:2:\"id\";s:29:\"media.image.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.field.media.remote_video.field_media_oembed_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"4ed02114-671f-4880-bd68-143fe1b70c33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.media.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Eo4HHenV5iZat_kEWgr_wydD3TgwURMCzwt-7qIEyoM\";}s:2:\"id\";s:43:\"media.remote_video.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:5:\"label\";s:9:\"Video URL\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:6:\"string\";}'),('','field.field.media.video.field_media_video_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"0b1a6314-b982-4d68-89cc-0362ac441239\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6kMMjmk2r_csGQ52qI9BUaO8r_oAzNLbxlclaj-JlDQ\";}s:2:\"id\";s:34:\"media.video.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:5:\"label\";s:10:\"Video file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:3:\"mp4\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),('','field.field.node.article.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"ac9343a5-d157-4641-93f9-1b5bd7d0980f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4Wxs1LseZ8JsNwD9uJVIbzZqG35yQXN8Eo1Hub6NMuI\";}s:2:\"id\";s:17:\"node.article.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.article.field_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"6c45f2f3-d271-4c13-b678-675fb9cbc261\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"field.storage.node.field_image\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j0riO_-77ZFWNLtj0iJ31HnohiNjdn8HUL86RueCF-M\";}s:2:\"id\";s:24:\"node.article.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.field.node.article.field_tags',_binary 'a:17:{s:4:\"uuid\";s:36:\"d3dcae7f-9494-4866-b051-d4817b208fd5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:29:\"field.storage.node.field_tags\";i:1;s:17:\"node.type.article\";i:2;s:24:\"taxonomy.vocabulary.tags\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QdUgf_beeoaPiyKorFv0q1fcJpWH_uZTqe_xoVJacrw\";}s:2:\"id\";s:23:\"node.article.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Tags\";s:11:\"description\";s:84:\"Enter a comma-separated list. For example: Amsterdam, Mexico City, \"Cleveland, Ohio\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:21:\"default:taxonomy_term\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:1;}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.node.page.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"c7106e91-0b1d-44f0-82fc-584be35a29c2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KHu9I-pR4FnP79crRJ5gVD_1mKGSZcJsdIm9bn64iFg\";}s:2:\"id\";s:14:\"node.page.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),('','field.field.node.page.field_components',_binary 'a:16:{s:4:\"uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:2:\"id\";s:26:\"node.page.field_components\";s:10:\"field_name\";s:16:\"field_components\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:10:\"Components\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_accordion.field_ept_accordion',_binary 'a:17:{s:4:\"uuid\";s:36:\"a6969ae3-e3c4-4adf-b115-07a5a0172b95\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:43:\"field.storage.paragraph.field_ept_accordion\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:2;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gyYZiR8Di3nPWs-p1SHNRU9nboJcW5hom8i6mSecVtc\";}s:2:\"id\";s:43:\"paragraph.ept_accordion.field_ept_accordion\";s:10:\"field_name\";s:19:\"field_ept_accordion\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:8:\"Sections\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:21:\"ept_accordion_section\";s:21:\"ept_accordion_section\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:23;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_accordion.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"71eb6510-d311-4704-9d7a-147c6ba1fca0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dFTek-2-VjYGV96ffjrJqRnc7cP8oR-xd4f0hA8JlyA\";}s:2:\"id\";s:42:\"paragraph.ept_accordion.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_accordion.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"38a67ca0-85d7-4dee-8871-eef6909b89f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7ILR55bNJzar89h8OPnJx-IpC8TrZBRKYFxLOI1p73c\";}s:2:\"id\";s:38:\"paragraph.ept_accordion.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_accordion.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"fa75defe-e7d5-4782-bedf-3d3107b3a40f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-fStMIM_IiXT6N43R2XfdUDoqFS_sK8AUA-WvSHfcwo\";}s:2:\"id\";s:39:\"paragraph.ept_accordion.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_accordion\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_accordion_section.field_ept_accordion_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"3f86759a-0926-49a9-a1b3-ebe22666f4d8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_accordion_text\";i:1;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3d4EpzZAObqkHVq5leB4wQ_vhii4h9OoUdsxw0lZgfg\";}s:2:\"id\";s:56:\"paragraph.ept_accordion_section.field_ept_accordion_text\";s:10:\"field_name\";s:24:\"field_ept_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:5:\"label\";s:13:\"Text / Answer\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_accordion_section.field_ept_accordion_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"5fd2a01d-4924-4824-af89-5638dcb01e07\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_accordion_title\";i:1;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1GJAw9hJcCS1kRz9iAwG1qqyJ5XL97F--Irgw6Ns0GY\";}s:2:\"id\";s:57:\"paragraph.ept_accordion_section.field_ept_accordion_title\";s:10:\"field_name\";s:25:\"field_ept_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_accordion_section\";s:5:\"label\";s:16:\"Title / Question\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_basic_button.field_ept_basic_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"d95cc73b-b5b3-45bb-ab62-c70e8411b8e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_basic_button_link\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SCjKiIWEbPAkzMucyajmerVFBDbaKtjD3HukL942flo\";}s:2:\"id\";s:54:\"paragraph.ept_basic_button.field_ept_basic_button_link\";s:10:\"field_name\";s:27:\"field_ept_basic_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:11:\"Button Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_basic_button.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"0369fd76-8a03-4f51-98c8-2662289d77b1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JzXRiuHUYaRtlmk8K0WT_Yp1_iUpogPj6XDbLmZ_hVA\";}s:2:\"id\";s:45:\"paragraph.ept_basic_button.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:18:\"Paragraph settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_basic_button.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"484e5ed3-f463-4d7b-b27a-25b553c3a82b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U4JGLZ-4C6DwE5xpnkLU2Ckqm-NdvOTgwe9gAMlW_Ls\";}s:2:\"id\";s:41:\"paragraph.ept_basic_button.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_basic_button.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"d5f47d43-c851-4f4d-a9bf-282937a2eb88\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q6Cswt1AxNHLXzTfwWiWRP4dJwyasulFfWasATFZdrU\";}s:2:\"id\";s:42:\"paragraph.ept_basic_button.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_basic_button\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_block.field_ept_block_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"9e49c287-a8e3-4673-b781-6db3e163c7f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ept_block_block\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Y5C1tDwIza9l7G1NAqWPtZndTwsI1uclqq7mOTUqmyg\";}s:2:\"id\";s:41:\"paragraph.ept_block.field_ept_block_block\";s:10:\"field_name\";s:21:\"field_ept_block_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:5:\"Block\";s:11:\"description\";s:25:\"Add existing Drupal Block\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:10:\"categories\";s:18:\"selection_settings\";a:1:{s:10:\"categories\";a:11:{s:5:\"Block\";s:5:\"Block\";s:4:\"core\";s:4:\"core\";s:5:\"Forms\";s:5:\"Forms\";s:4:\"Help\";s:4:\"Help\";s:13:\"Lists (Views)\";s:13:\"Lists (Views)\";s:5:\"Menus\";s:5:\"Menus\";s:6:\"System\";s:6:\"System\";s:4:\"User\";s:4:\"User\";s:5:\"Views\";s:5:\"Views\";s:13:\"Announcements\";s:1:\"0\";s:12:\"TB Mega Menu\";s:1:\"0\";}}}s:10:\"field_type\";s:11:\"block_field\";}'),('','field.field.paragraph.ept_block.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"2d995ad8-7b72-4241-8c5b-bfb64c7a936a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o3fZQjNNObe_TkbgxMWmav7VePiJKizuqf7wQm1RqgQ\";}s:2:\"id\";s:38:\"paragraph.ept_block.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_block.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"440982f1-1d49-45ce-856f-cb3b95954c65\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AhoRfTUTx6zdLkKC-tHQ_pZVKgtpGN452BRXc__PSgM\";}s:2:\"id\";s:34:\"paragraph.ept_block.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_block.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"b40d62dd-ee5a-44cf-9983-6bbbd7667b68\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LoHBLk0u3sVMSi5c2wsK0PWLWQ1aM4uvkXBsu3odiYk\";}s:2:\"id\";s:35:\"paragraph.ept_block.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"28952958-350e-4fa8-b1bf-0526c52b982e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.storage.paragraph.field_ept_bootstrap_button_link\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-csuiRgrTiYqGIjfvXfzBJvGlaY5drE5fp2a_BZjuo\";}s:2:\"id\";s:62:\"paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ept_bootstrap_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"97adadda-941e-43f5-8c16-c2a84adbb6a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9H_JnoEbVvGC1ew0GhZEnKhJOj78OfksYHFErUsrtVw\";}s:2:\"id\";s:49:\"paragraph.ept_bootstrap_button.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"9d80d485-b1e2-4fbf-ad86-60acbbdd3d92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YeaGECTvxFfymsGgUGC0AO8Uap3cVB1SFUvwKCEoP0c\";}s:2:\"id\";s:45:\"paragraph.ept_bootstrap_button.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:14:\"Paragraph Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_bootstrap_button.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"c9626d4b-c719-4c6c-bc96-f92de310cf2e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IbyiiWXl-WZPf_JAHHt9YHqt7GAEtb8FBXpeQ3OXG8c\";}s:2:\"id\";s:46:\"paragraph.ept_bootstrap_button.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:15:\"Paragraph Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel.field_ept_carousel',_binary 'a:17:{s:4:\"uuid\";s:36:\"d7d805e1-ee4a-4aeb-87d9-e74edbe4f1e7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:42:\"field.storage.paragraph.field_ept_carousel\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:2;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aXX70EioyFtKtGWUZXGbeNLyjZK-M_6xbjrznbKBxsQ\";}s:2:\"id\";s:41:\"paragraph.ept_carousel.field_ept_carousel\";s:10:\"field_name\";s:18:\"field_ept_carousel\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:8:\"Carousel\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:17:\"ept_carousel_item\";s:17:\"ept_carousel_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:31;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_carousel.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"9905b685-324b-4f6a-8423-5973b3364a40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_IVLsSToXRuYcAqksQE6q0UQCw5J0ys7z54fIX3Prcg\";}s:2:\"id\";s:41:\"paragraph.ept_carousel.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_carousel.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"e61c2ef3-bfa8-4a34-aa69-9a530904c063\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T9eYBrQXk7NZSU8LgCIvtf9ldAkjSDaUsIlMZK1m5ks\";}s:2:\"id\";s:37:\"paragraph.ept_carousel.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0f3cce54-16b4-433a-a3d8-f66dceadfb5e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NN8UIWMU2GbeEUny8ga4lRNGGKi0sRnscgZKNOBUJbU\";}s:2:\"id\";s:38:\"paragraph.ept_carousel.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ept_carousel\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel_item.field_ept_carousel_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"f1e8eab0-49cf-40c1-a0c3-1c7c52bbcf18\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ept_carousel_caption\";i:1;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2da0GoNsm_uJyuQNbeEacFu5K_me_-2I4TTM-UpRlLk\";}s:2:\"id\";s:54:\"paragraph.ept_carousel_item.field_ept_carousel_caption\";s:10:\"field_name\";s:26:\"field_ept_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:5:\"label\";s:13:\"Slide caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_carousel_item.field_ept_carousel_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"8a07cecc-6fab-4d81-8cda-096df1dc73ab\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:48:\"field.storage.paragraph.field_ept_carousel_image\";i:1;s:16:\"media.type.image\";i:2;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1qmbDr08-JuyqmRroyYKRiBXHMWBHN8Q8K3o4KxjQW0\";}s:2:\"id\";s:52:\"paragraph.ept_carousel_item.field_ept_carousel_image\";s:10:\"field_name\";s:24:\"field_ept_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_carousel_item\";s:5:\"label\";s:11:\"Slide image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_columns.field_ept_columns',_binary 'a:17:{s:4:\"uuid\";s:36:\"e3f4b834-b3d2-43cf-8914-8378ae9e9f82\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:41:\"field.storage.paragraph.field_ept_columns\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"R6rkX-mPMiS67Fz1NUwV172q4Get3igbZ_JqWTdWxKU\";}s:2:\"id\";s:39:\"paragraph.ept_columns.field_ept_columns\";s:10:\"field_name\";s:17:\"field_ept_columns\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:7:\"Columns\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:11:\"ept_columns\";s:11:\"ept_columns\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_columns.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"77e74bf9-008e-4d96-9381-dc809ff7b841\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"v6ug86IR2khsDICnCIAdzPfNfLXmkeVFT9UqUTRCd9s\";}s:2:\"id\";s:40:\"paragraph.ept_columns.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_columns.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f9935753-c052-4b7b-b23a-a14f2748a834\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"E5a_LPXp_bizIM-GzrOKjXX53p0mj01R_Ljy3UhbYmc\";}s:2:\"id\";s:36:\"paragraph.ept_columns.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_columns.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"3988d015-d4a9-4560-9665-3defb0bfead9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:38:\"paragraphs.paragraphs_type.ept_columns\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LCIv3BxeR6WGu8S2T4pGT69kr4zPkUTHJk0ehJJqVjs\";}s:2:\"id\";s:37:\"paragraph.ept_columns.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_columns\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_countdown.field_ept_countdown_date',_binary 'a:17:{s:4:\"uuid\";s:36:\"51db6984-7e76-4d6a-be3b-8f052f3bae29\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_countdown_date\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:8:\"datetime\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Tpuj04Fr7uNZO039Nd8J5cv4Ya-znGKtwNYc5cXn1gc\";}s:2:\"id\";s:48:\"paragraph.ept_countdown.field_ept_countdown_date\";s:10:\"field_name\";s:24:\"field_ept_countdown_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:14:\"Countdown date\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:8:\"datetime\";}'),('','field.field.paragraph.ept_countdown.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"991df58b-c253-4036-a94c-16bf928672f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Ba5vspWY7pQHKiHMxUWsBgPe13kyadBUwXJG_mtVF04\";}s:2:\"id\";s:42:\"paragraph.ept_countdown.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:12:\"EPT Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_countdown.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"36557cf2-e64e-4835-ad8e-b5bbc8150e8e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jxnjRfw__e_lRLCA703BFzbVEExF3BkVWaY6sDGBfno\";}s:2:\"id\";s:38:\"paragraph.ept_countdown.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_countdown.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"ae2f7f13-51c7-4ea2-99c7-c5b6b22f7360\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hE1iEpJa-BGC9-RbtJz3GYEuzj1nOmJqKNp7bNq63v8\";}s:2:\"id\";s:39:\"paragraph.ept_countdown.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_countdown\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter.field_ept_counter_items',_binary 'a:17:{s:4:\"uuid\";s:36:\"53805c44-6771-4268-b091-a3f4f1269139\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:47:\"field.storage.paragraph.field_ept_counter_items\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:2;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1MfRaU5RDocEjlC7nyIwXtGJAd9zHFyzfmxMz3nhoL8\";}s:2:\"id\";s:45:\"paragraph.ept_counter.field_ept_counter_items\";s:10:\"field_name\";s:23:\"field_ept_counter_items\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:17:\"EPT Counter Items\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:16:\"ept_counter_item\";s:16:\"ept_counter_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_counter.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"153fe814-ed15-45dd-ac36-e3166140cf03\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MNeAeSI8Y2lhDp_9PO88OMzAgUex8QzA7U6mYPsqZh4\";}s:2:\"id\";s:40:\"paragraph.ept_counter.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:12:\"EPT Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_counter.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"b4f633fb-12be-4793-b294-21badb491880\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_WgiVxSXXCkXpPedeKEQqBdTrL2yAV-R5njXnnWvkyQ\";}s:2:\"id\";s:36:\"paragraph.ept_counter.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"44deba9e-6935-4553-9ef0-ecc889381ae8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:38:\"paragraphs.paragraphs_type.ept_counter\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_A9WA0oPqrE9hJAdrstmGGAwR1IetKm59q9podeyJaI\";}s:2:\"id\";s:37:\"paragraph.ept_counter.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:11:\"ept_counter\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_description',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad867234-0316-48d0-bba3-4dcafd6d6091\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:53:\"field.storage.paragraph.field_ept_counter_description\";i:1;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n4-1RuE5rL9TNgTiA2lw7thDEjBhXTw_XAZuWfN21qY\";}s:2:\"id\";s:56:\"paragraph.ept_counter_item.field_ept_counter_description\";s:10:\"field_name\";s:29:\"field_ept_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:11:\"Description\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_icon',_binary 'a:17:{s:4:\"uuid\";s:36:\"94fe1479-276a-47c8-a255-ba6fdb6b874f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_ept_counter_icon\";i:1;s:16:\"media.type.image\";i:2;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T7rXLcACaUML0NMksYsmdVF9_PA7XqFakcAdD0PuMKk\";}s:2:\"id\";s:49:\"paragraph.ept_counter_item.field_ept_counter_icon\";s:10:\"field_name\";s:22:\"field_ept_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:4:\"Icon\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"9857343f-763e-4b29-8143-ec3fb9d9963d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_counter_number\";i:1;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NLE9w7TbjN5CmAnSSj-gSDT5bGz-IIqdEs-myskjLxo\";}s:2:\"id\";s:51:\"paragraph.ept_counter_item.field_ept_counter_number\";s:10:\"field_name\";s:24:\"field_ept_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:6:\"Number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:4:{s:3:\"min\";i:1;s:3:\"max\";N;s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"field_type\";s:7:\"integer\";}'),('','field.field.paragraph.ept_counter_item.field_ept_counter_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"9d669ec1-badd-49d6-82c8-4a8eba8ca7da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ept_counter_title\";i:1;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1YYXmvZIdinNPPgOBzpsoa5rCIzMayt9KFg5Gp6aGxI\";}s:2:\"id\";s:50:\"paragraph.ept_counter_item.field_ept_counter_title\";s:10:\"field_name\";s:23:\"field_ept_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_counter_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_cta.field_ept_cta_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"40656cb2-323c-4502-b916-5613d935c06a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:50:\"field.storage.paragraph.field_ept_cta_column_image\";i:1;s:16:\"media.type.image\";i:2;s:34:\"paragraphs.paragraphs_type.ept_cta\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M6DPa4NxYRx2y48yZGbZgB9RXiUBCln4aFQ2BSQ1ZRo\";}s:2:\"id\";s:44:\"paragraph.ept_cta.field_ept_cta_column_image\";s:10:\"field_name\";s:26:\"field_ept_cta_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_cta.field_ept_cta_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"a4f2e656-d59b-4df7-833b-709b38ab9360\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_cta_link\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"663HkJoryKb6fkU2dIBK7JnS0-v_HHMirdYKZ97PPXI\";}s:2:\"id\";s:36:\"paragraph.ept_cta.field_ept_cta_link\";s:10:\"field_name\";s:18:\"field_ept_cta_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_cta.field_ept_cta_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"2eb61b2c-ee83-43b2-beb6-334f5562bc8c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_cta_second_link\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zqb9GkzwNjNvs2k4e9egdt1MT_D0YfyITXC4BVAQS3s\";}s:2:\"id\";s:43:\"paragraph.ept_cta.field_ept_cta_second_link\";s:10:\"field_name\";s:25:\"field_ept_cta_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:11:\"Second Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_cta.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"7a06dca5-73c0-4c47-a217-2f9d7f3b9d43\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CdThFhM93LECXPeiHekVQZst4pAyaZauFLBc6ZZ2HJ0\";}s:2:\"id\";s:36:\"paragraph.ept_cta.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:18:\"Paragraph settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_cta.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a054c663-7358-4e24-99c7-7caa63091265\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QN1QM2C6SY_OR_LyAWi1j0iKDvbeAcJCe6s806EaZDo\";}s:2:\"id\";s:32:\"paragraph.ept_cta.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_cta.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"e6f7cd85-741e-4d86-ae78-2eabee82b952\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:34:\"paragraphs.paragraphs_type.ept_cta\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r_MAbOMwe1u3jdwZjUjmDHaxwmjIU-JGVZUkIUziPiQ\";}s:2:\"id\";s:33:\"paragraph.ept_cta.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ept_cta\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"b46ea217-84f7-4321-912a-7446b534bb92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:51:\"field.storage.paragraph.field_ept_hero_column_image\";i:1;s:16:\"media.type.image\";i:2;s:35:\"paragraphs.paragraphs_type.ept_hero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_3eydYXoFUtHpVqERbj-NUTxfjmRpY41GlotzDaiMHw\";}s:2:\"id\";s:46:\"paragraph.ept_hero.field_ept_hero_column_image\";s:10:\"field_name\";s:27:\"field_ept_hero_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"5dcc6a7e-0a0a-4b27-8ec1-fc41c3bb654a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_hero_link\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lxzpMFHK8I8nPXViJVyoXQFZitk8kttqyIRXSb9D1O0\";}s:2:\"id\";s:38:\"paragraph.ept_hero.field_ept_hero_link\";s:10:\"field_name\";s:19:\"field_ept_hero_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"93b358ac-f703-4792-a4cb-65cb87eb34aa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ept_hero_second_link\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"69BKIyb4s5Y9A2Ehq5ew6h-2_suAuoW3onibd8wyXpI\";}s:2:\"id\";s:45:\"paragraph.ept_hero.field_ept_hero_second_link\";s:10:\"field_name\";s:26:\"field_ept_hero_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:11:\"Second link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_hero.field_ept_hero_title_prefix',_binary 'a:17:{s:4:\"uuid\";s:36:\"00840cc4-7392-4663-a414-47758f14db31\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_hero_title_prefix\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"veAof1VE_5yLVqcM55gO7131zQkIVF8H4zYSRsZft-U\";}s:2:\"id\";s:46:\"paragraph.ept_hero.field_ept_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ept_hero_title_prefix\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:12:\"Title prefix\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_hero.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"9610a78c-d4d5-4d29-9221-2b862f3b5c9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jlfCaG2VGA8ar8Pw_-7SqeS8qRs_HrOK0KBRLdRLQGw\";}s:2:\"id\";s:37:\"paragraph.ept_hero.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_hero.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"eda0ee86-a9c6-40a3-90a6-52025f859080\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d6uOb6beHqZsXuoLFCkZ9d-OTiK3Lfl7WLMId5Ynb1o\";}s:2:\"id\";s:33:\"paragraph.ept_hero.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_hero.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"9cd49d18-67b3-4776-ba0b-dda42289ac3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4ZRR07jQy0amtEk8dDsUh5TwD7BiPqLSfZ64qa1IkaE\";}s:2:\"id\";s:34:\"paragraph.ept_hero.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image.field_ept_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"123bb9be-f4f0-4e79-9c1f-5a74d1adc56a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_image\";i:1;s:16:\"media.type.image\";i:2;s:36:\"paragraphs.paragraphs_type.ept_image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jo3X0pnIHasz5kmaVrv_VxOnp5yor6wvZ68l7Hpg9nc\";}s:2:\"id\";s:35:\"paragraph.ept_image.field_ept_image\";s:10:\"field_name\";s:15:\"field_ept_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_image.field_ept_image_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"720ab2af-faa7-4459-84ec-84810093337c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ept_image_caption\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tA0YJl2CpERDaSbF2WLaH5CxWoJo4OUxxMw-Y_Z85KA\";}s:2:\"id\";s:43:\"paragraph.ept_image.field_ept_image_caption\";s:10:\"field_name\";s:23:\"field_ept_image_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:13:\"Image caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image.field_ept_image_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"e46eefbb-e77e-4dbb-b856-37283bfcbcf6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_image_link\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Dmezv08ITbH8uMIaLoQS0_rAIw2TDc-iXuD0VCZW5q0\";}s:2:\"id\";s:40:\"paragraph.ept_image.field_ept_image_link\";s:10:\"field_name\";s:20:\"field_ept_image_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:10:\"Image Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_image.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"99ba3548-2963-43fc-9439-5c4981283ee3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"35ALufHFT-74ORycJJBebQ8dzd9UMefuOloBcGo5VZ0\";}s:2:\"id\";s:38:\"paragraph.ept_image.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_image.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"ee4ec7f5-67b4-42d7-baf2-7aaee393847f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TQxr_NqYWOx6AZeW6vZ-pqzPYQhGvMxRwPcm_djydmY\";}s:2:\"id\";s:34:\"paragraph.ept_image.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"b25f97c8-ef2e-408c-b977-6254d1414afe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_image\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"js6jXfcyujmxNS5eOXM-fX2nbJp4VUCmm_wWeBR272c\";}s:2:\"id\";s:35:\"paragraph.ept_image.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_image\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_image_gallery',_binary 'a:17:{s:4:\"uuid\";s:36:\"dfb637af-23af-4aa3-8753-1c3c1b41f2a4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:47:\"field.storage.paragraph.field_ept_image_gallery\";i:1;s:16:\"media.type.image\";i:2;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-waCmECFpztaOjQ1zzHETTjcKsonmUGYLmUUBB3P_K4\";}s:2:\"id\";s:51:\"paragraph.ept_image_gallery.field_ept_image_gallery\";s:10:\"field_name\";s:23:\"field_ept_image_gallery\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:13:\"Image Gallery\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"84658343-fa44-4fe9-acaa-5c0c2ff5f1d0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"guMxbDDWmEkT_hzhYXnmY2fyGUJMEPxeJW9uZmuIh7s\";}s:2:\"id\";s:46:\"paragraph.ept_image_gallery.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"3d160c57-3e25-403d-8a51-0a0b3397f5eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u25lX345GD4zaFxqQqboxwsRa0S9GMlNcD3drpGc6wE\";}s:2:\"id\";s:42:\"paragraph.ept_image_gallery.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_image_gallery.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"bbd8f0a6-7c0d-47e5-a62d-a2c5aed60232\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eKE4hyL1K1LGrcOlvyUoYrmTVsVfgHxMAfCbRZf4f5A\";}s:2:\"id\";s:43:\"paragraph.ept_image_gallery.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:17:\"ept_image_gallery\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_micromodal.field_ept_micromodal_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"1003b7da-189c-4687-89e9-fe627bd2f746\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ept_micromodal_title\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jDNhkuS0vb097p4tXdHxr-ydSAj5cLsbKHtJJ8CC8A0\";}s:2:\"id\";s:51:\"paragraph.ept_micromodal.field_ept_micromodal_title\";s:10:\"field_name\";s:26:\"field_ept_micromodal_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:16:\"Micromodal Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_micromodal.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"c3236ac3-dc6f-4f78-9199-3450f0c1f3b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nAJ_q4mUFfBF1PGkZwsvQdbCQKbSx6iW74pQQ8M2kaY\";}s:2:\"id\";s:43:\"paragraph.ept_micromodal.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_micromodal.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f9453349-a4b8-4f21-ad48-735cb6bb9eca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"L9_i6zE8UlUJcopkepORHiE8I3C69iY3aeKe3A1jKDg\";}s:2:\"id\";s:39:\"paragraph.ept_micromodal.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_micromodal.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"b6314b7b-d04b-4c21-b388-edad4a320f8e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GoRC0O7xqhZYbUT4g4Qv76pyVOo2S62CERLkOw5UcoU\";}s:2:\"id\";s:40:\"paragraph.ept_micromodal.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_micromodal\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_quote.field_ept_quote_author',_binary 'a:17:{s:4:\"uuid\";s:36:\"819b216b-97f6-4f18-82b6-2074094a280f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.storage.paragraph.field_ept_quote_author\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oNI4JdVXun_FojU2-XZoJP9ztB3e4wWwPkZYgvGQGCg\";}s:2:\"id\";s:42:\"paragraph.ept_quote.field_ept_quote_author\";s:10:\"field_name\";s:22:\"field_ept_quote_author\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:12:\"Quote Author\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_quote.field_ept_quote_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"fe2fb5d1-bcf8-4e29-9e00-d600aab8954a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:45:\"field.storage.paragraph.field_ept_quote_image\";i:1;s:16:\"media.type.image\";i:2;s:36:\"paragraphs.paragraphs_type.ept_quote\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YjnCUtsj4uSblj8ujLf9XPYiUCvxUQCzn6Si7IvFez0\";}s:2:\"id\";s:41:\"paragraph.ept_quote.field_ept_quote_image\";s:10:\"field_name\";s:21:\"field_ept_quote_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:11:\"Quote Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_quote.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"c4e09c22-0835-4bec-a402-756220f2e9f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t7gxB3ZTgUm7Yk0DbVkmAjHW8mI8AmfMf32Oxs3QZcI\";}s:2:\"id\";s:38:\"paragraph.ept_quote.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_quote.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f701ef4d-7de9-46b4-88f4-6995981e11ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"daebO4BuA3YZb6pUdTzPsiqUuJH_LDMHLJkxdMWVZSo\";}s:2:\"id\";s:34:\"paragraph.ept_quote.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:5:\"Quote\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_quote.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"a08772a7-ac82-466b-918c-b39c7f16c309\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_quote\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QGR28IMOBB-lAS8KMdPI2PxLFhQ8APHB11vjkOzEybM\";}s:2:\"id\";s:35:\"paragraph.ept_quote.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_quote\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"9bf7105c-9c7f-493b-b93c-2ee846a91521\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"75Fj62yEPi_Tkndg_Fr-WT5Fn81YlgSw2oEee7jQnKg\";}s:2:\"id\";s:45:\"paragraph.ept_slick_slider.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_slick_slider',_binary 'a:17:{s:4:\"uuid\";s:36:\"c440db95-46b7-4316-8502-e20c900704c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_ept_slick_slider\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:2;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VMJlv4iCLXipe6DB9Nw7mRcvCegf6AlaUe9pD4sFZw4\";}s:2:\"id\";s:49:\"paragraph.ept_slick_slider.field_ept_slick_slider\";s:10:\"field_name\";s:22:\"field_ept_slick_slider\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:12:\"Slick Slider\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:21:\"ept_slick_slider_item\";s:21:\"ept_slick_slider_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"4bad9ad2-5f7d-40ee-92a6-547badbee525\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qgc2mLoZ4HsNUAYaZCNUYpblK1Qy_Grwx-FiIrrd3fo\";}s:2:\"id\";s:41:\"paragraph.ept_slick_slider.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slick_slider.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0570de2b-d581-4073-a8b0-0729eacf75eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8znZ6dLr4j9QA4jZnTSyprUdnZL0N8ZENTLNXvgPaFo\";}s:2:\"id\";s:42:\"paragraph.ept_slick_slider.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ept_slick_slider\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"1b1a1524-2e19-47c4-af5c-c693044a59e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:52:\"field.storage.paragraph.field_ept_slick_slider_image\";i:1;s:16:\"media.type.image\";i:2;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XlD11lUQ6pjHnXyA9Z5Z_lyj35bmUgn2C_2xUYcE2wI\";}s:2:\"id\";s:60:\"paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ept_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"6d566515-d2a4-4ce3-96e1-678ae2feea9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_slick_slider_link\";i:1;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"f47xjCX2OUOsteSKP2-Rqy9EJ1ZQWtGr2EmizJ0jwsQ\";}s:2:\"id\";s:59:\"paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"532449b1-8d51-4c87-ad35-6a4555565967\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_slick_slider_text\";i:1;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dP7Z_3Sp9p8yprgyoPMwzTnDckg7oXVPKeGBpWi5yHs\";}s:2:\"id\";s:59:\"paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"a98491aa-0091-4a36-af08-7e4f9e2a3554\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wDLAk6apIKl_k-WeYvw2Sx7NuPQrdbmVpPi_pcf6Ank\";}s:2:\"id\";s:42:\"paragraph.ept_slideshow.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_slideshow.field_ept_slideshow',_binary 'a:17:{s:4:\"uuid\";s:36:\"929dd04a-655a-436e-b9ec-8b400a26f596\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:43:\"field.storage.paragraph.field_ept_slideshow\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:2;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sl3hYGCV99Y8zdhisWkqHtWAR4cKtwAzRiAC8g8O_3w\";}s:2:\"id\";s:43:\"paragraph.ept_slideshow.field_ept_slideshow\";s:10:\"field_name\";s:19:\"field_ept_slideshow\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:9:\"Slideshow\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:18:\"ept_slideshow_item\";s:18:\"ept_slideshow_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_slideshow.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"04f2459a-8250-49b8-9c26-a1bc5f23b1ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eFgq1F96D8Kk_yB-LhiHcUiv0NDGHiiESnrxKVotJ8M\";}s:2:\"id\";s:38:\"paragraph.ept_slideshow.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0a76e0e6-37a2-4e5e-a2ca-41101da17e1e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MaSZwNYeloEyTip3_uq3aYWI21fdjStPLv72a0OyAs0\";}s:2:\"id\";s:39:\"paragraph.ept_slideshow.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_slideshow\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"6671231f-f98f-4ea0-a6ab-9bfe42290292\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_slideshow_link\";i:1;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sj-aXmpz4XSqjlnaG36lSUzZ8k1NxnbVupC-3jXoTh4\";}s:2:\"id\";s:53:\"paragraph.ept_slideshow_item.field_ept_slideshow_link\";s:10:\"field_name\";s:24:\"field_ept_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide',_binary 'a:17:{s:4:\"uuid\";s:36:\"6483f62f-11d2-44ea-bf5b-d0db486d3689\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:49:\"field.storage.paragraph.field_ept_slideshow_slide\";i:1;s:16:\"media.type.image\";i:2;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a66BmJCI3SYkj4hLc0icKJq37QzM84zA3q3tcAMeAqA\";}s:2:\"id\";s:54:\"paragraph.ept_slideshow_item.field_ept_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ept_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad96e4c6-579a-4465-ba2d-117890a7bff3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_slideshow_text\";i:1;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JIuZsvq1IySXyy86tHyxkIPZnRhYgEKfm5uNfN4Qgi8\";}s:2:\"id\";s:53:\"paragraph.ept_slideshow_item.field_ept_slideshow_text\";s:10:\"field_name\";s:24:\"field_ept_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"84bea7b4-b9e4-4cf4-8ec9-389dd6b02c10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_slideshow_title\";i:1;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"of2_NLVXcX_Tqy_oCPxWCKkqkVV1GMoDc32IPKj-uAs\";}s:2:\"id\";s:54:\"paragraph.ept_slideshow_item.field_ept_slideshow_title\";s:10:\"field_name\";s:25:\"field_ept_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:11:\"Slide Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"f00824ef-dc9b-4ba7-81ad-8e7910f662a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"w6dTziASV3O9e_SoQSGcA7y3KjBRRRFKEmxbhx_eOPY\";}s:2:\"id\";s:38:\"paragraph.ept_stats.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_stats.field_ept_stats',_binary 'a:17:{s:4:\"uuid\";s:36:\"cfaf7cc4-f386-4397-8876-cdcee33b93b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_stats\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:2;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ixjxb8WmNFSxd8n64WYGee4M8gw_ihsOSTkxejxBK7I\";}s:2:\"id\";s:35:\"paragraph.ept_stats.field_ept_stats\";s:10:\"field_name\";s:15:\"field_ept_stats\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:9:\"EPT Stats\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ept_stats_item\";s:14:\"ept_stats_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_stats.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a8fb2e31-9a7a-45bb-84f7-84bce2a8e256\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5DBGJho8oBlSjoM127v2kkKEhKXLsn2dYpC1Gj4wep8\";}s:2:\"id\";s:34:\"paragraph.ept_stats.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"1c882037-c7e3-42e4-9707-af10c5015ef2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_stats\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T8Ioj6BqDtO5y16e6qpTBdiluC90CXivuhVNCfIlff8\";}s:2:\"id\";s:35:\"paragraph.ept_stats.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_stats\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"48e0dea0-fc4d-4a86-8ed4-203f0efe3a52\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:50:\"field.storage.paragraph.field_ept_stats_item_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gQ-WN8Z7uMhqF7m3PcgLkMbssZvUuoZDru39piaWdaY\";}s:2:\"id\";s:51:\"paragraph.ept_stats_item.field_ept_stats_item_image\";s:10:\"field_name\";s:26:\"field_ept_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:16:\"Stats item image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"64aa7603-d2f0-4050-a82f-35b5ef3b978f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_stats_item_link\";i:1;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MnXt19dK8rTz4x1hRigyeVWiXn1o6VumcHTMqrFFk74\";}s:2:\"id\";s:50:\"paragraph.ept_stats_item.field_ept_stats_item_link\";s:10:\"field_name\";s:25:\"field_ept_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:15:\"Stats item link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"4be87c8b-a691-4546-9b46-8104a7920252\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_stats_item_number\";i:1;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7DMKiTrisc5ETf4YO_Rg2a1hxbtze1sV29AulzJK_mo\";}s:2:\"id\";s:52:\"paragraph.ept_stats_item.field_ept_stats_item_number\";s:10:\"field_name\";s:27:\"field_ept_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:17:\"Stats item number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_stats_item.field_ept_stats_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"7ab22f13-220c-400f-9f56-3043d91300ed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ept_stats_item_text\";i:1;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"syABtrl4XuopN2UmpGpkCfjm8LZlB4zLjgHycG4AUww\";}s:2:\"id\";s:50:\"paragraph.ept_stats_item.field_ept_stats_item_text\";s:10:\"field_name\";s:25:\"field_ept_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_stats_item\";s:5:\"label\";s:15:\"Stats item text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"bcee11b6-9de3-4ea7-ab28-783aaf52a980\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7WAUPeogPEpndKAuLbuwHXSQX1_x1zQ1DkQgZ0xSJl8\";}s:2:\"id\";s:37:\"paragraph.ept_tabs.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_tabs.field_ept_tabs',_binary 'a:17:{s:4:\"uuid\";s:36:\"f3ed6271-02a1-49ae-87a5-dcbb0788200c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:38:\"field.storage.paragraph.field_ept_tabs\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:2;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oxGvFEmPYXx97wLochArKKDYG1lhbF0L77Sp4ki0K1I\";}s:2:\"id\";s:33:\"paragraph.ept_tabs.field_ept_tabs\";s:10:\"field_name\";s:14:\"field_ept_tabs\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:8:\"EPT Tabs\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_tabs.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"5d8d9518-713c-4c54-a1b1-e9255a1064cf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SxiqJRauMgF0Qzud0cz2Wj4-oLnMJ3Cr-bXZe_fdGC0\";}s:2:\"id\";s:33:\"paragraph.ept_tabs.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"3b694b0c-21b1-40f1-aab1-5f8f6b508006\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DehWRcrin5XDNZhAMoyHl3b5Vtw4Tpdijx5u8vCQ75Q\";}s:2:\"id\";s:34:\"paragraph.ept_tabs.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_tabs\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"c3f52d5a-54bd-4606-8b04-4a6c1e456a0b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_block\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Djebt4QCWYRzCydiBvhKgj0bMyEaWAKfY-YBAf7OX4Y\";}s:2:\"id\";s:43:\"paragraph.ept_tabs_item.field_ept_tab_block\";s:10:\"field_name\";s:19:\"field_ept_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:9:\"Tab Block\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:6:\"blocks\";s:18:\"selection_settings\";a:1:{s:10:\"plugin_ids\";a:0:{}}}s:10:\"field_type\";s:11:\"block_field\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_content',_binary 'a:17:{s:4:\"uuid\";s:36:\"8bd0ca98-8e9c-4dba-b1cf-ae98a043504f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ept_tab_content\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:7:\"options\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FHi-QeaCukjELTWL55S3DmUxMPC5qvpjm7YoUXlN2_k\";}s:2:\"id\";s:45:\"paragraph.ept_tabs_item.field_ept_tab_content\";s:10:\"field_name\";s:21:\"field_ept_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:11:\"Tab content\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:11:\"list_string\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_page',_binary 'a:17:{s:4:\"uuid\";s:36:\"15235fd9-9fad-4092-b19c-8e011debebfb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:42:\"field.storage.paragraph.field_ept_tab_page\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lSW-pbI_Dd3D3Pmk9Ey9S92Si1kgRJBouroj9i9FcxI\";}s:2:\"id\";s:42:\"paragraph.ept_tabs_item.field_ept_tab_page\";s:10:\"field_name\";s:18:\"field_ept_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:8:\"Tab page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:12:\"default:node\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:4:\"page\";s:4:\"page\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a059a1dc-b8c7-41a3-a0ba-57ef2b7c3ef2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_tab_text\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UhI0Db-BZ8kkyso5fdxGaK2SLKXQOo3Tz91NfllT_zE\";}s:2:\"id\";s:42:\"paragraph.ept_tabs_item.field_ept_tab_text\";s:10:\"field_name\";s:18:\"field_ept_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:8:\"Tab text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0c7eb82c-6093-4901-bd0b-fd48f6eedcb2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_title\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"evBpqQnLlVSI7JzfhV_sYlfl4Xj_FMH8yjfAXa3TuNo\";}s:2:\"id\";s:43:\"paragraph.ept_tabs_item.field_ept_tab_title\";s:10:\"field_name\";s:19:\"field_ept_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:9:\"Tab title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:4:\"text\";}'),('','field.field.paragraph.ept_tabs_item.field_ept_tab_views',_binary 'a:17:{s:4:\"uuid\";s:36:\"efd74810-b803-4db6-b891-9ea3905eb31d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_views\";i:1;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I_C7XUVcXIbh_wxTumKceK8yBCxb_QVNvaycgNmZB20\";}s:2:\"id\";s:43:\"paragraph.ept_tabs_item.field_ept_tab_views\";s:10:\"field_name\";s:19:\"field_ept_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ept_tabs_item\";s:5:\"label\";s:9:\"Tab views\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";i:0;}s:12:\"plugin_types\";a:5:{s:5:\"block\";s:5:\"block\";s:7:\"default\";i:0;s:4:\"page\";i:0;s:4:\"feed\";i:0;s:5:\"embed\";i:0;}s:15:\"preselect_views\";a:15:{s:13:\"block_content\";i:0;s:7:\"comment\";i:0;s:15:\"comments_recent\";i:0;s:7:\"content\";i:0;s:14:\"content_recent\";i:0;s:5:\"files\";i:0;s:9:\"frontpage\";i:0;s:5:\"media\";i:0;s:13:\"media_library\";i:0;s:13:\"taxonomy_term\";i:0;s:17:\"user_admin_people\";i:0;s:8:\"watchdog\";i:0;s:19:\"webform_submissions\";i:0;s:9:\"who_s_new\";i:0;s:12:\"who_s_online\";i:0;}s:16:\"enabled_settings\";a:5:{s:8:\"argument\";i:0;s:5:\"limit\";i:0;s:6:\"offset\";i:0;s:5:\"pager\";i:0;s:5:\"title\";i:0;}}s:10:\"field_type\";s:14:\"viewsreference\";}'),('','field.field.paragraph.ept_text.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"dd24c6a8-a5d2-434a-90d0-3a97c829c794\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zlnMwIZoq976NUR8ObTPmCmOG2YwYTmjc1fQpFhCzWs\";}s:2:\"id\";s:37:\"paragraph.ept_text.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:5:\"label\";s:18:\"field_ept_settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_text.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"406dd338-600c-4eb2-841a-df635188cfb3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yIzbNDHidtMFArQQv6qO6cTkFBTnI6e02KK-xT8FOIM\";}s:2:\"id\";s:33:\"paragraph.ept_text.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_text.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"6902be14-683f-4f5a-8d50-8543bbf0aca5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:35:\"paragraphs.paragraphs_type.ept_text\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DZTXvQuYpXkQt9q004RnVKvKTocT9hurW7VYy0As9Is\";}s:2:\"id\";s:34:\"paragraph.ept_text.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_text\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"ac698185-3f8a-4519-a9b7-29609da24892\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d-eKpx0qmCR-PZ85K0IfmM1LKHFjcx9xUcNT5mMFMuA\";}s:2:\"id\";s:38:\"paragraph.ept_tiles.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_tiles.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"7f39ca00-ae38-46ac-a2f2-ce0b4f545f9f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uGM6CpdmK0GJ5mrS4WHYG6QnXJLHx0fiEbs3D7e_iqE\";}s:2:\"id\";s:34:\"paragraph.ept_tiles.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles.field_ept_tiles',_binary 'a:17:{s:4:\"uuid\";s:36:\"254d23bc-cd9a-4186-b124-2f3fa923fc05\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_tiles\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:2;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Lii17sKUYm4ZAvrf-OKM8IF0auj5DIQWCMBUkdzT4BM\";}s:2:\"id\";s:35:\"paragraph.ept_tiles.field_ept_tiles\";s:10:\"field_name\";s:15:\"field_ept_tiles\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:5:\"Tiles\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:75;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_tiles.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"efadba67-9ef3-474a-8246-0e5a51d74660\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e58JwGJ1lDz1CUji4qvDlK_7WEadqaihU0jG6u0_10E\";}s:2:\"id\";s:35:\"paragraph.ept_tiles.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_tiles\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_clickable_tile',_binary 'a:17:{s:4:\"uuid\";s:36:\"29c56f04-456b-4f6f-87b5-6352ddaa6a51\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ept_clickable_tile\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BVIyqIinPodc30VYfLCsYHnMbl1U6L7LpKffkLNM6RY\";}s:2:\"id\";s:49:\"paragraph.ept_tiles_item.field_ept_clickable_tile\";s:10:\"field_name\";s:24:\"field_ept_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:14:\"Clickable Tile\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"af24502d-ca80-4229-bc11-8b9d175d53f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:45:\"field.storage.paragraph.field_ept_tiles_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AnFN9yAGXXY3wn6XD_DMYj4H1UfZR6gt3lITV4L2Jy4\";}s:2:\"id\";s:46:\"paragraph.ept_tiles_item.field_ept_tiles_image\";s:10:\"field_name\";s:21:\"field_ept_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"77a71623-7050-467d-bbb6-f7e2b8e10f9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_tiles_link\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"c5x2tFCR-aDLFMCY5a0CDVK8OLjI-eH92z0w6wsbq7I\";}s:2:\"id\";s:45:\"paragraph.ept_tiles_item.field_ept_tiles_link\";s:10:\"field_name\";s:20:\"field_ept_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"a96f802e-f6f6-415b-a00b-47d8e483f3c2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_tiles_text\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zLtl1oCO1H3AjX05GApCKNVIuZj-sWnEjN2TFBhgTpk\";}s:2:\"id\";s:45:\"paragraph.ept_tiles_item.field_ept_tiles_text\";s:10:\"field_name\";s:20:\"field_ept_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_tiles_item.field_ept_tiles_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"60166fc5-cd70-42a2-ab4a-021bef6afcf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ept_tiles_title\";i:1;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-RWZYOv7kMNcT6h0h3wa0LE8w3is_5A7gNJGRvk2Xh8\";}s:2:\"id\";s:46:\"paragraph.ept_tiles_item.field_ept_tiles_title\";s:10:\"field_name\";s:21:\"field_ept_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ept_tiles_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"65e27c50-82c3-46dd-ad6d-c95805dd83bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jKYz3Azrp1BbteF4w3ARDoD11HGUjD6Y1-Pi3j5bMMA\";}s:2:\"id\";s:38:\"paragraph.ept_video.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_video.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"de00022b-0652-4a4f-a13f-6d001b19f4c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rOcKKlFTqbEyP9jZpIA7FgAeEZVpAzkLMwyL7Ocl7ZA\";}s:2:\"id\";s:34:\"paragraph.ept_video.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"68fe7948-f81f-4f36-8ce6-3a736d2696be\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_video\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"liOGejMkGS8WchkLMEwnO9OEFeI2CuDopa6y4ARi6R4\";}s:2:\"id\";s:35:\"paragraph.ept_video.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video.field_ept_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"5fbf0b1d-881b-44e3-9225-31e307913827\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:39:\"field.storage.paragraph.field_ept_video\";i:1;s:23:\"media.type.remote_video\";i:2;s:36:\"paragraphs.paragraphs_type.ept_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"B2uO316aHzKE6mwH_4CehW7np6-M8ImTN-8E4ZUIOz4\";}s:2:\"id\";s:35:\"paragraph.ept_video.field_ept_video\";s:10:\"field_name\";s:15:\"field_ept_video\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:12:\"remote_video\";s:12:\"remote_video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"8b147c97-e78e-4773-a7dd-fbdd3db585a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A0AtClTrQ3Abbg6jEI-itnCAjYSI69l8ZIU5n6wGu-k\";}s:2:\"id\";s:56:\"paragraph.ept_video_and_image_gallery.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"5c1e6fab-0fe9-4952-a3c8-991a0f293a80\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iohq2efRKb05xjfjet4Iqszn41WFrfgfSMpBRl9I8EQ\";}s:2:\"id\";s:52:\"paragraph.ept_video_and_image_gallery.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"2bdd8485-4125-400d-b6ef-feffe57ca0b6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nYAF3MHEVZhy6EJ7hiHDE82BlOyi6F94s9AtJa31HxY\";}s:2:\"id\";s:53:\"paragraph.ept_video_and_image_gallery.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images',_binary 'a:17:{s:4:\"uuid\";s:36:\"c9a94fcc-b813-47ed-9b68-5780ad0e270c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:51:\"field.storage.paragraph.field_ept_videos_and_images\";i:1;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:2;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Md5TJXPOSzIMO3hzpok2uncR4UY-8oOvihBYAwl1UTE\";}s:2:\"id\";s:65:\"paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";s:10:\"field_name\";s:27:\"field_ept_videos_and_images\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:17:\"Videos and Images\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:32:\"ept_video_and_image_gallery_item\";s:32:\"ept_video_and_image_gallery_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:82;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),('','field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item',_binary 'a:17:{s:4:\"uuid\";s:36:\"8e45972c-1dc7-444f-9475-a98aa5a83a12\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:4:{i:0;s:46:\"field.storage.paragraph.field_ept_gallery_item\";i:1;s:16:\"media.type.image\";i:2;s:23:\"media.type.remote_video\";i:3;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pIblYcf3rZ3cLp4a87dabiYrK0YFYOLsXZ8PPx7JD2w\";}s:2:\"id\";s:65:\"paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";s:10:\"field_name\";s:22:\"field_ept_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:5:\"label\";s:12:\"Gallery Item\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:2:{s:5:\"image\";s:5:\"image\";s:12:\"remote_video\";s:12:\"remote_video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:5:\"image\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),('','field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"9302769a-011f-4ea8-8a1a-82c6399fc628\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ept_gallery_item_text\";i:1;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rHN5K2dhzZ2JBJLK9KNsBbDp_D8-ug9T0oRgKfs_L_8\";}s:2:\"id\";s:70:\"paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";s:10:\"field_name\";s:27:\"field_ept_gallery_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ept_video_and_image_gallery_item\";s:5:\"label\";s:17:\"Gallery item text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_views.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"0cd4c4a7-feca-4fb7-9e8b-02984559941b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qvGJxPRaclSHVbrfz5Je86o0KNtcIYQhWoZtkWbYOeY\";}s:2:\"id\";s:38:\"paragraph.ept_views.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:8:\"Settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ept_settings\";}'),('','field.field.paragraph.ept_views.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"f9ef68e5-ed23-45fb-a5d1-bac433eeb379\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yroYplh-3xAoBiIIaPAFqecCgnt--hr4wQOE6pydZiw\";}s:2:\"id\";s:34:\"paragraph.ept_views.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_views.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"0d3eae73-ae6d-4601-b1d4-4df1d7d62c53\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YN4Np9dhEdu3560d9b81PqIY6VAamYuCUEeaTR7MeA4\";}s:2:\"id\";s:35:\"paragraph.ept_views.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),('','field.field.paragraph.ept_views.field_ept_views_view',_binary 'a:17:{s:4:\"uuid\";s:36:\"ef74c15e-0e9f-4f8c-82b1-f7cec4763c50\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_views_view\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qezCi3E0L14u6YMFPeJ3FisM_AyqNacTs3hFkLyN-Bk\";}s:2:\"id\";s:40:\"paragraph.ept_views.field_ept_views_view\";s:10:\"field_name\";s:20:\"field_ept_views_view\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:5:\"label\";s:4:\"View\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}s:12:\"plugin_types\";a:1:{s:5:\"block\";s:5:\"block\";}s:15:\"preselect_views\";a:0:{}s:16:\"enabled_settings\";a:0:{}}s:10:\"field_type\";s:14:\"viewsreference\";}'),('','field.field.user.user.user_picture',_binary 'a:17:{s:4:\"uuid\";s:36:\"27323f57-acfd-4aff-a508-544c6c8bdf3d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:31:\"field.storage.user.user_picture\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TE3gYVzd6g0deXqUl8SEu2azHwVG-SdXm3kwbrz0kHw\";}s:2:\"id\";s:22:\"user.user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:5:\"label\";s:7:\"Picture\";s:11:\"description\";s:29:\"Your virtual face or picture.\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:40:\"pictures/[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:0;s:18:\"alt_field_required\";b:0;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),('','field.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nJk0TAQBzlNo52ehiHI7bIEPLGi0BYqZvPdEn7Chfu0\";}s:16:\"purge_batch_size\";i:50;}'),('','field.storage.block_content.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"05e5fd5b-7ad6-434e-99a8-8635a8fa97cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc\";}s:2:\"id\";s:18:\"block_content.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.comment.comment_body',_binary 'a:17:{s:4:\"uuid\";s:36:\"4a613783-5795-48bc-bd8e-e3fe3a00ea51\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swYoCch_hY8QO5uwr4FURplfnUCUlpPB4idF8WGVCpw\";}s:2:\"id\";s:20:\"comment.comment_body\";s:10:\"field_name\";s:12:\"comment_body\";s:11:\"entity_type\";s:7:\"comment\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_audio_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"1295648c-a917-438e-a846-fd85d14ae8a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JCHoh95CpUeBx9ch24Tmi6ru0nwmNz8xWVH4Qs7RnTg\";}s:2:\"id\";s:28:\"media.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_document',_binary 'a:17:{s:4:\"uuid\";s:36:\"6b41e063-a182-4108-9b56-c0f4bb265180\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BdkTx7IL59MCw5a_fOZprPTOGM_wcjz-Fm8g7HV3vFk\";}s:2:\"id\";s:26:\"media.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"ae1f0138-a2f5-4881-bf90-0ade773b59b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0N0KSFk57p6qsq3qM4lYVGSuROvzXK-tSsdwByqUh3g\";}s:2:\"id\";s:23:\"media.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_oembed_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"b471db54-e924-4e9f-b6d7-c7e32f497206\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cNf_852Dq-fNnSaMI4LxL-J6N7bLkHuDbD9EUqOn4_U\";}s:2:\"id\";s:30:\"media.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:0;s:8:\"is_ascii\";b:0;}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.media.field_media_video_file',_binary 'a:17:{s:4:\"uuid\";s:36:\"1567fe07-a329-492a-bc5f-d82e3865bd57\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z5mgbn1PIVZ5TNMByBmivqo_u3Rdk58UIzpyN4ypTeM\";}s:2:\"id\";s:28:\"media.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.body',_binary 'a:17:{s:4:\"uuid\";s:36:\"26a81385-82de-46f0-8582-8c93b0fbcb01\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY\";}s:2:\"id\";s:9:\"node.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_components',_binary 'a:16:{s:4:\"uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:2:\"id\";s:21:\"node.field_components\";s:10:\"field_name\";s:16:\"field_components\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"d9aff85c-3ad9-418b-b47e-58f08b64180e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE\";}s:2:\"id\";s:16:\"node.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.node.field_tags',_binary 'a:17:{s:4:\"uuid\";s:36:\"81f6ea79-133f-4e53-bb0a-4169a69c4472\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs\";}s:2:\"id\";s:15:\"node.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:13:\"taxonomy_term\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_accordion',_binary 'a:17:{s:4:\"uuid\";s:36:\"c9282b5e-9cbb-4d37-84d7-b405cf59a041\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"99EX18edsQlLBda3J37pHASAxF4OUjSVJ4_nSq1pW94\";}s:2:\"id\";s:29:\"paragraph.field_ept_accordion\";s:10:\"field_name\";s:19:\"field_ept_accordion\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_accordion_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"177e4cd0-bbd1-44cd-9d3f-5b5dd4378ed4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l5c0DoOjgcErJEjFGkUqN_upYgubdHpE_MiwbMK2YRI\";}s:2:\"id\";s:34:\"paragraph.field_ept_accordion_text\";s:10:\"field_name\";s:24:\"field_ept_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_accordion_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"012f2184-9082-4983-9239-7dac48864d9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6S4PB05UjgSgHEDSalqgqkJHWyCcYsdkgPKTvGC2c8s\";}s:2:\"id\";s:35:\"paragraph.field_ept_accordion_title\";s:10:\"field_name\";s:25:\"field_ept_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_basic_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"360bef36-b4f7-492b-9677-6170eebdf2bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Tj1qQArNpaPeg2XmPed8WY2JiAk8p21-R1HVn28zVoY\";}s:2:\"id\";s:37:\"paragraph.field_ept_basic_button_link\";s:10:\"field_name\";s:27:\"field_ept_basic_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_block_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"58c5cc3e-9949-4686-882a-a56b59c60ea8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hAESsXJ5KZsWYKr-KB5wJoHNBdcOTlIFJUomBW8VxoU\";}s:2:\"id\";s:31:\"paragraph.field_ept_block_block\";s:10:\"field_name\";s:21:\"field_ept_block_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_bootstrap_button_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"bceb6f2f-b114-41f5-8b07-0ce990d0087a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BweaoyqqEqOIBPWV2qKw_2N4R6oBSudk91cCNPtz_iY\";}s:2:\"id\";s:41:\"paragraph.field_ept_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ept_bootstrap_button_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_carousel',_binary 'a:17:{s:4:\"uuid\";s:36:\"fbb51140-67d8-4112-868c-19dd46c31b98\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RbALd0Xz78o-CtP2iD8j7s8h1scHn1lSdm-_EQqZyrY\";}s:2:\"id\";s:28:\"paragraph.field_ept_carousel\";s:10:\"field_name\";s:18:\"field_ept_carousel\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_carousel_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"4bdff313-152c-4ea9-ba49-6f433c48203a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HeWBlq69mptI0nGWU0dliRAS9rVOa2HzuJbUbzsJg4M\";}s:2:\"id\";s:36:\"paragraph.field_ept_carousel_caption\";s:10:\"field_name\";s:26:\"field_ept_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_carousel_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"1da3ad04-a3d6-45a2-8a2e-100f0d629948\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ViB2NrYfe_RWvrvvb9X_U6kuX0eI47m5Wpa6hCFqZWE\";}s:2:\"id\";s:34:\"paragraph.field_ept_carousel_image\";s:10:\"field_name\";s:24:\"field_ept_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_clickable_tile',_binary 'a:17:{s:4:\"uuid\";s:36:\"776f5eb1-0740-473f-b278-4678ab1e0a4e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKnQMenIUygu6qoP8n4_EzChFXMkjnwf78bFFBWCN0w\";}s:2:\"id\";s:34:\"paragraph.field_ept_clickable_tile\";s:10:\"field_name\";s:24:\"field_ept_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_columns',_binary 'a:17:{s:4:\"uuid\";s:36:\"7518ddce-1000-4e47-8c93-f8230ca40081\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lIenGVJ8vS3WAEr1xteI9sDUdCoc-UNgbf7xDipU4_s\";}s:2:\"id\";s:27:\"paragraph.field_ept_columns\";s:10:\"field_name\";s:17:\"field_ept_columns\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_countdown_date',_binary 'a:17:{s:4:\"uuid\";s:36:\"5741fa83-8e57-4e60-99ce-6e8bd5bf8b78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:8:\"datetime\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SWGbKy8XYRkCxbrmDvY2UYyxzAKxcSL7ouH4CljiXbY\";}s:2:\"id\";s:34:\"paragraph.field_ept_countdown_date\";s:10:\"field_name\";s:24:\"field_ept_countdown_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:8:\"datetime\";s:8:\"settings\";a:1:{s:13:\"datetime_type\";s:8:\"datetime\";}s:6:\"module\";s:8:\"datetime\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_description',_binary 'a:17:{s:4:\"uuid\";s:36:\"385056ad-483b-468c-8fc7-fa477f32138c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Vb_uSodiEH1YHgcoZFitK_cSCdO65_4U1fUOrl-0G-0\";}s:2:\"id\";s:39:\"paragraph.field_ept_counter_description\";s:10:\"field_name\";s:29:\"field_ept_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_icon',_binary 'a:17:{s:4:\"uuid\";s:36:\"bd174355-0ad0-4843-9909-9069e6e2eac2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I0JA4V_sLzmSUMXzEuZ7m6J_MFEw5Nrb7bG9XU34Ucc\";}s:2:\"id\";s:32:\"paragraph.field_ept_counter_icon\";s:10:\"field_name\";s:22:\"field_ept_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_items',_binary 'a:17:{s:4:\"uuid\";s:36:\"fa2205d7-3b05-4d76-a029-30510c45d952\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vFwfw4KEUwjCwBs2-7ay4ctFQ2ObvCZYU16zxuQC5HM\";}s:2:\"id\";s:33:\"paragraph.field_ept_counter_items\";s:10:\"field_name\";s:23:\"field_ept_counter_items\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"072a57f4-9c76-4a9a-a3f4-f13ef03b81be\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MzVJsn5k9Si1YXppdAIDnZzJ1W16U44-V2RnkeyaeyI\";}s:2:\"id\";s:34:\"paragraph.field_ept_counter_number\";s:10:\"field_name\";s:24:\"field_ept_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"integer\";s:8:\"settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_counter_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"a62c9e27-ad8b-430d-85ce-9db276ada8eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CTuSHda2RHGJciX7ZF12J7Y9A3TK_RrRj7CRxyKyNGA\";}s:2:\"id\";s:33:\"paragraph.field_ept_counter_title\";s:10:\"field_name\";s:23:\"field_ept_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_cta_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"2545ccb9-b7f9-49f1-a002-1aa70a099849\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BVZIBdZwlh9CG5xDwjnekBIIuVdEEtKvFPci5rwGdA0\";}s:2:\"id\";s:36:\"paragraph.field_ept_cta_column_image\";s:10:\"field_name\";s:26:\"field_ept_cta_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_cta_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"ef4b1edf-7e44-4fd4-9484-139b43615d23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LvryVrIdU5CC3UNEhpU7Vej6X8Y4RKKDsOdhseGGUVg\";}s:2:\"id\";s:28:\"paragraph.field_ept_cta_link\";s:10:\"field_name\";s:18:\"field_ept_cta_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_cta_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"e5ac8a81-1f96-4b7d-b8e0-6d9b2c08fcbd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DHvUvJxjsMX4y4-L8sAyVpFvA0pptpqcHZ8p_EMBBdU\";}s:2:\"id\";s:35:\"paragraph.field_ept_cta_second_link\";s:10:\"field_name\";s:25:\"field_ept_cta_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_gallery_item',_binary 'a:17:{s:4:\"uuid\";s:36:\"a1361495-0a6d-4f18-8570-b713e198ddf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8JLKZdRZR-OD6hbmGc3VHufx5PLi683tbf4QM_K4ZAU\";}s:2:\"id\";s:32:\"paragraph.field_ept_gallery_item\";s:10:\"field_name\";s:22:\"field_ept_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_gallery_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"ceb57be4-05e2-49c4-afad-48cb1341e682\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cWuIwOJOPOwoJ4OA0TCSko2wR73oMOOVlyC7clefebo\";}s:2:\"id\";s:37:\"paragraph.field_ept_gallery_item_text\";s:10:\"field_name\";s:27:\"field_ept_gallery_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_column_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"0bd5b0b1-4d3b-472e-ac51-086416f9360a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"knr6QfLVidPHSzwjlRdOZ6PqAiVNnXT73--qFC4pZqo\";}s:2:\"id\";s:37:\"paragraph.field_ept_hero_column_image\";s:10:\"field_name\";s:27:\"field_ept_hero_column_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"89e38776-3ba0-4f79-9023-af5e40b20171\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XgZuheOtVwvMdFAli6FX9XwC6jCtmfQsa4Y--V6AWLk\";}s:2:\"id\";s:29:\"paragraph.field_ept_hero_link\";s:10:\"field_name\";s:19:\"field_ept_hero_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_second_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"a51e7805-3dcf-415a-b08c-6e41b660115d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_LEdcxkwVZPMeBjAfFM_DTcqJxHu-SXmfvkzYA16OTE\";}s:2:\"id\";s:36:\"paragraph.field_ept_hero_second_link\";s:10:\"field_name\";s:26:\"field_ept_hero_second_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_hero_title_prefix',_binary 'a:17:{s:4:\"uuid\";s:36:\"be93c2a2-2803-47c8-8cbb-88ab3561ae6c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HgeEpS7HHbPsoLeKHrpRrax2ttxvlJADvMU3R-HwVf4\";}s:2:\"id\";s:37:\"paragraph.field_ept_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ept_hero_title_prefix\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"a3a4414c-7488-42d9-ad4e-706dbb16b1da\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t2q8Lh-nuJZ2Ozh8PR1_zVbozcHAD18kLOnsz0e4oxY\";}s:2:\"id\";s:25:\"paragraph.field_ept_image\";s:10:\"field_name\";s:15:\"field_ept_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image_caption',_binary 'a:17:{s:4:\"uuid\";s:36:\"d90ba792-7242-4c28-a755-2203bfbd33dc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-2PNM_k1cGXc-Q0fAWwWKl0WSoTksX8UcJ3-t0wUn1s\";}s:2:\"id\";s:33:\"paragraph.field_ept_image_caption\";s:10:\"field_name\";s:23:\"field_ept_image_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image_gallery',_binary 'a:17:{s:4:\"uuid\";s:36:\"a25a51c6-fb73-441d-bfe4-baf60db380f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"42vUEff48hmnJOtdaZMLlF0wtf_QYb_mBJO5EVMCKBk\";}s:2:\"id\";s:33:\"paragraph.field_ept_image_gallery\";s:10:\"field_name\";s:23:\"field_ept_image_gallery\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_image_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"389f5e03-e7e9-4fb0-bdb5-618f4ada2579\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VKNAP2cuu9mjHYh_BiZTS3nC4gx2nPLjvdAFIHAhJs\";}s:2:\"id\";s:30:\"paragraph.field_ept_image_link\";s:10:\"field_name\";s:20:\"field_ept_image_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_micromodal_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"58a0c8d3-2aaa-43a3-af29-df451a7410e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9wlDgbRXeLI7j3BoH97N3phJfeK2l1E2osqZh_FRkh4\";}s:2:\"id\";s:36:\"paragraph.field_ept_micromodal_title\";s:10:\"field_name\";s:26:\"field_ept_micromodal_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_quote_author',_binary 'a:17:{s:4:\"uuid\";s:36:\"f68b8da9-803f-4c9b-8f4c-4fc24f899205\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yN0vOPqU28gSDN6dC5uNd2vwbTDVhm0njE_mJ2k_rCk\";}s:2:\"id\";s:32:\"paragraph.field_ept_quote_author\";s:10:\"field_name\";s:22:\"field_ept_quote_author\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_quote_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"39b9627d-fdb9-4ed9-afc4-0c4d133a92c6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tQ8LcsYTu_fXhMAvx5We58I0EB2mrFc9tC42tO2YpQ4\";}s:2:\"id\";s:31:\"paragraph.field_ept_quote_image\";s:10:\"field_name\";s:21:\"field_ept_quote_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_settings',_binary 'a:17:{s:4:\"uuid\";s:36:\"aed153c8-a66a-428a-be76-0d9ff9c57e30\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HvKMBmRf1ancerUpnNjtwfTeY-R4_vPBnsqEe9j-ovs\";}s:2:\"id\";s:28:\"paragraph.field_ept_settings\";s:10:\"field_name\";s:18:\"field_ept_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:12:\"ept_settings\";s:8:\"settings\";a:0:{}s:6:\"module\";s:8:\"ept_core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider',_binary 'a:17:{s:4:\"uuid\";s:36:\"467150cb-7feb-412a-9426-4b2a3f4a1caa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"p4cFkBoz3tkJW1Ep5zM4g_f4mQ-XFHh3pShn7qHErpU\";}s:2:\"id\";s:32:\"paragraph.field_ept_slick_slider\";s:10:\"field_name\";s:22:\"field_ept_slick_slider\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"d985b37a-8f1d-4d3c-8d92-09cb8326cf66\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LzVCCy3JB_QNYYe-TIA7NOSStFsPdMhJRj2kRx6xp48\";}s:2:\"id\";s:38:\"paragraph.field_ept_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ept_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"3adc57b0-490d-4760-8c68-b19c339fedb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"urQvYyrbemmSrIdbqn5B3hiHO3OGBgCpwmTx0L9ipCM\";}s:2:\"id\";s:37:\"paragraph.field_ept_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slick_slider_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"d8e5d125-f4f7-4c1d-ac26-f7468f91d3b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9lgsbO7ntDggj0S64_Kj04ysNSAJqsLLVWCg1sASI7o\";}s:2:\"id\";s:37:\"paragraph.field_ept_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ept_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow',_binary 'a:17:{s:4:\"uuid\";s:36:\"1a9f268a-efba-464e-854e-f46e7e1341e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNz95cfhiI0VPQ9jlgmyexwx_snf3hcYXB3N76R6FEg\";}s:2:\"id\";s:29:\"paragraph.field_ept_slideshow\";s:10:\"field_name\";s:19:\"field_ept_slideshow\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"08a96db8-eb88-4875-8250-d218a934e839\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j3IfmwQ3lYIJp87Put31sIn-_9bc3uFqZWFLa_w_9hk\";}s:2:\"id\";s:34:\"paragraph.field_ept_slideshow_link\";s:10:\"field_name\";s:24:\"field_ept_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_slide',_binary 'a:17:{s:4:\"uuid\";s:36:\"d704c8d4-b783-49b6-af10-1f4524374151\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qxeflsuOm7AVY0acEDYWC8RbV1WUHCbVdEWrV-i8xCU\";}s:2:\"id\";s:35:\"paragraph.field_ept_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ept_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"8f6db9bb-d214-4b8e-a41e-8e68af02013e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hf7ieZizeOOo0vAYdXIuWovA7ihSiu5RQ6PQD9LV27c\";}s:2:\"id\";s:34:\"paragraph.field_ept_slideshow_text\";s:10:\"field_name\";s:24:\"field_ept_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_slideshow_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"c605bbbd-911f-4bca-9f1d-7575ba23063c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tyAlxAEOc2ScLxGA0DPp-lg0u4x8VXHrFuotd44B_SE\";}s:2:\"id\";s:35:\"paragraph.field_ept_slideshow_title\";s:10:\"field_name\";s:25:\"field_ept_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats',_binary 'a:17:{s:4:\"uuid\";s:36:\"54f29aab-0b38-45f1-bef4-33ea7848198c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A2WIvrY8Lq2oUgdXcZ6AeYNUvyM4mmPAuE7W3ZK_2Wc\";}s:2:\"id\";s:25:\"paragraph.field_ept_stats\";s:10:\"field_name\";s:15:\"field_ept_stats\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"32ff7444-1fb2-4c29-97a3-9e9f53ec491a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UoI74uzcaxvNAutge4YEMTgWFuRMeasXrgpq3PK1sVs\";}s:2:\"id\";s:36:\"paragraph.field_ept_stats_item_image\";s:10:\"field_name\";s:26:\"field_ept_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"48fc10e7-9c7a-4b33-8f60-3ce608c713c5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r9tIHirJngA0lU8nZzF4zo3Sk3sZoNMDm7tn4Q8f6nU\";}s:2:\"id\";s:35:\"paragraph.field_ept_stats_item_link\";s:10:\"field_name\";s:25:\"field_ept_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_number',_binary 'a:17:{s:4:\"uuid\";s:36:\"e0b4af62-c275-4029-b2a7-59ffabd9c786\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HhOT5HnntE62swJxbAxEUWcqiYJnPIfz8wawWbRbXDs\";}s:2:\"id\";s:37:\"paragraph.field_ept_stats_item_number\";s:10:\"field_name\";s:27:\"field_ept_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_stats_item_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"9bab1d24-d574-48e2-8d0e-4ab68fb47d98\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IMNMgfxAACwo5FdbEzobs2cmUZRx-IryVkWAVFd6jPc\";}s:2:\"id\";s:35:\"paragraph.field_ept_stats_item_text\";s:10:\"field_name\";s:25:\"field_ept_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tabs',_binary 'a:17:{s:4:\"uuid\";s:36:\"79fcf2b8-c7f0-45ad-b0c1-f2032eef3896\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NMqcA7Fqw60GbpdVeUtmztxo2zdXkrGvZx8twbTDDeU\";}s:2:\"id\";s:24:\"paragraph.field_ept_tabs\";s:10:\"field_name\";s:14:\"field_ept_tabs\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_block',_binary 'a:17:{s:4:\"uuid\";s:36:\"14901660-c7de-459b-8e6b-6065e1894829\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mkRqIh2Wq5dPyqwbNdS4O7366xpiXfnEqoCKO_Dxil8\";}s:2:\"id\";s:29:\"paragraph.field_ept_tab_block\";s:10:\"field_name\";s:19:\"field_ept_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_content',_binary 'a:17:{s:4:\"uuid\";s:36:\"87c56ad4-62d6-4644-86c1-680e4755ff8b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"options\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fKb1I7aWTTDXPpSXxFasd3Do_zu03KEABHYH6l26zZU\";}s:2:\"id\";s:31:\"paragraph.field_ept_tab_content\";s:10:\"field_name\";s:21:\"field_ept_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"list_string\";s:8:\"settings\";a:2:{s:14:\"allowed_values\";a:4:{i:0;a:2:{s:5:\"value\";s:4:\"text\";s:5:\"label\";s:4:\"Text\";}i:1;a:2:{s:5:\"value\";s:4:\"page\";s:5:\"label\";s:4:\"Page\";}i:2;a:2:{s:5:\"value\";s:5:\"block\";s:5:\"label\";s:5:\"Block\";}i:3;a:2:{s:5:\"value\";s:5:\"views\";s:5:\"label\";s:5:\"Views\";}}s:23:\"allowed_values_function\";s:0:\"\";}s:6:\"module\";s:7:\"options\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_page',_binary 'a:17:{s:4:\"uuid\";s:36:\"dd8a6a77-dce1-4167-81fc-78b560cda129\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HG0HGpRQXhX56PVuj3x5C5jDc-vtEneALavRoeN1CvM\";}s:2:\"id\";s:28:\"paragraph.field_ept_tab_page\";s:10:\"field_name\";s:18:\"field_ept_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"node\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"843571d5-1f13-41be-91d6-4a2cdc24036d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-LqQ-u0-ZIOFFNbSXCCLceO2nHJcofY3jorF2Bo_oOs\";}s:2:\"id\";s:28:\"paragraph.field_ept_tab_text\";s:10:\"field_name\";s:18:\"field_ept_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"75781815-4f60-47eb-bdc4-255e273d1add\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jmZoEFoCrYRXWTQoBNH-lk2Jtzlrk1QgYJW-ZwiojjU\";}s:2:\"id\";s:29:\"paragraph.field_ept_tab_title\";s:10:\"field_name\";s:19:\"field_ept_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"text\";s:8:\"settings\";a:1:{s:10:\"max_length\";i:255;}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tab_views',_binary 'a:17:{s:4:\"uuid\";s:36:\"0210aa9b-f809-485d-9dc9-01d5b19a7a97\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yuhCLkHFy1lOVHdkbi-9gSbiwW6Cz9cKfJdJaYwK_Pk\";}s:2:\"id\";s:29:\"paragraph.field_ept_tab_views\";s:10:\"field_name\";s:19:\"field_ept_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"e76f4c36-a02a-4c1e-b34f-cecbd30657dd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7r3ygKhgvLH2hBQgQ6uizJgLea8q4TUMhKv9AysHhVw\";}s:2:\"id\";s:24:\"paragraph.field_ept_text\";s:10:\"field_name\";s:14:\"field_ept_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles',_binary 'a:17:{s:4:\"uuid\";s:36:\"ad3c2c1b-78c7-400a-a114-8f5a64daf409\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XenLJeS9-3QAxnei6iPwJsGOprgjG7bUCwDd60onVWw\";}s:2:\"id\";s:25:\"paragraph.field_ept_tiles\";s:10:\"field_name\";s:15:\"field_ept_tiles\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_image',_binary 'a:17:{s:4:\"uuid\";s:36:\"c84089e9-ca27-4ede-81db-501ab243fe10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LTIRUfdCjzSopVuoQqk229l5haSvo7JDJ2W9r1MheDo\";}s:2:\"id\";s:31:\"paragraph.field_ept_tiles_image\";s:10:\"field_name\";s:21:\"field_ept_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_link',_binary 'a:17:{s:4:\"uuid\";s:36:\"62135f80-efc0-4ec3-883a-ce4ccfe66aaa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ca5c5aWMZPNjvFUQqM813ltjPOGiBvCBP1o5N8IrcOM\";}s:2:\"id\";s:30:\"paragraph.field_ept_tiles_link\";s:10:\"field_name\";s:20:\"field_ept_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_text',_binary 'a:17:{s:4:\"uuid\";s:36:\"095f6e1d-c38c-4e36-824d-929e502f2c16\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"K1TV7SR5GOPQTJv3GF_zAIsJciKLKB5xd_eo3WUc5HA\";}s:2:\"id\";s:30:\"paragraph.field_ept_tiles_text\";s:10:\"field_name\";s:20:\"field_ept_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_tiles_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"a21fa265-c368-46f8-b0bf-ccd4251290bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fWLTZKbXw0jB-UFCqh6l4jRNvxOPFhGWVUKUjcIHfEg\";}s:2:\"id\";s:31:\"paragraph.field_ept_tiles_title\";s:10:\"field_name\";s:21:\"field_ept_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_title',_binary 'a:17:{s:4:\"uuid\";s:36:\"d142f67c-eb14-402b-8d63-83e817038f33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjnRL-vwDWFKmoYTCU9jkwjIlui_gNnOJnIwnLo9m2k\";}s:2:\"id\";s:25:\"paragraph.field_ept_title\";s:10:\"field_name\";s:15:\"field_ept_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_video',_binary 'a:17:{s:4:\"uuid\";s:36:\"30383ff9-015d-4872-a3cb-3c814a4683f6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WUq7ljAeKbQ5WQGxUm1FFT157H56wcSHSihAGR-RPhc\";}s:2:\"id\";s:25:\"paragraph.field_ept_video\";s:10:\"field_name\";s:15:\"field_ept_video\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_videos_and_images',_binary 'a:17:{s:4:\"uuid\";s:36:\"fb3b02a6-684b-4508-8b49-e87fa4e916c1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P8bQebl9F2OCnDtVw7LFuwUlmGfUGA7HLJaYolmUgpU\";}s:2:\"id\";s:37:\"paragraph.field_ept_videos_and_images\";s:10:\"field_name\";s:27:\"field_ept_videos_and_images\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.paragraph.field_ept_views_view',_binary 'a:17:{s:4:\"uuid\";s:36:\"8622c9ec-6687-4349-af19-885f22d99285\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GjkDxormsrh0OTX-iAPBLiJLIDg3h8b7yPlpgyt-kM\";}s:2:\"id\";s:30:\"paragraph.field_ept_views_view\";s:10:\"field_name\";s:20:\"field_ept_views_view\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field.storage.user.user_picture',_binary 'a:17:{s:4:\"uuid\";s:36:\"233edf85-6a6a-473c-933a-1a6a9015993a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E\";}s:2:\"id\";s:17:\"user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),('','field_ui.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q1nMi90W6YQxKzZAgJQw7Ag9U4JrsEUwkomF0lhvbIM\";}s:12:\"field_prefix\";s:6:\"field_\";}'),('','file.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2bwjZB1IjEYbppgZT3g7YW_5h_LDZYNa3DaDEfWX82U\";}s:11:\"description\";a:2:{s:4:\"type\";s:9:\"textfield\";s:6:\"length\";i:128;}s:4:\"icon\";a:1:{s:9:\"directory\";s:23:\"core/modules/file/icons\";}s:35:\"make_unused_managed_files_temporary\";b:0;s:21:\"filename_sanitization\";a:6:{s:13:\"transliterate\";b:0;s:18:\"replace_whitespace\";b:0;s:24:\"replace_non_alphanumeric\";b:0;s:22:\"deduplicate_separators\";b:0;s:9:\"lowercase\";b:0;s:21:\"replacement_character\";s:1:\"-\";}}'),('','file_mdm.file_metadata_plugin.getimagesize',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o53U_2I-21Es-9iqxeUMDRcRxN0spL1OiHuAVQhh2oI\";}s:13:\"configuration\";a:1:{s:5:\"cache\";a:2:{s:8:\"override\";b:0;s:8:\"settings\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}}}}'),('','file_mdm.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fOx6TBj_84WfX_a6JhuWiPQ-twAjHykvYsTvJAKbZsE\";}s:14:\"metadata_cache\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}s:22:\"missing_file_log_level\";i:3;}'),('','file_mdm_exif.file_metadata_plugin.exif',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u0ZqkNrnyVSnHXGBP0zlKY9dP1ZARzJZ9VSovzU_eDg\";}s:7:\"ifd_map\";a:5:{i:0;a:2:{s:4:\"type\";i:0;s:7:\"aliases\";a:3:{i:0;s:1:\"0\";i:1;s:4:\"IFD0\";i:2;s:4:\"Main\";}}i:1;a:2:{s:4:\"type\";i:1;s:7:\"aliases\";a:3:{i:0;s:1:\"1\";i:1;s:4:\"IFD1\";i:2;s:9:\"Thumbnail\";}}s:4:\"Exif\";a:2:{s:4:\"type\";i:2;s:7:\"aliases\";a:1:{i:0;s:4:\"Exif\";}}s:3:\"GPS\";a:2:{s:4:\"type\";i:3;s:7:\"aliases\";a:1:{i:0;s:3:\"GPS\";}}s:16:\"Interoperability\";a:2:{s:4:\"type\";i:4;s:7:\"aliases\";a:2:{i:0;s:16:\"Interoperability\";i:1;s:7:\"Interop\";}}}s:13:\"configuration\";a:1:{s:5:\"cache\";a:2:{s:8:\"override\";b:0;s:8:\"settings\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}}}}'),('','file_mdm_font.file_metadata_plugin.font',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o53U_2I-21Es-9iqxeUMDRcRxN0spL1OiHuAVQhh2oI\";}s:13:\"configuration\";a:1:{s:5:\"cache\";a:2:{s:8:\"override\";b:0;s:8:\"settings\";a:3:{s:7:\"enabled\";b:1;s:10:\"expiration\";i:172800;s:16:\"disallowed_paths\";a:0:{}}}}}'),('','filter.format.basic_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"9ffd8de5-5d95-4675-941e-b6205d96c828\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:6:\"editor\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mclCbTlJwWJORez4Y1eX2MqA0aGjSMAoJb3TaBABcK8\";}s:4:\"name\";s:10:\"Basic HTML\";s:6:\"format\";s:10:\"basic_html\";s:6:\"weight\";i:-9;s:7:\"filters\";a:6:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:7;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:243:\"<br> <p> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id> <cite> <dl> <dt> <dd> <a hreflang href> <blockquote cite> <ul type> <ol start type> <strong> <em> <code> <li> <img src alt data-entity-uuid data-entity-type height width data-caption data-align>\";s:16:\"filter_html_help\";b:0;s:20:\"filter_html_nofollow\";b:0;}}s:24:\"filter_html_image_secure\";a:5:{s:2:\"id\";s:24:\"filter_html_image_secure\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}}}'),('','filter.format.full_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"5837f230-16d1-4857-8f42-39560aa7f6bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:32:\"core.entity_view_mode.media.full\";}s:6:\"module\";a:2:{i:0;s:6:\"editor\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpZysv3RHJjhYzq7O_q5q8mVlHdrSzKELmXyiX6RtV0\";}s:4:\"name\";s:9:\"Full HTML\";s:6:\"format\";s:9:\"full_html\";s:6:\"weight\";i:-10;s:7:\"filters\";a:7:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:0;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:38:\"<span class=\"title-prefix white-text\">\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:20:\"filter_htmlcorrector\";a:5:{s:2:\"id\";s:20:\"filter_htmlcorrector\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:10;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}s:11:\"media_embed\";a:5:{s:2:\"id\";s:11:\"media_embed\";s:8:\"provider\";s:5:\"media\";s:6:\"status\";b:1;s:6:\"weight\";i:100;s:8:\"settings\";a:3:{s:17:\"default_view_mode\";s:7:\"default\";s:18:\"allowed_view_modes\";a:2:{s:7:\"default\";s:7:\"default\";s:4:\"full\";s:4:\"full\";}s:19:\"allowed_media_types\";a:3:{s:5:\"image\";s:5:\"image\";s:12:\"remote_video\";s:12:\"remote_video\";s:5:\"video\";s:5:\"video\";}}}}}'),('','filter.format.plain_text',_binary 'a:9:{s:4:\"uuid\";s:36:\"e7b49ea5-e3d9-43a7-9355-811016606856\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JLMwODO0epnA_H-jFlH9ezVfa5YBJniRv3MmLqYNl_Q\";}s:4:\"name\";s:10:\"Plain text\";s:6:\"format\";s:10:\"plain_text\";s:6:\"weight\";i:-7;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:18:\"filter_html_escape\";a:5:{s:2:\"id\";s:18:\"filter_html_escape\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:0:{}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),('','filter.format.restricted_html',_binary 'a:9:{s:4:\"uuid\";s:36:\"b26630f8-bc66-410b-9271-2fd35673a39c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QiKqQS_YGAT3Qr4vaAgZICJknm-MGCzt_xBAMqg-tRM\";}s:4:\"name\";s:15:\"Restricted HTML\";s:6:\"format\";s:15:\"restricted_html\";s:6:\"weight\";i:-8;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:149:\"<a href hreflang> <em> <strong> <cite> <blockquote cite> <code> <ul type> <ol start type> <li> <dl> <dt> <dd> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id>\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),('','filter.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FiPjM3WdB__ruFA7B6TLwni_UcZbmek5G4b2dxQItxA\";}s:15:\"fallback_format\";s:10:\"plain_text\";s:27:\"always_show_fallback_choice\";b:0;}'),('','gin.settings',_binary 'a:17:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ug4-rUG_KE9H5v1RaDLLpkSZsu70E9HnJp6sqFfjvHk\";}s:7:\"favicon\";a:1:{s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:1;}s:4:\"logo\";a:1:{s:11:\"use_default\";b:1;}s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}s:19:\"preset_accent_color\";s:4:\"blue\";s:18:\"preset_focus_color\";s:3:\"gin\";s:15:\"enable_darkmode\";s:1:\"0\";s:15:\"classic_toolbar\";s:7:\"classic\";s:26:\"secondary_toolbar_frontend\";b:1;s:18:\"high_contrast_mode\";b:0;s:12:\"accent_color\";s:0:\"\";s:11:\"focus_color\";s:0:\"\";s:14:\"layout_density\";s:7:\"default\";s:23:\"show_description_toggle\";b:0;s:24:\"show_user_theme_settings\";b:0;s:21:\"sticky_action_buttons\";b:0;}'),('','glightbox.settings',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5G059LQS_7DV7oGUpxVTPM0aWtunW7bvDpRkgeb0KtE\";}s:6:\"custom\";a:17:{s:8:\"activate\";i:0;s:11:\"open_effect\";s:4:\"zoom\";s:12:\"close_effect\";s:4:\"zoom\";s:12:\"slide_effect\";s:5:\"slide\";s:5:\"width\";s:3:\"98%\";s:6:\"height\";s:3:\"98%\";s:11:\"videosWidth\";s:5:\"960px\";s:22:\"close_on_outside_click\";b:1;s:9:\"more_text\";s:8:\"See more\";s:11:\"more_length\";i:60;s:13:\"desc_position\";s:6:\"bottom\";s:4:\"loop\";b:0;s:8:\"zoomable\";b:1;s:9:\"draggable\";b:1;s:7:\"preload\";b:1;s:15:\"autoplay_videos\";b:1;s:16:\"autofocus_videos\";b:0;}s:8:\"advanced\";a:2:{s:12:\"unique_token\";i:0;s:16:\"compression_type\";s:8:\"minified\";}}'),('','image.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-yDFHbqNfpe-Srg4sdCSqaosCl2D8uwyEY5esF8gEw\";}s:13:\"preview_image\";s:29:\"core/modules/image/sample.png\";s:26:\"allow_insecure_derivatives\";b:0;s:20:\"suppress_itok_output\";b:0;}'),('','image.style.ept_gallery_image',_binary 'a:8:{s:4:\"uuid\";s:36:\"96327273-04cd-4db7-9889-976db88ae72b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"image_effects\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1Q9XGhzUPbe1wp53fxzN8EbXYFVVXfNTiWQshZB1x-o\";}s:4:\"name\";s:17:\"ept_gallery_image\";s:5:\"label\";s:17:\"EPT Gallery Image\";s:7:\"effects\";a:2:{s:36:\"5a3cbdd5-32d1-49cd-a00f-bbc716cc09ef\";a:4:{s:4:\"uuid\";s:36:\"5a3cbdd5-32d1-49cd-a00f-bbc716cc09ef\";s:2:\"id\";s:24:\"image_effects_set_canvas\";s:6:\"weight\";i:-8;s:4:\"data\";a:4:{s:11:\"canvas_size\";s:5:\"exact\";s:12:\"canvas_color\";s:9:\"#FFFFFFFF\";s:5:\"exact\";a:5:{s:5:\"width\";s:3:\"365\";s:6:\"height\";s:3:\"265\";s:9:\"placement\";s:13:\"center-center\";s:8:\"x_offset\";i:0;s:8:\"y_offset\";i:0;}s:8:\"relative\";a:4:{s:4:\"left\";i:0;s:5:\"right\";i:0;s:3:\"top\";i:0;s:6:\"bottom\";i:0;}}}s:36:\"7237f375-b695-4dca-8e1a-88b52b0437ea\";a:4:{s:4:\"uuid\";s:36:\"7237f375-b695-4dca-8e1a-88b52b0437ea\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:-9;s:4:\"data\";a:3:{s:5:\"width\";i:365;s:6:\"height\";i:265;s:7:\"upscale\";b:0;}}}}'),('','image.style.ept_quote_image',_binary 'a:8:{s:4:\"uuid\";s:36:\"8ad0f8e1-bf91-4861-b98d-bd4757ce19fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"R8OkUD1v3lvqA1ihlprDbuQcs3MJp_s2N37cfrJuul8\";}s:4:\"name\";s:15:\"ept_quote_image\";s:5:\"label\";s:15:\"EPT Quote Image\";s:7:\"effects\";a:1:{s:36:\"c7e1a3e5-c5e1-4f6b-92f2-525a6f9ca013\";a:4:{s:4:\"uuid\";s:36:\"c7e1a3e5-c5e1-4f6b-92f2-525a6f9ca013\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:530;s:6:\"height\";N;s:7:\"upscale\";b:1;}}}}'),('','image.style.ept_slick_slider_card',_binary 'a:8:{s:4:\"uuid\";s:36:\"d5e3c8ee-d135-4d9b-87f8-3983d8804dd0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TLssjGEnnOFSTHjAehxDElobDdWsdzT8XjjY2Ru_ZTQ\";}s:4:\"name\";s:21:\"ept_slick_slider_card\";s:5:\"label\";s:21:\"EPT Slick Slider card\";s:7:\"effects\";a:1:{s:36:\"55a5d05a-911b-44f6-8154-26bf4d5f89a2\";a:4:{s:4:\"uuid\";s:36:\"55a5d05a-911b-44f6-8154-26bf4d5f89a2\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:400;s:6:\"height\";i:300;s:6:\"anchor\";s:13:\"center-center\";}}}}'),('','image.style.ept_video_and_image_gallery',_binary 'a:8:{s:4:\"uuid\";s:36:\"c7167138-d49d-4235-8671-ee7f0d2d2b21\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VijhP4To3EdFocRuOjCdr8vV8fPomTYloLASZEYa0pc\";}s:4:\"name\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:27:\"EPT Video and Image gallery\";s:7:\"effects\";a:1:{s:36:\"dd219b2f-d95b-480c-83e9-b9b81fe45c90\";a:4:{s:4:\"uuid\";s:36:\"dd219b2f-d95b-480c-83e9-b9b81fe45c90\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:360;s:6:\"anchor\";s:13:\"center-center\";}}}}'),('','image.style.large',_binary 'a:8:{s:4:\"uuid\";s:36:\"1d081002-40ce-4508-b331-45087f55f851\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rDR2BOewa2UFH9yG4tVvrGxEVv8U7LQo-RLkJhFpERs\";}s:4:\"name\";s:5:\"large\";s:5:\"label\";s:16:\"Large (480×480)\";s:7:\"effects\";a:2:{s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";a:4:{s:4:\"uuid\";s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:480;s:7:\"upscale\";b:0;}}s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";a:4:{s:4:\"uuid\";s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.media_library',_binary 'a:8:{s:4:\"uuid\";s:36:\"dce163df-e6d0-4a19-be9f-835d8fb9ad19\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FxMdscEA4aDH0KPM73HIZtVn3zIAgC1kQ3CkBw26HYs\";}s:4:\"name\";s:13:\"media_library\";s:5:\"label\";s:34:\"Media Library thumbnail (220×220)\";s:7:\"effects\";a:2:{s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";a:4:{s:4:\"uuid\";s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";a:4:{s:4:\"uuid\";s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.medium',_binary 'a:8:{s:4:\"uuid\";s:36:\"cc99d86c-9cb9-4913-9000-8ea5ef978940\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dlar76VBuGj5iMGTruB_uMZX8VbivXt9_QLemaG2q4E\";}s:4:\"name\";s:6:\"medium\";s:5:\"label\";s:17:\"Medium (220×220)\";s:7:\"effects\";a:2:{s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";a:4:{s:4:\"uuid\";s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";a:4:{s:4:\"uuid\";s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.thumbnail',_binary 'a:8:{s:4:\"uuid\";s:36:\"45c23df0-c353-4723-86c7-ddfc29333553\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BgeBV-xOFINMsz-y2thm45EGesj6bRM6DTLZ6ce3V9I\";}s:4:\"name\";s:9:\"thumbnail\";s:5:\"label\";s:20:\"Thumbnail (100×100)\";s:7:\"effects\";a:2:{s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";a:4:{s:4:\"uuid\";s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:100;s:6:\"height\";i:100;s:7:\"upscale\";b:0;}}s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";a:4:{s:4:\"uuid\";s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image.style.wide',_binary 'a:8:{s:4:\"uuid\";s:36:\"7407b366-d102-42ad-8d9b-28fc84ce386e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XHh3ATMH7z4ljwmzdndM47qNMkgLnoYsP98rGxVgCOw\";}s:4:\"name\";s:4:\"wide\";s:5:\"label\";s:11:\"Wide (1090)\";s:7:\"effects\";a:2:{s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";a:4:{s:4:\"uuid\";s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:1090;s:6:\"height\";N;s:7:\"upscale\";b:0;}}s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";a:4:{s:4:\"uuid\";s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),('','image_effects.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eaXmaPSud65p-XhTwMIL9vKETD9zR3qNOMMa5EUuoNw\";}s:14:\"color_selector\";a:2:{s:9:\"plugin_id\";s:10:\"html_color\";s:15:\"plugin_settings\";a:1:{s:10:\"html_color\";a:0:{}}}s:14:\"image_selector\";a:2:{s:9:\"plugin_id\";s:5:\"basic\";s:15:\"plugin_settings\";a:1:{s:5:\"basic\";a:0:{}}}s:13:\"font_selector\";a:2:{s:9:\"plugin_id\";s:5:\"basic\";s:15:\"plugin_settings\";a:1:{s:5:\"basic\";a:0:{}}}}'),('','layout_paragraphs.modal_settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z9zmTNfo1bY0sbqYp1OAvqSynu_DXDRdJoZhi7oiS0I\";}s:5:\"width\";s:3:\"90%\";s:6:\"height\";s:4:\"auto\";s:10:\"autoresize\";b:1;}'),('','layout_paragraphs.settings',_binary 'a:6:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HBy2Jf-2HHsgvIjldhAl07r9vuy879dsx6Cm_LpbPrw\";}s:21:\"show_paragraph_labels\";i:0;s:18:\"show_layout_labels\";i:0;s:25:\"paragraph_behaviors_label\";s:9:\"Behaviors\";s:28:\"paragraph_behaviors_position\";i:-99;s:13:\"empty_message\";s:21:\"No components to add.\";}'),('','media.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WCFqLQAxMw1weToDJEhfnW1Z-iOF7cqMdL8X7YTFxBA\";}s:13:\"icon_base_uri\";s:28:\"public://media-icons/generic\";s:13:\"iframe_domain\";N;s:20:\"oembed_providers_url\";s:33:\"https://oembed.com/providers.json\";s:14:\"standalone_url\";b:0;}'),('','media.type.audio',_binary 'a:13:{s:4:\"uuid\";s:36:\"6a011382-b41c-428b-bec3-c2acb1a0b347\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJw8n6Tk2tO3ZysuEeGR1gZa1yRffaZzR4t0Q7iNurs\";}s:2:\"id\";s:5:\"audio\";s:5:\"label\";s:5:\"Audio\";s:11:\"description\";s:28:\"A locally hosted audio file.\";s:6:\"source\";s:10:\"audio_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_audio_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media.type.document',_binary 'a:13:{s:4:\"uuid\";s:36:\"f7d4d4ed-07f1-4c0e-add0-5205dca6bb2d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_D9q3XSnP6ik9we9UuoTvZsQKPuYNp_G9PfwVtWzgnQ\";}s:2:\"id\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:44:\"An uploaded file or document, such as a PDF.\";s:6:\"source\";s:4:\"file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:20:\"field_media_document\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media.type.image',_binary 'a:13:{s:4:\"uuid\";s:36:\"0bf0a6ff-42d0-4443-95d9-32bb21b3d878\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6Qope5wG7HUpV0tPOBMtDI_GZkHFcF1Xj4hgD9Cu_hM\";}s:2:\"id\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:36:\"Use local images for reusable media.\";s:6:\"source\";s:5:\"image\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:17:\"field_media_image\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media.type.remote_video',_binary 'a:13:{s:4:\"uuid\";s:36:\"d833ee62-0e66-41f9-bc64-0ee184be48b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hIBTnDGgDKnCiP6HUZm1m7600DHUEpC6FN3LQ4sUgZ4\";}s:2:\"id\";s:12:\"remote_video\";s:5:\"label\";s:12:\"Remote video\";s:11:\"description\";s:46:\"A remotely hosted video from YouTube or Vimeo.\";s:6:\"source\";s:12:\"oembed:video\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:3:{s:12:\"source_field\";s:24:\"field_media_oembed_video\";s:20:\"thumbnails_directory\";s:44:\"public://oembed_thumbnails/[date:custom:Y-m]\";s:9:\"providers\";a:2:{i:0;s:7:\"YouTube\";i:1;s:5:\"Vimeo\";}}s:9:\"field_map\";a:1:{s:5:\"title\";s:4:\"name\";}}'),('','media.type.video',_binary 'a:13:{s:4:\"uuid\";s:36:\"f37b6fcf-a1f5-41c8-ad6b-ab36d7822130\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hzgvcRgZHltqWf8hBmttoWh95tCJoPL25lPq9YSIRsY\";}s:2:\"id\";s:5:\"video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:28:\"A locally hosted video file.\";s:6:\"source\";s:10:\"video_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_video_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),('','media_library.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_3gQsCnZELUjUUqHk8SSh8bXnx7TZwN95vctAeVJG60\";}s:11:\"advanced_ui\";b:0;}'),('','menu_ui.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SqMarzIjxC3F8dZo9FEOxfqDKD_sdW1tbcFTV1BA2zU\";}s:24:\"override_parent_selector\";b:0;}'),('','node.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W0cgFPhPJ3gAdqm06-az48BLf5MVcoZVS0HdByoofi0\";}s:15:\"use_admin_theme\";b:1;}'),('','node.type.article',_binary 'a:13:{s:4:\"uuid\";s:36:\"9597cbd8-ec71-47b6-98f5-c2eeebffff0e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"menu_ui\";}}s:20:\"third_party_settings\";a:1:{s:7:\"menu_ui\";a:2:{s:15:\"available_menus\";a:1:{i:0;s:4:\"main\";}s:6:\"parent\";s:5:\"main:\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Fe3N1uqaAyyKJbVkqT-btXy3t98puW8GCRD822xjl10\";}s:4:\"name\";s:7:\"Article\";s:4:\"type\";s:7:\"article\";s:11:\"description\";s:89:\"Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:0;}'),('','node.type.page',_binary 'a:12:{s:4:\"uuid\";s:36:\"e24a8178-cabf-4c12-8439-99829f4ce10e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"i0snV8Wj--OkRW12UdachUiYiz3FbeMwHu_pZYfzKLc\";}s:4:\"name\";s:10:\"Basic page\";s:4:\"type\";s:4:\"page\";s:11:\"description\";s:77:\"Use <em>basic pages</em> for your static content, such as an \'About us\' page.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:0;}'),('','olivero.settings',_binary 'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1TswGK46jyu77aIM7Z-0JVQs5bxHmo-gtgrvrQGMXxc\";}s:7:\"favicon\";a:1:{s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:0;}s:4:\"logo\";a:1:{s:11:\"use_default\";b:0;}s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}s:22:\"mobile_menu_all_widths\";i:0;s:22:\"site_branding_bg_color\";s:7:\"default\";s:18:\"base_primary_color\";s:7:\"#1b9ae4\";}'),('','paragraphs.paragraphs_type.ept_accordion',_binary 'a:11:{s:4:\"uuid\";s:36:\"3252260c-9d6c-4095-8836-d9e0aaa25dc6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7pqqqPfYwBkkvx32K8x5QoezX6vxHdseC3YV0ajDLEI\";}s:2:\"id\";s:13:\"ept_accordion\";s:5:\"label\";s:17:\"EPT Accordion/FAQ\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:41:\"Extra Paragraph Type (EPT): Accordion/FAQ\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_accordion_section',_binary 'a:11:{s:4:\"uuid\";s:36:\"4290efa9-ba8f-4d75-8ae5-02743a3c35f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fmkcpDXAJK73b4nzzBnj4rVGpuHiDLrUxBK6rbvbQMY\";}s:2:\"id\";s:21:\"ept_accordion_section\";s:5:\"label\";s:35:\"EPT Accordion section / FAQ section\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:46:\"Accordion or FAQ section for EPT Accordion/FAQ\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_basic_button',_binary 'a:11:{s:4:\"uuid\";s:36:\"29db5768-3c25-444b-84f5-1a0ab0ba6377\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gzUQpZ2WLaq6cYbIJG9au02yBTA2Hi4xUPtwlz0CRhU\";}s:2:\"id\";s:16:\"ept_basic_button\";s:5:\"label\";s:16:\"EPT Basic Button\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:39:\"Extra Paragraph Type (EPT) Basic Button\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_block',_binary 'a:11:{s:4:\"uuid\";s:36:\"698fe7c4-0789-4365-b3ce-d8bbd2d7d879\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hSup62OW-6glALkcPyijfub_HXz0FNzEQuWRhyhtdXk\";}s:2:\"id\";s:9:\"ept_block\";s:5:\"label\";s:9:\"EPT Block\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Block\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_bootstrap_button',_binary 'a:11:{s:4:\"uuid\";s:36:\"ffeadf94-a846-4eeb-af7e-504e5b867d19\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4txRVN0PevwIGZwVEjxCxQoHq3fJGXNtgncbg5k5JDA\";}s:2:\"id\";s:20:\"ept_bootstrap_button\";s:5:\"label\";s:20:\"EPT Bootstrap Button\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:44:\"Extra Paragraph Type (EPT): Bootstrap Button\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_carousel',_binary 'a:11:{s:4:\"uuid\";s:36:\"0f8caf80-346b-4e13-bb09-4c47aafab045\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"E7xdcbl_-Um-sC9AVRpej77V2ILldHA3_zXTVVCz1sY\";}s:2:\"id\";s:12:\"ept_carousel\";s:5:\"label\";s:12:\"EPT Carousel\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:36:\"Extra Paragraph Type (EPT): Carousel\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_carousel_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"07a0dbc7-10e5-4ae6-897e-e0a112e89e81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YtKbftJ20RlhAbMlxwbbttKpDr7oOd_NrNquqRUyXK8\";}s:2:\"id\";s:17:\"ept_carousel_item\";s:5:\"label\";s:17:\"EPT Carousel Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:30:\"Carousel item for EPT Carousel\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_columns',_binary 'a:11:{s:4:\"uuid\";s:36:\"e359103e-fb7d-4814-b51e-5b6eb0bf50cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fmkytBjjMOfcRpE_qi-piB3B8O6AiLkllwZyK_sI7Gw\";}s:2:\"id\";s:11:\"ept_columns\";s:5:\"label\";s:23:\"EPT Columns / Container\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:48:\"Extra Paragraph Types (EPT): Columns / Container\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_countdown',_binary 'a:11:{s:4:\"uuid\";s:36:\"d468b305-ccc4-4dd1-827a-5ac37883f188\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BqPVlvdHbcXEIez6BBufo--6hdhOwAkO8rjIkAK5jq4\";}s:2:\"id\";s:13:\"ept_countdown\";s:5:\"label\";s:13:\"EPT Countdown\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:37:\"Extra Paragraph Type (EPT): Countdown\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_counter',_binary 'a:11:{s:4:\"uuid\";s:36:\"fb9a64bf-58bb-4e29-a23f-83bc70d9958c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Seed1ZP-O7N7haFpWM63DgrcW90m0L3mwRpNqOVCvms\";}s:2:\"id\";s:11:\"ept_counter\";s:5:\"label\";s:11:\"EPT Counter\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:66:\"Adds Counter with coffee cups, projects, case studies number, etc.\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_counter_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"8fca0905-ad07-4e5a-b80e-a842bece8ab5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1DUe53zhmyI3hSvz4PGQ9EcXk8A47wdqyIrDi3aJmo8\";}s:2:\"id\";s:16:\"ept_counter_item\";s:5:\"label\";s:16:\"EPT Counter Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:64:\"Counter Items to be used inside of Paragraph Type: \"EPT Counter\"\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_cta',_binary 'a:11:{s:4:\"uuid\";s:36:\"5a3625a2-f528-429b-8415-b0b1eface1d4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-6Ujd6Cr-x8TD472fJ9SX66k2Pn7_uw07fVQWq1DXQk\";}s:2:\"id\";s:7:\"ept_cta\";s:5:\"label\";s:24:\"EPT Call to Action (CTA)\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:48:\"Extra Paragraph Type (EPT): Call to Action (CTA)\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_hero',_binary 'a:11:{s:4:\"uuid\";s:36:\"ced6180f-b154-47b8-a7b7-61647c71db48\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kps1UJbRPEF2GuSjDQDJFWWG5EZ6qTHII92BJxLlwTk\";}s:2:\"id\";s:8:\"ept_hero\";s:5:\"label\";s:8:\"EPT Hero\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:36:\"Extra Paragraph Type (EPT): EPT Hero\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_image',_binary 'a:11:{s:4:\"uuid\";s:36:\"f1d6ed2b-6a40-4f21-930f-5cd318945855\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GEIZEGHO5Mf_kO9Yek21HvRO-j_2fbPepBSsr35U_zY\";}s:2:\"id\";s:9:\"ept_image\";s:5:\"label\";s:9:\"EPT Image\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Image\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_image_gallery',_binary 'a:11:{s:4:\"uuid\";s:36:\"ec405efa-b146-4a07-abc8-d507909706f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fQ2CW1Vm9f_8Xi0V4exsAGpv8RdV6Ptm-cjffg9lPyM\";}s:2:\"id\";s:17:\"ept_image_gallery\";s:5:\"label\";s:17:\"EPT Image Gallery\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:41:\"Extra Paragraph Type (EPT): Image Gallery\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_micromodal',_binary 'a:11:{s:4:\"uuid\";s:36:\"3188911c-48a1-42f6-8342-f2b8eb94edff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OvFmHRYOT8js98yougS_zy_ICFqOce54ziNcxoCbTq8\";}s:2:\"id\";s:14:\"ept_micromodal\";s:5:\"label\";s:14:\"EPT Micromodal\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:38:\"Extra Paragraph Type (EPT): Micromodal\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_quote',_binary 'a:11:{s:4:\"uuid\";s:36:\"e7cc4707-218e-4bb9-bcbe-65d47620375d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zd4SMxSGtEMXFqSse2TdY999VhcjYnraQj7qnFhHo6Q\";}s:2:\"id\";s:9:\"ept_quote\";s:5:\"label\";s:9:\"EPT Quote\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Quote\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slick_slider',_binary 'a:11:{s:4:\"uuid\";s:36:\"d1c90790-b1df-488f-a53e-bc8c9bbe2e9c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kF1ktW9usSGMpm4KK6xObCSXk1ZU-mWLNc7N1B5IN3A\";}s:2:\"id\";s:16:\"ept_slick_slider\";s:5:\"label\";s:16:\"EPT Slick Slider\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:40:\"Extra Paragraph Type (EPT): Slick Slider\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slick_slider_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"41cd1373-cca3-46dc-87a0-714c7a1489bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JzEHRSTeS_5k9aQaMIQiZssckNv0akkT0UHkl8qu8TE\";}s:2:\"id\";s:21:\"ept_slick_slider_item\";s:5:\"label\";s:21:\"EPT Slick Slider Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:0:\"\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slideshow',_binary 'a:11:{s:4:\"uuid\";s:36:\"b702ec4e-c33c-4331-beff-6b5b7107cc9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KeaY7LvgW90UqWSbJG60DfX1q0Up4566bgG8p85U12U\";}s:2:\"id\";s:13:\"ept_slideshow\";s:5:\"label\";s:13:\"EPT Slideshow\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:37:\"Extra Paragraph Type (EPT): Slideshow\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_slideshow_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"9953b7d8-252b-4d78-9b63-08418e206990\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yz4xVMckzLbuIuqcq5CLDr2LZyc6GPHhiCkw_ygR1cM\";}s:2:\"id\";s:18:\"ept_slideshow_item\";s:5:\"label\";s:18:\"EPT Slideshow Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:35:\"Slideshow section for EPT Slideshow\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_stats',_binary 'a:11:{s:4:\"uuid\";s:36:\"6838ec7f-c8a4-4325-97a7-1021f1dfe5d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KAQ05Ri6j17FmntgY7SCHOgGFRtUqdJWrNKlBxVsBsI\";}s:2:\"id\";s:9:\"ept_stats\";s:5:\"label\";s:9:\"EPT Stats\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Stats\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_stats_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"1f202608-b028-44b4-99c0-312ebcadcb47\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Be2-EmGyo2-KDBpxotaDl8GmJCgv5EKdsZNMXdWrM10\";}s:2:\"id\";s:14:\"ept_stats_item\";s:5:\"label\";s:14:\"EPT Stats Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:34:\"Stats Item for EPT Stats paragraph\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tabs',_binary 'a:11:{s:4:\"uuid\";s:36:\"d64be736-43ad-47c5-a174-0a5e19f4b24a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zt6Y01DpCpOfI3LIolOc9xk6SptdAkHJlZkEp2KhkRQ\";}s:2:\"id\";s:8:\"ept_tabs\";s:5:\"label\";s:8:\"EPT Tabs\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:32:\"Extra Paragraph Type (EPT): Tabs\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tabs_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"9e15e91a-5c5e-4c79-9e75-1386629a7208\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VixuGFI2mBIwt085I9X7vz9dq9H8dh0Bb20u-pT90X8\";}s:2:\"id\";s:13:\"ept_tabs_item\";s:5:\"label\";s:13:\"EPT Tabs Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:31:\"Tab item for EPT Tabs paragraph\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_text',_binary 'a:11:{s:4:\"uuid\";s:36:\"c76a9833-ec98-4fe9-9268-c55ecc6606f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fSKAEY0p1DQvC6AE_TEi0RWHmjahL13tHQTb3WVaVik\";}s:2:\"id\";s:8:\"ept_text\";s:5:\"label\";s:8:\"EPT Text\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:31:\"Extra Paragraph Type (EPT) Text\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tiles',_binary 'a:11:{s:4:\"uuid\";s:36:\"e1accd8b-a614-4659-8cf0-f0563effdfeb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AHyDurvHt3xm3keCp8kZSod4iM7Y1JlF1O0xivGQ7As\";}s:2:\"id\";s:9:\"ept_tiles\";s:5:\"label\";s:9:\"EPT Tiles\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Tiles\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_tiles_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"ae747fa8-05f4-441a-92bd-76441012dd9b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q4wQLWgQpxsrvWKawlFVZnqSn8qCCPj4IOKPpn7O8Po\";}s:2:\"id\";s:14:\"ept_tiles_item\";s:5:\"label\";s:14:\"EPT Tiles Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:21:\"Section for EPT Tiles\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_video',_binary 'a:11:{s:4:\"uuid\";s:36:\"e50ad18b-eff8-48a4-9102-1709c8e0bb40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FU0WTLBDpLuC53lMEuAJGnwlX6sqt0SutW7q0c-btWQ\";}s:2:\"id\";s:9:\"ept_video\";s:5:\"label\";s:9:\"EPT Video\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Video\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_video_and_image_gallery',_binary 'a:11:{s:4:\"uuid\";s:36:\"dee3b2de-c5f8-4d3f-8564-0f6f24943f59\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z1YuWpAuPdJe7k9v-67rALbAapgyfzwTi2cQLvreLbo\";}s:2:\"id\";s:27:\"ept_video_and_image_gallery\";s:5:\"label\";s:27:\"EPT Video and Image Gallery\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:51:\"Extra Paragraph Type (EPT): Video and Image Gallery\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_video_and_image_gallery_item',_binary 'a:11:{s:4:\"uuid\";s:36:\"1a4319ac-f841-4112-85c5-2a1ab06cb4d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OrMDgoP5KHK7xLNhKOohBVVuqmo2J4D3YWH3a3Od1Dw\";}s:2:\"id\";s:32:\"ept_video_and_image_gallery_item\";s:5:\"label\";s:32:\"EPT Video and Image gallery item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:62:\"Video and Image item for EPT Video and Image Gallery paragraph\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.paragraphs_type.ept_views',_binary 'a:11:{s:4:\"uuid\";s:36:\"7ac88ec9-7da9-488c-ac70-492b5bcfde08\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JfY6zZuA9cpemb4U-YVMX2rzmT1pm_Pr1YpT7xaSxeA\";}s:2:\"id\";s:9:\"ept_views\";s:5:\"label\";s:9:\"EPT Views\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Views\";s:16:\"behavior_plugins\";a:0:{}}'),('','paragraphs.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7eR0sk71Eol86r_A7BMqn5_46wzenh5J1O5vZRCGKv8\";}s:16:\"show_unpublished\";b:1;}'),('','search.page.help_search',_binary 'a:11:{s:4:\"uuid\";s:36:\"98a9a1a8-dfbe-4b36-a295-131fa324015e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RZ-bcSekNSsAbIPLW7Gmyd3uUjIOSrPvnb8RCCZYJm8\";}s:2:\"id\";s:11:\"help_search\";s:5:\"label\";s:4:\"Help\";s:4:\"path\";s:4:\"help\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"help_search\";s:13:\"configuration\";a:0:{}}'),('','search.page.node_search',_binary 'a:11:{s:4:\"uuid\";s:36:\"be4dce05-236d-43ce-aa4d-b829b5c9d8a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"97tvtzGOa8_flb22CzSjgtm_YkiGMHvEBO-6q2K9V_U\";}s:2:\"id\";s:11:\"node_search\";s:5:\"label\";s:7:\"Content\";s:4:\"path\";s:4:\"node\";s:6:\"weight\";i:-10;s:6:\"plugin\";s:11:\"node_search\";s:13:\"configuration\";a:1:{s:8:\"rankings\";a:0:{}}}'),('','search.page.user_search',_binary 'a:11:{s:4:\"uuid\";s:36:\"02f73622-4ae8-479b-bddb-6b507d943c7b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k3aUaZXGDuhkek2TZIee0PApOPTvYZLadziekdyHA5A\";}s:2:\"id\";s:11:\"user_search\";s:5:\"label\";s:5:\"Users\";s:4:\"path\";s:4:\"user\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"user_search\";s:13:\"configuration\";a:0:{}}'),('','search.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hvVxL1G-ZCxaq32IZws0YsfuhvaDiQE_np-0g35KjUk\";}s:12:\"and_or_limit\";i:7;s:12:\"default_page\";s:11:\"node_search\";s:5:\"index\";a:4:{s:10:\"cron_limit\";i:100;s:11:\"overlap_cjk\";b:1;s:17:\"minimum_word_size\";i:3;s:11:\"tag_weights\";a:12:{s:2:\"h1\";i:25;s:2:\"h2\";i:18;s:2:\"h3\";i:15;s:2:\"h4\";i:14;s:2:\"h5\";i:9;s:2:\"h6\";i:6;s:1:\"u\";i:3;s:1:\"b\";i:3;s:1:\"i\";i:3;s:6:\"strong\";i:3;s:2:\"em\";i:3;s:1:\"a\";i:10;}}s:7:\"logging\";b:0;}'),('','shortcut.set.default',_binary 'a:7:{s:4:\"uuid\";s:36:\"2b149d5c-a926-4de8-aae7-b7f45081ccab\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U5VlGjd_SfV0Qm_EfnaynOfc549cNscFAx48JfYoMRI\";}s:2:\"id\";s:7:\"default\";s:5:\"label\";s:7:\"Default\";}'),('','system.action.comment_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"6f753574-2b6f-4e3a-87fd-04f281182309\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpBH8OmL4sdesCdeZLsW8KOutB5gkbreWJbfjhfFKaQ\";}s:2:\"id\";s:21:\"comment_delete_action\";s:5:\"label\";s:14:\"Delete comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:28:\"entity:delete_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"c8e0fba3-a9ea-40bc-9886-42d52bf69615\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C00dyL_W_5M0nFlgUB3lWUTUs96jn51Jw1MLHVEHZD0\";}s:2:\"id\";s:22:\"comment_publish_action\";s:5:\"label\";s:15:\"Publish comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:29:\"entity:publish_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f2a7400a-fd44-4225-906e-c04f6f5f8944\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lfyE_snmvfg_EQ3VDyhUtGAXgmqtEiqa46I3bTMg8DU\";}s:2:\"id\";s:19:\"comment_save_action\";s:5:\"label\";s:12:\"Save comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:26:\"entity:save_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.comment_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"a09349ec-38d9-4ee0-b772-074a9b406491\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"comment\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tWOIjSMobEWOFZddMkNqb9JySbOVwE1diC6NRqcfLTk\";}s:2:\"id\";s:24:\"comment_unpublish_action\";s:5:\"label\";s:17:\"Unpublish comment\";s:4:\"type\";s:7:\"comment\";s:6:\"plugin\";s:31:\"entity:unpublish_action:comment\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"f8932ff6-cc40-43b7-9cd8-7fefb06c44cf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FrZy1tmuXJcOxhXlBoI1Hsnen5TT-9OCC1iolWH84go\";}s:2:\"id\";s:19:\"media_delete_action\";s:5:\"label\";s:12:\"Delete media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:26:\"entity:delete_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"5ee77a15-afb1-4e0c-bd3b-3e462abe568d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nh83qNNrmWE-CDdHz2MdFOAk60T9mzv3R-MaKfZR2jw\";}s:2:\"id\";s:20:\"media_publish_action\";s:5:\"label\";s:13:\"Publish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:27:\"entity:publish_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"9b97ffc0-0ba9-48fc-9e78-a23777ef7ff4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VVyUA6PIaVeGtcIbgEWqJ6SYDiJdReBeojFswURFpKs\";}s:2:\"id\";s:17:\"media_save_action\";s:5:\"label\";s:10:\"Save media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:24:\"entity:save_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.media_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"59cad6a4-a038-45d4-98e9-6ace07f80050\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CsK6TseQ2DatEbZgbd30swOlZ28_HHwAESU2LvEnWq0\";}s:2:\"id\";s:22:\"media_unpublish_action\";s:5:\"label\";s:15:\"Unpublish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:29:\"entity:unpublish_action:media\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_delete_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"455e72bb-d5c2-4233-8fae-fe874a5aecde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t43OqwzP3CTbcAagSsWKNy6KwMm_zShXo3c4-So6rQg\";}s:2:\"id\";s:18:\"node_delete_action\";s:5:\"label\";s:14:\"Delete content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"entity:delete_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_make_sticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"2003aeb9-8fd3-4006-8c7f-9129bef1a808\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sOb26JSy3fGpWkvR0WYN6_hMqj_6d1rvbvrkzp1yya0\";}s:2:\"id\";s:23:\"node_make_sticky_action\";s:5:\"label\";s:19:\"Make content sticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"node_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_make_unsticky_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"0640984c-3787-4c25-8abe-073f6ff633cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lDM9mvIGAu8Sw8rt-uCO4Sr7yX5VPrDPxYcawkbKd6k\";}s:2:\"id\";s:25:\"node_make_unsticky_action\";s:5:\"label\";s:21:\"Make content unsticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"node_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_promote_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"93459360-b66a-4249-92eb-59a0d4b9e585\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N0RDBTqiK4dKoN4p4oW2j0SGWycdHyALUe9M-Ofp89U\";}s:2:\"id\";s:19:\"node_promote_action\";s:5:\"label\";s:29:\"Promote content to front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:19:\"node_promote_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"6e3d2ae5-f68b-4adb-8345-78fe6e53c835\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2B9uF8NL5gutNKSdPRAhhAsDWFZZG1PJOBmx0aBGd_0\";}s:2:\"id\";s:19:\"node_publish_action\";s:5:\"label\";s:15:\"Publish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:26:\"entity:publish_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_save_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"7ff39d45-7ef9-4e69-a87b-aa71ae0d4343\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LhdsoZPL_pFas2fjaAWue4zvrQ_tEVofLYtcNec-JGM\";}s:2:\"id\";s:16:\"node_save_action\";s:5:\"label\";s:12:\"Save content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"entity:save_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_unpromote_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"29499598-fb70-43f6-a160-d2522304d4e7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JBptjnfuOMtsdKygklXxoOgeOCTMtQxlkymjnnj-cC0\";}s:2:\"id\";s:21:\"node_unpromote_action\";s:5:\"label\";s:30:\"Remove content from front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"node_unpromote_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.node_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"34872d09-0b48-4090-a401-75dc2bd3358d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C7X8h9FWlwkQ9y5mnU2JzgaZICAdc6HFbPVbhvjlAYE\";}s:2:\"id\";s:21:\"node_unpublish_action\";s:5:\"label\";s:17:\"Unpublish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:28:\"entity:unpublish_action:node\";s:13:\"configuration\";a:0:{}}'),('','system.action.taxonomy_term_publish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"8509e01a-1fe0-4d2b-80fe-6292c7281beb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DoVt_VGgVLcDD4XmVbSFzr0K17SJy9imFiYusKkJBgY\";}s:2:\"id\";s:28:\"taxonomy_term_publish_action\";s:5:\"label\";s:21:\"Publish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:35:\"entity:publish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),('','system.action.taxonomy_term_unpublish_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"07d84567-f6ce-480c-94fe-71f48ce157b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z2sNRM3ECa7FPCGnSNje_9SmZJQgwhD_6fG_L4Mr8zI\";}s:2:\"id\";s:30:\"taxonomy_term_unpublish_action\";s:5:\"label\";s:23:\"Unpublish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:37:\"entity:unpublish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_add_role_action.administrator',_binary 'a:9:{s:4:\"uuid\";s:36:\"080a7d5c-2fda-47ed-b9aa-be9cb07b6d2e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:34:\"user_add_role_action.administrator\";s:5:\"label\";s:50:\"Add the Administrator role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),('','system.action.user_add_role_action.content_editor',_binary 'a:9:{s:4:\"uuid\";s:36:\"e33f0ef8-e9df-400f-b24b-60c0f3497768\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"user.role.content_editor\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:35:\"user_add_role_action.content_editor\";s:5:\"label\";s:51:\"Add the Content editor role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:14:\"content_editor\";}}'),('','system.action.user_block_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"ec45edef-e3ef-44f8-87d8-428346ac0579\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DyypzTfThX10FFQw-399qPfEbLLyrhXgQrKPVsmAoJ4\";}s:2:\"id\";s:22:\"user_block_user_action\";s:5:\"label\";s:26:\"Block the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:22:\"user_block_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_cancel_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"7317c388-dffd-422a-b041-7ef8597810b4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nvrL9bFilzBvm2bjO9rQnFDpBA7dBBUjShSSt6NS-DU\";}s:2:\"id\";s:23:\"user_cancel_user_action\";s:5:\"label\";s:35:\"Cancel the selected user account(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_cancel_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.action.user_remove_role_action.administrator',_binary 'a:9:{s:4:\"uuid\";s:36:\"a3ac7eaa-5ae2-4c20-abbb-79b198424e39\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:37:\"user_remove_role_action.administrator\";s:5:\"label\";s:55:\"Remove the Administrator role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),('','system.action.user_remove_role_action.content_editor',_binary 'a:9:{s:4:\"uuid\";s:36:\"daca732c-22a4-42c1-a3c8-d54dae2a458c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"user.role.content_editor\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:38:\"user_remove_role_action.content_editor\";s:5:\"label\";s:56:\"Remove the Content editor role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:14:\"content_editor\";}}'),('','system.action.user_unblock_user_action',_binary 'a:10:{s:4:\"uuid\";s:36:\"879c5dbe-c854-4240-b44b-cc9946b7e95b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SPsUXsR3Rc8d1y3gewzaAKWa1ncea_ywXX3f7LTn7k0\";}s:2:\"id\";s:24:\"user_unblock_user_action\";s:5:\"label\";s:28:\"Unblock the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:24:\"user_unblock_user_action\";s:13:\"configuration\";a:0:{}}'),('','system.advisories',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"x0FuQ_7Cg81mSDQwG028_Z0CjH3R9ib5IDlHeV2BbAo\";}s:7:\"enabled\";b:1;s:14:\"interval_hours\";i:6;}'),('','system.cron',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"f3yToH8v8EaBZU0NFFw2qR8ogSCuWVmQaN0hpYR1BD8\";}s:9:\"threshold\";a:2:{s:20:\"requirements_warning\";i:172800;s:18:\"requirements_error\";i:1209600;}s:7:\"logging\";b:1;}'),('','system.date',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IVsFTD1mvR2NGBP_1myt9kFIFmGepH4PyaN5aQBYpno\";}s:9:\"first_day\";i:0;s:7:\"country\";a:1:{s:7:\"default\";N;}s:8:\"timezone\";a:2:{s:7:\"default\";s:15:\"Europe/Belgrade\";s:4:\"user\";a:3:{s:12:\"configurable\";b:1;s:7:\"default\";i:0;s:4:\"warn\";b:0;}}}'),('','system.diff',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1WanmaEhxW_vM8_5Ktsdntj8MaO9UBHXg0lN603PsWM\";}s:7:\"context\";a:2:{s:13:\"lines_leading\";i:2;s:14:\"lines_trailing\";i:2;}}'),('','system.feature_flags',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYyVj1FtPGV40Cf65YDVTUIc7YgLH6trXlotuevfs2I\";}s:16:\"linkset_endpoint\";b:0;}'),('','system.file',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mguGHCYb9Dw5EcpfjwoShGV1Vjkbz3QuPRCLfxiye-g\";}s:22:\"allow_insecure_uploads\";b:0;s:14:\"default_scheme\";s:6:\"public\";s:21:\"temporary_maximum_age\";i:21600;}'),('','system.image',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"durWHaKeBaq4d9Wpi4RqwADj1OufDepcnJuhVLmKN24\";}s:7:\"toolkit\";s:2:\"gd\";}'),('','system.image.gd',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eNXaHfkJJUThHeF0nvkoXyPLRrKYGxgHRjORvT4F5rQ\";}s:12:\"jpeg_quality\";i:75;}'),('','system.logging',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u3-njszl92FaxjrCMiq0yDcjAfcdx72w1zT1O9dx6aA\";}s:11:\"error_level\";s:4:\"hide\";}'),('','system.mail',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5PvD9swkqWUeHkabdvbJ2SQqdhrzjkCT21wtD4BLfk4\";}s:9:\"interface\";a:1:{s:7:\"default\";s:8:\"php_mail\";}s:10:\"mailer_dsn\";a:6:{s:6:\"scheme\";s:8:\"sendmail\";s:4:\"host\";s:7:\"default\";s:4:\"user\";N;s:8:\"password\";N;s:4:\"port\";N;s:7:\"options\";a:0:{}}}'),('','system.maintenance',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1SNdA25INsV5YjlgAJtfC-6AM8VcWe_00xneMLb2yFg\";}s:8:\"langcode\";s:2:\"en\";s:7:\"message\";s:93:\"@site is currently under maintenance. We should be back shortly. Thank you for your patience.\";}'),('','system.menu.account',_binary 'a:9:{s:4:\"uuid\";s:36:\"37d50e8a-b786-4ff3-a41f-5e41d67f88b1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Bh81osDyUQ4wV0GgU_NdBNqkzM87sLxjaCdFj9mnw\";}s:2:\"id\";s:7:\"account\";s:5:\"label\";s:17:\"User account menu\";s:11:\"description\";s:40:\"Links related to the active user account\";s:6:\"locked\";b:1;}'),('','system.menu.admin',_binary 'a:9:{s:4:\"uuid\";s:36:\"cf474897-e948-4315-a183-5878deecdaf0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sapEi2YDGoI9yQIT_WgIV2vUdQ6DScH0V3fAyTadAL0\";}s:2:\"id\";s:5:\"admin\";s:5:\"label\";s:14:\"Administration\";s:11:\"description\";s:25:\"Administrative task links\";s:6:\"locked\";b:1;}'),('','system.menu.footer',_binary 'a:9:{s:4:\"uuid\";s:36:\"d761cbba-9ebe-4d52-96fc-79063bff0783\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7yrlW5z9zdg2eBucB2GPqXKSMQfH9lSRSO4DbWF7AFc\";}s:2:\"id\";s:6:\"footer\";s:5:\"label\";s:6:\"Footer\";s:11:\"description\";s:22:\"Site information links\";s:6:\"locked\";b:1;}'),('','system.menu.main',_binary 'a:9:{s:4:\"uuid\";s:36:\"4108c568-d39d-4283-8af4-4ce0601c49ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q2Ra3jfoIVk0f3SjxJX61byRQFVBAbpzYDQOiY-kno8\";}s:2:\"id\";s:4:\"main\";s:5:\"label\";s:15:\"Main navigation\";s:11:\"description\";s:18:\"Site section links\";s:6:\"locked\";b:1;}'),('','system.menu.tools',_binary 'a:9:{s:4:\"uuid\";s:36:\"6e91308b-4a52-440d-824d-e3b9fb3941e2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCM-vV1zzRaLHN18dqAR_CuGOj8AFJvTx7BKl_8Gcxc\";}s:2:\"id\";s:5:\"tools\";s:5:\"label\";s:5:\"Tools\";s:11:\"description\";s:39:\"User tool links, often added by modules\";s:6:\"locked\";b:1;}'),('','system.performance',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jtno5biznHZbrIgKwzq-ze-7XaQxLCGe6PeUOR7bRiQ\";}s:5:\"cache\";a:1:{s:4:\"page\";a:1:{s:7:\"max_age\";i:0;}}s:3:\"css\";a:2:{s:10:\"preprocess\";b:0;s:4:\"gzip\";b:1;}s:8:\"fast_404\";a:4:{s:7:\"enabled\";b:1;s:5:\"paths\";s:69:\"/\\.(?:txt|png|gif|jpe?g|css|js|ico|swf|flv|cgi|bat|pl|dll|exe|asp)$/i\";s:13:\"exclude_paths\";s:27:\"/\\/(?:styles|imagecache)\\//\";s:4:\"html\";s:162:\"<!DOCTYPE html><html><head><title>404 Not Found</title></head><body><h1>Not Found</h1><p>The requested URL \"@path\" was not found on this server.</p></body></html>\";}s:2:\"js\";a:2:{s:10:\"preprocess\";b:0;s:4:\"gzip\";b:1;}}'),('','system.rss',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MIpNzlG4gPunfS7vTCwUPum6QH3GUsEBMj-qS631Jw0\";}s:5:\"items\";a:1:{s:9:\"view_mode\";s:3:\"rss\";}}'),('','system.site',_binary 'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ijfbzDTN4CbE7Sr-6ubWzy_t1vH4OtU1doNCLssVz-4\";}s:8:\"langcode\";s:2:\"en\";s:4:\"uuid\";s:36:\"78d4512f-043a-4ffe-b38d-c79b75c64b27\";s:4:\"name\";s:23:\"EPT Page Builder - Demo\";s:4:\"mail\";s:17:\"admin@example.com\";s:6:\"slogan\";s:0:\"\";s:4:\"page\";a:3:{i:403;s:0:\"\";i:404;s:0:\"\";s:5:\"front\";s:7:\"/node/1\";}s:18:\"admin_compact_mode\";b:0;s:17:\"weight_select_max\";i:100;s:16:\"default_langcode\";s:2:\"en\";s:17:\"mail_notification\";N;}'),('','system.theme',_binary 'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJ529VM1gSIA_vgTy2PdiDvJuG0xhSxfQjCyl5WKlv4\";}s:5:\"admin\";s:3:\"gin\";s:7:\"default\";s:9:\"ept_light\";}'),('','system.theme.global',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KZiV2LB312xgJBphfq5BTjmp16xiR5KM8InBJ-pff7Y\";}s:7:\"favicon\";a:4:{s:8:\"mimetype\";s:24:\"image/vnd.microsoft.icon\";s:4:\"path\";s:0:\"\";s:3:\"url\";s:0:\"\";s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:1;}s:4:\"logo\";a:3:{s:4:\"path\";s:0:\"\";s:3:\"url\";N;s:11:\"use_default\";b:1;}}'),('','taxonomy.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zKpaWT6cJc1tVQQaTqatGELaCqU_oyRym6zTl27Yias\";}s:20:\"maintain_index_table\";b:1;s:17:\"override_selector\";b:0;s:20:\"terms_per_page_admin\";i:100;}'),('','taxonomy.vocabulary.tags',_binary 'a:10:{s:4:\"uuid\";s:36:\"368fd9b7-ee40-4b51-8ac1-60f818b9f9f6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iTEzwrEQ_4JIb-OYGiqzyF2TmMgWyWayresXcWgwGWM\";}s:4:\"name\";s:4:\"Tags\";s:3:\"vid\";s:4:\"tags\";s:11:\"description\";s:61:\"Use tags to group articles on similar topics into categories.\";s:6:\"weight\";i:0;s:12:\"new_revision\";b:0;}'),('','tb_megamenu.menu_config.main__ept_light',_binary 'a:9:{s:4:\"uuid\";s:36:\"9a71f48f-4fa9-44ad-996b-21fe7ea77565\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:5:\"theme\";a:1:{i:0;s:9:\"ept_light\";}s:4:\"menu\";a:1:{i:0;s:4:\"main\";}}s:2:\"id\";s:15:\"main__ept_light\";s:4:\"menu\";s:4:\"main\";s:5:\"theme\";s:9:\"ept_light\";s:12:\"block_config\";s:120:\"{\"animation\":\"none\",\"duration\":400,\"delay\":200,\"style\":\"\",\"auto-arrow\":\"1\",\"always-show-submenu\":\"0\",\"number-columns\":1}\";s:11:\"menu_config\";s:707:\"{\"standard.front_page\":{\"rows_content\":[],\"submenu_config\":{\"width\":\"\",\"class\":\"\",\"group\":\"0\"},\"item_config\":{\"class\":\"\",\"xicon\":\"\",\"caption\":\"\",\"alignsub\":\"\",\"group\":\"0\",\"hidewcol\":\"0\",\"hidesub\":\"0\",\"label\":\"\"}},\"menu_link_content:d5043c53-9961-4a60-bb2a-a37bbaaa3961\":{\"rows_content\":[],\"submenu_config\":{\"width\":\"\",\"class\":\"\",\"group\":\"0\"},\"item_config\":{\"class\":\"\",\"xicon\":\"\",\"caption\":\"\",\"alignsub\":\"\",\"group\":\"0\",\"hidewcol\":\"0\",\"hidesub\":\"0\",\"label\":\"\"}},\"menu_link_content:addff990-0222-4099-9e61-5f98566f7f94\":{\"rows_content\":[],\"submenu_config\":{\"width\":\"\",\"class\":\"\",\"group\":\"0\"},\"item_config\":{\"class\":\"\",\"xicon\":\"\",\"caption\":\"\",\"alignsub\":\"\",\"group\":\"0\",\"hidewcol\":\"0\",\"hidesub\":\"0\",\"label\":\"\"}}}\";}'),('','text.settings',_binary 'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Bkewb77RBOK3_aXMPsp8p87gbc03NvmC5gBLzPl7hVA\";}s:22:\"default_summary_length\";i:600;}'),('','update.settings',_binary 'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xbYr66-g0FjNgVBkGypCuN46vBI2XHntXN1URawq1s4\";}s:5:\"check\";a:2:{s:19:\"disabled_extensions\";b:0;s:13:\"interval_days\";i:1;}s:5:\"fetch\";a:3:{s:3:\"url\";N;s:12:\"max_attempts\";i:2;s:7:\"timeout\";i:30;}s:12:\"notification\";a:2:{s:6:\"emails\";a:1:{i:0;s:17:\"admin@example.com\";}s:9:\"threshold\";s:3:\"all\";}}'),('','user.flood',_binary 'a:6:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UYfMzeP1S8jKm9PSvxf7nQNe8DsNS-3bc2WSNNXBQWs\";}s:8:\"uid_only\";b:0;s:8:\"ip_limit\";i:50;s:9:\"ip_window\";i:3600;s:10:\"user_limit\";i:5;s:11:\"user_window\";i:21600;}'),('','user.mail',_binary 'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6CZIzFifRq3qbdq3n3nDpEOO4hWIQtKOAQNPvGNGKeM\";}s:8:\"langcode\";s:2:\"en\";s:14:\"cancel_confirm\";a:2:{s:7:\"subject\";s:67:\"Account cancellation request for [user:display-name] at [site:name]\";s:4:\"body\";s:376:\"[user:display-name]\n\nA request to cancel your account has been made at [site:name].\n\nYou may now cancel your account on [site:url-brief] by clicking this link or copying and pasting it into your browser:\n\n[user:cancel-url]\n\nNOTE: The cancellation of your account is not reversible.\n\nThis link expires in one day and nothing will happen if it is not used.\n\n--  [site:name] team\";}s:14:\"password_reset\";a:2:{s:7:\"subject\";s:68:\"Replacement login information for [user:display-name] at [site:name]\";s:4:\"body\";s:407:\"[user:display-name],\n\nA request to reset the password for your account has been made at [site:name].\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password. It expires after one day and nothing will happen if it\'s not used.\n\n--  [site:name] team\";}s:22:\"register_admin_created\";a:2:{s:7:\"subject\";s:58:\"An administrator created an account for you at [site:name]\";s:4:\"body\";s:473:\"[user:display-name],\n\nA site administrator at [site:name] has created an account for you. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:29:\"register_no_approval_required\";a:2:{s:7:\"subject\";s:54:\"Account details for [user:display-name] at [site:name]\";s:4:\"body\";s:447:\"[user:display-name],\n\nThank you for registering at [site:name]. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:25:\"register_pending_approval\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:288:\"[user:display-name],\n\nThank you for registering at [site:name]. Your application for an account is currently pending approval. Once it has been approved, you will receive another email containing information about how to log in, set your password, and other details.\n\n--  [site:name] team\";}s:31:\"register_pending_approval_admin\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:64:\"[user:display-name] has applied for an account.\n\n[user:edit-url]\";}s:16:\"status_activated\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (approved)\";s:4:\"body\";s:462:\"[user:display-name],\n\nYour account at [site:name] has been activated.\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:account-name]\npassword: Your password\n\n--  [site:name] team\";}s:14:\"status_blocked\";a:2:{s:7:\"subject\";s:64:\"Account details for [user:display-name] at [site:name] (blocked)\";s:4:\"body\";s:89:\"[user:display-name],\n\nYour account on [site:name] has been blocked.\n\n--  [site:name] team\";}s:15:\"status_canceled\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (canceled)\";s:4:\"body\";s:90:\"[user:display-name],\n\nYour account on [site:name] has been canceled.\n\n--  [site:name] team\";}}'),('','user.role.administrator',_binary 'a:10:{s:4:\"uuid\";s:36:\"5f4748db-4b8a-4105-a888-23753782d022\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OeKGIkmZA_c-t6QLH81WNQx8gDCc1MRmxaTuQgxBByU\";}s:2:\"id\";s:13:\"administrator\";s:5:\"label\";s:13:\"Administrator\";s:6:\"weight\";i:3;s:8:\"is_admin\";b:1;s:11:\"permissions\";a:0:{}}'),('','user.role.anonymous',_binary 'a:10:{s:4:\"uuid\";s:36:\"eda565bf-dc62-4fa8-b48c-329d2d6fc492\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.restricted_html\";}s:6:\"module\";a:6:{i:0;s:7:\"comment\";i:1;s:7:\"contact\";i:2;s:6:\"filter\";i:3;s:5:\"media\";i:4;s:6:\"search\";i:5;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6WavjUYXIegP9AAg2zXGx54MWIVoomC3SZhNiqe-Dyk\";}s:2:\"id\";s:9:\"anonymous\";s:5:\"label\";s:14:\"Anonymous user\";s:6:\"weight\";i:0;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:6:{i:0;s:15:\"access comments\";i:1;s:14:\"access content\";i:2;s:29:\"access site-wide contact form\";i:3;s:14:\"search content\";i:4;s:31:\"use text format restricted_html\";i:5;s:10:\"view media\";}}'),('','user.role.authenticated',_binary 'a:10:{s:4:\"uuid\";s:36:\"369ad726-b0da-4331-8cb0-56ab9af109d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"filter.format.basic_html\";}s:6:\"module\";a:8:{i:0;s:7:\"comment\";i:1;s:7:\"contact\";i:2;s:4:\"file\";i:3;s:6:\"filter\";i:4;s:5:\"media\";i:5;s:6:\"search\";i:6;s:8:\"shortcut\";i:7;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFrlqjtkTfvY3RGccjJkPf1SGIfJ942IrxTLWAO4mgA\";}s:2:\"id\";s:13:\"authenticated\";s:5:\"label\";s:18:\"Authenticated user\";s:6:\"weight\";i:1;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:10:{i:0;s:15:\"access comments\";i:1;s:14:\"access content\";i:2;s:16:\"access shortcuts\";i:3;s:29:\"access site-wide contact form\";i:4;s:16:\"delete own files\";i:5;s:13:\"post comments\";i:6;s:14:\"search content\";i:7;s:21:\"skip comment approval\";i:8;s:26:\"use text format basic_html\";i:9;s:10:\"view media\";}}'),('','user.role.content_editor',_binary 'a:10:{s:4:\"uuid\";s:36:\"e916801a-5024-47c1-b402-bb0bb1592d19\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:17:\"node.type.article\";i:1;s:14:\"node.type.page\";i:2;s:24:\"taxonomy.vocabulary.tags\";}s:6:\"module\";a:9:{i:0;s:7:\"comment\";i:1;s:10:\"contextual\";i:2;s:4:\"file\";i:3;s:4:\"node\";i:4;s:4:\"path\";i:5;s:6:\"system\";i:6;s:8:\"taxonomy\";i:7;s:11:\"tb_megamenu\";i:8;s:7:\"toolbar\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e_wG1u7SrGaJbY2-Szgbgl-c8T3kdirU3uTNq2c_QJQ\";}s:2:\"id\";s:14:\"content_editor\";s:5:\"label\";s:14:\"Content editor\";s:6:\"weight\";i:2;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:24:{i:0;s:27:\"access administration pages\";i:1;s:23:\"access content overview\";i:2;s:23:\"access contextual links\";i:3;s:21:\"access files overview\";i:4;s:14:\"access toolbar\";i:5;s:22:\"administer tb_megamenu\";i:6;s:22:\"administer url aliases\";i:7;s:22:\"create article content\";i:8;s:19:\"create page content\";i:9;s:20:\"create terms in tags\";i:10;s:18:\"create url aliases\";i:11;s:24:\"delete article revisions\";i:12;s:26:\"delete own article content\";i:13;s:16:\"delete own files\";i:14;s:23:\"delete own page content\";i:15;s:21:\"delete page revisions\";i:16;s:24:\"edit own article content\";i:17;s:17:\"edit own comments\";i:18;s:21:\"edit own page content\";i:19;s:18:\"edit terms in tags\";i:20;s:20:\"revert all revisions\";i:21;s:18:\"view all revisions\";i:22;s:28:\"view own unpublished content\";i:23;s:29:\"view the administration theme\";}}'),('','user.settings',_binary 'a:9:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-htDFWUv1S4OlJMzta2nhFl4QbhJvu0D9xsJ-clxo-M\";}s:8:\"langcode\";s:2:\"en\";s:9:\"anonymous\";s:9:\"Anonymous\";s:11:\"verify_mail\";b:1;s:6:\"notify\";a:8:{s:14:\"cancel_confirm\";b:1;s:14:\"password_reset\";b:1;s:16:\"status_activated\";b:1;s:14:\"status_blocked\";b:0;s:15:\"status_canceled\";b:0;s:22:\"register_admin_created\";b:1;s:29:\"register_no_approval_required\";b:1;s:25:\"register_pending_approval\";b:1;}s:8:\"register\";s:23:\"visitors_admin_approval\";s:13:\"cancel_method\";s:17:\"user_cancel_block\";s:22:\"password_reset_timeout\";i:86400;s:17:\"password_strength\";b:1;}'),('','views.settings',_binary 'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8oDr9oPVb_ostrNnVV6V7VdphwoH_u-NqTS0u7SE7qc\";}s:17:\"display_extenders\";a:0:{}s:13:\"sql_signature\";b:0;s:2:\"ui\";a:3:{s:4:\"show\";a:7:{s:18:\"additional_queries\";b:0;s:15:\"advanced_column\";b:0;s:15:\"default_display\";b:0;s:22:\"performance_statistics\";b:0;s:19:\"preview_information\";b:1;s:9:\"sql_query\";a:2:{s:7:\"enabled\";b:0;s:5:\"where\";s:5:\"above\";}s:13:\"display_embed\";b:0;}s:19:\"always_live_preview\";b:1;s:24:\"exposed_filter_any_label\";s:7:\"old_any\";}s:22:\"field_rewrite_elements\";a:29:{s:3:\"div\";s:3:\"DIV\";s:4:\"span\";s:4:\"SPAN\";s:2:\"h1\";s:2:\"H1\";s:2:\"h2\";s:2:\"H2\";s:2:\"h3\";s:2:\"H3\";s:2:\"h4\";s:2:\"H4\";s:2:\"h5\";s:2:\"H5\";s:2:\"h6\";s:2:\"H6\";s:1:\"p\";s:1:\"P\";s:6:\"header\";s:6:\"HEADER\";s:6:\"footer\";s:6:\"FOOTER\";s:7:\"article\";s:7:\"ARTICLE\";s:7:\"section\";s:7:\"SECTION\";s:5:\"aside\";s:5:\"ASIDE\";s:7:\"details\";s:7:\"DETAILS\";s:10:\"blockquote\";s:10:\"BLOCKQUOTE\";s:6:\"figure\";s:6:\"FIGURE\";s:7:\"address\";s:7:\"ADDRESS\";s:4:\"code\";s:4:\"CODE\";s:3:\"pre\";s:3:\"PRE\";s:3:\"var\";s:3:\"VAR\";s:4:\"samp\";s:4:\"SAMP\";s:3:\"kbd\";s:3:\"KBD\";s:6:\"strong\";s:6:\"STRONG\";s:2:\"em\";s:2:\"EM\";s:3:\"del\";s:3:\"DEL\";s:3:\"ins\";s:3:\"INS\";s:1:\"q\";s:1:\"Q\";s:1:\"s\";s:1:\"S\";}}'),('','views.view.archive',_binary 'a:13:{s:4:\"uuid\";s:36:\"f33400de-a3e8-4128-b4b9-8f10fc897a3f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"exIF08PTvYSK6tJCsAzBqMEKUBKIptPorMn74SVhevc\";}s:2:\"id\";s:7:\"archive\";s:5:\"label\";s:7:\"Archive\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:22:\"All content, by month.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:15:\"Monthly archive\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:2:{s:8:\"override\";b:1;s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:2:{s:10:\"sort_order\";s:4:\"desc\";s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:0;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:1:{s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"archive\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.block_content',_binary 'a:13:{s:4:\"uuid\";s:36:\"f0a4d615-99cd-438c-a7fe-c2d84a594ee3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HfvTcWhiVuvxchoh4DjIkXhKkj9ow2TGgHkLHSvRLq8\";}s:2:\"id\";s:13:\"block_content\";s:5:\"label\";s:14:\"Content blocks\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:31:\"Find and manage content blocks.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:24:\"block_content_field_data\";s:10:\"base_field\";s:2:\"id\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:14:\"Content blocks\";s:6:\"fields\";a:4:{s:4:\"info\";a:37:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";N;s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:17:\"Block description\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Block type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access block library\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:2:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:38:\"There are no content blocks available.\";s:8:\"tokenize\";b:0;}s:27:\"block_content_listing_empty\";a:10:{s:2:\"id\";s:27:\"block_content_listing_empty\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:27:\"block_content_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:27:\"block_content_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:4:\"info\";a:16:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"info_op\";s:5:\"label\";s:17:\"Block description\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"info_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"info\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:10:\"Block type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"reusable\";a:16:{s:2:\"id\";s:8:\"reusable\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:8:\"reusable\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:8:\"reusable\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:4:\"info\";s:4:\"info\";s:4:\"type\";s:4:\"type\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:4:{s:4:\"info\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/block\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:6:\"Blocks\";s:11:\"description\";s:31:\"Create and edit content blocks.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:20:\"system.admin_content\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.comment',_binary 'a:13:{s:4:\"uuid\";s:36:\"e6cd565b-768b-47a9-b906-fe031ec4047e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"H6JHGXl97yOKmVaV62SoY1ki1tWVdyD44fgOkdmVyRM\";}s:2:\"id\";s:7:\"comment\";s:5:\"label\";s:8:\"Comments\";s:6:\"module\";s:7:\"comment\";s:11:\"description\";s:25:\"Find and manage comments.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:18:\"comment_field_data\";s:10:\"base_field\";s:3:\"cid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:26:{s:5:\"title\";s:8:\"Comments\";s:6:\"fields\";a:8:{s:17:\"comment_bulk_form\";a:26:{s:2:\"id\";s:17:\"comment_bulk_form\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:17:\"comment_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"comment_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:2:{i:0;s:21:\"comment_delete_action\";i:1;s:24:\"comment_unpublish_action\";}}s:7:\"subject\";a:37:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Subject\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:17:\"comment_permalink\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:9:\"{{ uid }}\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:16:\"comment_username\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:9:\"entity_id\";a:37:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:9:\"entity_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:16:\"commented_entity\";s:5:\"label\";s:9:\"Posted in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:6:\"name_1\";a:37:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"next ›\";s:8:\"previous\";s:12:\"‹ previous\";s:5:\"first\";s:8:\"« first\";s:4:\"last\";s:7:\"last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"administer comments\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:22:\"No comments available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:4:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"subject\";a:16:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"subject_op\";s:5:\"label\";s:7:\"Subject\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"subject_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"subject\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:11:\"Author name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:11:\"author_name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:6:\"name_1\";s:6:\"name_1\";}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:6:{s:17:\"comment_bulk_form\";s:17:\"comment_bulk_form\";s:7:\"subject\";s:7:\"subject\";s:3:\"uid\";s:3:\"uid\";s:9:\"entity_id\";s:9:\"entity_id\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:6:{s:17:\"comment_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"subject\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"uid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"entity_id\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:1;s:13:\"use_more_text\";s:4:\"more\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}s:14:\"page_published\";a:6:{s:2:\"id\";s:14:\"page_published\";s:13:\"display_title\";s:18:\"Published comments\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:19:\"display_description\";s:30:\"The approved comments listing.\";s:15:\"display_comment\";s:0:\"\";s:13:\"exposed_block\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:21:\"admin/content/comment\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:8:\"Comments\";s:11:\"description\";s:18:\"Comments published\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}s:15:\"page_unapproved\";a:6:{s:2:\"id\";s:15:\"page_unapproved\";s:13:\"display_title\";s:19:\"Unapproved comments\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:8:{s:6:\"fields\";a:8:{s:17:\"comment_bulk_form\";a:26:{s:2:\"id\";s:17:\"comment_bulk_form\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:17:\"comment_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"comment_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:2:{i:0;s:21:\"comment_delete_action\";i:1;s:22:\"comment_publish_action\";}}s:7:\"subject\";a:37:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Subject\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:17:\"comment_permalink\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:9:\"{{ uid }}\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:16:\"comment_username\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:9:\"entity_id\";a:37:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:9:\"entity_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:16:\"commented_entity\";s:5:\"label\";s:9:\"Posted in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:7:\"comment\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:6:\"name_1\";a:37:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:7:\"filters\";a:4:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"subject\";a:16:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"subject_op\";s:5:\"label\";s:7:\"Subject\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"subject_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"subject\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:11:\"Author Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:11:\"author_name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:6:\"name_1\";s:6:\"name_1\";}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:8:\"defaults\";a:3:{s:6:\"fields\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:19:\"display_description\";s:32:\"The unapproved comments listing.\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:30:\"admin/content/comment/approval\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:19:\"Unapproved comments\";s:11:\"description\";s:19:\"Comments unapproved\";s:6:\"weight\";i:1;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:4:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}s:9:\"cacheable\";b:0;}}}}'),('','views.view.comments_recent',_binary 'a:13:{s:4:\"uuid\";s:36:\"b85b83ea-7ca6-4445-91d4-33ba3dff6403\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:7:\"comment\";i:1;s:4:\"node\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFOucxH8PAXDQ2kViCcAHgK-JMCcxVkpIMzD56EfpZo\";}s:2:\"id\";s:15:\"comments_recent\";s:5:\"label\";s:15:\"Recent comments\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:16:\"Recent comments.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:18:\"comment_field_data\";s:10:\"base_field\";s:3:\"cid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:14:{s:5:\"title\";s:15:\"Recent comments\";s:6:\"fields\";a:2:{s:7:\"subject\";a:26:{s:2:\"id\";s:7:\"subject\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"subject\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"subject\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:1:{s:4:\"type\";s:5:\"basic\";}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:15:\"access comments\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:22:\"No comments available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:2:{s:7:\"created\";a:12:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;}s:3:\"cid\";a:12:{s:2:\"id\";s:3:\"cid\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:3:\"cid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:3:\"cid\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"cid\";}s:7:\"exposed\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:7:\"comment\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:11:\"status_node\";a:10:{s:2:\"id\";s:11:\"status_node\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"node\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:2:{s:22:\"default_field_elements\";b:1;s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:4:\"node\";a:5:{s:2:\"id\";s:4:\"node\";s:5:\"table\";s:18:\"comment_field_data\";s:5:\"field\";s:4:\"node\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:15:\"Recent comments\";s:14:\"block_category\";s:13:\"Lists (Views)\";s:5:\"allow\";a:1:{s:14:\"items_per_page\";b:1;}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.content',_binary 'a:13:{s:4:\"uuid\";s:36:\"db9f543b-a00c-4765-a8dd-36dc8ebd091c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d7p-wwJZ_Wmz1gnvla9jDtRsjOaWAhPoIoW9w3vo4R4\";}s:2:\"id\";s:7:\"content\";s:5:\"label\";s:7:\"Content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:24:\"Find and manage content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:7:\"Content\";s:6:\"fields\";a:8:{s:14:\"node_bulk_form\";a:14:{s:2:\"id\";s:14:\"node_bulk_form\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:14:\"node_bulk_form\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:14:\"node_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"title\";a:17:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Content type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:17:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:17:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}}s:7:\"changed\";a:17:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:8:\"langcode\";a:37:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:14:\"field_language\";s:5:\"label\";s:8:\"Language\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:8:\"language\";s:8:\"settings\";a:2:{s:14:\"link_to_entity\";b:0;s:15:\"native_language\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:23:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:3:{s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:23:\"access content overview\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:5:\"title\";a:16:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:8:\"title_op\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:8:\"title_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:5:\"title\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:12:\"Content type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:12:\"status_extra\";a:9:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:6:\"expose\";a:2:{s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:10:{s:14:\"node_bulk_form\";s:14:\"node_bulk_form\";s:5:\"title\";s:5:\"title\";s:4:\"type\";s:4:\"type\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:7:\"changed\";s:7:\"changed\";s:9:\"edit_node\";s:9:\"edit_node\";s:11:\"delete_node\";s:11:\"delete_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";s:9:\"timestamp\";s:5:\"title\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:10:{s:14:\"node_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"title\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"delete_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:18:\"admin/content/node\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:23:\"Find and manage content\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.content_recent',_binary 'a:13:{s:4:\"uuid\";s:36:\"9dd1c55e-db52-4c19-aa0d-4c122baa71f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YqZN5rc7XDQcFcInc8wkzuaHJmC5YvirhTmDcrarT6M\";}s:2:\"id\";s:14:\"content_recent\";s:5:\"label\";s:14:\"Recent content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:15:\"Recent content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:22:{s:5:\"title\";s:14:\"Recent content\";s:6:\"fields\";a:2:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"More\";s:12:\"link_display\";s:1:\"0\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:1:{s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.files',_binary 'a:13:{s:4:\"uuid\";s:36:\"36db1296-d05c-4dd7-bda9-64d0981e2f85\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"blP1XdpU4RqVoA_8po7qnIokIbHB6DJt0lpilgY5ovM\";}s:2:\"id\";s:5:\"files\";s:5:\"label\";s:5:\"Files\";s:6:\"module\";s:4:\"file\";s:11:\"description\";s:22:\"Find and manage files.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:12:\"file_managed\";s:10:\"base_field\";s:3:\"fid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:5:\"Files\";s:6:\"fields\";a:9:{s:3:\"fid\";a:24:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:3:\"Fid\";s:7:\"exclude\";b:1;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"filename\";a:36:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"file_link\";s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:8:\"filemime\";a:25:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"MIME type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"file_filemime\";}s:8:\"filesize\";a:25:{s:2:\"id\";s:8:\"filesize\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filesize\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filesize\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Size\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"file_size\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:9:\"Temporary\";s:18:\"format_custom_true\";s:9:\"Permanent\";}}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Upload date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Changed date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:3:\"fid\";s:10:\"group_type\";s:3:\"sum\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:7:\"Used in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/content/files/usage/{{ fid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:1;s:20:\"format_plural_string\";s:21:\"1 place@count places\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access files overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No files available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:8:\"filename\";a:16:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:8:\"Filename\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filename_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filename\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"filemime\";a:16:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:9:\"MIME type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filemime_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filemime\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:11:\"file_status\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"status_op\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:3:\"fid\";s:3:\"fid\";s:8:\"filename\";s:8:\"filename\";s:8:\"filemime\";s:8:\"filemime\";s:8:\"filesize\";s:8:\"filesize\";s:6:\"status\";s:6:\"status\";s:7:\"created\";s:7:\"created\";s:7:\"changed\";s:7:\"changed\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:8:{s:3:\"fid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filename\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filemime\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:8:\"filesize\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:1;s:16:\"show_admin_links\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:14:\"Files overview\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:2:{s:5:\"pager\";b:1;s:13:\"relationships\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:0;}}s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/files\";s:4:\"menu\";a:6:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Files\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_2\";a:6:{s:2:\"id\";s:6:\"page_2\";s:13:\"display_title\";s:10:\"File usage\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:15:{s:5:\"title\";s:10:\"File usage\";s:6:\"fields\";a:4:{s:12:\"entity_label\";a:23:{s:2:\"id\";s:12:\"entity_label\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:12:\"entity_label\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"entity_label\";s:5:\"label\";s:6:\"Entity\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:14:\"link_to_entity\";b:1;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:11:\"Entity type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:6:\"module\";a:22:{s:2:\"id\";s:6:\"module\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:6:\"module\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:18:\"Registering module\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:9:\"Use count\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:0;s:20:\"format_plural_string\";s:8:\"1@count\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:5:\"empty\";a:0:{}s:9:\"arguments\";a:1:{s:3:\"fid\";a:22:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:8:\"file_fid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:46:\"File usage information for {{ arguments.fid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;}}s:7:\"filters\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:12:\"entity_label\";s:12:\"entity_label\";s:4:\"type\";s:4:\"type\";s:6:\"module\";s:6:\"module\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:12:\"entity_label\";s:4:\"info\";a:4:{s:12:\"entity_label\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:6:\"module\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:11:{s:5:\"empty\";b:0;s:5:\"title\";b:0;s:5:\"pager\";b:0;s:8:\"group_by\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:13:\"relationships\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:0;s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:27:\"admin/content/files/usage/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.frontpage',_binary 'a:13:{s:4:\"uuid\";s:36:\"899f634a-224d-4abf-ae01-81a9b3031896\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OEEnRQIjfIaCFRsz8U3VqDrE82ltQKlo8wNbQJRZXu0\";}s:2:\"id\";s:9:\"frontpage\";s:5:\"label\";s:9:\"Frontpage\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:39:\"All content promoted to the front page.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:0:\"\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:3:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:181:\"No front page content has been created yet.<br/>Follow the <a target=\"_blank\" href=\"https://www.drupal.org/docs/user_guide/en/index.html\">User Guide</a> to start building your site.\";s:8:\"tokenize\";b:0;}s:18:\"node_listing_empty\";a:10:{s:2:\"id\";s:18:\"node_listing_empty\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:18:\"node_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:18:\"node_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}s:5:\"title\";a:10:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"title\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:5:\"title\";s:8:\"Welcome!\";}}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:12:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:7:\"promote\";a:16:{s:2:\"id\";s:7:\"promote\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"promote\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"promote\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:3:\"rss\";}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"rss.xml\";s:14:\"sitename_title\";b:1;s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:28:\"languages:language_interface\";i:1;s:21:\"user.node_grants:view\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:4:\"node\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.glossary',_binary 'a:13:{s:4:\"uuid\";s:36:\"9a843b37-02d2-45c5-84e0-2cd85511ce42\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r-klgGeO4haVHqAwxW1HXZLzdzLSMUVC08OuTBrRh58\";}s:2:\"id\";s:8:\"glossary\";s:5:\"label\";s:8:\"Glossary\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:23:\"All content, by letter.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:6:\"fields\";a:3:{s:5:\"title\";a:24:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:36;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"default\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:0:{}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;s:7:\"columns\";a:3:{s:5:\"title\";s:5:\"title\";s:4:\"name\";s:4:\"name\";s:7:\"changed\";s:7:\"changed\";}s:7:\"default\";s:5:\"title\";s:4:\"info\";a:3:{s:5:\"title\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:4:\"name\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:7:\"changed\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:5:\"order\";s:3:\"asc\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"attachment_1\";a:6:{s:2:\"id\";s:12:\"attachment_1\";s:13:\"display_title\";s:10:\"Attachment\";s:14:\"display_plugin\";s:10:\"attachment\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:0;}}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:3:{s:14:\"items_per_page\";i:25;s:6:\"inline\";b:1;s:9:\"separator\";s:3:\" | \";}s:7:\"summary\";a:1:{s:6:\"format\";s:19:\"unformatted_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}s:8:\"displays\";a:2:{s:7:\"default\";s:7:\"default\";s:6:\"page_1\";s:6:\"page_1\";}s:17:\"inherit_arguments\";b:0;}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:8:\"glossary\";s:4:\"menu\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:8:\"Glossary\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.media',_binary 'a:13:{s:4:\"uuid\";s:36:\"7c06b5e5-ebff-4822-8688-54ce69b5a404\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kOTUk5XWeupgBOJuRRarCiDcFKVZcvaW-FT5MTzrML8\";}s:2:\"id\";s:5:\"media\";s:5:\"label\";s:5:\"Media\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:8:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:20:\"thumbnail__target_id\";a:37:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:9:\"thumbnail\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:12:\"group_column\";s:0:\"\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:5:\"media\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Media name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"bundle\";a:37:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"status\";a:37:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:10:\"Media name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:4:\"True\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:6:{s:4:\"name\";s:4:\"name\";s:6:\"bundle\";s:6:\"bundle\";s:7:\"changed\";s:7:\"changed\";s:3:\"uid\";s:3:\"uid\";s:6:\"status\";s:6:\"status\";s:20:\"thumbnail__target_id\";s:20:\"thumbnail__target_id\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:6:{s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"bundle\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"uid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:15:\"media_page_list\";a:6:{s:2:\"id\";s:15:\"media_page_list\";s:13:\"display_title\";s:5:\"Media\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/media\";s:4:\"menu\";a:8:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Media\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:8:\"expanded\";b:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.media_library',_binary 'a:13:{s:4:\"uuid\";s:36:\"74d36492-489a-4ac8-ab15-1c22af9e302b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:25:\"image.style.media_library\";}s:6:\"module\";a:4:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:13:\"media_library\";i:3;s:4:\"user\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9u9hwW-Q0-uQJz1vgenJTQhZGYN0FBZoOogwPD6kgkQ\";}s:2:\"id\";s:13:\"media_library\";s:5:\"label\";s:13:\"Media library\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:4:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:2:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:24;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"6, 12, 24, 48\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:13:\"Apply filters\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:3:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:12:\"Newest first\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:1;s:11:\"granularity\";s:6:\"second\";}s:4:\"name\";a:12:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:3:\"ASC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (A-Z)\";s:16:\"field_identifier\";s:4:\"name\";}s:7:\"exposed\";b:1;}s:6:\"name_1\";a:12:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (Z-A)\";s:16:\"field_identifier\";s:6:\"name_1\";}s:7:\"exposed\";b:1;}}s:7:\"filters\";a:5:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:17:\"Publishing status\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:9:\"Published\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:10:\"Media type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:10:\"Media type\";s:11:\"description\";N;s:10:\"identifier\";s:6:\"bundle\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:3:{i:1;a:0:{}i:2;a:0:{}i:3;a:0:{}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:6:\"fields\";a:5:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"edit_media\";a:26:{s:2:\"id\";s:10:\"edit_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"edit_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:15:\"Edit {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:15:\"Edit {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"Edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:12:\"delete_media\";a:26:{s:2:\"id\";s:12:\"delete_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:12:\"delete_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:18:\"entity_link_delete\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:17:\"Delete {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:17:\"Delete {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:6:\"Delete\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:8:\"defaults\";a:1:{s:6:\"fields\";b:0;}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:24:\"admin/content/media-grid\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:22:\"url.query_args:sort_by\";i:5;s:4:\"user\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"widget\";a:6:{s:2:\"id\";s:6:\"widget\";s:13:\"display_title\";s:6:\"Widget\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:12:{s:6:\"fields\";a:2:{s:25:\"media_library_select_form\";a:23:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:8:\"defaults\";a:7:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:19:\"display_description\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:26:\"admin/content/media-widget\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"widget_table\";a:6:{s:2:\"id\";s:12:\"widget_table\";s:13:\"display_title\";s:14:\"Widget (table)\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:3;s:15:\"display_options\";a:13:{s:6:\"fields\";a:5:{s:25:\"media_library_select_form\";a:9:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:10:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:13:\"media_library\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}}}s:4:\"name\";a:10:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}}s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:20:\"media_field_revision\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}}s:7:\"changed\";a:10:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:2:{s:9:\"row_class\";s:85:\"media-library-item media-library-item--table js-media-library-item js-click-to-select\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:8:\"defaults\";a:9:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:32:\"admin/content/media-widget-table\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.taxonomy_term',_binary 'a:13:{s:4:\"uuid\";s:36:\"56651306-efed-4808-bbdc-d9cf02cff348\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:3:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KejdxDJQmx8SaO-t83OVekLw6ar4ldjmsJMGcotGxnQ\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:6:\"module\";s:8:\"taxonomy\";s:11:\"description\";s:45:\"Content belonging to a certain taxonomy term.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:10:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:11:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:3:\"tid\";a:22:{s:2:\"id\";s:3:\"tid\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:3:\"tid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:18:\"taxonomy_index_tid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:0:\"\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:19:\"{{ arguments.tid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:4:{s:7:\"bundles\";a:0:{}s:6:\"access\";b:1;s:9:\"operation\";s:4:\"view\";s:8:\"multiple\";i:0;}s:12:\"break_phrase\";b:0;s:9:\"add_table\";b:0;s:13:\"require_value\";b:0;s:17:\"reduce_duplicates\";b:0;}}s:7:\"filters\";a:2:{s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:14:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:1:{s:20:\"entity_taxonomy_term\";a:12:{s:2:\"id\";s:20:\"entity_taxonomy_term\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:20:\"entity_taxonomy_term\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"entity\";s:5:\"empty\";b:1;s:6:\"target\";s:23:\"{{ raw_arguments.tid }}\";s:9:\"view_mode\";s:4:\"full\";s:8:\"tokenize\";b:1;s:13:\"bypass_access\";b:0;}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:7:\"default\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:20:\"taxonomy/term/%/feed\";s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:15:\"taxonomy/term/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.user_admin_people',_binary 'a:13:{s:4:\"uuid\";s:36:\"66ac1092-d560-4cf9-a5d3-b1941a3311d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FFLg74mnzRE10lgg5fspPCZWLnIEcvCnJMlNzj8OEtw\";}s:2:\"id\";s:17:\"user_admin_people\";s:5:\"label\";s:6:\"People\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:25:{s:5:\"title\";s:6:\"People\";s:6:\"fields\";a:8:{s:14:\"user_bulk_form\";a:23:{s:2:\"id\";s:14:\"user_bulk_form\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:14:\"user_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:14:\"user_bulk_form\";s:5:\"label\";s:11:\"Bulk update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:8:\"Username\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:7:\"Blocked\";s:18:\"format_custom_true\";s:6:\"Active\";}}s:15:\"roles_target_id\";a:24:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:5:\"label\";s:5:\"Roles\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:2:\"ul\";s:9:\"separator\";s:2:\", \";}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Member for\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:9:\"@interval\";s:11:\"past_format\";s:9:\"@interval\";s:11:\"granularity\";i:2;}}s:6:\"access\";a:26:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last access\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:4:\"mail\";a:37:{s:2:\"id\";s:4:\"mail\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"mail\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"mail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:12:\"basic_string\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:16:\"administer users\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:20:\"No people available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:7:\"filters\";a:6:{s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:22:\"Name or email contains\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"user\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:4:\"mail\";s:4:\"mail\";}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:6:\"Active\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:7:\"Blocked\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:15:\"roles_target_id\";a:15:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:18:\"roles_target_id_op\";s:5:\"label\";s:4:\"Role\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:18:\"roles_target_id_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"role\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:10:\"permission\";a:15:{s:2:\"id\";s:10:\"permission\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:10:\"permission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"user_permissions\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:13:\"permission_op\";s:5:\"label\";s:10:\"Permission\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:13:\"permission_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:10:\"permission\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"uid_raw\";a:15:{s:2:\"id\";s:7:\"uid_raw\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"uid_raw\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:7:\"numeric\";s:8:\"operator\";s:2:\"!=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:1:\"0\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:10:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:14:\"user_bulk_form\";s:14:\"user_bulk_form\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:3:\"rid\";s:3:\"rid\";s:7:\"created\";s:7:\"created\";s:6:\"access\";s:6:\"access\";s:9:\"edit_node\";s:9:\"edit_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";}s:7:\"default\";s:7:\"created\";s:4:\"info\";a:8:{s:14:\"user_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:3:\"rid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"access\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"more\";s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:15:\"display_comment\";s:0:\"\";s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:1:{s:16:\"show_admin_links\";b:0;}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:17:\"admin/people/list\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:4:\"List\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:6:\"People\";s:11:\"description\";s:45:\"Manage user accounts, roles, and permissions.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.watchdog',_binary 'a:13:{s:4:\"uuid\";s:36:\"25587939-259b-48aa-8c6c-dbd04aa5d800\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"dblog\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SR5P89f0vUTPC7WY2YpLAffkDx8-Ar8LKFfowVXeqNU\";}s:2:\"id\";s:8:\"watchdog\";s:5:\"label\";s:8:\"Watchdog\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:19:\"Recent log messages\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"watchdog\";s:10:\"base_field\";s:3:\"wid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:19:\"Recent log messages\";s:6:\"fields\";a:8:{s:7:\"nothing\";a:22:{s:2:\"id\";s:7:\"nothing\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"nothing\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"Icon\";s:9:\"plugin_id\";s:6:\"custom\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:4:\"icon\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:0;}s:3:\"wid\";a:22:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:3:\"WID\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"severity\";a:23:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"machine_name\";s:5:\"label\";s:8:\"Severity\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"machine_name\";b:0;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:9:\"timestamp\";a:25:{s:2:\"id\";s:9:\"timestamp\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:9:\"timestamp\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"label\";s:4:\"Date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:7:\"message\";a:23:{s:2:\"id\";s:7:\"message\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:7:\"message\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:13:\"dblog_message\";s:5:\"label\";s:7:\"Message\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/reports/dblog/event/{{ wid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:13:\"{{ message }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:56;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:1;s:4:\"trim\";b:1;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:1;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"replace_variables\";b:1;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"User\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"link\";a:22:{s:2:\"id\";s:4:\"link\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"link\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"dblog_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"access site reports\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:4:\"area\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:26:\"No log messages available.\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:26:\"No log messages available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:3:\"wid\";a:10:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"wid\";}s:7:\"exposed\";b:0;}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:4:\"type\";a:14:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"dblog_types\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"severity\";a:14:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"in_operator\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"severity_op\";s:5:\"label\";s:8:\"Severity\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"severity_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"severity\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:25:\"{{ type }} {{ severity }}\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:7:\"nothing\";s:7:\"nothing\";s:3:\"wid\";s:3:\"wid\";s:8:\"severity\";s:8:\"severity\";s:4:\"type\";s:4:\"type\";s:9:\"timestamp\";s:9:\"timestamp\";s:7:\"message\";s:7:\"message\";s:4:\"name\";s:4:\"name\";s:4:\"link\";s:4:\"link\";}s:7:\"default\";s:3:\"wid\";s:4:\"info\";a:8:{s:7:\"nothing\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:3:\"wid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:8:\"severity\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"message\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:4:\"link\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:0;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"User\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:11:\"admin-dblog\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/reports/dblog\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.what_s_new',_binary 'a:12:{s:4:\"uuid\";s:36:\"e1df6ee8-b831-49f1-9777-12d640e99636\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:4:{i:0;s:22:\"better_exposed_filters\";i:1;s:4:\"node\";i:2;s:4:\"text\";i:3;s:4:\"user\";}}s:2:\"id\";s:10:\"what_s_new\";s:5:\"label\";s:10:\"What\'s New\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:0:\"\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:5:\"title\";s:10:\"What\'s New\";s:6:\"fields\";a:2:{s:5:\"title\";a:35:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:20:\"<h3>{{ title }}</h3>\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"body\";a:35:{s:2:\"id\";s:4:\"body\";s:5:\"table\";s:10:\"node__body\";s:5:\"field\";s:4:\"body\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:12:\"text_default\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:3:\"bef\";s:7:\"options\";a:10:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";s:19:\"text_input_required\";s:51:\"Select any filter and click on Apply to see results\";s:26:\"text_input_required_format\";s:9:\"full_html\";s:3:\"bef\";a:2:{s:7:\"general\";a:10:{s:10:\"autosubmit\";b:1;s:28:\"autosubmit_exclude_textfield\";b:0;s:26:\"autosubmit_textfield_delay\";i:500;s:35:\"autosubmit_textfield_minimum_length\";i:3;s:15:\"autosubmit_hide\";b:0;s:14:\"input_required\";b:0;s:15:\"allow_secondary\";b:0;s:15:\"secondary_label\";s:16:\"Advanced options\";s:14:\"secondary_open\";b:0;s:24:\"reset_button_always_show\";b:0;}s:6:\"filter\";a:1:{s:7:\"created\";a:2:{s:9:\"plugin_id\";s:7:\"default\";s:8:\"advanced\";a:6:{s:16:\"placeholder_text\";s:0:\"\";s:7:\"rewrite\";a:2:{s:21:\"filter_rewrite_values\";s:0:\"\";s:25:\"filter_rewrite_values_key\";b:0;}s:11:\"collapsible\";b:0;s:34:\"collapsible_disable_automatic_open\";b:0;s:12:\"is_secondary\";b:0;s:10:\"hide_label\";b:0;}}}}}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:0:\"\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:1:{s:8:\"operator\";s:0:\"\";}}s:4:\"type\";a:7:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:5:\"value\";a:1:{s:7:\"article\";s:7:\"article\";}}s:7:\"created\";a:16:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:0:\"\";s:4:\"type\";s:9:\"date_year\";}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:15:{s:11:\"operator_id\";s:10:\"created_op\";s:5:\"label\";s:11:\"Authored on\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"created_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:7:\"created\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:14:\"content_editor\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:15:\"min_placeholder\";s:0:\"\";s:15:\"max_placeholder\";s:0:\"\";s:11:\"placeholder\";s:0:\"\";}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:5:\"Year \";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:7:\"created\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:3:{i:1;a:3:{s:5:\"title\";s:4:\"2024\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:4:\"2024\";s:4:\"type\";s:9:\"date_year\";}}i:2;a:3:{s:5:\"title\";s:4:\"2023\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:4:\"2023\";s:4:\"type\";s:9:\"date_year\";}}i:3;a:3:{s:5:\"title\";s:4:\"2022\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:4:\"2022\";s:4:\"type\";s:9:\"date_year\";}}}}}}s:5:\"style\";a:1:{s:4:\"type\";s:7:\"default\";}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:1:{i:0;s:30:\"config:field.storage.node.body\";}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:13:\"exposed_block\";b:1;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:1:{i:0;s:30:\"config:field.storage.node.body\";}}}}}'),('','views.view.who_s_new',_binary 'a:13:{s:4:\"uuid\";s:36:\"d9b64673-64f0-48bb-8588-e15e4bdacdbf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zji0_13MyVGK7Bn1lUMDeZyyOIZedWvqpYUeM_SioPI\";}s:2:\"id\";s:9:\"who_s_new\";s:5:\"label\";s:9:\"Who\'s new\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:53:\"Shows a list of the newest user accounts on the site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:9:\"Who\'s new\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:5;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:1:\">\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:10:\"1970-01-01\";s:4:\"type\";s:4:\"date\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:1:{s:4:\"type\";s:9:\"html_list\";}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:9:\"Who\'s new\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:19:\"A list of new users\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:9:\"Who\'s new\";s:14:\"block_category\";s:4:\"User\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),('','views.view.who_s_online',_binary 'a:13:{s:4:\"uuid\";s:36:\"267c96ad-120e-49d6-9273-b49f1a603f01\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"suDsVMgawXoQt4rfmdfpr05EVX3z3KyfDDTYgeSM898\";}s:2:\"id\";s:12:\"who_s_online\";s:5:\"label\";s:18:\"Who\'s online block\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:93:\"Shows the user names of the most recently active users, and the total number of active users.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:12:\"Who\'s online\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access user profiles\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:35:\"There are currently 0 users online.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:6:\"access\";a:13:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"access\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:2:\">=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:11:\"-15 minutes\";s:4:\"type\";s:6:\"offset\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:9:\"access_op\";s:5:\"label\";s:11:\"Last access\";s:11:\"description\";s:77:\"A user is considered online for this long after they have last viewed a page.\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"access_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"access\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"result\";s:5:\"empty\";b:0;s:7:\"content\";s:40:\"There are currently @total users online.\";}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:18:\"who_s_online_block\";a:6:{s:2:\"id\";s:18:\"who_s_online_block\";s:13:\"display_title\";s:12:\"Who\'s online\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:19:\"display_description\";s:45:\"A list of users that are currently logged in.\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:12:\"Who\'s online\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}');
/*!40000 ALTER TABLE `config_export` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `file_managed`
--

DROP TABLE IF EXISTS `file_managed`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `file_managed` (
  `fid` int unsigned NOT NULL AUTO_INCREMENT,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `filename` varchar(255) DEFAULT NULL,
  `uri` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
  `filemime` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `filesize` bigint unsigned DEFAULT NULL,
  `status` tinyint NOT NULL,
  `created` int DEFAULT NULL,
  `changed` int NOT NULL,
  PRIMARY KEY (`fid`),
  UNIQUE KEY `file_field__uuid__value` (`uuid`),
  KEY `file_field__uid__target_id` (`uid`),
  KEY `file_field__uri` (`uri`(191)),
  KEY `file_field__status` (`status`),
  KEY `file_field__changed` (`changed`)
) ENGINE=InnoDB AUTO_INCREMENT=25 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for file entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `file_managed`
--

LOCK TABLES `file_managed` WRITE;
/*!40000 ALTER TABLE `file_managed` DISABLE KEYS */;
INSERT INTO `file_managed` VALUES (2,'60d8a89d-c0e4-4f6f-a02b-be56df95423e','en',1,'loU-RC_IfFJoRkm1ymCgvLwNgQN140h4McUa96sP_NM.jpg','public://oembed_thumbnails/2024-10/loU-RC_IfFJoRkm1ymCgvLwNgQN140h4McUa96sP_NM.jpg','image/jpeg',20824,1,1728242881,1728242881),(3,'1ef80ac2-157b-43e3-88d2-d1aa83385bbe','en',1,'333b8c43-dbee-469a-8766-c302f74bb595.jpg','public://2024-10/333b8c43-dbee-469a-8766-c302f74bb595.jpg','image/jpeg',92112,1,1728819558,1728819575),(4,'83ea2354-5924-4631-b0b9-c8235dcda17d','en',1,'bg-image1.webp','public://2024-10/bg-image1.webp','image/webp',73324,1,1728883281,1728883296),(5,'27a2e1c3-c1c1-406d-ac9f-ce46469004fc','en',1,'fluid_grid_1.webp','public://2024-10/fluid_grid_1.webp','image/webp',48672,1,1728884475,1728884491),(6,'a5734f68-39c4-447e-9b19-aa91c80aef37','en',1,'faq example.webp','public://2024-10/faq example.webp','image/webp',14826,1,1728884651,1728884661),(7,'a1b2e5be-a598-4a93-adad-be739d909ff1','en',1,'2 columns CTA.webp','public://2024-10/2 columns CTA.webp','image/webp',27076,1,1728884846,1728884856),(8,'210fbf6a-6326-4844-8ed3-bd55cf195244','en',1,'EBT Tabs.webp','public://2024-10/EBT Tabs.webp','image/webp',8288,1,1728885156,1728885164),(9,'03ea38ce-6683-4459-9011-0cbabcf143f9','en',1,'8af0c440-2152-4678-86c7-95ee5c055211.jpg','public://2024-10/8af0c440-2152-4678-86c7-95ee5c055211.jpg','image/jpeg',72125,1,1728885422,1728885435),(10,'f06ef861-cfbe-457e-9ee4-059ff7de69c0','en',1,'ept-slick-slider.webp','public://2024-10/ept-slick-slider.webp','image/webp',34012,1,1728885872,1728885878),(11,'b0d51bae-d787-4260-9ce3-c354cac9e303','en',1,'ebt carousel.webp','public://2024-10/ebt carousel.webp','image/webp',43104,1,1728887601,1728887611),(12,'eacb6931-12a4-462a-89ed-e8a0300dfbae','en',1,'Home-Drupal-9_0.webp','public://2024-10/Home-Drupal-9_0.webp','image/webp',44306,1,1728887677,1728887683),(13,'d2235e60-83f3-4650-b2b0-6e8a5fe0fb61','en',1,'with_square_img_0.webp','public://2024-10/with_square_img_0.webp','image/webp',36710,1,1728887791,1728887798),(14,'1db9b011-c7f0-4abc-9e6b-0d06e3e2a4fb','en',1,'ept tiles.webp','public://2024-10/ept tiles.webp','image/webp',56258,1,1728887900,1728887910),(15,'c5becdcc-54b2-48cd-acda-9e048f3d2ab1','en',1,'EPT text.webp','public://2024-10/EPT text.webp','image/webp',39042,1,1728888003,1728888015),(16,'c46c3254-d755-417b-ab28-21b8747e6918','en',1,'ept counter.webp','public://2024-10/ept counter.webp','image/webp',65676,1,1728888321,1728888367),(17,'8f411a08-cf69-4725-8f5b-ffb6f1982478','en',1,'glightbox.webp','public://2024-10/glightbox.webp','image/webp',22398,1,1728888670,1728888706),(18,'9728eed8-3c60-44e0-9972-fab3de265240','en',1,'dark drop.webp','public://2024-10/dark drop.webp','image/webp',67540,1,1728889183,1728889191),(19,'528ff0c5-d513-4850-a4c9-616c71d6255b','en',1,'ept case.webp','public://2024-10/ept case.webp','image/webp',142334,1,1728933322,1728933335),(20,'cca69110-3961-414d-9a95-75e39a356ca2','en',1,'4950565d-af48-45ef-be68-c27550a02da9.jpg','public://2024-10/4950565d-af48-45ef-be68-c27550a02da9.jpg','image/jpeg',111698,1,1728934033,1728934044),(21,'57499a89-5124-4b71-bcbf-14a53e8bae01','en',1,'4950565d-af48-45ef-be68-c27550a02da9.webp','public://2024-10/4950565d-af48-45ef-be68-c27550a02da9.webp','image/webp',102772,1,1728935124,1728935148),(22,'ba718488-03e3-44c6-9608-b7012b00a3a8','en',1,'DOM Box.webp','public://2024-10/DOM Box.webp','image/webp',74164,1,1728936151,1728936159),(23,'aceb3a02-bf1e-4e25-8bfc-dec82bce67ea','en',1,'background image or video.webp','public://2024-10/background image or video.webp','image/webp',28554,1,1728936355,1728936372),(24,'abcaf6ea-2236-4ac6-a648-a7c7c0111dd8','en',1,'javascript plugins.webp','public://2024-10/javascript plugins.webp','image/webp',32980,1,1728936556,1728936566);
/*!40000 ALTER TABLE `file_managed` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `file_usage`
--

DROP TABLE IF EXISTS `file_usage`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `file_usage` (
  `fid` int unsigned NOT NULL COMMENT 'File ID.',
  `module` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the module that is using the file.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the object type in which the file is used.',
  `id` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '0' COMMENT 'The primary key of the object using the file.',
  `count` int unsigned NOT NULL DEFAULT '0' COMMENT 'The number of times this file is used by this object.',
  PRIMARY KEY (`fid`,`type`,`id`,`module`),
  KEY `type_id` (`type`,`id`),
  KEY `fid_count` (`fid`,`count`),
  KEY `fid_module` (`fid`,`module`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Track where a file is used.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `file_usage`
--

LOCK TABLES `file_usage` WRITE;
/*!40000 ALTER TABLE `file_usage` DISABLE KEYS */;
INSERT INTO `file_usage` VALUES (2,'file','media','1',1),(3,'file','media','2',2),(4,'file','media','3',2),(5,'file','media','4',6),(6,'file','media','5',4),(7,'file','media','6',4),(8,'file','media','7',4),(9,'file','media','8',2),(10,'file','media','9',2),(11,'file','media','10',2),(12,'file','media','11',2),(13,'file','media','12',2),(14,'file','media','13',2),(15,'file','media','14',2),(16,'file','media','15',2),(17,'file','media','16',2),(18,'file','media','17',2),(19,'file','media','18',2),(20,'file','media','19',2),(21,'file','media','19',2),(22,'file','media','20',2),(23,'file','media','21',2),(24,'file','media','22',2);
/*!40000 ALTER TABLE `file_usage` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `help_search_items`
--

DROP TABLE IF EXISTS `help_search_items`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `help_search_items` (
  `sid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Numeric index of this item in the search index',
  `section_plugin_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The help section the item comes from',
  `permission` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The permission needed to view this item',
  `topic_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The topic ID of the item',
  PRIMARY KEY (`sid`),
  KEY `section_plugin_id` (`section_plugin_id`),
  KEY `topic_id` (`topic_id`)
) ENGINE=InnoDB AUTO_INCREMENT=87 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores information about indexed help search items';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `help_search_items`
--

LOCK TABLES `help_search_items` WRITE;
/*!40000 ALTER TABLE `help_search_items` DISABLE KEYS */;
INSERT INTO `help_search_items` VALUES (1,'help_topics','','config.export_full'),(2,'help_topics','','config.export_single'),(3,'help_topics','','config.import_full'),(4,'help_topics','','config.import_single'),(5,'help_topics','','contact.adding_fields'),(6,'help_topics','','contact.configuring_personal'),(7,'help_topics','','contact.creating'),(8,'help_topics','','contact.overview'),(9,'help_topics','','contact.setting_default'),(10,'help_topics','','core.appearance'),(11,'help_topics','','core.config_overview'),(12,'help_topics','','core.content_structure'),(13,'help_topics','','core.cron'),(14,'help_topics','','core.extending'),(15,'help_topics','','core.maintenance'),(16,'help_topics','','core.media'),(17,'help_topics','','core.menus'),(18,'help_topics','','core.performance'),(19,'help_topics','','core.security'),(20,'help_topics','','core.settings_tray'),(21,'help_topics','','core.tracking_content'),(22,'help_topics','','core.translations'),(23,'help_topics','','core.ui_accessibility'),(24,'help_topics','','core.ui_components'),(25,'help_topics','','core.web_services'),(26,'help_topics','','help.help_topic_search'),(27,'help_topics','','help.overview'),(28,'help_topics','','search.configuring'),(29,'help_topics','','search.index'),(30,'help_topics','','search.overview'),(31,'help_topics','','system.cache'),(32,'help_topics','','system.config_basic'),(33,'help_topics','','system.config_error'),(34,'help_topics','','system.maintenance_mode'),(35,'help_topics','','system.module_install'),(36,'help_topics','','system.module_uninstall'),(37,'help_topics','','system.reports'),(38,'help_topics','','system.theme_install'),(39,'help_topics','','system.theme_uninstall'),(40,'help_topics','','user.create'),(41,'help_topics','','user.new_role'),(42,'help_topics','','user.overview'),(43,'help_topics','','user.permissions'),(44,'help_topics','','user.security_account_settings'),(45,'help_topics','','user.update'),(46,'help_topics','','announcements_feed.overview'),(47,'help_topics','','block.configure'),(48,'help_topics','','block.overview'),(49,'help_topics','','block.place'),(50,'help_topics','','filter.overview'),(51,'help_topics','','block_content.add'),(52,'help_topics','','block_content.type'),(53,'help_topics','','breakpoint.overview'),(54,'help_topics','','editor.overview'),(55,'help_topics','','comment.configuring'),(56,'help_topics','','comment.creating_type'),(57,'help_topics','','comment.disabling'),(58,'help_topics','','comment.moderating'),(59,'help_topics','','comment.overview'),(60,'help_topics','','contextual.overview'),(61,'help_topics','','field_ui.add_field'),(62,'help_topics','','field_ui.manage_display'),(63,'help_topics','','field_ui.manage_form'),(64,'help_topics','','field_ui.reference_field'),(65,'help_topics','','node.creating_content'),(66,'help_topics','','node.creating_type'),(67,'help_topics','','node.editing'),(68,'help_topics','','node.overview'),(69,'help_topics','','history.tracking_user_content'),(70,'help_topics','','image.style'),(71,'help_topics','','views.overview'),(72,'help_topics','','menu_ui.content_type_configuration'),(73,'help_topics','','menu_ui.menu_item_add'),(74,'help_topics','','menu_ui.menu_operations'),(75,'help_topics','','menu_ui.overriding'),(76,'help_topics','','path.creating_alias'),(77,'help_topics','','path.editing_alias'),(78,'help_topics','','path.overview'),(79,'help_topics','','shortcut.overview'),(80,'help_topics','','taxonomy.configuring'),(81,'help_topics','','taxonomy.overview'),(82,'help_topics','','views_ui.add_display'),(83,'help_topics','','views_ui.bulk_operations'),(84,'help_topics','','views_ui.create'),(85,'help_topics','','views_ui.edit'),(86,'help_topics','','media.media_type');
/*!40000 ALTER TABLE `help_search_items` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `history`
--

DROP TABLE IF EXISTS `history`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `history` (
  `uid` int NOT NULL DEFAULT '0' COMMENT 'The "users".uid that read the "node" nid.',
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "node".nid that was read.',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp at which the read occurred.',
  PRIMARY KEY (`uid`,`nid`),
  KEY `nid` (`nid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='A record of which "users" have read which "node"s.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `history`
--

LOCK TABLES `history` WRITE;
/*!40000 ALTER TABLE `history` DISABLE KEYS */;
INSERT INTO `history` VALUES (1,1,1729067413),(1,2,1729063478),(1,3,1729063653),(1,4,1729063673),(1,5,1729063701),(1,6,1729063730),(1,7,1729063756),(1,8,1729063846),(1,9,1729063869),(1,10,1729063892),(1,11,1729063913),(1,12,1729063944),(1,13,1729063964),(1,14,1729063992),(1,15,1729064014),(1,16,1729064053),(1,17,1729064073),(1,18,1729064102),(1,19,1729067435);
/*!40000 ALTER TABLE `history` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `key_value`
--

DROP TABLE IF EXISTS `key_value`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `key_value` (
  `collection` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A named collection of key and value pairs.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The key of the key-value pair. As KEY is a SQL reserved keyword, name was chosen instead.',
  `value` longblob NOT NULL COMMENT 'The value.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Generic key-value storage table. See the state system for…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `key_value`
--

LOCK TABLES `key_value` WRITE;
/*!40000 ALTER TABLE `key_value` DISABLE KEYS */;
INSERT INTO `key_value` VALUES ('config.entity.key_store.action','uuid:0640984c-3787-4c25-8abe-073f6ff633cc',_binary 'a:1:{i:0;s:39:\"system.action.node_make_unsticky_action\";}'),('config.entity.key_store.action','uuid:07d84567-f6ce-480c-94fe-71f48ce157b7',_binary 'a:1:{i:0;s:44:\"system.action.taxonomy_term_unpublish_action\";}'),('config.entity.key_store.action','uuid:080a7d5c-2fda-47ed-b9aa-be9cb07b6d2e',_binary 'a:1:{i:0;s:48:\"system.action.user_add_role_action.administrator\";}'),('config.entity.key_store.action','uuid:2003aeb9-8fd3-4006-8c7f-9129bef1a808',_binary 'a:1:{i:0;s:37:\"system.action.node_make_sticky_action\";}'),('config.entity.key_store.action','uuid:29499598-fb70-43f6-a160-d2522304d4e7',_binary 'a:1:{i:0;s:35:\"system.action.node_unpromote_action\";}'),('config.entity.key_store.action','uuid:34872d09-0b48-4090-a401-75dc2bd3358d',_binary 'a:1:{i:0;s:35:\"system.action.node_unpublish_action\";}'),('config.entity.key_store.action','uuid:455e72bb-d5c2-4233-8fae-fe874a5aecde',_binary 'a:1:{i:0;s:32:\"system.action.node_delete_action\";}'),('config.entity.key_store.action','uuid:59cad6a4-a038-45d4-98e9-6ace07f80050',_binary 'a:1:{i:0;s:36:\"system.action.media_unpublish_action\";}'),('config.entity.key_store.action','uuid:5ee77a15-afb1-4e0c-bd3b-3e462abe568d',_binary 'a:1:{i:0;s:34:\"system.action.media_publish_action\";}'),('config.entity.key_store.action','uuid:6e3d2ae5-f68b-4adb-8345-78fe6e53c835',_binary 'a:1:{i:0;s:33:\"system.action.node_publish_action\";}'),('config.entity.key_store.action','uuid:6f753574-2b6f-4e3a-87fd-04f281182309',_binary 'a:1:{i:0;s:35:\"system.action.comment_delete_action\";}'),('config.entity.key_store.action','uuid:7317c388-dffd-422a-b041-7ef8597810b4',_binary 'a:1:{i:0;s:37:\"system.action.user_cancel_user_action\";}'),('config.entity.key_store.action','uuid:7ff39d45-7ef9-4e69-a87b-aa71ae0d4343',_binary 'a:1:{i:0;s:30:\"system.action.node_save_action\";}'),('config.entity.key_store.action','uuid:8509e01a-1fe0-4d2b-80fe-6292c7281beb',_binary 'a:1:{i:0;s:42:\"system.action.taxonomy_term_publish_action\";}'),('config.entity.key_store.action','uuid:879c5dbe-c854-4240-b44b-cc9946b7e95b',_binary 'a:1:{i:0;s:38:\"system.action.user_unblock_user_action\";}'),('config.entity.key_store.action','uuid:93459360-b66a-4249-92eb-59a0d4b9e585',_binary 'a:1:{i:0;s:33:\"system.action.node_promote_action\";}'),('config.entity.key_store.action','uuid:9b97ffc0-0ba9-48fc-9e78-a23777ef7ff4',_binary 'a:1:{i:0;s:31:\"system.action.media_save_action\";}'),('config.entity.key_store.action','uuid:a09349ec-38d9-4ee0-b772-074a9b406491',_binary 'a:1:{i:0;s:38:\"system.action.comment_unpublish_action\";}'),('config.entity.key_store.action','uuid:a3ac7eaa-5ae2-4c20-abbb-79b198424e39',_binary 'a:1:{i:0;s:51:\"system.action.user_remove_role_action.administrator\";}'),('config.entity.key_store.action','uuid:c8e0fba3-a9ea-40bc-9886-42d52bf69615',_binary 'a:1:{i:0;s:36:\"system.action.comment_publish_action\";}'),('config.entity.key_store.action','uuid:daca732c-22a4-42c1-a3c8-d54dae2a458c',_binary 'a:1:{i:0;s:52:\"system.action.user_remove_role_action.content_editor\";}'),('config.entity.key_store.action','uuid:e33f0ef8-e9df-400f-b24b-60c0f3497768',_binary 'a:1:{i:0;s:49:\"system.action.user_add_role_action.content_editor\";}'),('config.entity.key_store.action','uuid:ec45edef-e3ef-44f8-87d8-428346ac0579',_binary 'a:1:{i:0;s:36:\"system.action.user_block_user_action\";}'),('config.entity.key_store.action','uuid:f2a7400a-fd44-4225-906e-c04f6f5f8944',_binary 'a:1:{i:0;s:33:\"system.action.comment_save_action\";}'),('config.entity.key_store.action','uuid:f8932ff6-cc40-43b7-9cd8-7fefb06c44cf',_binary 'a:1:{i:0;s:33:\"system.action.media_delete_action\";}'),('config.entity.key_store.base_field_override','uuid:3818335f-a764-468f-ba14-8dbe325fa7f3',_binary 'a:1:{i:0;s:42:\"core.base_field_override.node.page.promote\";}'),('config.entity.key_store.block','theme:claro',_binary 'a:9:{i:0;s:31:\"block.block.claro_local_actions\";i:1;s:28:\"block.block.claro_page_title\";i:2;s:37:\"block.block.claro_primary_local_tasks\";i:3;s:39:\"block.block.claro_secondary_local_tasks\";i:4;s:22:\"block.block.claro_help\";i:5;s:29:\"block.block.claro_help_search\";i:6;s:29:\"block.block.claro_breadcrumbs\";i:7;s:25:\"block.block.claro_content\";i:8;s:26:\"block.block.claro_messages\";}'),('config.entity.key_store.block','theme:ept_light',_binary 'a:14:{i:0;s:34:\"block.block.ept_light_account_menu\";i:1;s:33:\"block.block.ept_light_breadcrumbs\";i:2;s:29:\"block.block.ept_light_content\";i:3;s:26:\"block.block.ept_light_help\";i:4;s:31:\"block.block.ept_light_main_menu\";i:5;s:30:\"block.block.ept_light_messages\";i:6;s:32:\"block.block.ept_light_page_title\";i:8;s:43:\"block.block.ept_light_primary_admin_actions\";i:9;s:41:\"block.block.ept_light_primary_local_tasks\";i:10;s:40:\"block.block.ept_light_search_form_narrow\";i:11;s:38:\"block.block.ept_light_search_form_wide\";i:12;s:43:\"block.block.ept_light_secondary_local_tasks\";i:13;s:35:\"block.block.ept_light_site_branding\";i:14;s:28:\"block.block.ept_light_footer\";}'),('config.entity.key_store.block','theme:gin',_binary 'a:8:{i:0;s:29:\"block.block.gin_local_actions\";i:1;s:26:\"block.block.gin_page_title\";i:2;s:35:\"block.block.gin_primary_local_tasks\";i:3;s:37:\"block.block.gin_secondary_local_tasks\";i:4;s:20:\"block.block.gin_help\";i:5;s:27:\"block.block.gin_breadcrumbs\";i:6;s:23:\"block.block.gin_content\";i:7;s:24:\"block.block.gin_messages\";}'),('config.entity.key_store.block','theme:olivero',_binary 'a:15:{i:0;s:24:\"block.block.olivero_help\";i:1;s:30:\"block.block.olivero_page_title\";i:2;s:41:\"block.block.olivero_primary_admin_actions\";i:3;s:39:\"block.block.olivero_primary_local_tasks\";i:4;s:41:\"block.block.olivero_secondary_local_tasks\";i:5;s:29:\"block.block.olivero_syndicate\";i:6;s:38:\"block.block.olivero_search_form_narrow\";i:7;s:36:\"block.block.olivero_search_form_wide\";i:8;s:31:\"block.block.olivero_breadcrumbs\";i:9;s:27:\"block.block.olivero_content\";i:10;s:28:\"block.block.olivero_messages\";i:11;s:27:\"block.block.olivero_powered\";i:12;s:33:\"block.block.olivero_site_branding\";i:13;s:32:\"block.block.olivero_account_menu\";i:14;s:29:\"block.block.olivero_main_menu\";}'),('config.entity.key_store.block','uuid:05eb19c5-b411-47d2-b90a-e862156e9997',_binary 'a:1:{i:0;s:29:\"block.block.claro_help_search\";}'),('config.entity.key_store.block','uuid:07cc9530-0745-41b8-a927-b15f94d11bfb',_binary 'a:1:{i:0;s:28:\"block.block.olivero_messages\";}'),('config.entity.key_store.block','uuid:11d088e1-eb0e-4d66-ac1d-c629d4c31759',_binary 'a:1:{i:0;s:37:\"block.block.gin_secondary_local_tasks\";}'),('config.entity.key_store.block','uuid:19cc65dc-0021-4f62-9692-28154e28e6d6',_binary 'a:1:{i:0;s:31:\"block.block.olivero_breadcrumbs\";}'),('config.entity.key_store.block','uuid:1f0cb4e0-55ff-4097-a00c-015a0892bae5',_binary 'a:1:{i:0;s:24:\"block.block.olivero_help\";}'),('config.entity.key_store.block','uuid:2889853d-c6c8-46fb-8345-4f1161d60b42',_binary 'a:1:{i:0;s:41:\"block.block.olivero_primary_admin_actions\";}'),('config.entity.key_store.block','uuid:302175a6-2514-4728-9834-feade3c1cb23',_binary 'a:1:{i:0;s:24:\"block.block.gin_messages\";}'),('config.entity.key_store.block','uuid:360ce22f-fdb1-4a74-baf4-b253df6d8b6d',_binary 'a:1:{i:0;s:32:\"block.block.olivero_account_menu\";}'),('config.entity.key_store.block','uuid:37f8f7d2-81b3-4c42-a9a4-84cb29380e2c',_binary 'a:1:{i:0;s:26:\"block.block.gin_page_title\";}'),('config.entity.key_store.block','uuid:38507368-0a7f-4498-a629-376fb4821455',_binary 'a:1:{i:0;s:23:\"block.block.gin_content\";}'),('config.entity.key_store.block','uuid:3b00e68f-1ed0-4482-b8b1-e496f1da9936',_binary 'a:1:{i:0;s:26:\"block.block.claro_messages\";}'),('config.entity.key_store.block','uuid:447aab50-0670-4a09-ad2b-204da3cad682',_binary 'a:1:{i:0;s:29:\"block.block.olivero_main_menu\";}'),('config.entity.key_store.block','uuid:45129ab9-c3af-46c1-b266-7caf3e552d05',_binary 'a:1:{i:0;s:27:\"block.block.olivero_content\";}'),('config.entity.key_store.block','uuid:4a702f15-1477-4e9c-a8bf-5c98f5bff5f5',_binary 'a:1:{i:0;s:39:\"block.block.olivero_primary_local_tasks\";}'),('config.entity.key_store.block','uuid:4e19c95d-851d-48dd-8e91-3df3501787a3',_binary 'a:1:{i:0;s:27:\"block.block.olivero_powered\";}'),('config.entity.key_store.block','uuid:56ef6a64-122b-4123-89be-e28c850c9ab5',_binary 'a:1:{i:0;s:41:\"block.block.ept_light_primary_local_tasks\";}'),('config.entity.key_store.block','uuid:5e004719-546a-4a9e-8ed6-bce3b1438316',_binary 'a:1:{i:0;s:33:\"block.block.olivero_site_branding\";}'),('config.entity.key_store.block','uuid:682b08d1-3f45-4c13-974e-95552426afcd',_binary 'a:1:{i:0;s:38:\"block.block.ept_light_search_form_wide\";}'),('config.entity.key_store.block','uuid:7010f57e-634e-4b97-8a69-97b80a011cb4',_binary 'a:1:{i:0;s:33:\"block.block.ept_light_breadcrumbs\";}'),('config.entity.key_store.block','uuid:736d4519-e22a-419a-87cd-009a768a73b7',_binary 'a:1:{i:0;s:31:\"block.block.ept_light_main_menu\";}'),('config.entity.key_store.block','uuid:7b17ab28-0376-4ee3-91ee-5bd02432291e',_binary 'a:1:{i:0;s:29:\"block.block.ept_light_content\";}'),('config.entity.key_store.block','uuid:877e883f-c61a-49fd-bf14-7370c20fec8c',_binary 'a:1:{i:0;s:35:\"block.block.gin_primary_local_tasks\";}'),('config.entity.key_store.block','uuid:8eba635a-7f03-408c-a4a4-28e12ca89e20',_binary 'a:1:{i:0;s:38:\"block.block.olivero_search_form_narrow\";}'),('config.entity.key_store.block','uuid:8ed1a440-61c0-42d9-af64-c0573a386802',_binary 'a:1:{i:0;s:30:\"block.block.olivero_page_title\";}'),('config.entity.key_store.block','uuid:8edfdbdd-cd33-4ebe-b1d4-74fb38d1039e',_binary 'a:1:{i:0;s:26:\"block.block.ept_light_help\";}'),('config.entity.key_store.block','uuid:901eabdd-054d-4bcb-9773-45c7fd010fdf',_binary 'a:1:{i:0;s:43:\"block.block.ept_light_secondary_local_tasks\";}'),('config.entity.key_store.block','uuid:906009a1-78bd-4b80-9f60-5260448561b2',_binary 'a:1:{i:0;s:27:\"block.block.gin_breadcrumbs\";}'),('config.entity.key_store.block','uuid:916365b2-7723-493b-8918-5f3ff7d57c7d',_binary 'a:1:{i:0;s:31:\"block.block.claro_local_actions\";}'),('config.entity.key_store.block','uuid:91c1ee17-a1ad-4235-992c-274ff1022382',_binary 'a:1:{i:0;s:35:\"block.block.ept_light_site_branding\";}'),('config.entity.key_store.block','uuid:a78731d9-6557-4805-9b50-71d93a910730',_binary 'a:1:{i:0;s:28:\"block.block.ept_light_footer\";}'),('config.entity.key_store.block','uuid:a8c9d41b-02e1-478d-85b3-fb3a1f815f49',_binary 'a:1:{i:0;s:37:\"block.block.claro_primary_local_tasks\";}'),('config.entity.key_store.block','uuid:ac6db2d5-4bab-486d-9cbd-5a8bc4c56df9',_binary 'a:1:{i:0;s:40:\"block.block.ept_light_search_form_narrow\";}'),('config.entity.key_store.block','uuid:b7350fce-d849-4243-936a-283b164fea04',_binary 'a:1:{i:0;s:41:\"block.block.olivero_secondary_local_tasks\";}'),('config.entity.key_store.block','uuid:b76f1641-4f78-438e-a0fe-ce65bd7f9006',_binary 'a:1:{i:0;s:28:\"block.block.claro_page_title\";}'),('config.entity.key_store.block','uuid:b7ad69dc-b6ab-4ee3-ab50-2994b490c801',_binary 'a:1:{i:0;s:29:\"block.block.olivero_syndicate\";}'),('config.entity.key_store.block','uuid:bb1e9b33-93c2-4829-9613-e4ccc525f30b',_binary 'a:1:{i:0;s:39:\"block.block.claro_secondary_local_tasks\";}'),('config.entity.key_store.block','uuid:be976f48-8227-4e04-b46e-05849e446c76',_binary 'a:1:{i:0;s:29:\"block.block.claro_breadcrumbs\";}'),('config.entity.key_store.block','uuid:c8fc509e-9767-4eae-81f5-6cdbe64aa2b3',_binary 'a:1:{i:0;s:30:\"block.block.ept_light_messages\";}'),('config.entity.key_store.block','uuid:ce83be5e-1fd7-4a0f-9b06-0a0d8710cb26',_binary 'a:1:{i:0;s:25:\"block.block.claro_content\";}'),('config.entity.key_store.block','uuid:d66baf8e-252f-4c79-acb6-b8b6d6b0a27a',_binary 'a:1:{i:0;s:22:\"block.block.claro_help\";}'),('config.entity.key_store.block','uuid:decd9477-39d6-4529-94a3-8a2d5f064f46',_binary 'a:1:{i:0;s:36:\"block.block.olivero_search_form_wide\";}'),('config.entity.key_store.block','uuid:e3753ad7-7b76-4f93-add9-02296fe5a072',_binary 'a:1:{i:0;s:20:\"block.block.gin_help\";}'),('config.entity.key_store.block','uuid:f127d369-8154-4de3-9366-638b32c1d495',_binary 'a:1:{i:0;s:29:\"block.block.gin_local_actions\";}'),('config.entity.key_store.block','uuid:f35c55e3-3d40-497f-9b7f-2896cbc2e345',_binary 'a:1:{i:0;s:34:\"block.block.ept_light_account_menu\";}'),('config.entity.key_store.block','uuid:f45a0a49-c001-47cb-b97e-767aac0f24f2',_binary 'a:1:{i:0;s:32:\"block.block.ept_light_page_title\";}'),('config.entity.key_store.block','uuid:feb5ed42-838e-41fe-bce3-ac32e38425f9',_binary 'a:1:{i:0;s:43:\"block.block.ept_light_primary_admin_actions\";}'),('config.entity.key_store.block_content_type','uuid:682f8d4b-7fbf-4b68-aeeb-78ff6ffa44c8',_binary 'a:1:{i:0;s:24:\"block_content.type.basic\";}'),('config.entity.key_store.comment_type','uuid:33c6c326-f5e0-4ece-8508-28b245963a92',_binary 'a:1:{i:0;s:20:\"comment.type.comment\";}'),('config.entity.key_store.contact_form','uuid:3d45f5dc-8385-44e2-add9-10e58ad548b8',_binary 'a:1:{i:0;s:21:\"contact.form.personal\";}'),('config.entity.key_store.contact_form','uuid:d9d62dfa-bada-46f4-869f-64b74f835a2f',_binary 'a:1:{i:0;s:21:\"contact.form.feedback\";}'),('config.entity.key_store.date_format','uuid:045e5b96-3ec2-48a7-ba8c-c6cd6c3e6478',_binary 'a:1:{i:0;s:26:\"core.date_format.html_year\";}'),('config.entity.key_store.date_format','uuid:1db472d5-aa8d-43d1-99f1-0718ae5620bf',_binary 'a:1:{i:0;s:27:\"core.date_format.html_month\";}'),('config.entity.key_store.date_format','uuid:1e7ea1cc-62aa-4605-b6b6-e50e8e13c716',_binary 'a:1:{i:0;s:26:\"core.date_format.html_date\";}'),('config.entity.key_store.date_format','uuid:26c2a255-dd57-40de-9edb-d3ecd4eafa69',_binary 'a:1:{i:0;s:21:\"core.date_format.long\";}'),('config.entity.key_store.date_format','uuid:3d36a601-a518-4117-b489-72f027a4d007',_binary 'a:1:{i:0;s:25:\"core.date_format.fallback\";}'),('config.entity.key_store.date_format','uuid:504c65d8-2f56-4376-8b9b-e7ca5b007ba8',_binary 'a:1:{i:0;s:26:\"core.date_format.html_time\";}'),('config.entity.key_store.date_format','uuid:9c97ee83-74c2-4456-80d2-eb94e9ca333e',_binary 'a:1:{i:0;s:26:\"core.date_format.html_week\";}'),('config.entity.key_store.date_format','uuid:b3b94f80-dd74-4a2f-b128-51de30c5e289',_binary 'a:1:{i:0;s:23:\"core.date_format.medium\";}'),('config.entity.key_store.date_format','uuid:c34d2a68-a9e5-40c6-8224-8940032e30eb',_binary 'a:1:{i:0;s:30:\"core.date_format.html_datetime\";}'),('config.entity.key_store.date_format','uuid:c5c2ce9a-1442-4bf1-a654-b45e23c4b6e3',_binary 'a:1:{i:0;s:22:\"core.date_format.short\";}'),('config.entity.key_store.date_format','uuid:ebd666ec-7725-4d54-8907-f69b8c4e48ec',_binary 'a:1:{i:0;s:35:\"core.date_format.html_yearless_date\";}'),('config.entity.key_store.date_format','uuid:f5992887-d80e-47c5-bcb3-28c304448abb',_binary 'a:1:{i:0;s:31:\"core.date_format.olivero_medium\";}'),('config.entity.key_store.editor','uuid:5b65cbab-6e9a-450e-a54e-4c334c4ca75d',_binary 'a:1:{i:0;s:23:\"editor.editor.full_html\";}'),('config.entity.key_store.editor','uuid:de26b70d-0b5e-4129-a929-f1de8a455f1b',_binary 'a:1:{i:0;s:24:\"editor.editor.basic_html\";}'),('config.entity.key_store.entity_form_display','uuid:063fafbf-a44a-44d9-b44e-e6b7f1c968f2',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_block.default\";}'),('config.entity.key_store.entity_form_display','uuid:0a168361-abfe-403a-8922-8305dbbef7af',_binary 'a:1:{i:0;s:51:\"core.entity_form_display.paragraph.ept_text.default\";}'),('config.entity.key_store.entity_form_display','uuid:0e9a2579-f110-4139-81b2-dc1025db5053',_binary 'a:1:{i:0;s:64:\"core.entity_form_display.paragraph.ept_slick_slider_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:1003a694-14ea-404d-bf58-34d4ad51a83c',_binary 'a:1:{i:0;s:56:\"core.entity_form_display.paragraph.ept_slideshow.default\";}'),('config.entity.key_store.entity_form_display','uuid:11f77720-51d3-4dc6-b653-b86d5771046b',_binary 'a:1:{i:0;s:57:\"core.entity_form_display.paragraph.ept_stats_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:1912a858-abb3-4ca8-aa94-e9265ace4567',_binary 'a:1:{i:0;s:44:\"core.entity_form_display.media.audio.default\";}'),('config.entity.key_store.entity_form_display','uuid:209743da-7b46-410c-8256-e9acf9b4200b',_binary 'a:1:{i:0;s:60:\"core.entity_form_display.paragraph.ept_carousel_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:21a9c7b6-423a-4c02-931a-6bb7c808ca5e',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.block_content.basic.default\";}'),('config.entity.key_store.entity_form_display','uuid:2a6ec3c5-051d-451f-bfa5-ae16ca4d9cc1',_binary 'a:1:{i:0;s:70:\"core.entity_form_display.paragraph.ept_video_and_image_gallery.default\";}'),('config.entity.key_store.entity_form_display','uuid:2ba6d267-9074-4e3c-a4c5-e392e2e1b8ec',_binary 'a:1:{i:0;s:56:\"core.entity_form_display.paragraph.ept_tabs_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:39e1a15a-eab7-4dcc-af37-af10f81e96dd',_binary 'a:1:{i:0;s:63:\"core.entity_form_display.paragraph.ept_bootstrap_button.default\";}'),('config.entity.key_store.entity_form_display','uuid:3b42b32b-b440-4ab8-9a73-96284648f0b9',_binary 'a:1:{i:0;s:55:\"core.entity_form_display.paragraph.ept_carousel.default\";}'),('config.entity.key_store.entity_form_display','uuid:3bbc19b5-b8d1-4737-93da-814614ad0da5',_binary 'a:1:{i:0;s:59:\"core.entity_form_display.paragraph.ept_basic_button.default\";}'),('config.entity.key_store.entity_form_display','uuid:3d683f4e-cbb1-4a0e-b1df-f9f9c87e4284',_binary 'a:1:{i:0;s:50:\"core.entity_form_display.media.video.media_library\";}'),('config.entity.key_store.entity_form_display','uuid:45b2e5a1-2031-4177-b3c2-580549849e46',_binary 'a:1:{i:0;s:57:\"core.entity_form_display.paragraph.ept_tiles_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:46bc1cc1-610e-4909-9538-f9f08a6a24c0',_binary 'a:1:{i:0;s:48:\"core.entity_form_display.comment.comment.default\";}'),('config.entity.key_store.entity_form_display','uuid:47cd5408-95d9-4b89-a9c5-7d8aedd625f0',_binary 'a:1:{i:0;s:57:\"core.entity_form_display.media.remote_video.media_library\";}'),('config.entity.key_store.entity_form_display','uuid:483f7e15-2bcb-4ed9-952b-548c4960e622',_binary 'a:1:{i:0;s:61:\"core.entity_form_display.paragraph.ept_slideshow_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:4c160f87-d7c6-4dde-a9d2-878ce2336387',_binary 'a:1:{i:0;s:50:\"core.entity_form_display.media.audio.media_library\";}'),('config.entity.key_store.entity_form_display','uuid:4fadf498-bcbb-44d6-b829-6d1abdabf326',_binary 'a:1:{i:0;s:54:\"core.entity_form_display.paragraph.ept_columns.default\";}'),('config.entity.key_store.entity_form_display','uuid:5a1fd1b5-9098-41dc-99e7-65246d6fe6da',_binary 'a:1:{i:0;s:75:\"core.entity_form_display.paragraph.ept_video_and_image_gallery_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:5f9fd1ed-53a9-4349-8202-c90230a11f12',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_views.default\";}'),('config.entity.key_store.entity_form_display','uuid:62a89609-5a89-4eb4-a5a2-c3c58c93480d',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_quote.default\";}'),('config.entity.key_store.entity_form_display','uuid:6b2455af-c7c1-4faf-ae2f-5faf8b33c82d',_binary 'a:1:{i:0;s:59:\"core.entity_form_display.paragraph.ept_slick_slider.default\";}'),('config.entity.key_store.entity_form_display','uuid:6e0ad4c3-90f1-4e63-9ad2-e7c012a124d2',_binary 'a:1:{i:0;s:54:\"core.entity_form_display.paragraph.ept_counter.default\";}'),('config.entity.key_store.entity_form_display','uuid:7c5e18c3-3d08-4151-8d31-a9d9a597a5ee',_binary 'a:1:{i:0;s:44:\"core.entity_form_display.media.video.default\";}'),('config.entity.key_store.entity_form_display','uuid:8323a260-ffc2-4476-8123-c40c72552a6e',_binary 'a:1:{i:0;s:53:\"core.entity_form_display.media.document.media_library\";}'),('config.entity.key_store.entity_form_display','uuid:8a29f047-88c0-4af9-8cd2-705177201f7a',_binary 'a:1:{i:0;s:50:\"core.entity_form_display.paragraph.ept_cta.default\";}'),('config.entity.key_store.entity_form_display','uuid:8c95a60e-1c70-45a6-b8a2-c4d53b93ce5d',_binary 'a:1:{i:0;s:59:\"core.entity_form_display.paragraph.ept_counter_item.default\";}'),('config.entity.key_store.entity_form_display','uuid:8eb5837f-793f-476b-8d5b-8eb1ea190520',_binary 'a:1:{i:0;s:42:\"core.entity_form_display.user.user.default\";}'),('config.entity.key_store.entity_form_display','uuid:91fbcfb7-0a83-434f-99ac-c23c349657be',_binary 'a:1:{i:0;s:50:\"core.entity_form_display.media.image.media_library\";}'),('config.entity.key_store.entity_form_display','uuid:97a32351-c013-445a-af13-08939389c3b1',_binary 'a:1:{i:0;s:51:\"core.entity_form_display.media.remote_video.default\";}'),('config.entity.key_store.entity_form_display','uuid:a18df3e8-1c60-449a-81fb-3d8f4dc347dc',_binary 'a:1:{i:0;s:64:\"core.entity_form_display.paragraph.ept_accordion_section.default\";}'),('config.entity.key_store.entity_form_display','uuid:a5784c00-a16b-4f3b-91dd-568be1356d3a',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_tiles.default\";}'),('config.entity.key_store.entity_form_display','uuid:a60ae7a6-353d-412e-81ca-b8eff5eb6f78',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_image.default\";}'),('config.entity.key_store.entity_form_display','uuid:a9e1d9c8-64cb-4c33-ae6e-7c4617fa82d4',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_stats.default\";}'),('config.entity.key_store.entity_form_display','uuid:bcf372a8-c025-4ef1-bc1e-7467ead740ff',_binary 'a:1:{i:0;s:56:\"core.entity_form_display.paragraph.ept_accordion.default\";}'),('config.entity.key_store.entity_form_display','uuid:bd32a1a0-f63c-4e6b-b14f-7dfa6323a07a',_binary 'a:1:{i:0;s:60:\"core.entity_form_display.paragraph.ept_image_gallery.default\";}'),('config.entity.key_store.entity_form_display','uuid:be53fd67-518c-4b3c-ac43-3b2c15a8d954',_binary 'a:1:{i:0;s:51:\"core.entity_form_display.paragraph.ept_hero.default\";}'),('config.entity.key_store.entity_form_display','uuid:c0e1ca3f-d656-43c4-a362-86c7cb0ac490',_binary 'a:1:{i:0;s:57:\"core.entity_form_display.paragraph.ept_micromodal.default\";}'),('config.entity.key_store.entity_form_display','uuid:c24b87ec-64f6-4fa0-aed7-1c3d86160e5e',_binary 'a:1:{i:0;s:47:\"core.entity_form_display.media.document.default\";}'),('config.entity.key_store.entity_form_display','uuid:c6ec1d38-d434-4a7d-be65-080873fd0aff',_binary 'a:1:{i:0;s:42:\"core.entity_form_display.node.page.default\";}'),('config.entity.key_store.entity_form_display','uuid:de67467e-664b-4fd4-b096-f4f20912ea91',_binary 'a:1:{i:0;s:45:\"core.entity_form_display.node.article.default\";}'),('config.entity.key_store.entity_form_display','uuid:e1a6c8e5-95b1-4c04-8b08-798a42e3f990',_binary 'a:1:{i:0;s:51:\"core.entity_form_display.paragraph.ept_tabs.default\";}'),('config.entity.key_store.entity_form_display','uuid:ed55009f-a01e-42ae-987d-b5ccc04e073b',_binary 'a:1:{i:0;s:56:\"core.entity_form_display.paragraph.ept_countdown.default\";}'),('config.entity.key_store.entity_form_display','uuid:f08ad847-8b1c-4396-9081-ca9a56f6b01a',_binary 'a:1:{i:0;s:44:\"core.entity_form_display.media.image.default\";}'),('config.entity.key_store.entity_form_display','uuid:fe1a956f-1eb5-49f4-8ccd-d852faeeea9d',_binary 'a:1:{i:0;s:52:\"core.entity_form_display.paragraph.ept_video.default\";}'),('config.entity.key_store.entity_form_mode','uuid:94fd7791-9806-4755-a50f-91d35400a4cb',_binary 'a:1:{i:0;s:41:\"core.entity_form_mode.media.media_library\";}'),('config.entity.key_store.entity_form_mode','uuid:ef62034d-b624-4a32-9e4a-54a2baf7fa78',_binary 'a:1:{i:0;s:35:\"core.entity_form_mode.user.register\";}'),('config.entity.key_store.entity_view_display','uuid:077ee820-2041-4778-8135-0fc65cd20cb5',_binary 'a:1:{i:0;s:59:\"core.entity_view_display.paragraph.ept_counter_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:08b2118c-18b9-4669-b9e4-0786d49af6ef',_binary 'a:1:{i:0;s:56:\"core.entity_view_display.paragraph.ept_countdown.default\";}'),('config.entity.key_store.entity_view_display','uuid:0f767bd2-1919-4166-8346-62c5fc895c81',_binary 'a:1:{i:0;s:45:\"core.entity_view_display.node.article.default\";}'),('config.entity.key_store.entity_view_display','uuid:1053ac57-9af0-4e5b-ba2f-c5695c62ef08',_binary 'a:1:{i:0;s:50:\"core.entity_view_display.media.image.media_library\";}'),('config.entity.key_store.entity_view_display','uuid:113fc4a1-1a78-4da6-b222-3a4cd08a0def',_binary 'a:1:{i:0;s:56:\"core.entity_view_display.paragraph.ept_slideshow.default\";}'),('config.entity.key_store.entity_view_display','uuid:153a53c8-5121-4586-9a2d-42dbb61c9965',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_tiles.default\";}'),('config.entity.key_store.entity_view_display','uuid:19dfadc9-d9a4-4d4c-9953-240f406fe79c',_binary 'a:1:{i:0;s:44:\"core.entity_view_display.media.image.default\";}'),('config.entity.key_store.entity_view_display','uuid:1e04e293-6847-44fd-816b-d0cafeb9bfb1',_binary 'a:1:{i:0;s:57:\"core.entity_view_display.paragraph.ept_tiles_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:2727e08a-658f-4ab5-b47b-287082974eca',_binary 'a:1:{i:0;s:51:\"core.entity_view_display.paragraph.ept_hero.default\";}'),('config.entity.key_store.entity_view_display','uuid:273d4d81-bc41-43e6-bbfd-346c986e0c86',_binary 'a:1:{i:0;s:75:\"core.entity_view_display.paragraph.ept_video_and_image_gallery_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:2b90284a-5b66-4a1f-8feb-f7da7fba402f',_binary 'a:1:{i:0;s:57:\"core.entity_view_display.paragraph.ept_micromodal.default\";}'),('config.entity.key_store.entity_view_display','uuid:3027dd27-1f17-44e8-84f5-7366b5d87788',_binary 'a:1:{i:0;s:53:\"core.entity_view_display.media.document.media_library\";}'),('config.entity.key_store.entity_view_display','uuid:49052cac-09f9-471f-8cc0-d9c144baf2ff',_binary 'a:1:{i:0;s:60:\"core.entity_view_display.paragraph.ept_image_gallery.default\";}'),('config.entity.key_store.entity_view_display','uuid:4bf53171-20df-4e38-bb87-a451cfc4aa6c',_binary 'a:1:{i:0;s:50:\"core.entity_view_display.paragraph.ept_cta.default\";}'),('config.entity.key_store.entity_view_display','uuid:4c097cad-2585-405b-86e6-5effe6d6f443',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_video.default\";}'),('config.entity.key_store.entity_view_display','uuid:4f8ec3e2-1797-492f-8b2d-8ce7545d59bc',_binary 'a:1:{i:0;s:54:\"core.entity_view_display.media.image.ept_image_gallery\";}'),('config.entity.key_store.entity_view_display','uuid:51e43f2e-4f69-45a1-95c7-5ecf07778894',_binary 'a:1:{i:0;s:53:\"core.entity_view_display.media.remote_video.ept_video\";}'),('config.entity.key_store.entity_view_display','uuid:53a48e63-4272-4544-9051-7617915e3d41',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.block_content.basic.default\";}'),('config.entity.key_store.entity_view_display','uuid:5672ce5e-9fb4-4800-8c9d-3b15ca3f7fde',_binary 'a:1:{i:0;s:50:\"core.entity_view_display.media.video.media_library\";}'),('config.entity.key_store.entity_view_display','uuid:63fe648a-c5c1-42b9-8b04-7bb9db119166',_binary 'a:1:{i:0;s:44:\"core.entity_view_display.media.video.default\";}'),('config.entity.key_store.entity_view_display','uuid:72019611-98d6-4f86-81ec-768c71520e64',_binary 'a:1:{i:0;s:76:\"core.entity_view_display.media.remote_video.ept_video_and_image_gallery_item\";}'),('config.entity.key_store.entity_view_display','uuid:772993d5-eed2-4b18-a6f6-28eb39e116b4',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_quote.default\";}'),('config.entity.key_store.entity_view_display','uuid:7da9a817-79f8-4bec-add7-e39bb0ba78c4',_binary 'a:1:{i:0;s:51:\"core.entity_view_display.paragraph.ept_tabs.default\";}'),('config.entity.key_store.entity_view_display','uuid:83448cb5-91c5-4a34-a576-3ea914fa7d6b',_binary 'a:1:{i:0;s:54:\"core.entity_view_display.paragraph.ept_columns.default\";}'),('config.entity.key_store.entity_view_display','uuid:87bcc8b2-7f6c-4c74-800a-a87d1b94f5f4',_binary 'a:1:{i:0;s:44:\"core.entity_view_display.media.audio.default\";}'),('config.entity.key_store.entity_view_display','uuid:8e1a5df7-4ec6-40ba-b5be-4d5d2b6f489f',_binary 'a:1:{i:0;s:57:\"core.entity_view_display.paragraph.ept_stats_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:95f5dba7-e075-42d7-bb71-a987d5625124',_binary 'a:1:{i:0;s:60:\"core.entity_view_display.paragraph.ept_carousel_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:9ecc7509-3522-45c5-bda4-7ed77885a161',_binary 'a:1:{i:0;s:51:\"core.entity_view_display.media.remote_video.default\";}'),('config.entity.key_store.entity_view_display','uuid:a34b4adb-f67d-4569-90a5-e74b6a28bcdb',_binary 'a:1:{i:0;s:55:\"core.entity_view_display.paragraph.ept_carousel.default\";}'),('config.entity.key_store.entity_view_display','uuid:a5054ddd-1cf1-49bf-bb8f-790f40e08130',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_image.default\";}'),('config.entity.key_store.entity_view_display','uuid:a806c6af-6b6a-4398-a270-06147cb09d21',_binary 'a:1:{i:0;s:63:\"core.entity_view_display.paragraph.ept_bootstrap_button.default\";}'),('config.entity.key_store.entity_view_display','uuid:ad408e08-db1a-47df-8098-0b2a61f16481',_binary 'a:1:{i:0;s:54:\"core.entity_view_display.paragraph.ept_counter.default\";}'),('config.entity.key_store.entity_view_display','uuid:af3b0da5-5654-474f-b056-1b7fe53c1991',_binary 'a:1:{i:0;s:47:\"core.entity_view_display.media.document.default\";}'),('config.entity.key_store.entity_view_display','uuid:afa0542b-6646-4a58-8063-b778fe6b3423',_binary 'a:1:{i:0;s:42:\"core.entity_view_display.user.user.default\";}'),('config.entity.key_store.entity_view_display','uuid:b0bc3306-d88a-4581-af6c-2a1f29aac6ce',_binary 'a:1:{i:0;s:57:\"core.entity_view_display.media.remote_video.media_library\";}'),('config.entity.key_store.entity_view_display','uuid:b64bcaef-5bd0-446f-a6d5-7096df12851d',_binary 'a:1:{i:0;s:41:\"core.entity_view_display.node.page.teaser\";}'),('config.entity.key_store.entity_view_display','uuid:b696c09e-d916-4b49-a1c2-566c781bf923',_binary 'a:1:{i:0;s:44:\"core.entity_view_display.node.article.teaser\";}'),('config.entity.key_store.entity_view_display','uuid:b90a3de2-2933-49e5-8726-03f0e73085fa',_binary 'a:1:{i:0;s:56:\"core.entity_view_display.paragraph.ept_tabs_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:bad692de-34e5-483c-9717-c610a77e5be5',_binary 'a:1:{i:0;s:41:\"core.entity_view_display.node.article.rss\";}'),('config.entity.key_store.entity_view_display','uuid:bc183acd-cdee-4366-86c4-4db46beceef3',_binary 'a:1:{i:0;s:42:\"core.entity_view_display.node.page.default\";}'),('config.entity.key_store.entity_view_display','uuid:c452f408-f85b-4944-a31e-1bbef7fcda71',_binary 'a:1:{i:0;s:61:\"core.entity_view_display.paragraph.ept_slideshow_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:c47a77e8-55b1-49a2-adeb-dc69b79b24e0',_binary 'a:1:{i:0;s:69:\"core.entity_view_display.media.image.ept_video_and_image_gallery_item\";}'),('config.entity.key_store.entity_view_display','uuid:d0875a9d-cb50-4731-ac2a-fb25c1858dae',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_views.default\";}'),('config.entity.key_store.entity_view_display','uuid:d4e6aedc-c8f3-451b-94d6-cd44fc4b6c11',_binary 'a:1:{i:0;s:64:\"core.entity_view_display.paragraph.ept_accordion_section.default\";}'),('config.entity.key_store.entity_view_display','uuid:da002566-b092-4563-9d08-c4b5c52593e5',_binary 'a:1:{i:0;s:48:\"core.entity_view_display.comment.comment.default\";}'),('config.entity.key_store.entity_view_display','uuid:dfadbabc-626b-46a2-a063-3f65ad0c2b45',_binary 'a:1:{i:0;s:70:\"core.entity_view_display.paragraph.ept_video_and_image_gallery.default\";}'),('config.entity.key_store.entity_view_display','uuid:e06c8535-7973-44b5-8144-18baa167f488',_binary 'a:1:{i:0;s:51:\"core.entity_view_display.paragraph.ept_text.default\";}'),('config.entity.key_store.entity_view_display','uuid:e7417c73-82e0-49a6-b66c-942b3596d612',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_block.default\";}'),('config.entity.key_store.entity_view_display','uuid:e906e660-3e2c-436c-9fb5-1dc3aaa2d1a9',_binary 'a:1:{i:0;s:64:\"core.entity_view_display.paragraph.ept_slick_slider_item.default\";}'),('config.entity.key_store.entity_view_display','uuid:ec282fce-d81d-4383-9a77-3fb87be08553',_binary 'a:1:{i:0;s:52:\"core.entity_view_display.paragraph.ept_stats.default\";}'),('config.entity.key_store.entity_view_display','uuid:f4454fef-a659-4b88-9579-11ba22f32177',_binary 'a:1:{i:0;s:59:\"core.entity_view_display.paragraph.ept_basic_button.default\";}'),('config.entity.key_store.entity_view_display','uuid:f60b271e-f09b-45a9-8e92-1ae341b267f5',_binary 'a:1:{i:0;s:56:\"core.entity_view_display.paragraph.ept_accordion.default\";}'),('config.entity.key_store.entity_view_display','uuid:fa961609-f5ef-403a-8089-73f33b1e73f0',_binary 'a:1:{i:0;s:59:\"core.entity_view_display.paragraph.ept_carousel_item.slider\";}'),('config.entity.key_store.entity_view_display','uuid:fd378f17-2b7e-4025-89fa-c56cabc7bab2',_binary 'a:1:{i:0;s:42:\"core.entity_view_display.user.user.compact\";}'),('config.entity.key_store.entity_view_display','uuid:fd3c8ee0-7347-4825-a6ac-e712dc98946b',_binary 'a:1:{i:0;s:50:\"core.entity_view_display.media.audio.media_library\";}'),('config.entity.key_store.entity_view_display','uuid:febc7649-4ada-4466-aea7-1872bc394145',_binary 'a:1:{i:0;s:59:\"core.entity_view_display.paragraph.ept_slick_slider.default\";}'),('config.entity.key_store.entity_view_mode','uuid:18890f85-c8b4-4c37-a805-81e116c96c33',_binary 'a:1:{i:0;s:31:\"core.entity_view_mode.user.full\";}'),('config.entity.key_store.entity_view_mode','uuid:298a8e9e-ea9f-462a-9e62-03ff202ebda4',_binary 'a:1:{i:0;s:39:\"core.entity_view_mode.paragraph.preview\";}'),('config.entity.key_store.entity_view_mode','uuid:3096aebe-dabe-4849-b718-4be67ed1e0a2',_binary 'a:1:{i:0;s:31:\"core.entity_view_mode.node.full\";}'),('config.entity.key_store.entity_view_mode','uuid:3267d362-0cde-4190-8a4e-f368fdab39d5',_binary 'a:1:{i:0;s:34:\"core.entity_view_mode.user.compact\";}'),('config.entity.key_store.entity_view_mode','uuid:3e515c12-bfb7-4a38-9360-e1bebd522e14',_binary 'a:1:{i:0;s:40:\"core.entity_view_mode.block_content.full\";}'),('config.entity.key_store.entity_view_mode','uuid:4578cd26-ab79-41fc-b999-3224d7b96b78',_binary 'a:1:{i:0;s:41:\"core.entity_view_mode.media.media_library\";}'),('config.entity.key_store.entity_view_mode','uuid:562fdf9e-431f-4436-87cc-5edcb21506bf',_binary 'a:1:{i:0;s:30:\"core.entity_view_mode.node.rss\";}'),('config.entity.key_store.entity_view_mode','uuid:56447995-bbf0-4a46-b361-7337f6962da6',_binary 'a:1:{i:0;s:60:\"core.entity_view_mode.media.ept_video_and_image_gallery_item\";}'),('config.entity.key_store.entity_view_mode','uuid:5eb23a5d-001b-4f18-b772-c45ec412d4a1',_binary 'a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}'),('config.entity.key_store.entity_view_mode','uuid:8ae8b19f-547b-42bd-9d8f-a88c05759d47',_binary 'a:1:{i:0;s:37:\"core.entity_view_mode.media.ept_video\";}'),('config.entity.key_store.entity_view_mode','uuid:976815c3-f2f0-4a48-82b3-fb4ee2924c88',_binary 'a:1:{i:0;s:32:\"core.entity_view_mode.media.full\";}'),('config.entity.key_store.entity_view_mode','uuid:aaef918d-7b8e-4ea0-822a-44703c28e61c',_binary 'a:1:{i:0;s:34:\"core.entity_view_mode.comment.full\";}'),('config.entity.key_store.entity_view_mode','uuid:ac6b99d6-0ed0-46ea-97e8-2b17a00adab0',_binary 'a:1:{i:0;s:40:\"core.entity_view_mode.node.search_result\";}'),('config.entity.key_store.entity_view_mode','uuid:c1d7c975-f7cc-4e65-a0b5-d7a0b84e6fed',_binary 'a:1:{i:0;s:40:\"core.entity_view_mode.taxonomy_term.full\";}'),('config.entity.key_store.entity_view_mode','uuid:c2742453-7e21-4da9-b647-07ef5aca9cf3',_binary 'a:1:{i:0;s:45:\"core.entity_view_mode.media.ept_image_gallery\";}'),('config.entity.key_store.entity_view_mode','uuid:edab19fa-a328-4f2e-a4a2-bce49808300d',_binary 'a:1:{i:0;s:39:\"core.entity_view_mode.node.search_index\";}'),('config.entity.key_store.entity_view_mode','uuid:f0967983-7199-4bf7-8047-72fb6a840ca0',_binary 'a:1:{i:0;s:38:\"core.entity_view_mode.paragraph.slider\";}'),('config.entity.key_store.field_config','uuid:00840cc4-7392-4663-a414-47758f14db31',_binary 'a:1:{i:0;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_title_prefix\";}'),('config.entity.key_store.field_config','uuid:0369fd76-8a03-4f51-98c8-2662289d77b1',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_basic_button.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:04f2459a-8250-49b8-9c26-a1bc5f23b1ce',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_slideshow.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:0570de2b-d581-4073-a8b0-0729eacf75eb',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_slick_slider.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:0a76e0e6-37a2-4e5e-a2ca-41101da17e1e',_binary 'a:1:{i:0;s:51:\"field.field.paragraph.ept_slideshow.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:0b1a6314-b982-4d68-89cc-0362ac441239',_binary 'a:1:{i:0;s:46:\"field.field.media.video.field_media_video_file\";}'),('config.entity.key_store.field_config','uuid:0c7eb82c-6093-4901-bd0b-fd48f6eedcb2',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_title\";}'),('config.entity.key_store.field_config','uuid:0cd4c4a7-feca-4fb7-9e8b-02984559941b',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_views.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:0d3eae73-ae6d-4601-b1d4-4df1d7d62c53',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_views.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:0f3cce54-16b4-433a-a3d8-f66dceadfb5e',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_carousel.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:1003b7da-189c-4687-89e9-fe627bd2f746',_binary 'a:1:{i:0;s:63:\"field.field.paragraph.ept_micromodal.field_ept_micromodal_title\";}'),('config.entity.key_store.field_config','uuid:123bb9be-f4f0-4e79-9c1f-5a74d1adc56a',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_image.field_ept_image\";}'),('config.entity.key_store.field_config','uuid:15235fd9-9fad-4092-b19c-8e011debebfb',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_page\";}'),('config.entity.key_store.field_config','uuid:153fe814-ed15-45dd-ac36-e3166140cf03',_binary 'a:1:{i:0;s:52:\"field.field.paragraph.ept_counter.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:1b1a1524-2e19-47c4-af5c-c693044a59e0',_binary 'a:1:{i:0;s:72:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_image\";}'),('config.entity.key_store.field_config','uuid:1c882037-c7e3-42e4-9707-af10c5015ef2',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_stats.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:254d23bc-cd9a-4186-b124-2f3fa923fc05',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_tiles.field_ept_tiles\";}'),('config.entity.key_store.field_config','uuid:27323f57-acfd-4aff-a508-544c6c8bdf3d',_binary 'a:1:{i:0;s:34:\"field.field.user.user.user_picture\";}'),('config.entity.key_store.field_config','uuid:28952958-350e-4fa8-b1bf-0526c52b982e',_binary 'a:1:{i:0;s:74:\"field.field.paragraph.ept_bootstrap_button.field_ept_bootstrap_button_link\";}'),('config.entity.key_store.field_config','uuid:29c56f04-456b-4f6f-87b5-6352ddaa6a51',_binary 'a:1:{i:0;s:61:\"field.field.paragraph.ept_tiles_item.field_ept_clickable_tile\";}'),('config.entity.key_store.field_config','uuid:2bdd8485-4125-400d-b6ef-feffe57ca0b6',_binary 'a:1:{i:0;s:65:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:2d995ad8-7b72-4241-8c5b-bfb64c7a936a',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_block.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:2ea8eb6b-de2b-4de9-ac7c-5703ce8bc44f',_binary 'a:1:{i:0;s:40:\"field.field.comment.comment.comment_body\";}'),('config.entity.key_store.field_config','uuid:2eb61b2c-ee83-43b2-beb6-334f5562bc8c',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_cta.field_ept_cta_second_link\";}'),('config.entity.key_store.field_config','uuid:36557cf2-e64e-4835-ad8e-b5bbc8150e8e',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_countdown.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:38a67ca0-85d7-4dee-8871-eef6909b89f3',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_accordion.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:3988d015-d4a9-4560-9665-3defb0bfead9',_binary 'a:1:{i:0;s:49:\"field.field.paragraph.ept_columns.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:3b694b0c-21b1-40f1-aab1-5f8f6b508006',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_tabs.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:3d160c57-3e25-403d-8a51-0a0b3397f5eb',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_image_gallery.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:3f86759a-0926-49a9-a1b3-ebe22666f4d8',_binary 'a:1:{i:0;s:68:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_text\";}'),('config.entity.key_store.field_config','uuid:40656cb2-323c-4502-b916-5613d935c06a',_binary 'a:1:{i:0;s:56:\"field.field.paragraph.ept_cta.field_ept_cta_column_image\";}'),('config.entity.key_store.field_config','uuid:406dd338-600c-4eb2-841a-df635188cfb3',_binary 'a:1:{i:0;s:45:\"field.field.paragraph.ept_text.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:410f42b6-e143-4eb8-9c88-c13fd9c4c17f',_binary 'a:1:{i:0;s:41:\"field.field.media.image.field_media_image\";}'),('config.entity.key_store.field_config','uuid:440982f1-1d49-45ce-856f-cb3b95954c65',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_block.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:44deba9e-6935-4553-9ef0-ecc889381ae8',_binary 'a:1:{i:0;s:49:\"field.field.paragraph.ept_counter.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:484e5ed3-f463-4d7b-b27a-25b553c3a82b',_binary 'a:1:{i:0;s:53:\"field.field.paragraph.ept_basic_button.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:48e0dea0-fc4d-4a86-8ed4-203f0efe3a52',_binary 'a:1:{i:0;s:63:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_image\";}'),('config.entity.key_store.field_config','uuid:4bad9ad2-5f7d-40ee-92a6-547badbee525',_binary 'a:1:{i:0;s:53:\"field.field.paragraph.ept_slick_slider.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:4be87c8b-a691-4546-9b46-8104a7920252',_binary 'a:1:{i:0;s:64:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_number\";}'),('config.entity.key_store.field_config','uuid:4ed02114-671f-4880-bd68-143fe1b70c33',_binary 'a:1:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";}'),('config.entity.key_store.field_config','uuid:51db6984-7e76-4d6a-be3b-8f052f3bae29',_binary 'a:1:{i:0;s:60:\"field.field.paragraph.ept_countdown.field_ept_countdown_date\";}'),('config.entity.key_store.field_config','uuid:532449b1-8d51-4c87-ad35-6a4555565967',_binary 'a:1:{i:0;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_text\";}'),('config.entity.key_store.field_config','uuid:53805c44-6771-4268-b091-a3f4f1269139',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_counter.field_ept_counter_items\";}'),('config.entity.key_store.field_config','uuid:5c1e6fab-0fe9-4952-a3c8-991a0f293a80',_binary 'a:1:{i:0;s:64:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:5d8d9518-713c-4c54-a1b1-e9255a1064cf',_binary 'a:1:{i:0;s:45:\"field.field.paragraph.ept_tabs.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:5dcc6a7e-0a0a-4b27-8ec1-fc41c3bb654a',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_hero.field_ept_hero_link\";}'),('config.entity.key_store.field_config','uuid:5fbf0b1d-881b-44e3-9225-31e307913827',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_video.field_ept_video\";}'),('config.entity.key_store.field_config','uuid:5fd2a01d-4924-4824-af89-5638dcb01e07',_binary 'a:1:{i:0;s:69:\"field.field.paragraph.ept_accordion_section.field_ept_accordion_title\";}'),('config.entity.key_store.field_config','uuid:60166fc5-cd70-42a2-ab4a-021bef6afcf3',_binary 'a:1:{i:0;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_title\";}'),('config.entity.key_store.field_config','uuid:64183760-d4b4-4088-905f-cc5481b32e41',_binary 'a:1:{i:0;s:38:\"field.field.node.page.field_components\";}'),('config.entity.key_store.field_config','uuid:6483f62f-11d2-44ea-bf5b-d0db486d3689',_binary 'a:1:{i:0;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_slide\";}'),('config.entity.key_store.field_config','uuid:64aa7603-d2f0-4050-a82f-35b5ef3b978f',_binary 'a:1:{i:0;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_link\";}'),('config.entity.key_store.field_config','uuid:65e27c50-82c3-46dd-ad6d-c95805dd83bf',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_video.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:6671231f-f98f-4ea0-a6ab-9bfe42290292',_binary 'a:1:{i:0;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_link\";}'),('config.entity.key_store.field_config','uuid:68fe7948-f81f-4f36-8ce6-3a736d2696be',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_video.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:6902be14-683f-4f5a-8d50-8543bbf0aca5',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_text.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:6c45f2f3-d271-4c13-b678-675fb9cbc261',_binary 'a:1:{i:0;s:36:\"field.field.node.article.field_image\";}'),('config.entity.key_store.field_config','uuid:6d566515-d2a4-4ce3-96e1-678ae2feea9c',_binary 'a:1:{i:0;s:71:\"field.field.paragraph.ept_slick_slider_item.field_ept_slick_slider_link\";}'),('config.entity.key_store.field_config','uuid:71eb6510-d311-4704-9d7a-147c6ba1fca0',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_accordion.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:720ab2af-faa7-4459-84ec-84810093337c',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_image.field_ept_image_caption\";}'),('config.entity.key_store.field_config','uuid:77a71623-7050-467d-bbb6-f7e2b8e10f9d',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_link\";}'),('config.entity.key_store.field_config','uuid:77e74bf9-008e-4d96-9381-dc809ff7b841',_binary 'a:1:{i:0;s:52:\"field.field.paragraph.ept_columns.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:7a06dca5-73c0-4c47-a217-2f9d7f3b9d43',_binary 'a:1:{i:0;s:48:\"field.field.paragraph.ept_cta.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:7ab22f13-220c-400f-9f56-3043d91300ed',_binary 'a:1:{i:0;s:62:\"field.field.paragraph.ept_stats_item.field_ept_stats_item_text\";}'),('config.entity.key_store.field_config','uuid:7f39ca00-ae38-46ac-a2f2-ce0b4f545f9f',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_tiles.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:819b216b-97f6-4f18-82b6-2074094a280f',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_quote.field_ept_quote_author\";}'),('config.entity.key_store.field_config','uuid:84658343-fa44-4fe9-acaa-5c0c2ff5f1d0',_binary 'a:1:{i:0;s:58:\"field.field.paragraph.ept_image_gallery.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:84bea7b4-b9e4-4cf4-8ec9-389dd6b02c10',_binary 'a:1:{i:0;s:66:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_title\";}'),('config.entity.key_store.field_config','uuid:8a07cecc-6fab-4d81-8cda-096df1dc73ab',_binary 'a:1:{i:0;s:64:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_image\";}'),('config.entity.key_store.field_config','uuid:8b147c97-e78e-4773-a7dd-fbdd3db585a6',_binary 'a:1:{i:0;s:68:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:8bd0ca98-8e9c-4dba-b1cf-ae98a043504f',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_tabs_item.field_ept_tab_content\";}'),('config.entity.key_store.field_config','uuid:8e45972c-1dc7-444f-9475-a98aa5a83a12',_binary 'a:1:{i:0;s:77:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item\";}'),('config.entity.key_store.field_config','uuid:8fecb003-ae49-44e1-ac0e-aeaebabeca06',_binary 'a:1:{i:0;s:36:\"field.field.block_content.basic.body\";}'),('config.entity.key_store.field_config','uuid:90b23d65-43c8-4f09-8924-c0be432e4510',_binary 'a:1:{i:0;s:47:\"field.field.media.document.field_media_document\";}'),('config.entity.key_store.field_config','uuid:929dd04a-655a-436e-b9ec-8b400a26f596',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_slideshow.field_ept_slideshow\";}'),('config.entity.key_store.field_config','uuid:9302769a-011f-4ea8-8a1a-82c6399fc628',_binary 'a:1:{i:0;s:82:\"field.field.paragraph.ept_video_and_image_gallery_item.field_ept_gallery_item_text\";}'),('config.entity.key_store.field_config','uuid:93b358ac-f703-4792-a4cb-65cb87eb34aa',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_hero.field_ept_hero_second_link\";}'),('config.entity.key_store.field_config','uuid:94fe1479-276a-47c8-a255-ba6fdb6b874f',_binary 'a:1:{i:0;s:61:\"field.field.paragraph.ept_counter_item.field_ept_counter_icon\";}'),('config.entity.key_store.field_config','uuid:9610a78c-d4d5-4d29-9221-2b862f3b5c9d',_binary 'a:1:{i:0;s:49:\"field.field.paragraph.ept_hero.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:97adadda-941e-43f5-8c16-c2a84adbb6a6',_binary 'a:1:{i:0;s:61:\"field.field.paragraph.ept_bootstrap_button.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:9857343f-763e-4b29-8143-ec3fb9d9963d',_binary 'a:1:{i:0;s:63:\"field.field.paragraph.ept_counter_item.field_ept_counter_number\";}'),('config.entity.key_store.field_config','uuid:9905b685-324b-4f6a-8423-5973b3364a40',_binary 'a:1:{i:0;s:53:\"field.field.paragraph.ept_carousel.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:991df58b-c253-4036-a94c-16bf928672f2',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_countdown.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:99ba3548-2963-43fc-9439-5c4981283ee3',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_image.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:9bf7105c-9c7f-493b-b93c-2ee846a91521',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_slick_slider.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:9cd49d18-67b3-4776-ba0b-dda42289ac3c',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_hero.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:9d669ec1-badd-49d6-82c8-4a8eba8ca7da',_binary 'a:1:{i:0;s:62:\"field.field.paragraph.ept_counter_item.field_ept_counter_title\";}'),('config.entity.key_store.field_config','uuid:9d80d485-b1e2-4fbf-ad86-60acbbdd3d92',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_bootstrap_button.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:9e49c287-a8e3-4673-b781-6db3e163c7f1',_binary 'a:1:{i:0;s:53:\"field.field.paragraph.ept_block.field_ept_block_block\";}'),('config.entity.key_store.field_config','uuid:a054c663-7358-4e24-99c7-7caa63091265',_binary 'a:1:{i:0;s:44:\"field.field.paragraph.ept_cta.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:a059a1dc-b8c7-41a3-a0ba-57ef2b7c3ef2',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_tabs_item.field_ept_tab_text\";}'),('config.entity.key_store.field_config','uuid:a08772a7-ac82-466b-918c-b39c7f16c309',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_quote.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:a4f2e656-d59b-4df7-833b-709b38ab9360',_binary 'a:1:{i:0;s:48:\"field.field.paragraph.ept_cta.field_ept_cta_link\";}'),('config.entity.key_store.field_config','uuid:a6969ae3-e3c4-4adf-b115-07a5a0172b95',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_accordion.field_ept_accordion\";}'),('config.entity.key_store.field_config','uuid:a8fb2e31-9a7a-45bb-84f7-84bce2a8e256',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_stats.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:a96f802e-f6f6-415b-a00b-47d8e483f3c2',_binary 'a:1:{i:0;s:57:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_text\";}'),('config.entity.key_store.field_config','uuid:a98491aa-0091-4a36-af08-7e4f9e2a3554',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_slideshow.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:ac698185-3f8a-4519-a9b7-29609da24892',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_tiles.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:ac9343a5-d157-4641-93f9-1b5bd7d0980f',_binary 'a:1:{i:0;s:29:\"field.field.node.article.body\";}'),('config.entity.key_store.field_config','uuid:ad867234-0316-48d0-bba3-4dcafd6d6091',_binary 'a:1:{i:0;s:68:\"field.field.paragraph.ept_counter_item.field_ept_counter_description\";}'),('config.entity.key_store.field_config','uuid:ad96e4c6-579a-4465-ba2d-117890a7bff3',_binary 'a:1:{i:0;s:65:\"field.field.paragraph.ept_slideshow_item.field_ept_slideshow_text\";}'),('config.entity.key_store.field_config','uuid:ae2f7f13-51c7-4ea2-99c7-c5b6b22f7360',_binary 'a:1:{i:0;s:51:\"field.field.paragraph.ept_countdown.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:af24502d-ca80-4229-bc11-8b9d175d53f2',_binary 'a:1:{i:0;s:58:\"field.field.paragraph.ept_tiles_item.field_ept_tiles_image\";}'),('config.entity.key_store.field_config','uuid:b25f97c8-ef2e-408c-b977-6254d1414afe',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_image.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:b40d62dd-ee5a-44cf-9983-6bbbd7667b68',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_block.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:b46ea217-84f7-4321-912a-7446b534bb92',_binary 'a:1:{i:0;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_column_image\";}'),('config.entity.key_store.field_config','uuid:b4f633fb-12be-4793-b294-21badb491880',_binary 'a:1:{i:0;s:48:\"field.field.paragraph.ept_counter.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:b6314b7b-d04b-4c21-b388-edad4a320f8e',_binary 'a:1:{i:0;s:52:\"field.field.paragraph.ept_micromodal.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:bbd8f0a6-7c0d-47e5-a62d-a2c5aed60232',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_image_gallery.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:bcee11b6-9de3-4ea7-ab28-783aaf52a980',_binary 'a:1:{i:0;s:49:\"field.field.paragraph.ept_tabs.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:c3236ac3-dc6f-4f78-9199-3450f0c1f3b9',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_micromodal.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:c3f52d5a-54bd-4606-8b04-4a6c1e456a0b',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_block\";}'),('config.entity.key_store.field_config','uuid:c440db95-46b7-4316-8502-e20c900704c5',_binary 'a:1:{i:0;s:61:\"field.field.paragraph.ept_slick_slider.field_ept_slick_slider\";}'),('config.entity.key_store.field_config','uuid:c4e09c22-0835-4bec-a402-756220f2e9f7',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_quote.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:c7106e91-0b1d-44f0-82fc-584be35a29c2',_binary 'a:1:{i:0;s:26:\"field.field.node.page.body\";}'),('config.entity.key_store.field_config','uuid:c9626d4b-c719-4c6c-bc96-f92de310cf2e',_binary 'a:1:{i:0;s:58:\"field.field.paragraph.ept_bootstrap_button.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:c9a94fcc-b813-47ed-9b68-5780ad0e270c',_binary 'a:1:{i:0;s:77:\"field.field.paragraph.ept_video_and_image_gallery.field_ept_videos_and_images\";}'),('config.entity.key_store.field_config','uuid:cccc3ad2-8bd3-4a0b-8777-2510ebee041b',_binary 'a:1:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";}'),('config.entity.key_store.field_config','uuid:cfaf7cc4-f386-4397-8876-cdcee33b93b6',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_stats.field_ept_stats\";}'),('config.entity.key_store.field_config','uuid:d3dcae7f-9494-4866-b051-d4817b208fd5',_binary 'a:1:{i:0;s:35:\"field.field.node.article.field_tags\";}'),('config.entity.key_store.field_config','uuid:d5f47d43-c851-4f4d-a9bf-282937a2eb88',_binary 'a:1:{i:0;s:54:\"field.field.paragraph.ept_basic_button.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:d7d805e1-ee4a-4aeb-87d9-e74edbe4f1e7',_binary 'a:1:{i:0;s:53:\"field.field.paragraph.ept_carousel.field_ept_carousel\";}'),('config.entity.key_store.field_config','uuid:d95cc73b-b5b3-45bb-ab62-c70e8411b8e9',_binary 'a:1:{i:0;s:66:\"field.field.paragraph.ept_basic_button.field_ept_basic_button_link\";}'),('config.entity.key_store.field_config','uuid:dd24c6a8-a5d2-434a-90d0-3a97c829c794',_binary 'a:1:{i:0;s:49:\"field.field.paragraph.ept_text.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:de00022b-0652-4a4f-a13f-6d001b19f4c0',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_video.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:dfb637af-23af-4aa3-8753-1c3c1b41f2a4',_binary 'a:1:{i:0;s:63:\"field.field.paragraph.ept_image_gallery.field_ept_image_gallery\";}'),('config.entity.key_store.field_config','uuid:e3f4b834-b3d2-43cf-8914-8378ae9e9f82',_binary 'a:1:{i:0;s:51:\"field.field.paragraph.ept_columns.field_ept_columns\";}'),('config.entity.key_store.field_config','uuid:e46eefbb-e77e-4dbb-b856-37283bfcbcf6',_binary 'a:1:{i:0;s:52:\"field.field.paragraph.ept_image.field_ept_image_link\";}'),('config.entity.key_store.field_config','uuid:e61c2ef3-bfa8-4a34-aa69-9a530904c063',_binary 'a:1:{i:0;s:49:\"field.field.paragraph.ept_carousel.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:e6f7cd85-741e-4d86-ae78-2eabee82b952',_binary 'a:1:{i:0;s:45:\"field.field.paragraph.ept_cta.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:eda0ee86-a9c6-40a3-90a6-52025f859080',_binary 'a:1:{i:0;s:45:\"field.field.paragraph.ept_hero.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:ee4ec7f5-67b4-42d7-baf2-7aaee393847f',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_image.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:ef74c15e-0e9f-4f8c-82b1-f7cec4763c50',_binary 'a:1:{i:0;s:52:\"field.field.paragraph.ept_views.field_ept_views_view\";}'),('config.entity.key_store.field_config','uuid:efadba67-9ef3-474a-8246-0e5a51d74660',_binary 'a:1:{i:0;s:47:\"field.field.paragraph.ept_tiles.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:efd74810-b803-4db6-b891-9ea3905eb31d',_binary 'a:1:{i:0;s:55:\"field.field.paragraph.ept_tabs_item.field_ept_tab_views\";}'),('config.entity.key_store.field_config','uuid:f00824ef-dc9b-4ba7-81ad-8e7910f662a6',_binary 'a:1:{i:0;s:50:\"field.field.paragraph.ept_stats.field_ept_settings\";}'),('config.entity.key_store.field_config','uuid:f1e8eab0-49cf-40c1-a0c3-1c7c52bbcf18',_binary 'a:1:{i:0;s:66:\"field.field.paragraph.ept_carousel_item.field_ept_carousel_caption\";}'),('config.entity.key_store.field_config','uuid:f3ed6271-02a1-49ae-87a5-dcbb0788200c',_binary 'a:1:{i:0;s:45:\"field.field.paragraph.ept_tabs.field_ept_tabs\";}'),('config.entity.key_store.field_config','uuid:f701ef4d-7de9-46b4-88f4-6995981e11ce',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_quote.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:f9453349-a4b8-4f21-ad48-735cb6bb9eca',_binary 'a:1:{i:0;s:51:\"field.field.paragraph.ept_micromodal.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:f9935753-c052-4b7b-b23a-a14f2748a834',_binary 'a:1:{i:0;s:48:\"field.field.paragraph.ept_columns.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:f9ef68e5-ed23-45fb-a5d1-bac433eeb379',_binary 'a:1:{i:0;s:46:\"field.field.paragraph.ept_views.field_ept_text\";}'),('config.entity.key_store.field_config','uuid:fa75defe-e7d5-4782-bedf-3d3107b3a40f',_binary 'a:1:{i:0;s:51:\"field.field.paragraph.ept_accordion.field_ept_title\";}'),('config.entity.key_store.field_config','uuid:fe2fb5d1-bcf8-4e29-9e00-d600aab8954a',_binary 'a:1:{i:0;s:53:\"field.field.paragraph.ept_quote.field_ept_quote_image\";}'),('config.entity.key_store.field_storage_config','uuid:012f2184-9082-4983-9239-7dac48864d9c',_binary 'a:1:{i:0;s:49:\"field.storage.paragraph.field_ept_accordion_title\";}'),('config.entity.key_store.field_storage_config','uuid:0210aa9b-f809-485d-9dc9-01d5b19a7a97',_binary 'a:1:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_views\";}'),('config.entity.key_store.field_storage_config','uuid:05e5fd5b-7ad6-434e-99a8-8635a8fa97cc',_binary 'a:1:{i:0;s:32:\"field.storage.block_content.body\";}'),('config.entity.key_store.field_storage_config','uuid:072a57f4-9c76-4a9a-a3f4-f13ef03b81be',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_counter_number\";}'),('config.entity.key_store.field_storage_config','uuid:08a96db8-eb88-4875-8250-d218a934e839',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_slideshow_link\";}'),('config.entity.key_store.field_storage_config','uuid:095f6e1d-c38c-4e36-824d-929e502f2c16',_binary 'a:1:{i:0;s:44:\"field.storage.paragraph.field_ept_tiles_text\";}'),('config.entity.key_store.field_storage_config','uuid:0bd5b0b1-4d3b-472e-ac51-086416f9360a',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_hero_column_image\";}'),('config.entity.key_store.field_storage_config','uuid:1295648c-a917-438e-a846-fd85d14ae8a0',_binary 'a:1:{i:0;s:42:\"field.storage.media.field_media_audio_file\";}'),('config.entity.key_store.field_storage_config','uuid:14901660-c7de-459b-8e6b-6065e1894829',_binary 'a:1:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_block\";}'),('config.entity.key_store.field_storage_config','uuid:1567fe07-a329-492a-bc5f-d82e3865bd57',_binary 'a:1:{i:0;s:42:\"field.storage.media.field_media_video_file\";}'),('config.entity.key_store.field_storage_config','uuid:177e4cd0-bbd1-44cd-9d3f-5b5dd4378ed4',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_accordion_text\";}'),('config.entity.key_store.field_storage_config','uuid:1a9f268a-efba-464e-854e-f46e7e1341e9',_binary 'a:1:{i:0;s:43:\"field.storage.paragraph.field_ept_slideshow\";}'),('config.entity.key_store.field_storage_config','uuid:1da3ad04-a3d6-45a2-8a2e-100f0d629948',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_carousel_image\";}'),('config.entity.key_store.field_storage_config','uuid:233edf85-6a6a-473c-933a-1a6a9015993a',_binary 'a:1:{i:0;s:31:\"field.storage.user.user_picture\";}'),('config.entity.key_store.field_storage_config','uuid:2545ccb9-b7f9-49f1-a002-1aa70a099849',_binary 'a:1:{i:0;s:50:\"field.storage.paragraph.field_ept_cta_column_image\";}'),('config.entity.key_store.field_storage_config','uuid:26a81385-82de-46f0-8582-8c93b0fbcb01',_binary 'a:1:{i:0;s:23:\"field.storage.node.body\";}'),('config.entity.key_store.field_storage_config','uuid:30383ff9-015d-4872-a3cb-3c814a4683f6',_binary 'a:1:{i:0;s:39:\"field.storage.paragraph.field_ept_video\";}'),('config.entity.key_store.field_storage_config','uuid:32ff7444-1fb2-4c29-97a3-9e9f53ec491a',_binary 'a:1:{i:0;s:50:\"field.storage.paragraph.field_ept_stats_item_image\";}'),('config.entity.key_store.field_storage_config','uuid:360bef36-b4f7-492b-9677-6170eebdf2bb',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_basic_button_link\";}'),('config.entity.key_store.field_storage_config','uuid:385056ad-483b-468c-8fc7-fa477f32138c',_binary 'a:1:{i:0;s:53:\"field.storage.paragraph.field_ept_counter_description\";}'),('config.entity.key_store.field_storage_config','uuid:389f5e03-e7e9-4fb0-bdb5-618f4ada2579',_binary 'a:1:{i:0;s:44:\"field.storage.paragraph.field_ept_image_link\";}'),('config.entity.key_store.field_storage_config','uuid:39b9627d-fdb9-4ed9-afc4-0c4d133a92c6',_binary 'a:1:{i:0;s:45:\"field.storage.paragraph.field_ept_quote_image\";}'),('config.entity.key_store.field_storage_config','uuid:3adc57b0-490d-4760-8c68-b19c339fedb5',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_slick_slider_link\";}'),('config.entity.key_store.field_storage_config','uuid:467150cb-7feb-412a-9426-4b2a3f4a1caa',_binary 'a:1:{i:0;s:46:\"field.storage.paragraph.field_ept_slick_slider\";}'),('config.entity.key_store.field_storage_config','uuid:48fc10e7-9c7a-4b33-8f60-3ce608c713c5',_binary 'a:1:{i:0;s:49:\"field.storage.paragraph.field_ept_stats_item_link\";}'),('config.entity.key_store.field_storage_config','uuid:4a613783-5795-48bc-bd8e-e3fe3a00ea51',_binary 'a:1:{i:0;s:34:\"field.storage.comment.comment_body\";}'),('config.entity.key_store.field_storage_config','uuid:4bdff313-152c-4ea9-ba49-6f433c48203a',_binary 'a:1:{i:0;s:50:\"field.storage.paragraph.field_ept_carousel_caption\";}'),('config.entity.key_store.field_storage_config','uuid:54f29aab-0b38-45f1-bef4-33ea7848198c',_binary 'a:1:{i:0;s:39:\"field.storage.paragraph.field_ept_stats\";}'),('config.entity.key_store.field_storage_config','uuid:5741fa83-8e57-4e60-99ce-6e8bd5bf8b78',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_countdown_date\";}'),('config.entity.key_store.field_storage_config','uuid:58a0c8d3-2aaa-43a3-af29-df451a7410e3',_binary 'a:1:{i:0;s:50:\"field.storage.paragraph.field_ept_micromodal_title\";}'),('config.entity.key_store.field_storage_config','uuid:58c5cc3e-9949-4686-882a-a56b59c60ea8',_binary 'a:1:{i:0;s:45:\"field.storage.paragraph.field_ept_block_block\";}'),('config.entity.key_store.field_storage_config','uuid:62135f80-efc0-4ec3-883a-ce4ccfe66aaa',_binary 'a:1:{i:0;s:44:\"field.storage.paragraph.field_ept_tiles_link\";}'),('config.entity.key_store.field_storage_config','uuid:6b41e063-a182-4108-9b56-c0f4bb265180',_binary 'a:1:{i:0;s:40:\"field.storage.media.field_media_document\";}'),('config.entity.key_store.field_storage_config','uuid:7518ddce-1000-4e47-8c93-f8230ca40081',_binary 'a:1:{i:0;s:41:\"field.storage.paragraph.field_ept_columns\";}'),('config.entity.key_store.field_storage_config','uuid:75781815-4f60-47eb-bdc4-255e273d1add',_binary 'a:1:{i:0;s:43:\"field.storage.paragraph.field_ept_tab_title\";}'),('config.entity.key_store.field_storage_config','uuid:776f5eb1-0740-473f-b278-4678ab1e0a4e',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_clickable_tile\";}'),('config.entity.key_store.field_storage_config','uuid:79fcf2b8-c7f0-45ad-b0c1-f2032eef3896',_binary 'a:1:{i:0;s:38:\"field.storage.paragraph.field_ept_tabs\";}'),('config.entity.key_store.field_storage_config','uuid:7baebb7a-a11d-4ca3-803c-81356e567dc2',_binary 'a:1:{i:0;s:35:\"field.storage.node.field_components\";}'),('config.entity.key_store.field_storage_config','uuid:81f6ea79-133f-4e53-bb0a-4169a69c4472',_binary 'a:1:{i:0;s:29:\"field.storage.node.field_tags\";}'),('config.entity.key_store.field_storage_config','uuid:843571d5-1f13-41be-91d6-4a2cdc24036d',_binary 'a:1:{i:0;s:42:\"field.storage.paragraph.field_ept_tab_text\";}'),('config.entity.key_store.field_storage_config','uuid:8622c9ec-6687-4349-af19-885f22d99285',_binary 'a:1:{i:0;s:44:\"field.storage.paragraph.field_ept_views_view\";}'),('config.entity.key_store.field_storage_config','uuid:87c56ad4-62d6-4644-86c1-680e4755ff8b',_binary 'a:1:{i:0;s:45:\"field.storage.paragraph.field_ept_tab_content\";}'),('config.entity.key_store.field_storage_config','uuid:89e38776-3ba0-4f79-9023-af5e40b20171',_binary 'a:1:{i:0;s:43:\"field.storage.paragraph.field_ept_hero_link\";}'),('config.entity.key_store.field_storage_config','uuid:8f6db9bb-d214-4b8e-a41e-8e68af02013e',_binary 'a:1:{i:0;s:48:\"field.storage.paragraph.field_ept_slideshow_text\";}'),('config.entity.key_store.field_storage_config','uuid:9bab1d24-d574-48e2-8d0e-4ab68fb47d98',_binary 'a:1:{i:0;s:49:\"field.storage.paragraph.field_ept_stats_item_text\";}'),('config.entity.key_store.field_storage_config','uuid:a1361495-0a6d-4f18-8570-b713e198ddf3',_binary 'a:1:{i:0;s:46:\"field.storage.paragraph.field_ept_gallery_item\";}'),('config.entity.key_store.field_storage_config','uuid:a21fa265-c368-46f8-b0bf-ccd4251290bf',_binary 'a:1:{i:0;s:45:\"field.storage.paragraph.field_ept_tiles_title\";}'),('config.entity.key_store.field_storage_config','uuid:a25a51c6-fb73-441d-bfe4-baf60db380f2',_binary 'a:1:{i:0;s:47:\"field.storage.paragraph.field_ept_image_gallery\";}'),('config.entity.key_store.field_storage_config','uuid:a3a4414c-7488-42d9-ad4e-706dbb16b1da',_binary 'a:1:{i:0;s:39:\"field.storage.paragraph.field_ept_image\";}'),('config.entity.key_store.field_storage_config','uuid:a51e7805-3dcf-415a-b08c-6e41b660115d',_binary 'a:1:{i:0;s:50:\"field.storage.paragraph.field_ept_hero_second_link\";}'),('config.entity.key_store.field_storage_config','uuid:a62c9e27-ad8b-430d-85ce-9db276ada8eb',_binary 'a:1:{i:0;s:47:\"field.storage.paragraph.field_ept_counter_title\";}'),('config.entity.key_store.field_storage_config','uuid:ad3c2c1b-78c7-400a-a114-8f5a64daf409',_binary 'a:1:{i:0;s:39:\"field.storage.paragraph.field_ept_tiles\";}'),('config.entity.key_store.field_storage_config','uuid:ae1f0138-a2f5-4881-bf90-0ade773b59b5',_binary 'a:1:{i:0;s:37:\"field.storage.media.field_media_image\";}'),('config.entity.key_store.field_storage_config','uuid:aed153c8-a66a-428a-be76-0d9ff9c57e30',_binary 'a:1:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";}'),('config.entity.key_store.field_storage_config','uuid:b471db54-e924-4e9f-b6d7-c7e32f497206',_binary 'a:1:{i:0;s:44:\"field.storage.media.field_media_oembed_video\";}'),('config.entity.key_store.field_storage_config','uuid:bceb6f2f-b114-41f5-8b07-0ce990d0087a',_binary 'a:1:{i:0;s:55:\"field.storage.paragraph.field_ept_bootstrap_button_link\";}'),('config.entity.key_store.field_storage_config','uuid:bd174355-0ad0-4843-9909-9069e6e2eac2',_binary 'a:1:{i:0;s:46:\"field.storage.paragraph.field_ept_counter_icon\";}'),('config.entity.key_store.field_storage_config','uuid:be93c2a2-2803-47c8-8cbb-88ab3561ae6c',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_hero_title_prefix\";}'),('config.entity.key_store.field_storage_config','uuid:c605bbbd-911f-4bca-9f1d-7575ba23063c',_binary 'a:1:{i:0;s:49:\"field.storage.paragraph.field_ept_slideshow_title\";}'),('config.entity.key_store.field_storage_config','uuid:c84089e9-ca27-4ede-81db-501ab243fe10',_binary 'a:1:{i:0;s:45:\"field.storage.paragraph.field_ept_tiles_image\";}'),('config.entity.key_store.field_storage_config','uuid:c9282b5e-9cbb-4d37-84d7-b405cf59a041',_binary 'a:1:{i:0;s:43:\"field.storage.paragraph.field_ept_accordion\";}'),('config.entity.key_store.field_storage_config','uuid:ceb57be4-05e2-49c4-afad-48cb1341e682',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_gallery_item_text\";}'),('config.entity.key_store.field_storage_config','uuid:d142f67c-eb14-402b-8d63-83e817038f33',_binary 'a:1:{i:0;s:39:\"field.storage.paragraph.field_ept_title\";}'),('config.entity.key_store.field_storage_config','uuid:d704c8d4-b783-49b6-af10-1f4524374151',_binary 'a:1:{i:0;s:49:\"field.storage.paragraph.field_ept_slideshow_slide\";}'),('config.entity.key_store.field_storage_config','uuid:d8e5d125-f4f7-4c1d-ac26-f7468f91d3b9',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_slick_slider_text\";}'),('config.entity.key_store.field_storage_config','uuid:d90ba792-7242-4c28-a755-2203bfbd33dc',_binary 'a:1:{i:0;s:47:\"field.storage.paragraph.field_ept_image_caption\";}'),('config.entity.key_store.field_storage_config','uuid:d985b37a-8f1d-4d3c-8d92-09cb8326cf66',_binary 'a:1:{i:0;s:52:\"field.storage.paragraph.field_ept_slick_slider_image\";}'),('config.entity.key_store.field_storage_config','uuid:d9aff85c-3ad9-418b-b47e-58f08b64180e',_binary 'a:1:{i:0;s:30:\"field.storage.node.field_image\";}'),('config.entity.key_store.field_storage_config','uuid:dd8a6a77-dce1-4167-81fc-78b560cda129',_binary 'a:1:{i:0;s:42:\"field.storage.paragraph.field_ept_tab_page\";}'),('config.entity.key_store.field_storage_config','uuid:e0b4af62-c275-4029-b2a7-59ffabd9c786',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_stats_item_number\";}'),('config.entity.key_store.field_storage_config','uuid:e5ac8a81-1f96-4b7d-b8e0-6d9b2c08fcbd',_binary 'a:1:{i:0;s:49:\"field.storage.paragraph.field_ept_cta_second_link\";}'),('config.entity.key_store.field_storage_config','uuid:e76f4c36-a02a-4c1e-b34f-cecbd30657dd',_binary 'a:1:{i:0;s:38:\"field.storage.paragraph.field_ept_text\";}'),('config.entity.key_store.field_storage_config','uuid:ef4b1edf-7e44-4fd4-9484-139b43615d23',_binary 'a:1:{i:0;s:42:\"field.storage.paragraph.field_ept_cta_link\";}'),('config.entity.key_store.field_storage_config','uuid:f68b8da9-803f-4c9b-8f4c-4fc24f899205',_binary 'a:1:{i:0;s:46:\"field.storage.paragraph.field_ept_quote_author\";}'),('config.entity.key_store.field_storage_config','uuid:fa2205d7-3b05-4d76-a029-30510c45d952',_binary 'a:1:{i:0;s:47:\"field.storage.paragraph.field_ept_counter_items\";}'),('config.entity.key_store.field_storage_config','uuid:fb3b02a6-684b-4508-8b49-e87fa4e916c1',_binary 'a:1:{i:0;s:51:\"field.storage.paragraph.field_ept_videos_and_images\";}'),('config.entity.key_store.field_storage_config','uuid:fbb51140-67d8-4112-868c-19dd46c31b98',_binary 'a:1:{i:0;s:42:\"field.storage.paragraph.field_ept_carousel\";}'),('config.entity.key_store.filter_format','uuid:5837f230-16d1-4857-8f42-39560aa7f6bb',_binary 'a:1:{i:0;s:23:\"filter.format.full_html\";}'),('config.entity.key_store.filter_format','uuid:9ffd8de5-5d95-4675-941e-b6205d96c828',_binary 'a:1:{i:0;s:24:\"filter.format.basic_html\";}'),('config.entity.key_store.filter_format','uuid:b26630f8-bc66-410b-9271-2fd35673a39c',_binary 'a:1:{i:0;s:29:\"filter.format.restricted_html\";}'),('config.entity.key_store.filter_format','uuid:e7b49ea5-e3d9-43a7-9355-811016606856',_binary 'a:1:{i:0;s:24:\"filter.format.plain_text\";}'),('config.entity.key_store.image_style','uuid:1d081002-40ce-4508-b331-45087f55f851',_binary 'a:1:{i:0;s:17:\"image.style.large\";}'),('config.entity.key_store.image_style','uuid:45c23df0-c353-4723-86c7-ddfc29333553',_binary 'a:1:{i:0;s:21:\"image.style.thumbnail\";}'),('config.entity.key_store.image_style','uuid:7407b366-d102-42ad-8d9b-28fc84ce386e',_binary 'a:1:{i:0;s:16:\"image.style.wide\";}'),('config.entity.key_store.image_style','uuid:8ad0f8e1-bf91-4861-b98d-bd4757ce19fe',_binary 'a:1:{i:0;s:27:\"image.style.ept_quote_image\";}'),('config.entity.key_store.image_style','uuid:96327273-04cd-4db7-9889-976db88ae72b',_binary 'a:1:{i:0;s:29:\"image.style.ept_gallery_image\";}'),('config.entity.key_store.image_style','uuid:c7167138-d49d-4235-8671-ee7f0d2d2b21',_binary 'a:1:{i:0;s:39:\"image.style.ept_video_and_image_gallery\";}'),('config.entity.key_store.image_style','uuid:cc99d86c-9cb9-4913-9000-8ea5ef978940',_binary 'a:1:{i:0;s:18:\"image.style.medium\";}'),('config.entity.key_store.image_style','uuid:d5e3c8ee-d135-4d9b-87f8-3983d8804dd0',_binary 'a:1:{i:0;s:33:\"image.style.ept_slick_slider_card\";}'),('config.entity.key_store.image_style','uuid:dce163df-e6d0-4a19-be9f-835d8fb9ad19',_binary 'a:1:{i:0;s:25:\"image.style.media_library\";}'),('config.entity.key_store.media_type','uuid:0bf0a6ff-42d0-4443-95d9-32bb21b3d878',_binary 'a:1:{i:0;s:16:\"media.type.image\";}'),('config.entity.key_store.media_type','uuid:6a011382-b41c-428b-bec3-c2acb1a0b347',_binary 'a:1:{i:0;s:16:\"media.type.audio\";}'),('config.entity.key_store.media_type','uuid:d833ee62-0e66-41f9-bc64-0ee184be48b7',_binary 'a:1:{i:0;s:23:\"media.type.remote_video\";}'),('config.entity.key_store.media_type','uuid:f37b6fcf-a1f5-41c8-ad6b-ab36d7822130',_binary 'a:1:{i:0;s:16:\"media.type.video\";}'),('config.entity.key_store.media_type','uuid:f7d4d4ed-07f1-4c0e-add0-5205dca6bb2d',_binary 'a:1:{i:0;s:19:\"media.type.document\";}'),('config.entity.key_store.menu','uuid:37d50e8a-b786-4ff3-a41f-5e41d67f88b1',_binary 'a:1:{i:0;s:19:\"system.menu.account\";}'),('config.entity.key_store.menu','uuid:4108c568-d39d-4283-8af4-4ce0601c49ec',_binary 'a:1:{i:0;s:16:\"system.menu.main\";}'),('config.entity.key_store.menu','uuid:6e91308b-4a52-440d-824d-e3b9fb3941e2',_binary 'a:1:{i:0;s:17:\"system.menu.tools\";}'),('config.entity.key_store.menu','uuid:cf474897-e948-4315-a183-5878deecdaf0',_binary 'a:1:{i:0;s:17:\"system.menu.admin\";}'),('config.entity.key_store.menu','uuid:d761cbba-9ebe-4d52-96fc-79063bff0783',_binary 'a:1:{i:0;s:18:\"system.menu.footer\";}'),('config.entity.key_store.node_type','uuid:9597cbd8-ec71-47b6-98f5-c2eeebffff0e',_binary 'a:1:{i:0;s:17:\"node.type.article\";}'),('config.entity.key_store.node_type','uuid:e24a8178-cabf-4c12-8439-99829f4ce10e',_binary 'a:1:{i:0;s:14:\"node.type.page\";}'),('config.entity.key_store.paragraphs_type','uuid:07a0dbc7-10e5-4ae6-897e-e0a112e89e81',_binary 'a:1:{i:0;s:44:\"paragraphs.paragraphs_type.ept_carousel_item\";}'),('config.entity.key_store.paragraphs_type','uuid:0f8caf80-346b-4e13-bb09-4c47aafab045',_binary 'a:1:{i:0;s:39:\"paragraphs.paragraphs_type.ept_carousel\";}'),('config.entity.key_store.paragraphs_type','uuid:1a4319ac-f841-4112-85c5-2a1ab06cb4d1',_binary 'a:1:{i:0;s:59:\"paragraphs.paragraphs_type.ept_video_and_image_gallery_item\";}'),('config.entity.key_store.paragraphs_type','uuid:1f202608-b028-44b4-99c0-312ebcadcb47',_binary 'a:1:{i:0;s:41:\"paragraphs.paragraphs_type.ept_stats_item\";}'),('config.entity.key_store.paragraphs_type','uuid:29db5768-3c25-444b-84f5-1a0ab0ba6377',_binary 'a:1:{i:0;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";}'),('config.entity.key_store.paragraphs_type','uuid:3188911c-48a1-42f6-8342-f2b8eb94edff',_binary 'a:1:{i:0;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";}'),('config.entity.key_store.paragraphs_type','uuid:3252260c-9d6c-4095-8836-d9e0aaa25dc6',_binary 'a:1:{i:0;s:40:\"paragraphs.paragraphs_type.ept_accordion\";}'),('config.entity.key_store.paragraphs_type','uuid:41cd1373-cca3-46dc-87a0-714c7a1489bb',_binary 'a:1:{i:0;s:48:\"paragraphs.paragraphs_type.ept_slick_slider_item\";}'),('config.entity.key_store.paragraphs_type','uuid:4290efa9-ba8f-4d75-8ae5-02743a3c35f1',_binary 'a:1:{i:0;s:48:\"paragraphs.paragraphs_type.ept_accordion_section\";}'),('config.entity.key_store.paragraphs_type','uuid:5a3625a2-f528-429b-8415-b0b1eface1d4',_binary 'a:1:{i:0;s:34:\"paragraphs.paragraphs_type.ept_cta\";}'),('config.entity.key_store.paragraphs_type','uuid:6838ec7f-c8a4-4325-97a7-1021f1dfe5d5',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_stats\";}'),('config.entity.key_store.paragraphs_type','uuid:698fe7c4-0789-4365-b3ce-d8bbd2d7d879',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_block\";}'),('config.entity.key_store.paragraphs_type','uuid:7ac88ec9-7da9-488c-ac70-492b5bcfde08',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_views\";}'),('config.entity.key_store.paragraphs_type','uuid:8fca0905-ad07-4e5a-b80e-a842bece8ab5',_binary 'a:1:{i:0;s:43:\"paragraphs.paragraphs_type.ept_counter_item\";}'),('config.entity.key_store.paragraphs_type','uuid:9953b7d8-252b-4d78-9b63-08418e206990',_binary 'a:1:{i:0;s:45:\"paragraphs.paragraphs_type.ept_slideshow_item\";}'),('config.entity.key_store.paragraphs_type','uuid:9e15e91a-5c5e-4c79-9e75-1386629a7208',_binary 'a:1:{i:0;s:40:\"paragraphs.paragraphs_type.ept_tabs_item\";}'),('config.entity.key_store.paragraphs_type','uuid:ae747fa8-05f4-441a-92bd-76441012dd9b',_binary 'a:1:{i:0;s:41:\"paragraphs.paragraphs_type.ept_tiles_item\";}'),('config.entity.key_store.paragraphs_type','uuid:b702ec4e-c33c-4331-beff-6b5b7107cc9d',_binary 'a:1:{i:0;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";}'),('config.entity.key_store.paragraphs_type','uuid:c76a9833-ec98-4fe9-9268-c55ecc6606f7',_binary 'a:1:{i:0;s:35:\"paragraphs.paragraphs_type.ept_text\";}'),('config.entity.key_store.paragraphs_type','uuid:ced6180f-b154-47b8-a7b7-61647c71db48',_binary 'a:1:{i:0;s:35:\"paragraphs.paragraphs_type.ept_hero\";}'),('config.entity.key_store.paragraphs_type','uuid:d1c90790-b1df-488f-a53e-bc8c9bbe2e9c',_binary 'a:1:{i:0;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";}'),('config.entity.key_store.paragraphs_type','uuid:d468b305-ccc4-4dd1-827a-5ac37883f188',_binary 'a:1:{i:0;s:40:\"paragraphs.paragraphs_type.ept_countdown\";}'),('config.entity.key_store.paragraphs_type','uuid:d64be736-43ad-47c5-a174-0a5e19f4b24a',_binary 'a:1:{i:0;s:35:\"paragraphs.paragraphs_type.ept_tabs\";}'),('config.entity.key_store.paragraphs_type','uuid:dee3b2de-c5f8-4d3f-8564-0f6f24943f59',_binary 'a:1:{i:0;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";}'),('config.entity.key_store.paragraphs_type','uuid:e1accd8b-a614-4659-8cf0-f0563effdfeb',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_tiles\";}'),('config.entity.key_store.paragraphs_type','uuid:e359103e-fb7d-4814-b51e-5b6eb0bf50cd',_binary 'a:1:{i:0;s:38:\"paragraphs.paragraphs_type.ept_columns\";}'),('config.entity.key_store.paragraphs_type','uuid:e50ad18b-eff8-48a4-9102-1709c8e0bb40',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_video\";}'),('config.entity.key_store.paragraphs_type','uuid:e7cc4707-218e-4bb9-bcbe-65d47620375d',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_quote\";}'),('config.entity.key_store.paragraphs_type','uuid:ec405efa-b146-4a07-abc8-d507909706f1',_binary 'a:1:{i:0;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";}'),('config.entity.key_store.paragraphs_type','uuid:f1d6ed2b-6a40-4f21-930f-5cd318945855',_binary 'a:1:{i:0;s:36:\"paragraphs.paragraphs_type.ept_image\";}'),('config.entity.key_store.paragraphs_type','uuid:fb9a64bf-58bb-4e29-a23f-83bc70d9958c',_binary 'a:1:{i:0;s:38:\"paragraphs.paragraphs_type.ept_counter\";}'),('config.entity.key_store.paragraphs_type','uuid:ffeadf94-a846-4eeb-af7e-504e5b867d19',_binary 'a:1:{i:0;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";}'),('config.entity.key_store.search_page','uuid:02f73622-4ae8-479b-bddb-6b507d943c7b',_binary 'a:1:{i:0;s:23:\"search.page.user_search\";}'),('config.entity.key_store.search_page','uuid:98a9a1a8-dfbe-4b36-a295-131fa324015e',_binary 'a:1:{i:0;s:23:\"search.page.help_search\";}'),('config.entity.key_store.search_page','uuid:be4dce05-236d-43ce-aa4d-b829b5c9d8a0',_binary 'a:1:{i:0;s:23:\"search.page.node_search\";}'),('config.entity.key_store.shortcut_set','uuid:2b149d5c-a926-4de8-aae7-b7f45081ccab',_binary 'a:1:{i:0;s:20:\"shortcut.set.default\";}'),('config.entity.key_store.taxonomy_vocabulary','uuid:368fd9b7-ee40-4b51-8ac1-60f818b9f9f6',_binary 'a:1:{i:0;s:24:\"taxonomy.vocabulary.tags\";}'),('config.entity.key_store.tb_megamenu','uuid:9a71f48f-4fa9-44ad-996b-21fe7ea77565',_binary 'a:1:{i:0;s:39:\"tb_megamenu.menu_config.main__ept_light\";}'),('config.entity.key_store.user_role','uuid:369ad726-b0da-4331-8cb0-56ab9af109d5',_binary 'a:1:{i:0;s:23:\"user.role.authenticated\";}'),('config.entity.key_store.user_role','uuid:5f4748db-4b8a-4105-a888-23753782d022',_binary 'a:1:{i:0;s:23:\"user.role.administrator\";}'),('config.entity.key_store.user_role','uuid:e916801a-5024-47c1-b402-bb0bb1592d19',_binary 'a:1:{i:0;s:24:\"user.role.content_editor\";}'),('config.entity.key_store.user_role','uuid:eda565bf-dc62-4fa8-b48c-329d2d6fc492',_binary 'a:1:{i:0;s:19:\"user.role.anonymous\";}'),('config.entity.key_store.view','uuid:25587939-259b-48aa-8c6c-dbd04aa5d800',_binary 'a:1:{i:0;s:19:\"views.view.watchdog\";}'),('config.entity.key_store.view','uuid:267c96ad-120e-49d6-9273-b49f1a603f01',_binary 'a:1:{i:0;s:23:\"views.view.who_s_online\";}'),('config.entity.key_store.view','uuid:36db1296-d05c-4dd7-bda9-64d0981e2f85',_binary 'a:1:{i:0;s:16:\"views.view.files\";}'),('config.entity.key_store.view','uuid:56651306-efed-4808-bbdc-d9cf02cff348',_binary 'a:1:{i:0;s:24:\"views.view.taxonomy_term\";}'),('config.entity.key_store.view','uuid:66ac1092-d560-4cf9-a5d3-b1941a3311d1',_binary 'a:1:{i:0;s:28:\"views.view.user_admin_people\";}'),('config.entity.key_store.view','uuid:74d36492-489a-4ac8-ab15-1c22af9e302b',_binary 'a:1:{i:0;s:24:\"views.view.media_library\";}'),('config.entity.key_store.view','uuid:7c06b5e5-ebff-4822-8688-54ce69b5a404',_binary 'a:1:{i:0;s:16:\"views.view.media\";}'),('config.entity.key_store.view','uuid:899f634a-224d-4abf-ae01-81a9b3031896',_binary 'a:1:{i:0;s:20:\"views.view.frontpage\";}'),('config.entity.key_store.view','uuid:9a843b37-02d2-45c5-84e0-2cd85511ce42',_binary 'a:1:{i:0;s:19:\"views.view.glossary\";}'),('config.entity.key_store.view','uuid:9dd1c55e-db52-4c19-aa0d-4c122baa71f4',_binary 'a:1:{i:0;s:25:\"views.view.content_recent\";}'),('config.entity.key_store.view','uuid:b85b83ea-7ca6-4445-91d4-33ba3dff6403',_binary 'a:1:{i:0;s:26:\"views.view.comments_recent\";}'),('config.entity.key_store.view','uuid:d9b64673-64f0-48bb-8588-e15e4bdacdbf',_binary 'a:1:{i:0;s:20:\"views.view.who_s_new\";}'),('config.entity.key_store.view','uuid:db9f543b-a00c-4765-a8dd-36dc8ebd091c',_binary 'a:1:{i:0;s:18:\"views.view.content\";}'),('config.entity.key_store.view','uuid:e1df6ee8-b831-49f1-9777-12d640e99636',_binary 'a:1:{i:0;s:21:\"views.view.what_s_new\";}'),('config.entity.key_store.view','uuid:e6cd565b-768b-47a9-b906-fe031ec4047e',_binary 'a:1:{i:0;s:18:\"views.view.comment\";}'),('config.entity.key_store.view','uuid:f0a4d615-99cd-438c-a7fe-c2d84a594ee3',_binary 'a:1:{i:0;s:24:\"views.view.block_content\";}'),('config.entity.key_store.view','uuid:f33400de-a3e8-4128-b4b9-8f10fc897a3f',_binary 'a:1:{i:0;s:18:\"views.view.archive\";}'),('entity.definitions.bundle_field_map','block_content',_binary 'a:1:{s:4:\"body\";a:2:{s:4:\"type\";s:17:\"text_with_summary\";s:7:\"bundles\";a:1:{s:5:\"basic\";s:5:\"basic\";}}}'),('entity.definitions.bundle_field_map','comment',_binary 'a:1:{s:12:\"comment_body\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:7:\"comment\";s:7:\"comment\";}}}'),('entity.definitions.bundle_field_map','media',_binary 'a:5:{s:22:\"field_media_audio_file\";a:2:{s:4:\"type\";s:4:\"file\";s:7:\"bundles\";a:1:{s:5:\"audio\";s:5:\"audio\";}}s:20:\"field_media_document\";a:2:{s:4:\"type\";s:4:\"file\";s:7:\"bundles\";a:1:{s:8:\"document\";s:8:\"document\";}}s:17:\"field_media_image\";a:2:{s:4:\"type\";s:5:\"image\";s:7:\"bundles\";a:1:{s:5:\"image\";s:5:\"image\";}}s:24:\"field_media_oembed_video\";a:2:{s:4:\"type\";s:6:\"string\";s:7:\"bundles\";a:1:{s:12:\"remote_video\";s:12:\"remote_video\";}}s:22:\"field_media_video_file\";a:2:{s:4:\"type\";s:4:\"file\";s:7:\"bundles\";a:1:{s:5:\"video\";s:5:\"video\";}}}'),('entity.definitions.bundle_field_map','node',_binary 'a:4:{s:11:\"field_image\";a:2:{s:4:\"type\";s:5:\"image\";s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}s:10:\"field_tags\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}s:4:\"body\";a:2:{s:4:\"type\";s:17:\"text_with_summary\";s:7:\"bundles\";a:2:{s:4:\"page\";s:4:\"page\";s:7:\"article\";s:7:\"article\";}}s:16:\"field_components\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:4:\"page\";s:4:\"page\";}}}'),('entity.definitions.bundle_field_map','paragraph',_binary 'a:65:{s:18:\"field_ept_settings\";a:2:{s:4:\"type\";s:12:\"ept_settings\";s:7:\"bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}}s:19:\"field_ept_accordion\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";}}s:25:\"field_ept_accordion_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:21:\"ept_accordion_section\";s:21:\"ept_accordion_section\";}}s:24:\"field_ept_accordion_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:21:\"ept_accordion_section\";s:21:\"ept_accordion_section\";}}s:15:\"field_ept_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}}s:14:\"field_ept_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}}s:27:\"field_ept_basic_button_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";}}s:21:\"field_ept_block_block\";a:2:{s:4:\"type\";s:11:\"block_field\";s:7:\"bundles\";a:1:{s:9:\"ept_block\";s:9:\"ept_block\";}}s:31:\"field_ept_bootstrap_button_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";}}s:24:\"field_ept_carousel_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:17:\"ept_carousel_item\";s:17:\"ept_carousel_item\";}}s:18:\"field_ept_carousel\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:12:\"ept_carousel\";s:12:\"ept_carousel\";}}s:26:\"field_ept_carousel_caption\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:17:\"ept_carousel_item\";s:17:\"ept_carousel_item\";}}s:17:\"field_ept_columns\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:11:\"ept_columns\";s:11:\"ept_columns\";}}s:24:\"field_ept_countdown_date\";a:2:{s:4:\"type\";s:8:\"datetime\";s:7:\"bundles\";a:1:{s:13:\"ept_countdown\";s:13:\"ept_countdown\";}}s:24:\"field_ept_counter_number\";a:2:{s:4:\"type\";s:7:\"integer\";s:7:\"bundles\";a:1:{s:16:\"ept_counter_item\";s:16:\"ept_counter_item\";}}s:22:\"field_ept_counter_icon\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:16:\"ept_counter_item\";s:16:\"ept_counter_item\";}}s:23:\"field_ept_counter_items\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:11:\"ept_counter\";s:11:\"ept_counter\";}}s:23:\"field_ept_counter_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:16:\"ept_counter_item\";s:16:\"ept_counter_item\";}}s:29:\"field_ept_counter_description\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:16:\"ept_counter_item\";s:16:\"ept_counter_item\";}}s:25:\"field_ept_cta_second_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:7:\"ept_cta\";s:7:\"ept_cta\";}}s:18:\"field_ept_cta_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:7:\"ept_cta\";s:7:\"ept_cta\";}}s:26:\"field_ept_cta_column_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:7:\"ept_cta\";s:7:\"ept_cta\";}}s:26:\"field_ept_hero_second_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:8:\"ept_hero\";s:8:\"ept_hero\";}}s:19:\"field_ept_hero_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:8:\"ept_hero\";s:8:\"ept_hero\";}}s:27:\"field_ept_hero_column_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:8:\"ept_hero\";s:8:\"ept_hero\";}}s:27:\"field_ept_hero_title_prefix\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:8:\"ept_hero\";s:8:\"ept_hero\";}}s:20:\"field_ept_image_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:9:\"ept_image\";s:9:\"ept_image\";}}s:15:\"field_ept_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:9:\"ept_image\";s:9:\"ept_image\";}}s:23:\"field_ept_image_caption\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:9:\"ept_image\";s:9:\"ept_image\";}}s:23:\"field_ept_image_gallery\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";}}s:26:\"field_ept_micromodal_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";}}s:21:\"field_ept_quote_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:9:\"ept_quote\";s:9:\"ept_quote\";}}s:22:\"field_ept_quote_author\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:9:\"ept_quote\";s:9:\"ept_quote\";}}s:27:\"field_ept_slick_slider_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:21:\"ept_slick_slider_item\";s:21:\"ept_slick_slider_item\";}}s:28:\"field_ept_slick_slider_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:21:\"ept_slick_slider_item\";s:21:\"ept_slick_slider_item\";}}s:22:\"field_ept_slick_slider\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";}}s:27:\"field_ept_slick_slider_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:21:\"ept_slick_slider_item\";s:21:\"ept_slick_slider_item\";}}s:25:\"field_ept_slideshow_slide\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:18:\"ept_slideshow_item\";s:18:\"ept_slideshow_item\";}}s:24:\"field_ept_slideshow_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:18:\"ept_slideshow_item\";s:18:\"ept_slideshow_item\";}}s:19:\"field_ept_slideshow\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";}}s:25:\"field_ept_slideshow_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:18:\"ept_slideshow_item\";s:18:\"ept_slideshow_item\";}}s:24:\"field_ept_slideshow_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:18:\"ept_slideshow_item\";s:18:\"ept_slideshow_item\";}}s:25:\"field_ept_stats_item_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:14:\"ept_stats_item\";s:14:\"ept_stats_item\";}}s:26:\"field_ept_stats_item_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:14:\"ept_stats_item\";s:14:\"ept_stats_item\";}}s:15:\"field_ept_stats\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:9:\"ept_stats\";s:9:\"ept_stats\";}}s:25:\"field_ept_stats_item_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ept_stats_item\";s:14:\"ept_stats_item\";}}s:27:\"field_ept_stats_item_number\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ept_stats_item\";s:14:\"ept_stats_item\";}}s:18:\"field_ept_tab_page\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}}s:21:\"field_ept_tab_content\";a:2:{s:4:\"type\";s:11:\"list_string\";s:7:\"bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}}s:19:\"field_ept_tab_block\";a:2:{s:4:\"type\";s:11:\"block_field\";s:7:\"bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}}s:14:\"field_ept_tabs\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:8:\"ept_tabs\";s:8:\"ept_tabs\";}}s:19:\"field_ept_tab_title\";a:2:{s:4:\"type\";s:4:\"text\";s:7:\"bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}}s:18:\"field_ept_tab_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}}s:19:\"field_ept_tab_views\";a:2:{s:4:\"type\";s:14:\"viewsreference\";s:7:\"bundles\";a:1:{s:13:\"ept_tabs_item\";s:13:\"ept_tabs_item\";}}s:20:\"field_ept_tiles_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}}s:21:\"field_ept_tiles_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}}s:24:\"field_ept_clickable_tile\";a:2:{s:4:\"type\";s:7:\"boolean\";s:7:\"bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}}s:15:\"field_ept_tiles\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:9:\"ept_tiles\";s:9:\"ept_tiles\";}}s:21:\"field_ept_tiles_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}}s:20:\"field_ept_tiles_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ept_tiles_item\";s:14:\"ept_tiles_item\";}}s:15:\"field_ept_video\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:9:\"ept_video\";s:9:\"ept_video\";}}s:22:\"field_ept_gallery_item\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:32:\"ept_video_and_image_gallery_item\";s:32:\"ept_video_and_image_gallery_item\";}}s:27:\"field_ept_videos_and_images\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";}}s:27:\"field_ept_gallery_item_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:32:\"ept_video_and_image_gallery_item\";s:32:\"ept_video_and_image_gallery_item\";}}s:20:\"field_ept_views_view\";a:2:{s:4:\"type\";s:14:\"viewsreference\";s:7:\"bundles\";a:1:{s:9:\"ept_views\";s:9:\"ept_views\";}}}'),('entity.definitions.bundle_field_map','user',_binary 'a:1:{s:12:\"user_picture\";a:2:{s:4:\"type\";s:5:\"image\";s:7:\"bundles\";a:1:{s:4:\"user\";s:4:\"user\";}}}'),('entity.definitions.installed','action.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:6:\"action\";s:8:\"\0*\0class\";s:27:\"Drupal\\system\\Entity\\Action\";s:11:\"\0*\0provider\";s:6:\"system\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\system\\Entity\\Action\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:18:\"administer actions\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Action\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Actions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"action\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"actions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:13:\"@count action\";s:6:\"plural\";s:14:\"@count actions\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"config:action_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:4:\"type\";i:3;s:6:\"plugin\";i:4;s:13:\"configuration\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','base_field_override.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"base_field_override\";s:8:\"\0*\0class\";s:42:\"Drupal\\Core\\Field\\Entity\\BaseFieldOverride\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:42:\"Drupal\\Core\\Field\\Entity\\BaseFieldOverride\";s:11:\"\0*\0handlers\";a:2:{s:7:\"storage\";s:42:\"Drupal\\Core\\Field\\BaseFieldOverrideStorage\";s:6:\"access\";s:55:\"Drupal\\Core\\Field\\BaseFieldOverrideAccessControlHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Base field override\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:base_field_override_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:5:{i:0;s:2:\"id\";i:1;s:11:\"entity_type\";i:2;s:6:\"bundle\";i:3;s:10:\"field_name\";i:4;s:10:\"field_type\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:19:\"base_field_override\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:12:{i:0;s:2:\"id\";i:1;s:10:\"field_name\";i:2;s:11:\"entity_type\";i:3;s:6:\"bundle\";i:4;s:5:\"label\";i:5;s:11:\"description\";i:6;s:8:\"required\";i:7;s:12:\"translatable\";i:8;s:13:\"default_value\";i:9;s:22:\"default_value_callback\";i:10;s:8:\"settings\";i:11;s:10:\"field_type\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','block.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:5:\"block\";s:8:\"\0*\0class\";s:25:\"Drupal\\block\\Entity\\Block\";s:11:\"\0*\0provider\";s:5:\"block\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:25:\"Drupal\\block\\Entity\\Block\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:38:\"Drupal\\block\\BlockAccessControlHandler\";s:12:\"view_builder\";s:29:\"Drupal\\block\\BlockViewBuilder\";s:12:\"list_builder\";s:29:\"Drupal\\block\\BlockListBuilder\";s:4:\"form\";a:2:{s:7:\"default\";s:22:\"Drupal\\block\\BlockForm\";s:6:\"delete\";s:33:\"Drupal\\block\\Form\\BlockDeleteForm\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:17:\"administer blocks\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:11:\"delete-form\";s:44:\"/admin/structure/block/manage/{block}/delete\";s:9:\"edit-form\";s:37:\"/admin/structure/block/manage/{block}\";s:6:\"enable\";s:44:\"/admin/structure/block/manage/{block}/enable\";s:7:\"disable\";s:45:\"/admin/structure/block/manage/{block}/disable\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:12:\"@count block\";s:6:\"plural\";s:13:\"@count blocks\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:17:\"config:block_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:2:{i:0;s:5:\"theme\";i:1;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"theme\";i:2;s:6:\"region\";i:3;s:6:\"weight\";i:4;s:8:\"provider\";i:5;s:6:\"plugin\";i:6;s:8:\"settings\";i:7;s:10:\"visibility\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','block_content.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:13:\"block_content\";s:8:\"\0*\0class\";s:40:\"Drupal\\block_content\\Entity\\BlockContent\";s:11:\"\0*\0provider\";s:13:\"block_content\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:0;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:11:\"revision_id\";s:6:\"bundle\";s:4:\"type\";s:5:\"label\";s:4:\"info\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\block_content\\Entity\\BlockContent\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:46:\"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage\";s:14:\"storage_schema\";s:46:\"Drupal\\block_content\\BlockContentStorageSchema\";s:6:\"access\";s:53:\"Drupal\\block_content\\BlockContentAccessControlHandler\";s:12:\"list_builder\";s:44:\"Drupal\\block_content\\BlockContentListBuilder\";s:12:\"view_builder\";s:44:\"Drupal\\block_content\\BlockContentViewBuilder\";s:10:\"views_data\";s:42:\"Drupal\\block_content\\BlockContentViewsData\";s:4:\"form\";a:6:{s:3:\"add\";s:37:\"Drupal\\block_content\\BlockContentForm\";s:4:\"edit\";s:37:\"Drupal\\block_content\\BlockContentForm\";s:6:\"delete\";s:48:\"Drupal\\block_content\\Form\\BlockContentDeleteForm\";s:7:\"default\";s:37:\"Drupal\\block_content\\BlockContentForm\";s:15:\"revision-delete\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionDeleteForm\";s:15:\"revision-revert\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionRevertForm\";}s:14:\"route_provider\";a:1:{s:8:\"revision\";s:52:\"Drupal\\Core\\Entity\\Routing\\RevisionHtmlRouteProvider\";}s:11:\"translation\";s:51:\"Drupal\\block_content\\BlockContentTranslationHandler\";}s:19:\"\0*\0admin_permission\";s:24:\"administer block content\";s:24:\"\0*\0collection_permission\";s:20:\"access block library\";s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:8:{s:9:\"canonical\";s:36:\"/admin/content/block/{block_content}\";s:11:\"delete-form\";s:43:\"/admin/content/block/{block_content}/delete\";s:9:\"edit-form\";s:36:\"/admin/content/block/{block_content}\";s:10:\"collection\";s:20:\"/admin/content/block\";s:6:\"create\";s:6:\"/block\";s:20:\"revision-delete-form\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/delete\";s:20:\"revision-revert-form\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/revert\";s:15:\"version-history\";s:46:\"/admin/content/block/{block_content}/revisions\";}s:21:\"\0*\0bundle_entity_type\";s:18:\"block_content_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:13:\"block_content\";s:22:\"\0*\0revision_data_table\";s:28:\"block_content_field_revision\";s:17:\"\0*\0revision_table\";s:22:\"block_content_revision\";s:13:\"\0*\0data_table\";s:24:\"block_content_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Content block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Content blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"content block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"content blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:20:\"@count content block\";s:6:\"plural\";s:21:\"@count content blocks\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:35:\"entity.block_content_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"block_content_list\";}s:14:\"\0*\0constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:25:\"BlockContentEntityChanged\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:12:\"revision_log\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','block_content.field_storage_definitions',_binary 'a:16:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Content block ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"The content block ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The content block UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"The revision ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"The content block language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"The block type.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:4:\"type\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:18:\"block_content_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:155;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:193;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:223;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"revision_log\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"The log entry explaining the changes in this revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:12:\"revision_log\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:260;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:302;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"info\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Block description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"A brief description of your block.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:4:\"info\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:341;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"The time that the content block was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:384;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"reusable\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Reusable\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"A boolean indicating whether this block is reusable.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:0;s:12:\"revisionable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:8:\"reusable\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:415;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:458;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:501;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:543;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"body\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:18:\"block_content.body\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"05e5fd5b-7ad6-434e-99a8-8635a8fa97cc\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:18:\"block_content.body\";s:13:\"\0*\0field_name\";s:4:\"body\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:17:\"text_with_summary\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),('entity.definitions.installed','block_content_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:18:\"block_content_type\";s:8:\"\0*\0class\";s:44:\"Drupal\\block_content\\Entity\\BlockContentType\";s:11:\"\0*\0provider\";s:13:\"block_content\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:44:\"Drupal\\block_content\\Entity\\BlockContentType\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:50:\"Drupal\\block_content\\BlockTypeAccessControlHandler\";s:4:\"form\";a:4:{s:7:\"default\";s:41:\"Drupal\\block_content\\BlockContentTypeForm\";s:3:\"add\";s:41:\"Drupal\\block_content\\BlockContentTypeForm\";s:4:\"edit\";s:41:\"Drupal\\block_content\\BlockContentTypeForm\";s:6:\"delete\";s:52:\"Drupal\\block_content\\Form\\BlockContentTypeDeleteForm\";}s:14:\"route_provider\";a:2:{s:4:\"html\";s:49:\"Drupal\\Core\\Entity\\Routing\\AdminHtmlRouteProvider\";s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}s:12:\"list_builder\";s:48:\"Drupal\\block_content\\BlockContentTypeListBuilder\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:22:\"administer block types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:11:\"delete-form\";s:65:\"/admin/structure/block-content/manage/{block_content_type}/delete\";s:9:\"edit-form\";s:58:\"/admin/structure/block-content/manage/{block_content_type}\";s:23:\"entity-permissions-form\";s:70:\"/admin/structure/block-content/manage/{block_content_type}/permissions\";s:10:\"collection\";s:30:\"/admin/structure/block-content\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:13:\"block_content\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Block types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"block types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count block type\";s:6:\"plural\";s:18:\"@count block types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:30:\"config:block_content_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:8:\"revision\";i:3;s:11:\"description\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','ckeditor5_template.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:18:\"ckeditor5_template\";s:8:\"\0*\0class\";s:63:\"Drupal\\ckeditor5_plugin_pack_templates\\Entity\\CKEditor5Template\";s:11:\"\0*\0provider\";s:31:\"ckeditor5_plugin_pack_templates\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"weight\";s:6:\"weight\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:63:\"Drupal\\ckeditor5_plugin_pack_templates\\Entity\\CKEditor5Template\";s:11:\"\0*\0handlers\";a:4:{s:12:\"list_builder\";s:67:\"Drupal\\ckeditor5_plugin_pack_templates\\CKEditor5TemplateListBuilder\";s:4:\"form\";a:4:{s:7:\"default\";s:88:\"Drupal\\ckeditor5_plugin_pack_templates\\Form\\ContentTemplates\\CKEditor5TemplateEntityForm\";s:3:\"add\";s:88:\"Drupal\\ckeditor5_plugin_pack_templates\\Form\\ContentTemplates\\CKEditor5TemplateEntityForm\";s:4:\"edit\";s:88:\"Drupal\\ckeditor5_plugin_pack_templates\\Form\\ContentTemplates\\CKEditor5TemplateEntityForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:30:\"administer ckeditor5 templates\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:10:\"collection\";s:51:\"/admin/config/ckeditor5-templates/content-templates\";s:8:\"add-form\";s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";s:9:\"edit-form\";s:72:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}\";s:11:\"delete-form\";s:61:\"/admin/config/ckeditor5-templates/{ckeditor5_template}/delete\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"CKEditor5 Template\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"CKEditor5 Templates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"CKEditor5 Template\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"CKEditor5 Templates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:25:\"@count ckeditor5 template\";s:6:\"plural\";s:26:\"@count ckeditor5 templates\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:30:\"config:ckeditor5_template_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:18:\"ckeditor5_template\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:6:\"status\";i:4;s:4:\"data\";i:5;s:4:\"icon\";i:6;s:11:\"textFormats\";i:7;s:6:\"weight\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','comment.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:7:\"comment\";s:8:\"\0*\0class\";s:29:\"Drupal\\comment\\Entity\\Comment\";s:11:\"\0*\0provider\";s:7:\"comment\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:3:\"cid\";s:6:\"bundle\";s:12:\"comment_type\";s:5:\"label\";s:7:\"subject\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:5:\"owner\";s:3:\"uid\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:29:\"Drupal\\comment\\Entity\\Comment\";s:11:\"\0*\0handlers\";a:8:{s:7:\"storage\";s:29:\"Drupal\\comment\\CommentStorage\";s:14:\"storage_schema\";s:35:\"Drupal\\comment\\CommentStorageSchema\";s:6:\"access\";s:42:\"Drupal\\comment\\CommentAccessControlHandler\";s:12:\"list_builder\";s:36:\"Drupal\\Core\\Entity\\EntityListBuilder\";s:12:\"view_builder\";s:33:\"Drupal\\comment\\CommentViewBuilder\";s:10:\"views_data\";s:31:\"Drupal\\comment\\CommentViewsData\";s:4:\"form\";a:2:{s:7:\"default\";s:26:\"Drupal\\comment\\CommentForm\";s:6:\"delete\";s:30:\"Drupal\\comment\\Form\\DeleteForm\";}s:11:\"translation\";s:40:\"Drupal\\comment\\CommentTranslationHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:9:\"canonical\";s:18:\"/comment/{comment}\";s:11:\"delete-form\";s:25:\"/comment/{comment}/delete\";s:20:\"delete-multiple-form\";s:29:\"/admin/content/comment/delete\";s:9:\"edit-form\";s:23:\"/comment/{comment}/edit\";s:6:\"create\";s:8:\"/comment\";}s:21:\"\0*\0bundle_entity_type\";s:12:\"comment_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Comment type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:7:\"comment\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";s:18:\"comment_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Comment\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"comment\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"comments\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:14:\"@count comment\";s:6:\"plural\";s:15:\"@count comments\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";s:11:\"comment_uri\";s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:29:\"entity.comment_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:12:\"comment_list\";}s:14:\"\0*\0constraints\";a:3:{s:11:\"CommentName\";a:0:{}s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','comment.field_storage_definitions',_binary 'a:20:{s:3:\"cid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Comment ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"The comment ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:3:\"cid\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The comment UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The comment language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"comment_type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Comment Type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The comment type.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:12:\"comment_type\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:12:\"comment_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:116;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:22:\"default_value_callback\";s:47:\"Drupal\\comment\\Entity\\Comment::getDefaultStatus\";s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:154;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"User ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:22:\"default_value_callback\";s:52:\"Drupal\\comment\\Entity\\Comment::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"The user ID of the comment author.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:194;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"pid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Parent ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"The parent comment ID if this is a reply to a comment.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:3:\"pid\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:7:\"comment\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:232;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"entity_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Entity ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"The ID of the entity of which this comment is a reply.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:9:\"entity_id\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:268;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"subject\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Subject\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:10;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:7:\"subject\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:64;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:305;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:64;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The comment author\'s name.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:60;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:342;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:60;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"mail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The comment author\'s email address.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:4:\"mail\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:380;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"homepage\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Homepage\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The comment author\'s home page address.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:8:\"homepage\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:14:\"field_item:uri\";s:8:\"settings\";a:2:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:411;}s:7:\"\0*\0type\";s:3:\"uri\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"hostname\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Hostname\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The comment author\'s hostname.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:22:\"default_value_callback\";s:49:\"Drupal\\comment\\Entity\\Comment::getDefaultHostname\";s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:8:\"hostname\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:445;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"The time that the comment was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:481;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"The time that the comment was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:511;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"thread\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Thread place\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:144:\"The alphadecimal representation of the comment\'s place in a thread, consisting of a base 36 string prefixed by an integer indicating its length.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:6:\"thread\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:541;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"entity_type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Entity type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The entity type to which this comment is attached.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:11:\"entity_type\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:575;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:10:\"field_name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Comment field name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The field name through which this comment was added.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:10:\"field_name\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:610;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:7:\"comment\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:7:\"comment\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:645;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"comment_body\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:20:\"comment.comment_body\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"4a613783-5795-48bc-bd8e-e3fe3a00ea51\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swYoCch_hY8QO5uwr4FURplfnUCUlpPB4idF8WGVCpw\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"comment\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:20:\"comment.comment_body\";s:13:\"\0*\0field_name\";s:12:\"comment_body\";s:14:\"\0*\0entity_type\";s:7:\"comment\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),('entity.definitions.installed','comment_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"comment_type\";s:8:\"\0*\0class\";s:33:\"Drupal\\comment\\Entity\\CommentType\";s:11:\"\0*\0provider\";s:7:\"comment\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\comment\\Entity\\CommentType\";s:11:\"\0*\0handlers\";a:5:{s:4:\"form\";a:4:{s:7:\"default\";s:30:\"Drupal\\comment\\CommentTypeForm\";s:3:\"add\";s:30:\"Drupal\\comment\\CommentTypeForm\";s:4:\"edit\";s:30:\"Drupal\\comment\\CommentTypeForm\";s:6:\"delete\";s:41:\"Drupal\\comment\\Form\\CommentTypeDeleteForm\";}s:14:\"route_provider\";a:1:{s:11:\"permissions\";s:58:\"Drupal\\user\\Entity\\EntityPermissionsRouteProviderWithCheck\";}s:12:\"list_builder\";s:37:\"Drupal\\comment\\CommentTypeListBuilder\";s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:24:\"administer comment types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:11:\"delete-form\";s:53:\"/admin/structure/comment/manage/{comment_type}/delete\";s:9:\"edit-form\";s:46:\"/admin/structure/comment/manage/{comment_type}\";s:8:\"add-form\";s:34:\"/admin/structure/comment/types/add\";s:23:\"entity-permissions-form\";s:58:\"/admin/structure/comment/manage/{comment_type}/permissions\";s:10:\"collection\";s:24:\"/admin/structure/comment\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:7:\"comment\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Comment type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"comment type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"comment types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count comment type\";s:6:\"plural\";s:20:\"@count comment types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:comment_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:21:\"target_entity_type_id\";i:3;s:11:\"description\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','contact_form.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"contact_form\";s:8:\"\0*\0class\";s:33:\"Drupal\\contact\\Entity\\ContactForm\";s:11:\"\0*\0provider\";s:7:\"contact\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\contact\\Entity\\ContactForm\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:46:\"Drupal\\contact\\ContactFormAccessControlHandler\";s:12:\"list_builder\";s:37:\"Drupal\\contact\\ContactFormListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:34:\"Drupal\\contact\\ContactFormEditForm\";s:4:\"edit\";s:34:\"Drupal\\contact\\ContactFormEditForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}s:14:\"route_provider\";a:1:{s:11:\"permissions\";s:58:\"Drupal\\user\\Entity\\EntityPermissionsRouteProviderWithCheck\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:24:\"administer contact forms\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:11:\"delete-form\";s:53:\"/admin/structure/contact/manage/{contact_form}/delete\";s:9:\"edit-form\";s:46:\"/admin/structure/contact/manage/{contact_form}\";s:23:\"entity-permissions-form\";s:58:\"/admin/structure/contact/manage/{contact_form}/permissions\";s:10:\"collection\";s:24:\"/admin/structure/contact\";s:9:\"canonical\";s:23:\"/contact/{contact_form}\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:15:\"contact_message\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Contact forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"contact forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count contact form\";s:6:\"plural\";s:20:\"@count contact forms\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:contact_form_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"form\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:7:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:10:\"recipients\";i:3;s:5:\"reply\";i:4;s:6:\"weight\";i:5;s:7:\"message\";i:6;s:8:\"redirect\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','contact_message.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:15:\"contact_message\";s:8:\"\0*\0class\";s:29:\"Drupal\\contact\\Entity\\Message\";s:11:\"\0*\0provider\";s:7:\"contact\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:6:{s:6:\"bundle\";s:12:\"contact_form\";s:4:\"uuid\";s:4:\"uuid\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:29:\"Drupal\\contact\\Entity\\Message\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:49:\"Drupal\\contact\\ContactMessageAccessControlHandler\";s:7:\"storage\";s:43:\"Drupal\\Core\\Entity\\ContentEntityNullStorage\";s:12:\"view_builder\";s:33:\"Drupal\\contact\\MessageViewBuilder\";s:4:\"form\";a:1:{s:7:\"default\";s:26:\"Drupal\\contact\\MessageForm\";}}s:19:\"\0*\0admin_permission\";s:24:\"administer contact forms\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";s:12:\"contact_form\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Contact message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Contact messages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"contact message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"contact messages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:22:\"@count contact message\";s:6:\"plural\";s:23:\"@count contact messages\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:29:\"entity.contact_form.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:20:\"contact_message_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','contact_message.field_storage_definitions',_binary 'a:9:{s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The message UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The message language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:28;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:12:\"contact_form\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Form ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The ID of the associated form.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:12:\"contact_form\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:12:\"contact_form\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:58;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The sender\'s name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"The name of the person that is sending the contact message.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:85;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:4:\"mail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"The sender\'s email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"The email of the person that is sending the contact message.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"mail\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:110;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:7:\"subject\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Subject\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-10;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:7:\"subject\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:100;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:132;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:7:\"message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:7:\"display\";a:2:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:4:\"rows\";i:12;}}s:12:\"configurable\";b:1;}s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:0;s:5:\"label\";s:5:\"above\";}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:7:\"message\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:160;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:4:\"copy\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Copy\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"Whether to send a copy of the message to the sender.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"copy\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:194;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:9:\"recipient\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Recipient ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"The ID of the recipient user for personal contact messages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:9:\"recipient\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:224;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','date_format.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:11:\"date_format\";s:8:\"\0*\0class\";s:38:\"Drupal\\Core\\Datetime\\Entity\\DateFormat\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:38:\"Drupal\\Core\\Datetime\\Entity\\DateFormat\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:44:\"Drupal\\system\\DateFormatAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";s:4:\"form\";a:3:{s:3:\"add\";s:36:\"Drupal\\system\\Form\\DateFormatAddForm\";s:4:\"edit\";s:37:\"Drupal\\system\\Form\\DateFormatEditForm\";s:6:\"delete\";s:39:\"Drupal\\system\\Form\\DateFormatDeleteForm\";}s:12:\"list_builder\";s:35:\"Drupal\\system\\DateFormatListBuilder\";}s:19:\"\0*\0admin_permission\";s:29:\"administer site configuration\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"edit-form\";s:61:\"/admin/config/regional/date-time/formats/manage/{date_format}\";s:11:\"delete-form\";s:68:\"/admin/config/regional/date-time/formats/manage/{date_format}/delete\";s:10:\"collection\";s:40:\"/admin/config/regional/date-time/formats\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Date format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:8:\"rendered\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:6:\"locked\";i:3;s:7:\"pattern\";}s:21:\"\0*\0mergedConfigExport\";a:10:{s:4:\"uuid\";s:4:\"uuid\";s:8:\"langcode\";s:8:\"langcode\";s:6:\"status\";s:6:\"status\";s:12:\"dependencies\";s:12:\"dependencies\";s:20:\"third_party_settings\";s:20:\"third_party_settings\";s:5:\"_core\";s:5:\"_core\";s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"locked\";s:6:\"locked\";s:7:\"pattern\";s:7:\"pattern\";}}'),('entity.definitions.installed','editor.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:6:\"editor\";s:8:\"\0*\0class\";s:27:\"Drupal\\editor\\Entity\\Editor\";s:11:\"\0*\0provider\";s:6:\"editor\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:6:\"format\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\editor\\Entity\\Editor\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:40:\"Drupal\\editor\\EditorAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Text editor\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Text editors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"text editor\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"text editors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:18:\"@count text editor\";s:6:\"plural\";s:19:\"@count text editors\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"config:editor_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"RequiredConfigDependencies\";a:1:{i:0;s:13:\"filter_format\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:6:\"format\";i:1;s:6:\"editor\";i:2;s:8:\"settings\";i:3;s:12:\"image_upload\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','entity_form_display.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"entity_form_display\";s:8:\"\0*\0class\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:71:\"\\Drupal\\Core\\Entity\\Entity\\Access\\EntityFormDisplayAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Entity form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:entity_form_display_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:4:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";i:4;s:7:\"content\";i:5;s:6:\"hidden\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','entity_form_mode.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:16:\"entity_form_mode\";s:8:\"\0*\0class\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityFormMode\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:11:\"description\";s:11:\"description\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityFormMode\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Form mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:28:\"config:entity_form_mode_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:2:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:16:\"targetEntityType\";i:4;s:5:\"cache\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','entity_view_display.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"entity_view_display\";s:8:\"\0*\0class\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityViewDisplay\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityViewDisplay\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:71:\"\\Drupal\\Core\\Entity\\Entity\\Access\\EntityViewDisplayAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Entity view display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:entity_view_display_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:4:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";i:4;s:7:\"content\";i:5;s:6:\"hidden\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','entity_view_mode.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:16:\"entity_view_mode\";s:8:\"\0*\0class\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityViewMode\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:11:\"description\";s:11:\"description\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityViewMode\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"View mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:28:\"config:entity_view_mode_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:2:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:16:\"targetEntityType\";i:4;s:5:\"cache\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','field_config.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"field_config\";s:8:\"\0*\0class\";s:31:\"Drupal\\field\\Entity\\FieldConfig\";s:11:\"\0*\0provider\";s:5:\"field\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:31:\"Drupal\\field\\Entity\\FieldConfig\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:44:\"Drupal\\field\\FieldConfigAccessControlHandler\";s:7:\"storage\";s:31:\"Drupal\\field\\FieldConfigStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Field\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"field\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:12:\"@count field\";s:6:\"plural\";s:13:\"@count fields\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:field_config_list\";}s:14:\"\0*\0constraints\";a:2:{s:26:\"RequiredConfigDependencies\";a:1:{i:0;s:20:\"field_storage_config\";}s:19:\"ImmutableProperties\";a:5:{i:0;s:2:\"id\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";i:3;s:6:\"bundle\";i:4;s:10:\"field_type\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:5:\"field\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:12:{i:0;s:2:\"id\";i:1;s:10:\"field_name\";i:2;s:11:\"entity_type\";i:3;s:6:\"bundle\";i:4;s:5:\"label\";i:5;s:11:\"description\";i:6;s:8:\"required\";i:7;s:12:\"translatable\";i:8;s:13:\"default_value\";i:9;s:22:\"default_value_callback\";i:10;s:8:\"settings\";i:11;s:10:\"field_type\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','field_storage_config.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:20:\"field_storage_config\";s:8:\"\0*\0class\";s:38:\"Drupal\\field\\Entity\\FieldStorageConfig\";s:11:\"\0*\0provider\";s:5:\"field\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:2:\"id\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:38:\"Drupal\\field\\Entity\\FieldStorageConfig\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:51:\"Drupal\\field\\FieldStorageConfigAccessControlHandler\";s:7:\"storage\";s:38:\"Drupal\\field\\FieldStorageConfigStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Field storage\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Field storages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"field storage\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"field storages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:20:\"@count field storage\";s:6:\"plural\";s:21:\"@count field storages\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:32:\"config:field_storage_config_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:4:{i:0;s:2:\"id\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";i:3;s:4:\"type\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:7:\"storage\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:12:{i:0;s:2:\"id\";i:1;s:10:\"field_name\";i:2;s:11:\"entity_type\";i:3;s:4:\"type\";i:4;s:8:\"settings\";i:5;s:6:\"module\";i:6;s:6:\"locked\";i:7;s:11:\"cardinality\";i:8;s:12:\"translatable\";i:9;s:7:\"indexes\";i:10;s:22:\"persist_with_no_fields\";i:11;s:14:\"custom_storage\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','file.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:4:\"file\";s:8:\"\0*\0class\";s:23:\"Drupal\\file\\Entity\\File\";s:11:\"\0*\0provider\";s:4:\"file\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:3:\"fid\";s:5:\"label\";s:8:\"filename\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:5:\"owner\";s:3:\"uid\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\file\\Entity\\File\";s:11:\"\0*\0handlers\";a:8:{s:7:\"storage\";s:23:\"Drupal\\file\\FileStorage\";s:14:\"storage_schema\";s:29:\"Drupal\\file\\FileStorageSchema\";s:6:\"access\";s:36:\"Drupal\\file\\FileAccessControlHandler\";s:10:\"views_data\";s:25:\"Drupal\\file\\FileViewsData\";s:12:\"list_builder\";s:36:\"Drupal\\Core\\Entity\\EntityListBuilder\";s:4:\"form\";a:1:{s:6:\"delete\";s:42:\"Drupal\\Core\\Entity\\ContentEntityDeleteForm\";}s:14:\"route_provider\";a:1:{s:4:\"html\";s:36:\"Drupal\\file\\Entity\\FileRouteProvider\";}s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:1:{s:11:\"delete-form\";s:19:\"/file/{file}/delete\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:12:\"file_managed\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"File\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Files\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"file\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"files\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count file\";s:6:\"plural\";s:12:\"@count files\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:9:\"file_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','file.field_storage_definitions',_binary 'a:11:{s:3:\"fid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"File ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"The file ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:3:\"fid\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"The file UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The file language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"User ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:0;s:22:\"default_value_callback\";s:46:\"Drupal\\file\\Entity\\File::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"The user ID of the file.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"filename\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Filename\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:41:\"Name of the file with no path components.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"filename\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:153;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uri\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"URI\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The URI to access the file (either local or remote).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:1:{s:13:\"FileUriUnique\";N;}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:3:\"uri\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:file_uri\";s:8:\"settings\";a:2:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:1;}}s:18:\"\0*\0fieldDefinition\";r:187;}s:7:\"\0*\0type\";s:8:\"file_uri\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:1;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"filemime\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"File MIME type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"The file\'s MIME type.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"filemime\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:222;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"filesize\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"File size\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The size of the file in bytes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"filesize\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:3:\"big\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:256;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Status\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:63:\"The status of the file, temporary (FALSE) and permanent (TRUE).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:293;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"The timestamp that the file was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:334;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"The timestamp that the file was last changed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:363;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','filter_format.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:13:\"filter_format\";s:8:\"\0*\0class\";s:33:\"Drupal\\filter\\Entity\\FilterFormat\";s:11:\"\0*\0provider\";s:6:\"filter\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:6:\"format\";s:5:\"label\";s:4:\"name\";s:6:\"weight\";s:6:\"weight\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\filter\\Entity\\FilterFormat\";s:11:\"\0*\0handlers\";a:4:{s:4:\"form\";a:3:{s:3:\"add\";s:33:\"Drupal\\filter\\FilterFormatAddForm\";s:4:\"edit\";s:34:\"Drupal\\filter\\FilterFormatEditForm\";s:7:\"disable\";s:36:\"Drupal\\filter\\Form\\FilterDisableForm\";}s:12:\"list_builder\";s:37:\"Drupal\\filter\\FilterFormatListBuilder\";s:6:\"access\";s:46:\"Drupal\\filter\\FilterFormatAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:18:\"administer filters\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:2:{s:9:\"edit-form\";s:52:\"/admin/config/content/formats/manage/{filter_format}\";s:7:\"disable\";s:60:\"/admin/config/content/formats/manage/{filter_format}/disable\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Text format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Text formats\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"text format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"text formats\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:18:\"@count text format\";s:6:\"plural\";s:19:\"@count text formats\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:25:\"config:filter_format_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:6:\"format\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:4:\"name\";i:1;s:6:\"format\";i:2;s:6:\"weight\";i:3;s:5:\"roles\";i:4;s:7:\"filters\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','image_style.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:11:\"image_style\";s:8:\"\0*\0class\";s:30:\"Drupal\\image\\Entity\\ImageStyle\";s:11:\"\0*\0provider\";s:5:\"image\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:4:\"name\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:30:\"Drupal\\image\\Entity\\ImageStyle\";s:11:\"\0*\0handlers\";a:4:{s:4:\"form\";a:4:{s:3:\"add\";s:35:\"Drupal\\image\\Form\\ImageStyleAddForm\";s:4:\"edit\";s:36:\"Drupal\\image\\Form\\ImageStyleEditForm\";s:6:\"delete\";s:38:\"Drupal\\image\\Form\\ImageStyleDeleteForm\";s:5:\"flush\";s:37:\"Drupal\\image\\Form\\ImageStyleFlushForm\";}s:12:\"list_builder\";s:34:\"Drupal\\image\\ImageStyleListBuilder\";s:7:\"storage\";s:30:\"Drupal\\image\\ImageStyleStorage\";s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";}s:19:\"\0*\0admin_permission\";s:23:\"administer image styles\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:10:\"flush-form\";s:59:\"/admin/config/media/image-styles/manage/{image_style}/flush\";s:9:\"edit-form\";s:53:\"/admin/config/media/image-styles/manage/{image_style}\";s:11:\"delete-form\";s:60:\"/admin/config/media/image-styles/manage/{image_style}/delete\";s:10:\"collection\";s:32:\"/admin/config/media/image-styles\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Image style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Image styles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"image style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"image styles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:18:\"@count image style\";s:6:\"plural\";s:19:\"@count image styles\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:23:\"config:image_style_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:5:\"style\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:3:{i:0;s:4:\"name\";i:1;s:5:\"label\";i:2;s:7:\"effects\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','media.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:5:\"media\";s:8:\"\0*\0class\";s:25:\"Drupal\\media\\Entity\\Media\";s:11:\"\0*\0provider\";s:5:\"media\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:3:\"mid\";s:8:\"revision\";s:3:\"vid\";s:6:\"bundle\";s:6:\"bundle\";s:5:\"label\";s:4:\"name\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:5:\"owner\";s:3:\"uid\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:25:\"Drupal\\media\\Entity\\Media\";s:11:\"\0*\0handlers\";a:7:{s:7:\"storage\";s:25:\"Drupal\\media\\MediaStorage\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";s:12:\"list_builder\";s:29:\"Drupal\\media\\MediaListBuilder\";s:6:\"access\";s:38:\"Drupal\\media\\MediaAccessControlHandler\";s:4:\"form\";a:7:{s:7:\"default\";s:22:\"Drupal\\media\\MediaForm\";s:3:\"add\";s:22:\"Drupal\\media\\MediaForm\";s:4:\"edit\";s:22:\"Drupal\\media\\MediaForm\";s:6:\"delete\";s:42:\"Drupal\\Core\\Entity\\ContentEntityDeleteForm\";s:23:\"delete-multiple-confirm\";s:42:\"Drupal\\Core\\Entity\\Form\\DeleteMultipleForm\";s:15:\"revision-delete\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionDeleteForm\";s:15:\"revision-revert\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionRevertForm\";}s:10:\"views_data\";s:27:\"Drupal\\media\\MediaViewsData\";s:14:\"route_provider\";a:2:{s:4:\"html\";s:39:\"Drupal\\media\\Routing\\MediaRouteProvider\";s:8:\"revision\";s:52:\"Drupal\\Core\\Entity\\Routing\\RevisionHtmlRouteProvider\";}}s:19:\"\0*\0admin_permission\";s:16:\"administer media\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:11:{s:8:\"add-page\";s:10:\"/media/add\";s:8:\"add-form\";s:23:\"/media/add/{media_type}\";s:9:\"canonical\";s:19:\"/media/{media}/edit\";s:10:\"collection\";s:20:\"/admin/content/media\";s:11:\"delete-form\";s:21:\"/media/{media}/delete\";s:20:\"delete-multiple-form\";s:13:\"/media/delete\";s:9:\"edit-form\";s:19:\"/media/{media}/edit\";s:8:\"revision\";s:46:\"/media/{media}/revisions/{media_revision}/view\";s:20:\"revision-delete-form\";s:47:\"/media/{media}/revision/{media_revision}/delete\";s:20:\"revision-revert-form\";s:47:\"/media/{media}/revision/{media_revision}/revert\";s:15:\"version-history\";s:24:\"/media/{media}/revisions\";}s:21:\"\0*\0bundle_entity_type\";s:10:\"media_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Media type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:5:\"media\";s:22:\"\0*\0revision_data_table\";s:20:\"media_field_revision\";s:17:\"\0*\0revision_table\";s:14:\"media_revision\";s:13:\"\0*\0data_table\";s:16:\"media_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"media item\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"media items\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count media item\";s:6:\"plural\";s:18:\"@count media items\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:27:\"entity.media_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:10:\"media_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:20:\"revision_log_message\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','media.field_storage_definitions',_binary 'a:22:{s:3:\"mid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:3:\"mid\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"vid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:3:\"vid\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"bundle\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";s:10:\"Media type\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:6:\"bundle\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:10:\"media_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:139;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:170;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:200;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:20:\"revision_log_message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:20:\"revision_log_message\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:237;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:100;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:279;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored by\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:22:\"default_value_callback\";s:48:\"Drupal\\media\\Entity\\Media::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The user ID of the author.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:4:\"size\";s:2:\"60\";s:17:\"autocomplete_type\";s:4:\"tags\";s:11:\"placeholder\";s:0:\"\";}}s:12:\"configurable\";b:1;}s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"author\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:326;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:2:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}s:4:\"view\";a:2:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:382;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"thumbnail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Thumbnail\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"The thumbnail of the media item.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"view\";a:2:{s:7:\"options\";a:4:{s:4:\"type\";s:5:\"image\";s:6:\"weight\";i:5;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"image_style\";s:9:\"thumbnail\";}}s:12:\"configurable\";b:1;}}s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:9:\"thumbnail\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:image\";s:8:\"settings\";a:16:{s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:9:\"alt_field\";i:1;s:18:\"alt_field_required\";i:1;s:11:\"title_field\";i:0;s:20:\"title_field_required\";i:0;s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:12:\"max_filesize\";s:0:\"\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:428;}s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:5:{s:9:\"target_id\";a:3:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}s:3:\"alt\";a:3:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;}s:5:\"title\";a:3:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;}s:5:\"width\";a:3:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}s:6:\"height\";a:3:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:12:\"foreign keys\";a:1:{s:9:\"target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:9:\"target_id\";s:3:\"fid\";}}}s:11:\"unique keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored on\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"The time the media item was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:22:\"default_value_callback\";s:41:\"Drupal\\media\\Entity\\Media::getRequestTime\";s:7:\"display\";a:2:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;}s:12:\"configurable\";b:1;}s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:9:\"timestamp\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:514;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"The time the media item was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:558;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:589;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:632;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:674;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:22:\"field_media_audio_file\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"media.field_media_audio_file\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"1295648c-a917-438e-a846-fd85d14ae8a0\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JCHoh95CpUeBx9ch24Tmi6ru0nwmNz8xWVH4Qs7RnTg\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"media.field_media_audio_file\";s:13:\"\0*\0field_name\";s:22:\"field_media_audio_file\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:4:\"file\";s:9:\"\0*\0module\";s:4:\"file\";s:11:\"\0*\0settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_media_document\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"media.field_media_document\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"6b41e063-a182-4108-9b56-c0f4bb265180\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BdkTx7IL59MCw5a_fOZprPTOGM_wcjz-Fm8g7HV3vFk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"media.field_media_document\";s:13:\"\0*\0field_name\";s:20:\"field_media_document\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:4:\"file\";s:9:\"\0*\0module\";s:4:\"file\";s:11:\"\0*\0settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:17:\"field_media_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:23:\"media.field_media_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ae1f0138-a2f5-4881-bf90-0ade773b59b5\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0N0KSFk57p6qsq3qM4lYVGSuROvzXK-tSsdwByqUh3g\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:2:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:23:\"media.field_media_image\";s:13:\"\0*\0field_name\";s:17:\"field_media_image\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0module\";s:5:\"image\";s:11:\"\0*\0settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_media_oembed_video\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"media.field_media_oembed_video\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"b471db54-e924-4e9f-b6d7-c7e32f497206\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cNf_852Dq-fNnSaMI4LxL-J6N7bLkHuDbD9EUqOn4_U\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"media.field_media_oembed_video\";s:13:\"\0*\0field_name\";s:24:\"field_media_oembed_video\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:3:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:0;s:8:\"is_ascii\";b:0;}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_media_video_file\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"media.field_media_video_file\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"1567fe07-a329-492a-bc5f-d82e3865bd57\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z5mgbn1PIVZ5TNMByBmivqo_u3Rdk58UIzpyN4ypTeM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"media.field_media_video_file\";s:13:\"\0*\0field_name\";s:22:\"field_media_video_file\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:4:\"file\";s:9:\"\0*\0module\";s:4:\"file\";s:11:\"\0*\0settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),('entity.definitions.installed','media_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:10:\"media_type\";s:8:\"\0*\0class\";s:29:\"Drupal\\media\\Entity\\MediaType\";s:11:\"\0*\0provider\";s:5:\"media\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:29:\"Drupal\\media\\Entity\\MediaType\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:42:\"Drupal\\media\\MediaTypeAccessControlHandler\";s:4:\"form\";a:3:{s:3:\"add\";s:26:\"Drupal\\media\\MediaTypeForm\";s:4:\"edit\";s:26:\"Drupal\\media\\MediaTypeForm\";s:6:\"delete\";s:44:\"Drupal\\media\\Form\\MediaTypeDeleteConfirmForm\";}s:12:\"list_builder\";s:33:\"Drupal\\media\\MediaTypeListBuilder\";s:14:\"route_provider\";a:2:{s:4:\"html\";s:51:\"Drupal\\Core\\Entity\\Routing\\DefaultHtmlRouteProvider\";s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:22:\"administer media types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:8:\"add-form\";s:26:\"/admin/structure/media/add\";s:9:\"edit-form\";s:42:\"/admin/structure/media/manage/{media_type}\";s:11:\"delete-form\";s:49:\"/admin/structure/media/manage/{media_type}/delete\";s:23:\"entity-permissions-form\";s:54:\"/admin/structure/media/manage/{media_type}/permissions\";s:10:\"collection\";s:22:\"/admin/structure/media\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:5:\"media\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Media type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Media types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"media type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"media types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count media type\";s:6:\"plural\";s:18:\"@count media types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:22:\"config:media_type_list\";}s:14:\"\0*\0constraints\";a:2:{s:19:\"ImmutableProperties\";a:2:{i:0;s:2:\"id\";i:1;s:6:\"source\";}s:23:\"MediaMappingsConstraint\";a:0:{}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:9:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:6:\"source\";i:4;s:25:\"queue_thumbnail_downloads\";i:5;s:12:\"new_revision\";i:6;s:20:\"source_configuration\";i:7;s:9:\"field_map\";i:8;s:6:\"status\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','menu.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:4:\"menu\";s:8:\"\0*\0class\";s:25:\"Drupal\\system\\Entity\\Menu\";s:11:\"\0*\0provider\";s:6:\"system\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:25:\"Drupal\\system\\Entity\\Menu\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:38:\"Drupal\\system\\MenuAccessControlHandler\";s:7:\"storage\";s:25:\"Drupal\\system\\MenuStorage\";}s:19:\"\0*\0admin_permission\";s:15:\"administer menu\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Menus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"menus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count menu\";s:6:\"plural\";s:12:\"@count menus\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:16:\"config:menu_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:6:\"locked\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','menu_link_content.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":40:{s:5:\"\0*\0id\";s:17:\"menu_link_content\";s:8:\"\0*\0class\";s:47:\"Drupal\\menu_link_content\\Entity\\MenuLinkContent\";s:11:\"\0*\0provider\";s:17:\"menu_link_content\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:11:\"revision_id\";s:5:\"label\";s:5:\"title\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"bundle\";s:6:\"bundle\";s:9:\"published\";s:7:\"enabled\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:47:\"Drupal\\menu_link_content\\Entity\\MenuLinkContent\";s:11:\"\0*\0handlers\";a:7:{s:7:\"storage\";s:48:\"\\Drupal\\menu_link_content\\MenuLinkContentStorage\";s:14:\"storage_schema\";s:53:\"Drupal\\menu_link_content\\MenuLinkContentStorageSchema\";s:6:\"access\";s:60:\"Drupal\\menu_link_content\\MenuLinkContentAccessControlHandler\";s:4:\"form\";a:2:{s:7:\"default\";s:49:\"Drupal\\menu_link_content\\Form\\MenuLinkContentForm\";s:6:\"delete\";s:55:\"Drupal\\menu_link_content\\Form\\MenuLinkContentDeleteForm\";}s:12:\"list_builder\";s:44:\"Drupal\\menu_link_content\\MenuLinkListBuilder\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";s:10:\"moderation\";s:0:\"\";}s:19:\"\0*\0admin_permission\";s:15:\"administer menu\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"canonical\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:9:\"edit-form\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:11:\"delete-form\";s:53:\"/admin/structure/menu/item/{menu_link_content}/delete\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:17:\"menu_link_content\";s:22:\"\0*\0revision_data_table\";s:32:\"menu_link_content_field_revision\";s:17:\"\0*\0revision_table\";s:26:\"menu_link_content_revision\";s:13:\"\0*\0data_table\";s:22:\"menu_link_content_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Custom menu link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Custom menu links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"custom menu link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"custom menu links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:23:\"@count custom menu link\";s:6:\"plural\";s:24:\"@count custom menu links\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:22:\"menu_link_content_list\";}s:14:\"\0*\0constraints\";a:3:{s:17:\"MenuTreeHierarchy\";a:0:{}s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:1:{s:17:\"stringTranslation\";s:18:\"string_translation\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:20:\"revision_log_message\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','menu_link_content.field_storage_definitions',_binary 'a:22:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Entity ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"The entity ID for this menu link content entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"The content menu link UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"The menu link language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:111;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"bundle\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";s:23:\"Custom menu link bundle\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"The content menu link bundle.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:6:\"bundle\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:151;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:184;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:214;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:20:\"revision_log_message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:20:\"revision_log_message\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:251;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"enabled\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Enabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:65:\"A flag for whether the link should be enabled in menus or hidden.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:7:\"boolean\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:-1;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:7:\"enabled\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:290;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"title\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Menu link title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:46:\"The text to be used for this link in the menu.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:-5;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:5:\"title\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:344;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"description\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Shown when hovering over the menu link.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:11:\"description\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:392;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"menu_name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Menu name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:93:\"The menu name. All links with the same menu name (such as \"tools\") are part of the same menu.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:5:\"tools\";}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:9:\"menu_name\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:438;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"link\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"The location this menu link points to.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:-2;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:4:\"link\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:link\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}}s:18:\"\0*\0fieldDefinition\";r:475;}s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:3:{s:3:\"uri\";a:3:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;}s:5:\"title\";a:3:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;}s:7:\"options\";a:4:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;}}s:7:\"indexes\";a:1:{s:3:\"uri\";a:1:{i:0;a:2:{i:0;s:3:\"uri\";i:1;i:30;}}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"external\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"External\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:120:\"A flag to indicate if the link points to a full URL starting with a protocol, like http:// (1 = external, 0 = internal).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:8:\"external\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:528;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:10:\"rediscover\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"Indicates whether the menu link should be rediscovered\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:10:\"rediscover\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:570;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"weight\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Weight\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:172:\"Link weight among links in the same menu at the same depth. In the menu, the links with high weight will sink and links with a low weight will be positioned nearer the top.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:14:\"number_integer\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:6:\"number\";s:6:\"weight\";i:20;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:6:\"weight\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:607;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"expanded\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Show as expanded\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:164:\"If selected and this menu link has children, the menu will always appear expanded. This option may be overridden for the entire menu tree when placing a menu block.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:7:\"boolean\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:0;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:8:\"expanded\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:657;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"parent\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Parent plugin ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:94:\"The ID of the parent menu link plugin, or empty string when at the top level of the hierarchy.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:6:\"parent\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:709;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"The time that the menu link was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:743;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:774;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:817;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:859;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','node.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:4:\"node\";s:8:\"\0*\0class\";s:23:\"Drupal\\node\\Entity\\Node\";s:11:\"\0*\0provider\";s:4:\"node\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:12:{s:2:\"id\";s:3:\"nid\";s:8:\"revision\";s:3:\"vid\";s:6:\"bundle\";s:4:\"type\";s:5:\"label\";s:5:\"title\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"status\";s:6:\"status\";s:9:\"published\";s:6:\"status\";s:3:\"uid\";s:3:\"uid\";s:5:\"owner\";s:3:\"uid\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\node\\Entity\\Node\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:23:\"Drupal\\node\\NodeStorage\";s:14:\"storage_schema\";s:29:\"Drupal\\node\\NodeStorageSchema\";s:12:\"view_builder\";s:27:\"Drupal\\node\\NodeViewBuilder\";s:6:\"access\";s:36:\"Drupal\\node\\NodeAccessControlHandler\";s:10:\"views_data\";s:25:\"Drupal\\node\\NodeViewsData\";s:4:\"form\";a:4:{s:7:\"default\";s:20:\"Drupal\\node\\NodeForm\";s:6:\"delete\";s:31:\"Drupal\\node\\Form\\NodeDeleteForm\";s:4:\"edit\";s:20:\"Drupal\\node\\NodeForm\";s:23:\"delete-multiple-confirm\";s:31:\"Drupal\\node\\Form\\DeleteMultiple\";}s:14:\"route_provider\";a:1:{s:4:\"html\";s:36:\"Drupal\\node\\Entity\\NodeRouteProvider\";}s:12:\"list_builder\";s:27:\"Drupal\\node\\NodeListBuilder\";s:11:\"translation\";s:34:\"Drupal\\node\\NodeTranslationHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";s:23:\"access content overview\";s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:7:{s:9:\"canonical\";s:12:\"/node/{node}\";s:11:\"delete-form\";s:19:\"/node/{node}/delete\";s:20:\"delete-multiple-form\";s:26:\"/admin/content/node/delete\";s:9:\"edit-form\";s:17:\"/node/{node}/edit\";s:15:\"version-history\";s:22:\"/node/{node}/revisions\";s:8:\"revision\";s:43:\"/node/{node}/revisions/{node_revision}/view\";s:6:\"create\";s:5:\"/node\";}s:21:\"\0*\0bundle_entity_type\";s:9:\"node_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:4:\"node\";s:22:\"\0*\0revision_data_table\";s:19:\"node_field_revision\";s:17:\"\0*\0revision_table\";s:13:\"node_revision\";s:13:\"\0*\0data_table\";s:15:\"node_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"content item\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"content items\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count content item\";s:6:\"plural\";s:20:\"@count content items\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:26:\"entity.node_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:1:{i:0;s:21:\"user.node_grants:view\";}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:9:\"node_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:12:\"revision_uid\";s:16:\"revision_created\";s:18:\"revision_timestamp\";s:20:\"revision_log_message\";s:12:\"revision_log\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','node.field_storage_definitions',_binary 'a:22:{s:3:\"nid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:3:\"nid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"vid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:3:\"vid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";s:12:\"Content type\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:4:\"type\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:9:\"node_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:139;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:18:\"revision_timestamp\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:18:\"revision_timestamp\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:170;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"revision_uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:12:\"revision_uid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:200;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"revision_log\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:12:\"revision_log\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:237;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:120;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:279;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored by\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:22:\"default_value_callback\";s:46:\"Drupal\\node\\Entity\\Node::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The username of the content author.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"author\";s:6:\"weight\";i:0;}}s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:8:\"settings\";a:3:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:4:\"size\";s:2:\"60\";s:11:\"placeholder\";s:0:\"\";}}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:326;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"title\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:-5;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:5:\"title\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:380;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored on\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The date and time that the content was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:9:\"timestamp\";s:6:\"weight\";i:0;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:424;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The time that the node was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:466;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"promote\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Promoted to front page\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:15;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:497;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"sticky\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Sticky at top of lists\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:16;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:6:\"sticky\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:544;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:591;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:634;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:676;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"body\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:9:\"node.body\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"26a81385-82de-46f0-8582-8c93b0fbcb01\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:9:\"node.body\";s:13:\"\0*\0field_name\";s:4:\"body\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:17:\"text_with_summary\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:11:\"field_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:16:\"node.field_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d9aff85c-3ad9-418b-b47e-58f08b64180e\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"node\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:16:\"node.field_image\";s:13:\"\0*\0field_name\";s:11:\"field_image\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0module\";s:5:\"image\";s:11:\"\0*\0settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:10:\"\0*\0deleted\";b:0;}s:10:\"field_tags\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:15:\"node.field_tags\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"81f6ea79-133f-4e53-bb0a-4169a69c4472\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:15:\"node.field_tags\";s:13:\"\0*\0field_name\";s:10:\"field_tags\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:13:\"taxonomy_term\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:16:\"field_components\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":32:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";s:2:\"-1\";s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;s:20:\"field_storage_submit\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Update settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:18:\"cardinality_number\";s:1:\"1\";}}'),('entity.definitions.installed','node_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:9:\"node_type\";s:8:\"\0*\0class\";s:27:\"Drupal\\node\\Entity\\NodeType\";s:11:\"\0*\0provider\";s:4:\"node\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:4:\"type\";s:5:\"label\";s:4:\"name\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\node\\Entity\\NodeType\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:40:\"Drupal\\node\\NodeTypeAccessControlHandler\";s:4:\"form\";a:3:{s:3:\"add\";s:24:\"Drupal\\node\\NodeTypeForm\";s:4:\"edit\";s:24:\"Drupal\\node\\NodeTypeForm\";s:6:\"delete\";s:38:\"Drupal\\node\\Form\\NodeTypeDeleteConfirm\";}s:14:\"route_provider\";a:1:{s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}s:12:\"list_builder\";s:31:\"Drupal\\node\\NodeTypeListBuilder\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:24:\"administer content types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:9:\"edit-form\";s:41:\"/admin/structure/types/manage/{node_type}\";s:11:\"delete-form\";s:48:\"/admin/structure/types/manage/{node_type}/delete\";s:23:\"entity-permissions-form\";s:53:\"/admin/structure/types/manage/{node_type}/permissions\";s:10:\"collection\";s:22:\"/admin/structure/types\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:4:\"node\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Content types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"content types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count content type\";s:6:\"plural\";s:20:\"@count content types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:21:\"config:node_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:7:{i:0;s:4:\"name\";i:1;s:4:\"type\";i:2;s:11:\"description\";i:3;s:4:\"help\";i:4;s:12:\"new_revision\";i:5;s:12:\"preview_mode\";i:6;s:17:\"display_submitted\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','paragraph.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:9:\"paragraph\";s:8:\"\0*\0class\";s:34:\"Drupal\\paragraphs\\Entity\\Paragraph\";s:11:\"\0*\0provider\";s:10:\"paragraphs\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:0;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"bundle\";s:4:\"type\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:11:\"revision_id\";s:9:\"published\";s:6:\"status\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:34:\"Drupal\\paragraphs\\Entity\\Paragraph\";s:11:\"\0*\0handlers\";a:7:{s:12:\"view_builder\";s:38:\"Drupal\\paragraphs\\ParagraphViewBuilder\";s:6:\"access\";s:47:\"Drupal\\paragraphs\\ParagraphAccessControlHandler\";s:14:\"storage_schema\";s:40:\"Drupal\\paragraphs\\ParagraphStorageSchema\";s:4:\"form\";a:3:{s:7:\"default\";s:36:\"Drupal\\Core\\Entity\\ContentEntityForm\";s:6:\"delete\";s:42:\"Drupal\\Core\\Entity\\ContentEntityDeleteForm\";s:4:\"edit\";s:36:\"Drupal\\Core\\Entity\\ContentEntityForm\";}s:10:\"views_data\";s:28:\"Drupal\\views\\EntityViewsData\";s:7:\"storage\";s:46:\"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage\";s:10:\"moderation\";s:0:\"\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";s:15:\"paragraphs_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Paragraph type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:15:\"paragraphs_item\";s:22:\"\0*\0revision_data_table\";s:35:\"paragraphs_item_revision_field_data\";s:17:\"\0*\0revision_table\";s:24:\"paragraphs_item_revision\";s:13:\"\0*\0data_table\";s:26:\"paragraphs_item_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Paragraphs\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Paragraphs\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:16:\"@count Paragraph\";s:6:\"plural\";s:17:\"@count Paragraphs\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:32:\"entity.paragraphs_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:14:\"paragraph_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:7:{s:33:\"entity_revision_parent_type_field\";s:11:\"parent_type\";s:31:\"entity_revision_parent_id_field\";s:9:\"parent_id\";s:39:\"entity_revision_parent_field_name_field\";s:17:\"parent_field_name\";s:33:\"common_reference_revisions_target\";b:1;s:27:\"content_translation_ui_skip\";b:1;s:35:\"default_reference_revision_settings\";a:4:{s:20:\"field_storage_config\";a:2:{s:11:\"cardinality\";i:-1;s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}}s:12:\"field_config\";a:1:{s:8:\"settings\";a:1:{s:7:\"handler\";s:17:\"default:paragraph\";}}s:19:\"entity_form_display\";a:1:{s:4:\"type\";s:10:\"paragraphs\";}s:19:\"entity_view_display\";a:1:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";}}s:31:\"serialized_field_property_names\";a:1:{s:17:\"behavior_settings\";a:1:{i:0;s:5:\"value\";}}}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','paragraph.field_storage_definitions',_binary 'a:79:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"The paragraphs entity language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";s:14:\"Paragraph type\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:4:\"type\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:15:\"paragraphs_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:135;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:166;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored on\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"The time that the Paragraph was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:6:\"region\";s:6:\"hidden\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:210;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"parent_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Parent ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:63:\"The ID of the parent entity of which this entity is referenced.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:9:\"parent_id\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:247;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"parent_type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Parent type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"The entity parent type to which this entity is referenced.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:11:\"parent_type\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:282;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:17:\"parent_field_name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Parent field name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:64:\"The entity parent field name to which this entity is referenced.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:17:\"parent_field_name\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:317;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:17:\"behavior_settings\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Behavior settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"The behavior plugin settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:17:\"behavior_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:352;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:387;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:430;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:472;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:18:\"field_ept_settings\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ept_settings\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"aed153c8-a66a-428a-be76-0d9ff9c57e30\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HvKMBmRf1ancerUpnNjtwfTeY-R4_vPBnsqEe9j-ovs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:8:\"ept_core\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ept_settings\";s:13:\"\0*\0field_name\";s:18:\"field_ept_settings\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:12:\"ept_settings\";s:9:\"\0*\0module\";s:8:\"ept_core\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ept_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:25:\"paragraph.field_ept_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d142f67c-eb14-402b-8d63-83e817038f33\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjnRL-vwDWFKmoYTCU9jkwjIlui_gNnOJnIwnLo9m2k\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:25:\"paragraph.field_ept_title\";s:13:\"\0*\0field_name\";s:15:\"field_ept_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"field_ept_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:24:\"paragraph.field_ept_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"e76f4c36-a02a-4c1e-b34f-cecbd30657dd\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7r3ygKhgvLH2hBQgQ6uizJgLea8q4TUMhKv9AysHhVw\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:24:\"paragraph.field_ept_text\";s:13:\"\0*\0field_name\";s:14:\"field_ept_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ept_accordion\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ept_accordion\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"c9282b5e-9cbb-4d37-84d7-b405cf59a041\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"99EX18edsQlLBda3J37pHASAxF4OUjSVJ4_nSq1pW94\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ept_accordion\";s:13:\"\0*\0field_name\";s:19:\"field_ept_accordion\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ept_accordion_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ept_accordion_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"012f2184-9082-4983-9239-7dac48864d9c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6S4PB05UjgSgHEDSalqgqkJHWyCcYsdkgPKTvGC2c8s\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ept_accordion_title\";s:13:\"\0*\0field_name\";s:25:\"field_ept_accordion_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ept_accordion_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_accordion_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"177e4cd0-bbd1-44cd-9d3f-5b5dd4378ed4\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l5c0DoOjgcErJEjFGkUqN_upYgubdHpE_MiwbMK2YRI\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_accordion_text\";s:13:\"\0*\0field_name\";s:24:\"field_ept_accordion_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_basic_button_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_basic_button_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"360bef36-b4f7-492b-9677-6170eebdf2bb\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Tj1qQArNpaPeg2XmPed8WY2JiAk8p21-R1HVn28zVoY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_basic_button_link\";s:13:\"\0*\0field_name\";s:27:\"field_ept_basic_button_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ept_block_block\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":32:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ept_block_block\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"58c5cc3e-9949-4686-882a-a56b59c60ea8\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hAESsXJ5KZsWYKr-KB5wJoHNBdcOTlIFJUomBW8VxoU\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ept_block_block\";s:13:\"\0*\0field_name\";s:21:\"field_ept_block_block\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:11:\"block_field\";s:9:\"\0*\0module\";s:11:\"block_field\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;s:20:\"field_storage_submit\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Update settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:18:\"cardinality_number\";s:1:\"1\";}s:31:\"field_ept_bootstrap_button_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:41:\"paragraph.field_ept_bootstrap_button_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"bceb6f2f-b114-41f5-8b07-0ce990d0087a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BweaoyqqEqOIBPWV2qKw_2N4R6oBSudk91cCNPtz_iY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:41:\"paragraph.field_ept_bootstrap_button_link\";s:13:\"\0*\0field_name\";s:31:\"field_ept_bootstrap_button_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ept_carousel_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_carousel_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"1da3ad04-a3d6-45a2-8a2e-100f0d629948\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ViB2NrYfe_RWvrvvb9X_U6kuX0eI47m5Wpa6hCFqZWE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_carousel_image\";s:13:\"\0*\0field_name\";s:24:\"field_ept_carousel_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ept_carousel\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ept_carousel\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"fbb51140-67d8-4112-868c-19dd46c31b98\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RbALd0Xz78o-CtP2iD8j7s8h1scHn1lSdm-_EQqZyrY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ept_carousel\";s:13:\"\0*\0field_name\";s:18:\"field_ept_carousel\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ept_carousel_caption\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"paragraph.field_ept_carousel_caption\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"4bdff313-152c-4ea9-ba49-6f433c48203a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HeWBlq69mptI0nGWU0dliRAS9rVOa2HzuJbUbzsJg4M\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"paragraph.field_ept_carousel_caption\";s:13:\"\0*\0field_name\";s:26:\"field_ept_carousel_caption\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:17:\"field_ept_columns\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:27:\"paragraph.field_ept_columns\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7518ddce-1000-4e47-8c93-f8230ca40081\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lIenGVJ8vS3WAEr1xteI9sDUdCoc-UNgbf7xDipU4_s\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:27:\"paragraph.field_ept_columns\";s:13:\"\0*\0field_name\";s:17:\"field_ept_columns\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ept_countdown_date\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_countdown_date\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"5741fa83-8e57-4e60-99ce-6e8bd5bf8b78\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SWGbKy8XYRkCxbrmDvY2UYyxzAKxcSL7ouH4CljiXbY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:8:\"datetime\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_countdown_date\";s:13:\"\0*\0field_name\";s:24:\"field_ept_countdown_date\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:8:\"datetime\";s:9:\"\0*\0module\";s:8:\"datetime\";s:11:\"\0*\0settings\";a:1:{s:13:\"datetime_type\";s:8:\"datetime\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ept_counter_number\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_counter_number\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"072a57f4-9c76-4a9a-a3f4-f13ef03b81be\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MzVJsn5k9Si1YXppdAIDnZzJ1W16U44-V2RnkeyaeyI\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_counter_number\";s:13:\"\0*\0field_name\";s:24:\"field_ept_counter_number\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ept_counter_items\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"paragraph.field_ept_counter_items\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"fa2205d7-3b05-4d76-a029-30510c45d952\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vFwfw4KEUwjCwBs2-7ay4ctFQ2ObvCZYU16zxuQC5HM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"paragraph.field_ept_counter_items\";s:13:\"\0*\0field_name\";s:23:\"field_ept_counter_items\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ept_counter_icon\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"paragraph.field_ept_counter_icon\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"bd174355-0ad0-4843-9909-9069e6e2eac2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I0JA4V_sLzmSUMXzEuZ7m6J_MFEw5Nrb7bG9XU34Ucc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"paragraph.field_ept_counter_icon\";s:13:\"\0*\0field_name\";s:22:\"field_ept_counter_icon\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ept_counter_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"paragraph.field_ept_counter_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"a62c9e27-ad8b-430d-85ce-9db276ada8eb\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CTuSHda2RHGJciX7ZF12J7Y9A3TK_RrRj7CRxyKyNGA\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"paragraph.field_ept_counter_title\";s:13:\"\0*\0field_name\";s:23:\"field_ept_counter_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:29:\"field_ept_counter_description\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:39:\"paragraph.field_ept_counter_description\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"385056ad-483b-468c-8fc7-fa477f32138c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Vb_uSodiEH1YHgcoZFitK_cSCdO65_4U1fUOrl-0G-0\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:39:\"paragraph.field_ept_counter_description\";s:13:\"\0*\0field_name\";s:29:\"field_ept_counter_description\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ept_cta_second_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ept_cta_second_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"e5ac8a81-1f96-4b7d-b8e0-6d9b2c08fcbd\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DHvUvJxjsMX4y4-L8sAyVpFvA0pptpqcHZ8p_EMBBdU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ept_cta_second_link\";s:13:\"\0*\0field_name\";s:25:\"field_ept_cta_second_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ept_cta_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ept_cta_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ef4b1edf-7e44-4fd4-9484-139b43615d23\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LvryVrIdU5CC3UNEhpU7Vej6X8Y4RKKDsOdhseGGUVg\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ept_cta_link\";s:13:\"\0*\0field_name\";s:18:\"field_ept_cta_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ept_cta_column_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"paragraph.field_ept_cta_column_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"2545ccb9-b7f9-49f1-a002-1aa70a099849\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BVZIBdZwlh9CG5xDwjnekBIIuVdEEtKvFPci5rwGdA0\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"paragraph.field_ept_cta_column_image\";s:13:\"\0*\0field_name\";s:26:\"field_ept_cta_column_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ept_hero_second_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"paragraph.field_ept_hero_second_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"a51e7805-3dcf-415a-b08c-6e41b660115d\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_LEdcxkwVZPMeBjAfFM_DTcqJxHu-SXmfvkzYA16OTE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"paragraph.field_ept_hero_second_link\";s:13:\"\0*\0field_name\";s:26:\"field_ept_hero_second_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ept_hero_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ept_hero_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"89e38776-3ba0-4f79-9023-af5e40b20171\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XgZuheOtVwvMdFAli6FX9XwC6jCtmfQsa4Y--V6AWLk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ept_hero_link\";s:13:\"\0*\0field_name\";s:19:\"field_ept_hero_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_hero_column_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_hero_column_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"0bd5b0b1-4d3b-472e-ac51-086416f9360a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"knr6QfLVidPHSzwjlRdOZ6PqAiVNnXT73--qFC4pZqo\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_hero_column_image\";s:13:\"\0*\0field_name\";s:27:\"field_ept_hero_column_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_hero_title_prefix\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_hero_title_prefix\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"be93c2a2-2803-47c8-8cbb-88ab3561ae6c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HgeEpS7HHbPsoLeKHrpRrax2ttxvlJADvMU3R-HwVf4\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_hero_title_prefix\";s:13:\"\0*\0field_name\";s:27:\"field_ept_hero_title_prefix\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_ept_image_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"paragraph.field_ept_image_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"389f5e03-e7e9-4fb0-bdb5-618f4ada2579\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VKNAP2cuu9mjHYh_BiZTS3nC4gx2nPLjvdAFIHAhJs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"paragraph.field_ept_image_link\";s:13:\"\0*\0field_name\";s:20:\"field_ept_image_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ept_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:25:\"paragraph.field_ept_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"a3a4414c-7488-42d9-ad4e-706dbb16b1da\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t2q8Lh-nuJZ2Ozh8PR1_zVbozcHAD18kLOnsz0e4oxY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:25:\"paragraph.field_ept_image\";s:13:\"\0*\0field_name\";s:15:\"field_ept_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ept_image_caption\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"paragraph.field_ept_image_caption\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d90ba792-7242-4c28-a755-2203bfbd33dc\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-2PNM_k1cGXc-Q0fAWwWKl0WSoTksX8UcJ3-t0wUn1s\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"paragraph.field_ept_image_caption\";s:13:\"\0*\0field_name\";s:23:\"field_ept_image_caption\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ept_image_gallery\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"paragraph.field_ept_image_gallery\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"a25a51c6-fb73-441d-bfe4-baf60db380f2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"42vUEff48hmnJOtdaZMLlF0wtf_QYb_mBJO5EVMCKBk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"paragraph.field_ept_image_gallery\";s:13:\"\0*\0field_name\";s:23:\"field_ept_image_gallery\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ept_micromodal_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"paragraph.field_ept_micromodal_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"58a0c8d3-2aaa-43a3-af29-df451a7410e3\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9wlDgbRXeLI7j3BoH97N3phJfeK2l1E2osqZh_FRkh4\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"paragraph.field_ept_micromodal_title\";s:13:\"\0*\0field_name\";s:26:\"field_ept_micromodal_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ept_quote_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ept_quote_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"39b9627d-fdb9-4ed9-afc4-0c4d133a92c6\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tQ8LcsYTu_fXhMAvx5We58I0EB2mrFc9tC42tO2YpQ4\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ept_quote_image\";s:13:\"\0*\0field_name\";s:21:\"field_ept_quote_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ept_quote_author\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"paragraph.field_ept_quote_author\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"f68b8da9-803f-4c9b-8f4c-4fc24f899205\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yN0vOPqU28gSDN6dC5uNd2vwbTDVhm0njE_mJ2k_rCk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"paragraph.field_ept_quote_author\";s:13:\"\0*\0field_name\";s:22:\"field_ept_quote_author\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_slick_slider_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_slick_slider_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"3adc57b0-490d-4760-8c68-b19c339fedb5\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"urQvYyrbemmSrIdbqn5B3hiHO3OGBgCpwmTx0L9ipCM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_slick_slider_link\";s:13:\"\0*\0field_name\";s:27:\"field_ept_slick_slider_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:28:\"field_ept_slick_slider_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:38:\"paragraph.field_ept_slick_slider_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d985b37a-8f1d-4d3c-8d92-09cb8326cf66\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LzVCCy3JB_QNYYe-TIA7NOSStFsPdMhJRj2kRx6xp48\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:38:\"paragraph.field_ept_slick_slider_image\";s:13:\"\0*\0field_name\";s:28:\"field_ept_slick_slider_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ept_slick_slider\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"paragraph.field_ept_slick_slider\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"467150cb-7feb-412a-9426-4b2a3f4a1caa\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"p4cFkBoz3tkJW1Ep5zM4g_f4mQ-XFHh3pShn7qHErpU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"paragraph.field_ept_slick_slider\";s:13:\"\0*\0field_name\";s:22:\"field_ept_slick_slider\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_slick_slider_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_slick_slider_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d8e5d125-f4f7-4c1d-ac26-f7468f91d3b9\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9lgsbO7ntDggj0S64_Kj04ysNSAJqsLLVWCg1sASI7o\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_slick_slider_text\";s:13:\"\0*\0field_name\";s:27:\"field_ept_slick_slider_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ept_slideshow_slide\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ept_slideshow_slide\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d704c8d4-b783-49b6-af10-1f4524374151\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qxeflsuOm7AVY0acEDYWC8RbV1WUHCbVdEWrV-i8xCU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ept_slideshow_slide\";s:13:\"\0*\0field_name\";s:25:\"field_ept_slideshow_slide\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ept_slideshow_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_slideshow_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"08a96db8-eb88-4875-8250-d218a934e839\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j3IfmwQ3lYIJp87Put31sIn-_9bc3uFqZWFLa_w_9hk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_slideshow_link\";s:13:\"\0*\0field_name\";s:24:\"field_ept_slideshow_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ept_slideshow\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ept_slideshow\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"1a9f268a-efba-464e-854e-f46e7e1341e9\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNz95cfhiI0VPQ9jlgmyexwx_snf3hcYXB3N76R6FEg\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ept_slideshow\";s:13:\"\0*\0field_name\";s:19:\"field_ept_slideshow\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ept_slideshow_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ept_slideshow_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"c605bbbd-911f-4bca-9f1d-7575ba23063c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tyAlxAEOc2ScLxGA0DPp-lg0u4x8VXHrFuotd44B_SE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ept_slideshow_title\";s:13:\"\0*\0field_name\";s:25:\"field_ept_slideshow_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ept_slideshow_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_slideshow_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"8f6db9bb-d214-4b8e-a41e-8e68af02013e\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hf7ieZizeOOo0vAYdXIuWovA7ihSiu5RQ6PQD9LV27c\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_slideshow_text\";s:13:\"\0*\0field_name\";s:24:\"field_ept_slideshow_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ept_stats_item_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ept_stats_item_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"48fc10e7-9c7a-4b33-8f60-3ce608c713c5\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r9tIHirJngA0lU8nZzF4zo3Sk3sZoNMDm7tn4Q8f6nU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ept_stats_item_link\";s:13:\"\0*\0field_name\";s:25:\"field_ept_stats_item_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ept_stats_item_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"paragraph.field_ept_stats_item_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"32ff7444-1fb2-4c29-97a3-9e9f53ec491a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UoI74uzcaxvNAutge4YEMTgWFuRMeasXrgpq3PK1sVs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"paragraph.field_ept_stats_item_image\";s:13:\"\0*\0field_name\";s:26:\"field_ept_stats_item_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ept_stats\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:25:\"paragraph.field_ept_stats\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"54f29aab-0b38-45f1-bef4-33ea7848198c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A2WIvrY8Lq2oUgdXcZ6AeYNUvyM4mmPAuE7W3ZK_2Wc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:25:\"paragraph.field_ept_stats\";s:13:\"\0*\0field_name\";s:15:\"field_ept_stats\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ept_stats_item_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ept_stats_item_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"9bab1d24-d574-48e2-8d0e-4ab68fb47d98\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IMNMgfxAACwo5FdbEzobs2cmUZRx-IryVkWAVFd6jPc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ept_stats_item_text\";s:13:\"\0*\0field_name\";s:25:\"field_ept_stats_item_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_stats_item_number\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_stats_item_number\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"e0b4af62-c275-4029-b2a7-59ffabd9c786\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HhOT5HnntE62swJxbAxEUWcqiYJnPIfz8wawWbRbXDs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_stats_item_number\";s:13:\"\0*\0field_name\";s:27:\"field_ept_stats_item_number\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"field_ept_tabs\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:24:\"paragraph.field_ept_tabs\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"79fcf2b8-c7f0-45ad-b0c1-f2032eef3896\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NMqcA7Fqw60GbpdVeUtmztxo2zdXkrGvZx8twbTDDeU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:24:\"paragraph.field_ept_tabs\";s:13:\"\0*\0field_name\";s:14:\"field_ept_tabs\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ept_tab_page\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ept_tab_page\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"dd8a6a77-dce1-4167-81fc-78b560cda129\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HG0HGpRQXhX56PVuj3x5C5jDc-vtEneALavRoeN1CvM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ept_tab_page\";s:13:\"\0*\0field_name\";s:18:\"field_ept_tab_page\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:4:\"node\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ept_tab_content\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ept_tab_content\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"87c56ad4-62d6-4644-86c1-680e4755ff8b\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fKb1I7aWTTDXPpSXxFasd3Do_zu03KEABHYH6l26zZU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"options\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ept_tab_content\";s:13:\"\0*\0field_name\";s:21:\"field_ept_tab_content\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:11:\"list_string\";s:9:\"\0*\0module\";s:7:\"options\";s:11:\"\0*\0settings\";a:2:{s:14:\"allowed_values\";a:4:{s:4:\"text\";s:4:\"Text\";s:4:\"page\";s:4:\"Page\";s:5:\"block\";s:5:\"Block\";s:5:\"views\";s:5:\"Views\";}s:23:\"allowed_values_function\";s:0:\"\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ept_tab_block\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ept_tab_block\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"14901660-c7de-459b-8e6b-6065e1894829\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mkRqIh2Wq5dPyqwbNdS4O7366xpiXfnEqoCKO_Dxil8\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ept_tab_block\";s:13:\"\0*\0field_name\";s:19:\"field_ept_tab_block\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:11:\"block_field\";s:9:\"\0*\0module\";s:11:\"block_field\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ept_tab_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ept_tab_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"75781815-4f60-47eb-bdc4-255e273d1add\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jmZoEFoCrYRXWTQoBNH-lk2Jtzlrk1QgYJW-ZwiojjU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ept_tab_title\";s:13:\"\0*\0field_name\";s:19:\"field_ept_tab_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"text\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:1:{s:10:\"max_length\";i:255;}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ept_tab_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ept_tab_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"843571d5-1f13-41be-91d6-4a2cdc24036d\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-LqQ-u0-ZIOFFNbSXCCLceO2nHJcofY3jorF2Bo_oOs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ept_tab_text\";s:13:\"\0*\0field_name\";s:18:\"field_ept_tab_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ept_tab_views\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ept_tab_views\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"0210aa9b-f809-485d-9dc9-01d5b19a7a97\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yuhCLkHFy1lOVHdkbi-9gSbiwW6Cz9cKfJdJaYwK_Pk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ept_tab_views\";s:13:\"\0*\0field_name\";s:19:\"field_ept_tab_views\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:14:\"viewsreference\";s:9:\"\0*\0module\";s:14:\"viewsreference\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_ept_tiles_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"paragraph.field_ept_tiles_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"62135f80-efc0-4ec3-883a-ce4ccfe66aaa\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ca5c5aWMZPNjvFUQqM813ltjPOGiBvCBP1o5N8IrcOM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"paragraph.field_ept_tiles_link\";s:13:\"\0*\0field_name\";s:20:\"field_ept_tiles_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ept_tiles_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ept_tiles_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"c84089e9-ca27-4ede-81db-501ab243fe10\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LTIRUfdCjzSopVuoQqk229l5haSvo7JDJ2W9r1MheDo\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ept_tiles_image\";s:13:\"\0*\0field_name\";s:21:\"field_ept_tiles_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ept_tiles\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:25:\"paragraph.field_ept_tiles\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ad3c2c1b-78c7-400a-a114-8f5a64daf409\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XenLJeS9-3QAxnei6iPwJsGOprgjG7bUCwDd60onVWw\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:25:\"paragraph.field_ept_tiles\";s:13:\"\0*\0field_name\";s:15:\"field_ept_tiles\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ept_clickable_tile\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ept_clickable_tile\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"776f5eb1-0740-473f-b278-4678ab1e0a4e\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKnQMenIUygu6qoP8n4_EzChFXMkjnwf78bFFBWCN0w\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ept_clickable_tile\";s:13:\"\0*\0field_name\";s:24:\"field_ept_clickable_tile\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ept_tiles_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ept_tiles_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"a21fa265-c368-46f8-b0bf-ccd4251290bf\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fWLTZKbXw0jB-UFCqh6l4jRNvxOPFhGWVUKUjcIHfEg\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ept_tiles_title\";s:13:\"\0*\0field_name\";s:21:\"field_ept_tiles_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_ept_tiles_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"paragraph.field_ept_tiles_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"095f6e1d-c38c-4e36-824d-929e502f2c16\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"K1TV7SR5GOPQTJv3GF_zAIsJciKLKB5xd_eo3WUc5HA\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"paragraph.field_ept_tiles_text\";s:13:\"\0*\0field_name\";s:20:\"field_ept_tiles_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ept_video\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:25:\"paragraph.field_ept_video\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"30383ff9-015d-4872-a3cb-3c814a4683f6\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WUq7ljAeKbQ5WQGxUm1FFT157H56wcSHSihAGR-RPhc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:25:\"paragraph.field_ept_video\";s:13:\"\0*\0field_name\";s:15:\"field_ept_video\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_videos_and_images\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_videos_and_images\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"fb3b02a6-684b-4508-8b49-e87fa4e916c1\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P8bQebl9F2OCnDtVw7LFuwUlmGfUGA7HLJaYolmUgpU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:26:\"entity_reference_revisions\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_videos_and_images\";s:13:\"\0*\0field_name\";s:27:\"field_ept_videos_and_images\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ept_gallery_item\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"paragraph.field_ept_gallery_item\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"a1361495-0a6d-4f18-8570-b713e198ddf3\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8JLKZdRZR-OD6hbmGc3VHufx5PLi683tbf4QM_K4ZAU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"paragraph.field_ept_gallery_item\";s:13:\"\0*\0field_name\";s:22:\"field_ept_gallery_item\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ept_gallery_item_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_gallery_item_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ceb57be4-05e2-49c4-afad-48cb1341e682\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cWuIwOJOPOwoJ4OA0TCSko2wR73oMOOVlyC7clefebo\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_gallery_item_text\";s:13:\"\0*\0field_name\";s:27:\"field_ept_gallery_item_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_ept_views_view\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"paragraph.field_ept_views_view\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"8622c9ec-6687-4349-af19-885f22d99285\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GjkDxormsrh0OTX-iAPBLiJLIDg3h8b7yPlpgyt-kM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"paragraph.field_ept_views_view\";s:13:\"\0*\0field_name\";s:20:\"field_ept_views_view\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:14:\"viewsreference\";s:9:\"\0*\0module\";s:14:\"viewsreference\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),('entity.definitions.installed','paragraphs_type.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:15:\"paragraphs_type\";s:8:\"\0*\0class\";s:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\";s:11:\"\0*\0provider\";s:10:\"paragraphs\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:52:\"Drupal\\paragraphs\\ParagraphsTypeAccessControlHandler\";s:12:\"list_builder\";s:54:\"Drupal\\paragraphs\\Controller\\ParagraphsTypeListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:41:\"Drupal\\paragraphs\\Form\\ParagraphsTypeForm\";s:4:\"edit\";s:41:\"Drupal\\paragraphs\\Form\\ParagraphsTypeForm\";s:6:\"delete\";s:50:\"Drupal\\paragraphs\\Form\\ParagraphsTypeDeleteConfirm\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:27:\"administer paragraphs types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"edit-form\";s:50:\"/admin/structure/paragraphs_type/{paragraphs_type}\";s:11:\"delete-form\";s:57:\"/admin/structure/paragraphs_type/{paragraphs_type}/delete\";s:10:\"collection\";s:32:\"/admin/structure/paragraphs_type\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:9:\"paragraph\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Paragraphs type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Paragraphs types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Paragraphs type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Paragraphs types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:22:\"@count Paragraphs type\";s:6:\"plural\";s:23:\"@count Paragraphs types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:27:\"config:paragraphs_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:15:\"paragraphs_type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:9:\"icon_uuid\";i:3;s:12:\"icon_default\";i:4;s:11:\"description\";i:5;s:16:\"behavior_plugins\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','path_alias.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:10:\"path_alias\";s:8:\"\0*\0class\";s:34:\"Drupal\\path_alias\\Entity\\PathAlias\";s:11:\"\0*\0provider\";s:10:\"path_alias\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:11:\"revision_id\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:6:\"bundle\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:34:\"Drupal\\path_alias\\Entity\\PathAlias\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:34:\"Drupal\\path_alias\\PathAliasStorage\";s:14:\"storage_schema\";s:40:\"Drupal\\path_alias\\PathAliasStorageSchema\";s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";s:22:\"administer url aliases\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:10:\"path_alias\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";s:19:\"path_alias_revision\";s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"URL aliases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"URL aliases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:16:\"@count URL alias\";s:6:\"plural\";s:18:\"@count URL aliases\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:11:\"route_match\";}s:14:\"\0*\0constraints\";a:2:{s:15:\"UniquePathAlias\";a:0:{}s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','path_alias.field_storage_definitions',_binary 'a:8:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"und\";}}s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"path\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"System path\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"The path that this alias belongs to.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:4:\"path\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:2:{s:9:\"ValidPath\";a:0:{}s:5:\"Regex\";a:2:{s:7:\"pattern\";s:6:\"/^\\//i\";s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"The source path has to start with a slash.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}}}s:18:\"\0*\0fieldDefinition\";r:141;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"alias\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"An alias used with this path.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:5:\"alias\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:1:{s:5:\"Regex\";a:2:{s:7:\"pattern\";s:6:\"/^\\//i\";s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:41:\"The alias path has to start with a slash.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}}}s:18:\"\0*\0fieldDefinition\";r:187;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:232;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:271;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','search_page.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:11:\"search_page\";s:8:\"\0*\0class\";s:31:\"Drupal\\search\\Entity\\SearchPage\";s:11:\"\0*\0provider\";s:6:\"search\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"weight\";s:6:\"weight\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:31:\"Drupal\\search\\Entity\\SearchPage\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:44:\"Drupal\\search\\SearchPageAccessControlHandler\";s:12:\"list_builder\";s:35:\"Drupal\\search\\SearchPageListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:36:\"Drupal\\search\\Form\\SearchPageAddForm\";s:4:\"edit\";s:37:\"Drupal\\search\\Form\\SearchPageEditForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:17:\"administer search\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:6:{s:9:\"edit-form\";s:47:\"/admin/config/search/pages/manage/{search_page}\";s:11:\"delete-form\";s:54:\"/admin/config/search/pages/manage/{search_page}/delete\";s:6:\"enable\";s:54:\"/admin/config/search/pages/manage/{search_page}/enable\";s:7:\"disable\";s:55:\"/admin/config/search/pages/manage/{search_page}/disable\";s:11:\"set-default\";s:59:\"/admin/config/search/pages/manage/{search_page}/set-default\";s:10:\"collection\";s:26:\"/admin/config/search/pages\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Search page\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Search pages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"search page\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"search pages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:18:\"@count search page\";s:6:\"plural\";s:19:\"@count search pages\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:23:\"config:search_page_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"page\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:4:\"path\";i:3;s:6:\"weight\";i:4;s:6:\"plugin\";i:5;s:13:\"configuration\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','shortcut.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:8:\"shortcut\";s:8:\"\0*\0class\";s:31:\"Drupal\\shortcut\\Entity\\Shortcut\";s:11:\"\0*\0provider\";s:8:\"shortcut\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"bundle\";s:12:\"shortcut_set\";s:5:\"label\";s:5:\"title\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:31:\"Drupal\\shortcut\\Entity\\Shortcut\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:44:\"Drupal\\shortcut\\ShortcutAccessControlHandler\";s:4:\"form\";a:4:{s:7:\"default\";s:28:\"Drupal\\shortcut\\ShortcutForm\";s:3:\"add\";s:28:\"Drupal\\shortcut\\ShortcutForm\";s:4:\"edit\";s:28:\"Drupal\\shortcut\\ShortcutForm\";s:6:\"delete\";s:39:\"Drupal\\shortcut\\Form\\ShortcutDeleteForm\";}s:7:\"storage\";s:46:\"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"canonical\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";s:11:\"delete-form\";s:60:\"/admin/config/user-interface/shortcut/link/{shortcut}/delete\";s:9:\"edit-form\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";}s:21:\"\0*\0bundle_entity_type\";s:12:\"shortcut_set\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:8:\"shortcut\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";s:19:\"shortcut_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Shortcut link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Shortcut links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"shortcut link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"shortcut links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:20:\"@count shortcut link\";s:6:\"plural\";s:21:\"@count shortcut links\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:shortcut_set_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','shortcut.field_storage_definitions',_binary 'a:8:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The ID of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The UUID of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"The language code of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"shortcut_set\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"The bundle of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:12:\"shortcut_set\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:12:\"shortcut_set\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:116;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"title\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The name of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-10;s:8:\"settings\";a:1:{s:4:\"size\";i:40;}}}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:5:\"title\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:154;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"weight\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Weight\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Weight among shortcuts in the same shortcut set.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:6:\"weight\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:197;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"link\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Path\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"The location this shortcut points to.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:4:\"link\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:link\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:1;}}s:18:\"\0*\0fieldDefinition\";r:234;}s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:3:{s:3:\"uri\";a:3:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;}s:5:\"title\";a:3:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;}s:7:\"options\";a:4:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;}}s:7:\"indexes\";a:1:{s:3:\"uri\";a:1:{i:0;a:2:{i:0;s:3:\"uri\";i:1;i:30;}}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:287;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','shortcut_set.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"shortcut_set\";s:8:\"\0*\0class\";s:34:\"Drupal\\shortcut\\Entity\\ShortcutSet\";s:11:\"\0*\0provider\";s:8:\"shortcut\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:34:\"Drupal\\shortcut\\Entity\\ShortcutSet\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:34:\"Drupal\\shortcut\\ShortcutSetStorage\";s:6:\"access\";s:47:\"Drupal\\shortcut\\ShortcutSetAccessControlHandler\";s:12:\"list_builder\";s:38:\"Drupal\\shortcut\\ShortcutSetListBuilder\";s:4:\"form\";a:5:{s:7:\"default\";s:31:\"Drupal\\shortcut\\ShortcutSetForm\";s:3:\"add\";s:31:\"Drupal\\shortcut\\ShortcutSetForm\";s:4:\"edit\";s:31:\"Drupal\\shortcut\\ShortcutSetForm\";s:9:\"customize\";s:33:\"Drupal\\shortcut\\Form\\SetCustomize\";s:6:\"delete\";s:42:\"Drupal\\shortcut\\Form\\ShortcutSetDeleteForm\";}}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:14:\"customize-form\";s:69:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize\";s:11:\"delete-form\";s:66:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete\";s:9:\"edit-form\";s:59:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}\";s:10:\"collection\";s:37:\"/admin/config/user-interface/shortcut\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:8:\"shortcut\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Shortcut sets\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"shortcut sets\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count shortcut set\";s:6:\"plural\";s:20:\"@count shortcut sets\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:shortcut_set_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:3:\"set\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:2:{i:0;s:2:\"id\";i:1;s:5:\"label\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','taxonomy_term.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:13:\"taxonomy_term\";s:8:\"\0*\0class\";s:27:\"Drupal\\taxonomy\\Entity\\Term\";s:11:\"\0*\0provider\";s:8:\"taxonomy\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:3:\"tid\";s:8:\"revision\";s:11:\"revision_id\";s:6:\"bundle\";s:3:\"vid\";s:5:\"label\";s:4:\"name\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\taxonomy\\Entity\\Term\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:27:\"Drupal\\taxonomy\\TermStorage\";s:14:\"storage_schema\";s:33:\"Drupal\\taxonomy\\TermStorageSchema\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";s:12:\"list_builder\";s:36:\"Drupal\\Core\\Entity\\EntityListBuilder\";s:6:\"access\";s:40:\"Drupal\\taxonomy\\TermAccessControlHandler\";s:10:\"views_data\";s:29:\"Drupal\\taxonomy\\TermViewsData\";s:4:\"form\";a:4:{s:7:\"default\";s:24:\"Drupal\\taxonomy\\TermForm\";s:6:\"delete\";s:35:\"Drupal\\taxonomy\\Form\\TermDeleteForm\";s:15:\"revision-delete\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionDeleteForm\";s:15:\"revision-revert\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionRevertForm\";}s:14:\"route_provider\";a:1:{s:8:\"revision\";s:52:\"Drupal\\Core\\Entity\\Routing\\RevisionHtmlRouteProvider\";}s:11:\"translation\";s:38:\"Drupal\\taxonomy\\TermTranslationHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";s:24:\"access taxonomy overview\";s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:8:{s:9:\"canonical\";s:30:\"/taxonomy/term/{taxonomy_term}\";s:11:\"delete-form\";s:37:\"/taxonomy/term/{taxonomy_term}/delete\";s:9:\"edit-form\";s:35:\"/taxonomy/term/{taxonomy_term}/edit\";s:6:\"create\";s:14:\"/taxonomy/term\";s:8:\"revision\";s:69:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view\";s:20:\"revision-delete-form\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete\";s:20:\"revision-revert-form\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert\";s:15:\"version-history\";s:40:\"/taxonomy/term/{taxonomy_term}/revisions\";}s:21:\"\0*\0bundle_entity_type\";s:19:\"taxonomy_vocabulary\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:18:\"taxonomy_term_data\";s:22:\"\0*\0revision_data_table\";s:28:\"taxonomy_term_field_revision\";s:17:\"\0*\0revision_table\";s:22:\"taxonomy_term_revision\";s:13:\"\0*\0data_table\";s:24:\"taxonomy_term_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Taxonomy term\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Taxonomy terms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"taxonomy term\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"taxonomy terms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:20:\"@count taxonomy term\";s:6:\"plural\";s:21:\"@count taxonomy terms\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:40:\"entity.taxonomy_vocabulary.overview_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"taxonomy_term_list\";}s:14:\"\0*\0constraints\";a:3:{s:17:\"TaxonomyHierarchy\";a:0:{}s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:20:\"revision_log_message\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','taxonomy_term.field_storage_definitions',_binary 'a:17:{s:3:\"tid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Term ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"The term ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:3:\"tid\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"The term UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The term language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:111;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"vid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"The vocabulary to which the term is assigned.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:3:\"vid\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:19:\"taxonomy_vocabulary\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:151;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:189;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:219;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:20:\"revision_log_message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:20:\"revision_log_message\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:256;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:100;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:5:\"class\";s:22:\"Drupal\\user\\StatusItem\";}s:18:\"\0*\0fieldDefinition\";r:298;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"required\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:-5;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:346;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"description\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:12:\"text_default\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:14:\"text_textfield\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:11:\"description\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:text_long\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:390;}s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:2:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}s:6:\"format\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;}}s:7:\"indexes\";a:1:{s:6:\"format\";a:1:{i:0;s:6:\"format\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"weight\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Weight\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:51:\"The weight of this term in relation to other terms.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:6:\"weight\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:436;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"parent\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Term Parents\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The parents of this term.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"cardinality\";i:-1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:6:\"parent\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:13:\"taxonomy_term\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:476;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The time that the term was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:512;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:543;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:586;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:628;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),('entity.definitions.installed','taxonomy_vocabulary.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"taxonomy_vocabulary\";s:8:\"\0*\0class\";s:33:\"Drupal\\taxonomy\\Entity\\Vocabulary\";s:11:\"\0*\0provider\";s:8:\"taxonomy\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:3:\"vid\";s:5:\"label\";s:4:\"name\";s:6:\"weight\";s:6:\"weight\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\taxonomy\\Entity\\Vocabulary\";s:11:\"\0*\0handlers\";a:5:{s:7:\"storage\";s:33:\"Drupal\\taxonomy\\VocabularyStorage\";s:12:\"list_builder\";s:37:\"Drupal\\taxonomy\\VocabularyListBuilder\";s:6:\"access\";s:46:\"Drupal\\taxonomy\\VocabularyAccessControlHandler\";s:4:\"form\";a:4:{s:7:\"default\";s:30:\"Drupal\\taxonomy\\VocabularyForm\";s:5:\"reset\";s:40:\"Drupal\\taxonomy\\Form\\VocabularyResetForm\";s:6:\"delete\";s:41:\"Drupal\\taxonomy\\Form\\VocabularyDeleteForm\";s:8:\"overview\";s:34:\"Drupal\\taxonomy\\Form\\OverviewTerms\";}s:14:\"route_provider\";a:2:{s:4:\"html\";s:54:\"Drupal\\taxonomy\\Entity\\Routing\\VocabularyRouteProvider\";s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}}s:19:\"\0*\0admin_permission\";s:19:\"administer taxonomy\";s:24:\"\0*\0collection_permission\";s:24:\"access taxonomy overview\";s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:7:{s:8:\"add-form\";s:29:\"/admin/structure/taxonomy/add\";s:11:\"delete-form\";s:61:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete\";s:10:\"reset-form\";s:60:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset\";s:13:\"overview-form\";s:63:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview\";s:9:\"edit-form\";s:54:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}\";s:23:\"entity-permissions-form\";s:75:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions\";s:10:\"collection\";s:25:\"/admin/structure/taxonomy\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:13:\"taxonomy_term\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Taxonomy vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Taxonomy\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"vocabularies\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count vocabulary\";s:6:\"plural\";s:19:\"@count vocabularies\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:taxonomy_vocabulary_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:10:\"vocabulary\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:4:\"name\";i:1;s:3:\"vid\";i:2;s:11:\"description\";i:3;s:6:\"weight\";i:4;s:12:\"new_revision\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','tb_megamenu.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:11:\"tb_megamenu\";s:8:\"\0*\0class\";s:40:\"Drupal\\tb_megamenu\\Entity\\MegaMenuConfig\";s:11:\"\0*\0provider\";s:11:\"tb_megamenu\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:4:\"menu\";s:4:\"menu\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\tb_megamenu\\Entity\\MegaMenuConfig\";s:11:\"\0*\0handlers\";a:4:{s:12:\"list_builder\";s:42:\"Drupal\\tb_megamenu\\Controller\\MegaMenuList\";s:4:\"form\";a:3:{s:3:\"add\";s:35:\"Drupal\\tb_megamenu\\Form\\MegaMenuAdd\";s:4:\"edit\";s:35:\"Drupal\\tb_megamenu\\Form\\MegaMenuAdd\";s:6:\"delete\";s:38:\"Drupal\\tb_megamenu\\Form\\MegaMenuDelete\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:22:\"administer tb_megamenu\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:2:{s:9:\"edit-form\";s:42:\"/admin/structure/tb-megamenu/{tb_megamenu}\";s:11:\"delete-form\";s:49:\"/admin/structure/tb-megamenu/{tb_megamenu}/delete\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"TB Mega Menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:23:\"config:tb_megamenu_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:11:\"menu_config\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:4:\"menu\";i:2;s:5:\"theme\";i:3;s:12:\"block_config\";i:4;s:11:\"menu_config\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','user.entity_type',_binary 'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:4:\"user\";s:8:\"\0*\0class\";s:23:\"Drupal\\user\\Entity\\User\";s:11:\"\0*\0provider\";s:4:\"user\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:3:\"uid\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\user\\Entity\\User\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:23:\"Drupal\\user\\UserStorage\";s:14:\"storage_schema\";s:29:\"Drupal\\user\\UserStorageSchema\";s:6:\"access\";s:36:\"Drupal\\user\\UserAccessControlHandler\";s:12:\"list_builder\";s:27:\"Drupal\\user\\UserListBuilder\";s:10:\"views_data\";s:25:\"Drupal\\user\\UserViewsData\";s:14:\"route_provider\";a:1:{s:4:\"html\";s:36:\"Drupal\\user\\Entity\\UserRouteProvider\";}s:4:\"form\";a:3:{s:7:\"default\";s:23:\"Drupal\\user\\ProfileForm\";s:6:\"cancel\";s:31:\"Drupal\\user\\Form\\UserCancelForm\";s:8:\"register\";s:24:\"Drupal\\user\\RegisterForm\";}s:11:\"translation\";s:37:\"Drupal\\user\\ProfileTranslationHandler\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";s:16:\"administer users\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:9:\"canonical\";s:12:\"/user/{user}\";s:9:\"edit-form\";s:17:\"/user/{user}/edit\";s:11:\"cancel-form\";s:19:\"/user/{user}/cancel\";s:10:\"collection\";s:13:\"/admin/people\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:5:\"users\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";s:16:\"users_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"User\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Users\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"users\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count user\";s:6:\"plural\";s:12:\"@count users\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:22:\"entity.user.admin_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:9:\"user_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),('entity.definitions.installed','user.field_storage_definitions',_binary 'a:18:{s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"User ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"The user ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"The user UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}}s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The user language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:18:\"preferred_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"Preferred language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:77:\"The user\'s preferred language code for receiving emails and viewing the site.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:18:\"preferred_langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:2:{s:13:\"AllowedValues\";a:1:{s:8:\"callback\";s:60:\"Drupal\\user\\Entity\\User::getAllowedConfigurableLanguageCodes\";}s:6:\"Length\";a:1:{s:3:\"max\";i:12;}}}}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:24:\"preferred_admin_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Preferred admin language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:68:\"The user\'s preferred language code for viewing administration pages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";N;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:24:\"preferred_admin_langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:2:{s:13:\"AllowedValues\";a:1:{s:8:\"callback\";s:60:\"Drupal\\user\\Entity\\User::getAllowedConfigurableLanguageCodes\";}s:6:\"Length\";a:1:{s:3:\"max\";i:12;}}}}}s:18:\"\0*\0fieldDefinition\";r:152;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"The name of this user.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:11:\"constraints\";a:2:{s:8:\"UserName\";a:0:{}s:14:\"UserNameUnique\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:5:\"class\";s:25:\"\\Drupal\\user\\UserNameItem\";}s:18:\"\0*\0fieldDefinition\";r:192;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"pass\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Password\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The password of this user (hashed).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:1:{s:18:\"ProtectedUserField\";N;}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"pass\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:password\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:231;}s:7:\"\0*\0type\";s:8:\"password\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"mail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The email of this user.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:11:\"constraints\";a:3:{s:14:\"UserMailUnique\";N;s:16:\"UserMailRequired\";N;s:18:\"ProtectedUserField\";N;}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"mail\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:267;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"timezone\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Timezone\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The timezone of this user.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:8:\"timezone\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:4:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:1:{s:13:\"AllowedValues\";a:1:{s:8:\"callback\";s:44:\"Drupal\\user\\Entity\\User::getAllowedTimezones\";}}}}s:5:\"class\";s:24:\"Drupal\\user\\TimeZoneItem\";}s:18:\"\0*\0fieldDefinition\";r:304;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"User status\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"Whether the user is active or blocked.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:5:\"class\";s:22:\"Drupal\\user\\StatusItem\";}s:18:\"\0*\0fieldDefinition\";r:344;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The time that the user was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:386;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The time that the user was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:415;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"access\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Last access\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:46:\"The time that the user last accessed the site.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:6:\"access\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:timestamp\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:445;}s:7:\"\0*\0type\";s:9:\"timestamp\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"login\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Last login\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"The time that the user last logged in.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:5:\"login\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:timestamp\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:477;}s:7:\"\0*\0type\";s:9:\"timestamp\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"init\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Initial email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The email address used for initial account creation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"init\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:509;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"roles\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"cardinality\";i:-1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The roles the user has.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:5:\"roles\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:9:\"user_role\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:542;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:578;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"user_picture\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:17:\"user.user_picture\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"233edf85-6a6a-473c-933a-1a6a9015993a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"user\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:17:\"user.user_picture\";s:13:\"\0*\0field_name\";s:12:\"user_picture\";s:14:\"\0*\0entity_type\";s:4:\"user\";s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0module\";s:5:\"image\";s:11:\"\0*\0settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:10:\"\0*\0deleted\";b:0;}}'),('entity.definitions.installed','user_role.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:9:\"user_role\";s:8:\"\0*\0class\";s:23:\"Drupal\\user\\Entity\\Role\";s:11:\"\0*\0provider\";s:4:\"user\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:6:\"weight\";s:6:\"weight\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\user\\Entity\\Role\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:23:\"Drupal\\user\\RoleStorage\";s:6:\"access\";s:36:\"Drupal\\user\\RoleAccessControlHandler\";s:12:\"list_builder\";s:27:\"Drupal\\user\\RoleListBuilder\";s:4:\"form\";a:2:{s:7:\"default\";s:20:\"Drupal\\user\\RoleForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}}s:19:\"\0*\0admin_permission\";s:22:\"administer permissions\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:11:\"delete-form\";s:45:\"/admin/people/roles/manage/{user_role}/delete\";s:9:\"edit-form\";s:38:\"/admin/people/roles/manage/{user_role}\";s:21:\"edit-permissions-form\";s:37:\"/admin/people/permissions/{user_role}\";s:10:\"collection\";s:19:\"/admin/people/roles\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Role\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"role\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count role\";s:6:\"plural\";s:12:\"@count roles\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:21:\"config:user_role_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"role\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:6:\"weight\";i:3;s:8:\"is_admin\";i:4;s:11:\"permissions\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.definitions.installed','view.entity_type',_binary 'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:4:\"view\";s:8:\"\0*\0class\";s:24:\"Drupal\\views\\Entity\\View\";s:11:\"\0*\0provider\";s:5:\"views\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:24:\"Drupal\\views\\Entity\\View\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:16:\"administer views\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"View\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:16:\"View entity type\";}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Views\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:16:\"View entity type\";}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"view\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:16:\"View entity type\";}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"views\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:16:\"View entity type\";}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count view\";s:6:\"plural\";s:12:\"@count views\";s:7:\"context\";s:16:\"View entity type\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:16:\"config:view_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:6:\"module\";i:3;s:11:\"description\";i:4;s:3:\"tag\";i:5;s:10:\"base_table\";i:6;s:10:\"base_field\";i:7;s:7:\"display\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),('entity.storage_schema.sql','block_content.entity_schema_data',_binary 'a:4:{s:13:\"block_content\";a:2:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:11:\"unique keys\";a:1:{s:26:\"block_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:22:\"block_content_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:17:\"block_content__id\";a:1:{i:0;s:2:\"id\";}}}s:24:\"block_content_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:45:\"block_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:26:\"block_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"block_content__status_type\";a:3:{i:0;s:6:\"status\";i:1;s:4:\"type\";i:2;s:2:\"id\";}}}s:28:\"block_content_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:45:\"block_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.body',_binary 'a:2:{s:19:\"block_content__body\";a:4:{s:11:\"description\";s:42:\"Data storage for block_content field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}s:28:\"block_content_revision__body\";a:4:{s:11:\"description\";s:54:\"Revision archive storage for block_content field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.changed',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.default_langcode',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.id',_binary 'a:4:{s:13:\"block_content\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.info',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"info\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"info\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.langcode',_binary 'a:4:{s:13:\"block_content\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.reusable',_binary 'a:1:{s:24:\"block_content_field_data\";a:2:{s:6:\"fields\";a:1:{s:8:\"reusable\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:29:\"block_content_field__reusable\";a:1:{i:0;s:8:\"reusable\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_created',_binary 'a:1:{s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_default',_binary 'a:1:{s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_id',_binary 'a:4:{s:13:\"block_content\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_log',_binary 'a:1:{s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:12:\"revision_log\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_translation_affected',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.revision_user',_binary 'a:1:{s:22:\"block_content_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:45:\"block_content_field__revision_user__target_id\";a:1:{i:0;s:13:\"revision_user\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.status',_binary 'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.type',_binary 'a:2:{s:13:\"block_content\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:36:\"block_content_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}s:24:\"block_content_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:36:\"block_content_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}}'),('entity.storage_schema.sql','block_content.field_schema_data.uuid',_binary 'a:1:{s:13:\"block_content\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:32:\"block_content_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','comment.entity_schema_data',_binary 'a:2:{s:7:\"comment\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"cid\";}}s:18:\"comment_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"cid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:5:{s:39:\"comment__id__default_langcode__langcode\";a:3:{i:0;s:3:\"cid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:28:\"comment__status_comment_type\";a:3:{i:0;s:6:\"status\";i:1;s:12:\"comment_type\";i:2;s:3:\"cid\";}s:19:\"comment__status_pid\";a:2:{i:0;s:3:\"pid\";i:1;s:6:\"status\";}s:16:\"comment__num_new\";a:7:{i:0;s:9:\"entity_id\";i:1;s:11:\"entity_type\";i:2;s:12:\"comment_type\";i:3;s:6:\"status\";i:4;s:7:\"created\";i:5;s:3:\"cid\";i:6;s:6:\"thread\";}s:24:\"comment__entity_langcode\";a:4:{i:0;s:9:\"entity_id\";i:1;s:11:\"entity_type\";i:2;s:12:\"comment_type\";i:3;s:16:\"default_langcode\";}}}}'),('entity.storage_schema.sql','comment.field_schema_data.changed',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.cid',_binary 'a:2:{s:7:\"comment\";a:1:{s:6:\"fields\";a:1:{s:3:\"cid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"cid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.comment_body',_binary 'a:1:{s:21:\"comment__comment_body\";a:4:{s:11:\"description\";s:44:\"Data storage for comment field comment_body.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:114:\"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:18:\"comment_body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:19:\"comment_body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:19:\"comment_body_format\";a:1:{i:0;s:19:\"comment_body_format\";}}}}'),('entity.storage_schema.sql','comment.field_schema_data.comment_type',_binary 'a:2:{s:7:\"comment\";a:2:{s:6:\"fields\";a:1:{s:12:\"comment_type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:38:\"comment_field__comment_type__target_id\";a:1:{i:0;s:12:\"comment_type\";}}}s:18:\"comment_field_data\";a:2:{s:6:\"fields\";a:1:{s:12:\"comment_type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:38:\"comment_field__comment_type__target_id\";a:1:{i:0;s:12:\"comment_type\";}}}}'),('entity.storage_schema.sql','comment.field_schema_data.created',_binary 'a:1:{s:18:\"comment_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:22:\"comment_field__created\";a:1:{i:0;s:7:\"created\";}}}}'),('entity.storage_schema.sql','comment.field_schema_data.default_langcode',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.entity_id',_binary 'a:1:{s:18:\"comment_field_data\";a:2:{s:6:\"fields\";a:1:{s:9:\"entity_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:0:{}}}'),('entity.storage_schema.sql','comment.field_schema_data.entity_type',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"entity_type\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.field_name',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:10:\"field_name\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.homepage',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"homepage\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.hostname',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"hostname\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.langcode',_binary 'a:2:{s:7:\"comment\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.mail',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"mail\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.name',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:60;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.pid',_binary 'a:1:{s:18:\"comment_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"pid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:0:{}}}'),('entity.storage_schema.sql','comment.field_schema_data.status',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.subject',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"subject\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:64;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.thread',_binary 'a:1:{s:18:\"comment_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"thread\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','comment.field_schema_data.uid',_binary 'a:1:{s:18:\"comment_field_data\";a:3:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:29:\"comment_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}s:12:\"foreign keys\";a:1:{s:18:\"comment_field__uid\";a:2:{s:5:\"table\";s:5:\"users\";s:7:\"columns\";a:1:{s:3:\"uid\";s:3:\"uid\";}}}}}'),('entity.storage_schema.sql','comment.field_schema_data.uuid',_binary 'a:1:{s:7:\"comment\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:26:\"comment_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','file.entity_schema_data',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"fid\";}}}'),('entity.storage_schema.sql','file.field_schema_data.changed',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"file_field__changed\";a:1:{i:0;s:7:\"changed\";}}}}'),('entity.storage_schema.sql','file.field_schema_data.created',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','file.field_schema_data.fid',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:3:\"fid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','file.field_schema_data.filemime',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"filemime\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','file.field_schema_data.filename',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"filename\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','file.field_schema_data.filesize',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"filesize\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','file.field_schema_data.langcode',_binary 'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','file.field_schema_data.status',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:18:\"file_field__status\";a:1:{i:0;s:6:\"status\";}}}}'),('entity.storage_schema.sql','file.field_schema_data.uid',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:26:\"file_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),('entity.storage_schema.sql','file.field_schema_data.uri',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:3:\"uri\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:15:\"file_field__uri\";a:1:{i:0;s:3:\"uri\";}}}}'),('entity.storage_schema.sql','file.field_schema_data.uuid',_binary 'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:23:\"file_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','media.entity_schema_data',_binary 'a:4:{s:5:\"media\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"mid\";}s:11:\"unique keys\";a:1:{s:10:\"media__vid\";a:1:{i:0;s:3:\"vid\";}}}s:14:\"media_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"vid\";}s:7:\"indexes\";a:1:{s:10:\"media__mid\";a:1:{i:0;s:3:\"mid\";}}}s:16:\"media_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"mid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:37:\"media__id__default_langcode__langcode\";a:3:{i:0;s:3:\"mid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:10:\"media__vid\";a:1:{i:0;s:3:\"vid\";}s:20:\"media__status_bundle\";a:3:{i:0;s:6:\"status\";i:1;s:6:\"bundle\";i:2;s:3:\"mid\";}}}s:20:\"media_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"vid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:37:\"media__id__default_langcode__langcode\";a:3:{i:0;s:3:\"mid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','media.field_schema_data.bundle',_binary 'a:2:{s:5:\"media\";a:2:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:30:\"media_field__bundle__target_id\";a:1:{i:0;s:6:\"bundle\";}}}s:16:\"media_field_data\";a:2:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:30:\"media_field__bundle__target_id\";a:1:{i:0;s:6:\"bundle\";}}}}'),('entity.storage_schema.sql','media.field_schema_data.changed',_binary 'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.created',_binary 'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.default_langcode',_binary 'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','media.field_schema_data.field_media_audio_file',_binary 'a:2:{s:29:\"media__field_media_audio_file\";a:5:{s:11:\"description\";s:52:\"Data storage for media field field_media_audio_file.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_media_audio_file_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:30:\"field_media_audio_file_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:34:\"field_media_audio_file_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_media_audio_file_target_id\";a:1:{i:0;s:32:\"field_media_audio_file_target_id\";}}s:12:\"foreign keys\";a:1:{s:32:\"field_media_audio_file_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:32:\"field_media_audio_file_target_id\";s:3:\"fid\";}}}}s:38:\"media_revision__field_media_audio_file\";a:5:{s:11:\"description\";s:64:\"Revision archive storage for media field field_media_audio_file.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_media_audio_file_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:30:\"field_media_audio_file_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:34:\"field_media_audio_file_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_media_audio_file_target_id\";a:1:{i:0;s:32:\"field_media_audio_file_target_id\";}}s:12:\"foreign keys\";a:1:{s:32:\"field_media_audio_file_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:32:\"field_media_audio_file_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','media.field_schema_data.field_media_document',_binary 'a:2:{s:27:\"media__field_media_document\";a:5:{s:11:\"description\";s:50:\"Data storage for media field field_media_document.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_media_document_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:28:\"field_media_document_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:32:\"field_media_document_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_media_document_target_id\";a:1:{i:0;s:30:\"field_media_document_target_id\";}}s:12:\"foreign keys\";a:1:{s:30:\"field_media_document_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:30:\"field_media_document_target_id\";s:3:\"fid\";}}}}s:36:\"media_revision__field_media_document\";a:5:{s:11:\"description\";s:62:\"Revision archive storage for media field field_media_document.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_media_document_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:28:\"field_media_document_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:32:\"field_media_document_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_media_document_target_id\";a:1:{i:0;s:30:\"field_media_document_target_id\";}}s:12:\"foreign keys\";a:1:{s:30:\"field_media_document_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:30:\"field_media_document_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','media.field_schema_data.field_media_image',_binary 'a:2:{s:24:\"media__field_media_image\";a:5:{s:11:\"description\";s:47:\"Data storage for media field field_media_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_media_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:21:\"field_media_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:23:\"field_media_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:23:\"field_media_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:24:\"field_media_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_media_image_target_id\";a:1:{i:0;s:27:\"field_media_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:27:\"field_media_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:27:\"field_media_image_target_id\";s:3:\"fid\";}}}}s:33:\"media_revision__field_media_image\";a:5:{s:11:\"description\";s:59:\"Revision archive storage for media field field_media_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_media_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:21:\"field_media_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:23:\"field_media_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:23:\"field_media_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:24:\"field_media_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_media_image_target_id\";a:1:{i:0;s:27:\"field_media_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:27:\"field_media_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:27:\"field_media_image_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','media.field_schema_data.field_media_oembed_video',_binary 'a:2:{s:31:\"media__field_media_oembed_video\";a:4:{s:11:\"description\";s:54:\"Data storage for media field field_media_oembed_video.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_media_oembed_video_value\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:40:\"media_revision__field_media_oembed_video\";a:4:{s:11:\"description\";s:66:\"Revision archive storage for media field field_media_oembed_video.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_media_oembed_video_value\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),('entity.storage_schema.sql','media.field_schema_data.field_media_video_file',_binary 'a:2:{s:29:\"media__field_media_video_file\";a:5:{s:11:\"description\";s:52:\"Data storage for media field field_media_video_file.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_media_video_file_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:30:\"field_media_video_file_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:34:\"field_media_video_file_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_media_video_file_target_id\";a:1:{i:0;s:32:\"field_media_video_file_target_id\";}}s:12:\"foreign keys\";a:1:{s:32:\"field_media_video_file_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:32:\"field_media_video_file_target_id\";s:3:\"fid\";}}}}s:38:\"media_revision__field_media_video_file\";a:5:{s:11:\"description\";s:64:\"Revision archive storage for media field field_media_video_file.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_media_video_file_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:30:\"field_media_video_file_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:34:\"field_media_video_file_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_media_video_file_target_id\";a:1:{i:0;s:32:\"field_media_video_file_target_id\";}}s:12:\"foreign keys\";a:1:{s:32:\"field_media_video_file_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:32:\"field_media_video_file_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','media.field_schema_data.langcode',_binary 'a:4:{s:5:\"media\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','media.field_schema_data.mid',_binary 'a:4:{s:5:\"media\";a:1:{s:6:\"fields\";a:1:{s:3:\"mid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"mid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"mid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"mid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','media.field_schema_data.name',_binary 'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.revision_created',_binary 'a:1:{s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.revision_default',_binary 'a:1:{s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.revision_log_message',_binary 'a:1:{s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:20:\"revision_log_message\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.revision_translation_affected',_binary 'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','media.field_schema_data.revision_user',_binary 'a:1:{s:14:\"media_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:37:\"media_field__revision_user__target_id\";a:1:{i:0;s:13:\"revision_user\";}}}}'),('entity.storage_schema.sql','media.field_schema_data.status',_binary 'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','media.field_schema_data.thumbnail',_binary 'a:2:{s:16:\"media_field_data\";a:3:{s:6:\"fields\";a:5:{s:20:\"thumbnail__target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:14:\"thumbnail__alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:16:\"thumbnail__title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:16:\"thumbnail__width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:17:\"thumbnail__height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:33:\"media_field__thumbnail__target_id\";a:1:{i:0;s:20:\"thumbnail__target_id\";}}s:12:\"foreign keys\";a:1:{s:33:\"media_field__thumbnail__target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:20:\"thumbnail__target_id\";s:3:\"fid\";}}}}s:20:\"media_field_revision\";a:3:{s:6:\"fields\";a:5:{s:20:\"thumbnail__target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:14:\"thumbnail__alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:16:\"thumbnail__title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:16:\"thumbnail__width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:17:\"thumbnail__height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:33:\"media_field__thumbnail__target_id\";a:1:{i:0;s:20:\"thumbnail__target_id\";}}s:12:\"foreign keys\";a:1:{s:33:\"media_field__thumbnail__target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:20:\"thumbnail__target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','media.field_schema_data.uid',_binary 'a:2:{s:16:\"media_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"media_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}s:20:\"media_field_revision\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"media_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),('entity.storage_schema.sql','media.field_schema_data.uuid',_binary 'a:1:{s:5:\"media\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:24:\"media_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','media.field_schema_data.vid',_binary 'a:4:{s:5:\"media\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.entity_schema_data',_binary 'a:4:{s:17:\"menu_link_content\";a:2:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:11:\"unique keys\";a:1:{s:30:\"menu_link_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:26:\"menu_link_content_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:21:\"menu_link_content__id\";a:1:{i:0;s:2:\"id\";}}}s:22:\"menu_link_content_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:49:\"menu_link_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:30:\"menu_link_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"menu_link_content__enabled_bundle\";a:3:{i:0;s:7:\"enabled\";i:1;s:6:\"bundle\";i:2;s:2:\"id\";}}}s:32:\"menu_link_content_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:49:\"menu_link_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.bundle',_binary 'a:2:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.changed',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.default_langcode',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.description',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"description\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"description\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.enabled',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"enabled\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"enabled\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.expanded',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"expanded\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.external',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"external\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"external\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.id',_binary 'a:4:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.langcode',_binary 'a:4:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.link',_binary 'a:2:{s:22:\"menu_link_content_data\";a:2:{s:6:\"fields\";a:3:{s:9:\"link__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:11:\"link__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:13:\"link__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:34:\"menu_link_content_field__link__uri\";a:1:{i:0;a:2:{i:0;s:9:\"link__uri\";i:1;i:30;}}}}s:32:\"menu_link_content_field_revision\";a:2:{s:6:\"fields\";a:3:{s:9:\"link__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:11:\"link__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:13:\"link__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:34:\"menu_link_content_field__link__uri\";a:1:{i:0;a:2:{i:0;s:9:\"link__uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.menu_name',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:9:\"menu_name\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.parent',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"parent\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.rediscover',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:10:\"rediscover\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_created',_binary 'a:1:{s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_default',_binary 'a:1:{s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_id',_binary 'a:4:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_log_message',_binary 'a:1:{s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:20:\"revision_log_message\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_translation_affected',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.revision_user',_binary 'a:1:{s:26:\"menu_link_content_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:29:\"menu_link_content__ef029a1897\";a:1:{i:0;s:13:\"revision_user\";}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.title',_binary 'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.uuid',_binary 'a:1:{s:17:\"menu_link_content\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:36:\"menu_link_content_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','menu_link_content.field_schema_data.weight',_binary 'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"weight\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.entity_schema_data',_binary 'a:4:{s:4:\"node\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"nid\";}s:11:\"unique keys\";a:1:{s:9:\"node__vid\";a:1:{i:0;s:3:\"vid\";}}}s:13:\"node_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"vid\";}s:7:\"indexes\";a:1:{s:9:\"node__nid\";a:1:{i:0;s:3:\"nid\";}}}s:15:\"node_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"nid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:5:{s:36:\"node__id__default_langcode__langcode\";a:3:{i:0;s:3:\"nid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:9:\"node__vid\";a:1:{i:0;s:3:\"vid\";}s:17:\"node__status_type\";a:3:{i:0;s:6:\"status\";i:1;s:4:\"type\";i:2;s:3:\"nid\";}s:15:\"node__frontpage\";a:4:{i:0;s:7:\"promote\";i:1;s:6:\"status\";i:2;s:6:\"sticky\";i:3;s:7:\"created\";}s:16:\"node__title_type\";a:2:{i:0;s:5:\"title\";i:1;a:2:{i:0;s:4:\"type\";i:1;i:4;}}}}s:19:\"node_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"vid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:36:\"node__id__default_langcode__langcode\";a:3:{i:0;s:3:\"nid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.body',_binary 'a:2:{s:10:\"node__body\";a:4:{s:11:\"description\";s:33:\"Data storage for node field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}s:19:\"node_revision__body\";a:4:{s:11:\"description\";s:45:\"Revision archive storage for node field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.changed',_binary 'a:2:{s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"node_field__changed\";a:1:{i:0;s:7:\"changed\";}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.created',_binary 'a:2:{s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"node_field__created\";a:1:{i:0;s:7:\"created\";}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.default_langcode',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','node.field_schema_data.field_components',_binary 'a:2:{s:22:\"node__field_components\";a:4:{s:11:\"description\";s:45:\"Data storage for node field field_components.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:26:\"field_components_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:35:\"field_components_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"field_components_target_id\";a:1:{i:0;s:26:\"field_components_target_id\";}s:35:\"field_components_target_revision_id\";a:1:{i:0;s:35:\"field_components_target_revision_id\";}}}s:31:\"node_revision__field_components\";a:4:{s:11:\"description\";s:57:\"Revision archive storage for node field field_components.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:26:\"field_components_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:35:\"field_components_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"field_components_target_id\";a:1:{i:0;s:26:\"field_components_target_id\";}s:35:\"field_components_target_revision_id\";a:1:{i:0;s:35:\"field_components_target_revision_id\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.field_image',_binary 'a:2:{s:17:\"node__field_image\";a:5:{s:11:\"description\";s:40:\"Data storage for node field field_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:21:\"field_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:15:\"field_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:17:\"field_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:17:\"field_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:18:\"field_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:21:\"field_image_target_id\";a:1:{i:0;s:21:\"field_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:21:\"field_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:21:\"field_image_target_id\";s:3:\"fid\";}}}}s:26:\"node_revision__field_image\";a:5:{s:11:\"description\";s:52:\"Revision archive storage for node field field_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:21:\"field_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:15:\"field_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:17:\"field_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:17:\"field_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:18:\"field_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:21:\"field_image_target_id\";a:1:{i:0;s:21:\"field_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:21:\"field_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:21:\"field_image_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','node.field_schema_data.field_tags',_binary 'a:2:{s:16:\"node__field_tags\";a:4:{s:11:\"description\";s:39:\"Data storage for node field field_tags.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_tags_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:20:\"field_tags_target_id\";a:1:{i:0;s:20:\"field_tags_target_id\";}}}s:25:\"node_revision__field_tags\";a:4:{s:11:\"description\";s:51:\"Revision archive storage for node field field_tags.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_tags_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:20:\"field_tags_target_id\";a:1:{i:0;s:20:\"field_tags_target_id\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.langcode',_binary 'a:4:{s:4:\"node\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:13:\"node_revision\";a:2:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:20:\"node_field__langcode\";a:1:{i:0;s:8:\"langcode\";}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','node.field_schema_data.nid',_binary 'a:4:{s:4:\"node\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','node.field_schema_data.promote',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"promote\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"promote\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_default',_binary 'a:1:{s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_log',_binary 'a:1:{s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:12:\"revision_log\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_timestamp',_binary 'a:1:{s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:18:\"revision_timestamp\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_translation_affected',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.revision_uid',_binary 'a:1:{s:13:\"node_revision\";a:3:{s:6:\"fields\";a:1:{s:12:\"revision_uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:35:\"node_field__revision_uid__target_id\";a:1:{i:0;s:12:\"revision_uid\";}}s:12:\"foreign keys\";a:1:{s:24:\"node_field__revision_uid\";a:2:{s:5:\"table\";s:5:\"users\";s:7:\"columns\";a:1:{s:12:\"revision_uid\";s:3:\"uid\";}}}}}'),('entity.storage_schema.sql','node.field_schema_data.status',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','node.field_schema_data.sticky',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"sticky\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"sticky\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.title',_binary 'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','node.field_schema_data.type',_binary 'a:2:{s:4:\"node\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"node_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"node_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.uid',_binary 'a:2:{s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:26:\"node_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}s:19:\"node_field_revision\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:26:\"node_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.uuid',_binary 'a:1:{s:4:\"node\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:23:\"node_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','node.field_schema_data.vid',_binary 'a:4:{s:4:\"node\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','paragraph.entity_schema_data',_binary 'a:4:{s:15:\"paragraphs_item\";a:2:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:11:\"unique keys\";a:1:{s:22:\"paragraph__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:24:\"paragraphs_item_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:13:\"paragraph__id\";a:1:{i:0;s:2:\"id\";}}}s:26:\"paragraphs_item_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:41:\"paragraph__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:22:\"paragraph__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"paragraph__status_type\";a:3:{i:0;s:6:\"status\";i:1;s:4:\"type\";i:2;s:2:\"id\";}s:25:\"paragraphs__parent_fields\";a:3:{i:0;s:11:\"parent_type\";i:1;s:9:\"parent_id\";i:2;s:17:\"parent_field_name\";}}}s:35:\"paragraphs_item_revision_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:41:\"paragraph__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:25:\"paragraphs__parent_fields\";a:3:{i:0;s:11:\"parent_type\";i:1;s:9:\"parent_id\";i:2;s:17:\"parent_field_name\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.behavior_settings',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:17:\"behavior_settings\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:17:\"behavior_settings\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.created',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.default_langcode',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_accordion',_binary 'a:2:{s:30:\"paragraph__field_ept_accordion\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ept_accordion.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_accordion_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:38:\"field_ept_accordion_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_accordion_target_id\";a:1:{i:0;s:29:\"field_ept_accordion_target_id\";}s:38:\"field_ept_accordion_target_revision_id\";a:1:{i:0;s:38:\"field_ept_accordion_target_revision_id\";}}}s:39:\"paragraph_revision__field_ept_accordion\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ept_accordion.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_accordion_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:38:\"field_ept_accordion_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_accordion_target_id\";a:1:{i:0;s:29:\"field_ept_accordion_target_id\";}s:38:\"field_ept_accordion_target_revision_id\";a:1:{i:0;s:38:\"field_ept_accordion_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_accordion_text',_binary 'a:2:{s:35:\"paragraph__field_ept_accordion_text\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_accordion_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_accordion_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:31:\"field_ept_accordion_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_accordion_text_format\";a:1:{i:0;s:31:\"field_ept_accordion_text_format\";}}}s:44:\"paragraph_revision__field_ept_accordion_text\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_accordion_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_accordion_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:31:\"field_ept_accordion_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_accordion_text_format\";a:1:{i:0;s:31:\"field_ept_accordion_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_accordion_title',_binary 'a:2:{s:36:\"paragraph__field_ept_accordion_title\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ept_accordion_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_accordion_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ept_accordion_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_accordion_title_format\";a:1:{i:0;s:32:\"field_ept_accordion_title_format\";}}}s:45:\"paragraph_revision__field_ept_accordion_title\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ept_accordion_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_accordion_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ept_accordion_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_accordion_title_format\";a:1:{i:0;s:32:\"field_ept_accordion_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_basic_button_link',_binary 'a:2:{s:38:\"paragraph__field_ept_basic_button_link\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_basic_button_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_basic_button_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:33:\"field_ept_basic_button_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:35:\"field_ept_basic_button_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_basic_button_link_uri\";a:1:{i:0;a:2:{i:0;s:31:\"field_ept_basic_button_link_uri\";i:1;i:30;}}}}s:47:\"paragraph_revision__field_ept_basic_button_link\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_basic_button_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_basic_button_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:33:\"field_ept_basic_button_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:35:\"field_ept_basic_button_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_basic_button_link_uri\";a:1:{i:0;a:2:{i:0;s:31:\"field_ept_basic_button_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_block_block',_binary 'a:2:{s:32:\"paragraph__field_ept_block_block\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_ept_block_block.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_block_block_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:30:\"field_ept_block_block_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_block_block_plugin_id\";a:1:{i:0;s:31:\"field_ept_block_block_plugin_id\";}}}s:41:\"paragraph_revision__field_ept_block_block\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_ept_block_block.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_block_block_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:30:\"field_ept_block_block_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_block_block_plugin_id\";a:1:{i:0;s:31:\"field_ept_block_block_plugin_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_bootstrap_button_link',_binary 'a:2:{s:42:\"paragraph__field_ept_bootstrap_button_link\";a:4:{s:11:\"description\";s:65:\"Data storage for paragraph field field_ept_bootstrap_button_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ept_bootstrap_button_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:37:\"field_ept_bootstrap_button_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:39:\"field_ept_bootstrap_button_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:35:\"field_ept_bootstrap_button_link_uri\";a:1:{i:0;a:2:{i:0;s:35:\"field_ept_bootstrap_button_link_uri\";i:1;i:30;}}}}s:23:\"paragraph_r__32204566b2\";a:4:{s:11:\"description\";s:77:\"Revision archive storage for paragraph field field_ept_bootstrap_button_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ept_bootstrap_button_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:37:\"field_ept_bootstrap_button_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:39:\"field_ept_bootstrap_button_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:35:\"field_ept_bootstrap_button_link_uri\";a:1:{i:0;a:2:{i:0;s:35:\"field_ept_bootstrap_button_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_carousel',_binary 'a:2:{s:29:\"paragraph__field_ept_carousel\";a:4:{s:11:\"description\";s:52:\"Data storage for paragraph field field_ept_carousel.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_carousel_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:37:\"field_ept_carousel_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_carousel_target_id\";a:1:{i:0;s:28:\"field_ept_carousel_target_id\";}s:37:\"field_ept_carousel_target_revision_id\";a:1:{i:0;s:37:\"field_ept_carousel_target_revision_id\";}}}s:38:\"paragraph_revision__field_ept_carousel\";a:4:{s:11:\"description\";s:64:\"Revision archive storage for paragraph field field_ept_carousel.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_carousel_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:37:\"field_ept_carousel_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_carousel_target_id\";a:1:{i:0;s:28:\"field_ept_carousel_target_id\";}s:37:\"field_ept_carousel_target_revision_id\";a:1:{i:0;s:37:\"field_ept_carousel_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_carousel_caption',_binary 'a:2:{s:37:\"paragraph__field_ept_carousel_caption\";a:4:{s:11:\"description\";s:60:\"Data storage for paragraph field field_ept_carousel_caption.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_carousel_caption_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:33:\"field_ept_carousel_caption_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_carousel_caption_format\";a:1:{i:0;s:33:\"field_ept_carousel_caption_format\";}}}s:46:\"paragraph_revision__field_ept_carousel_caption\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for paragraph field field_ept_carousel_caption.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_carousel_caption_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:33:\"field_ept_carousel_caption_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_carousel_caption_format\";a:1:{i:0;s:33:\"field_ept_carousel_caption_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_carousel_image',_binary 'a:2:{s:35:\"paragraph__field_ept_carousel_image\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_carousel_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:34:\"field_ept_carousel_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_carousel_image_target_id\";a:1:{i:0;s:34:\"field_ept_carousel_image_target_id\";}}}s:44:\"paragraph_revision__field_ept_carousel_image\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_carousel_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:34:\"field_ept_carousel_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_carousel_image_target_id\";a:1:{i:0;s:34:\"field_ept_carousel_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_clickable_tile',_binary 'a:2:{s:35:\"paragraph__field_ept_clickable_tile\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_clickable_tile.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_clickable_tile_value\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:44:\"paragraph_revision__field_ept_clickable_tile\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_clickable_tile.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_clickable_tile_value\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_columns',_binary 'a:2:{s:28:\"paragraph__field_ept_columns\";a:4:{s:11:\"description\";s:51:\"Data storage for paragraph field field_ept_columns.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ept_columns_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:36:\"field_ept_columns_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ept_columns_target_id\";a:1:{i:0;s:27:\"field_ept_columns_target_id\";}s:36:\"field_ept_columns_target_revision_id\";a:1:{i:0;s:36:\"field_ept_columns_target_revision_id\";}}}s:37:\"paragraph_revision__field_ept_columns\";a:4:{s:11:\"description\";s:63:\"Revision archive storage for paragraph field field_ept_columns.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ept_columns_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:36:\"field_ept_columns_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ept_columns_target_id\";a:1:{i:0;s:27:\"field_ept_columns_target_id\";}s:36:\"field_ept_columns_target_revision_id\";a:1:{i:0;s:36:\"field_ept_columns_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_countdown_date',_binary 'a:2:{s:35:\"paragraph__field_ept_countdown_date\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_countdown_date.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_countdown_date_value\";a:4:{s:11:\"description\";s:15:\"The date value.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_countdown_date_value\";a:1:{i:0;s:30:\"field_ept_countdown_date_value\";}}}s:44:\"paragraph_revision__field_ept_countdown_date\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_countdown_date.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_countdown_date_value\";a:4:{s:11:\"description\";s:15:\"The date value.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_countdown_date_value\";a:1:{i:0;s:30:\"field_ept_countdown_date_value\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_counter_description',_binary 'a:2:{s:40:\"paragraph__field_ept_counter_description\";a:4:{s:11:\"description\";s:63:\"Data storage for paragraph field field_ept_counter_description.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ept_counter_description_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:36:\"field_ept_counter_description_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ept_counter_description_format\";a:1:{i:0;s:36:\"field_ept_counter_description_format\";}}}s:23:\"paragraph_r__f6562160d8\";a:4:{s:11:\"description\";s:75:\"Revision archive storage for paragraph field field_ept_counter_description.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ept_counter_description_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:36:\"field_ept_counter_description_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ept_counter_description_format\";a:1:{i:0;s:36:\"field_ept_counter_description_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_counter_icon',_binary 'a:2:{s:33:\"paragraph__field_ept_counter_icon\";a:4:{s:11:\"description\";s:56:\"Data storage for paragraph field field_ept_counter_icon.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_counter_icon_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_counter_icon_target_id\";a:1:{i:0;s:32:\"field_ept_counter_icon_target_id\";}}}s:42:\"paragraph_revision__field_ept_counter_icon\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for paragraph field field_ept_counter_icon.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_counter_icon_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_counter_icon_target_id\";a:1:{i:0;s:32:\"field_ept_counter_icon_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_counter_items',_binary 'a:2:{s:34:\"paragraph__field_ept_counter_items\";a:4:{s:11:\"description\";s:57:\"Data storage for paragraph field field_ept_counter_items.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_counter_items_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:42:\"field_ept_counter_items_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_counter_items_target_id\";a:1:{i:0;s:33:\"field_ept_counter_items_target_id\";}s:42:\"field_ept_counter_items_target_revision_id\";a:1:{i:0;s:42:\"field_ept_counter_items_target_revision_id\";}}}s:43:\"paragraph_revision__field_ept_counter_items\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for paragraph field field_ept_counter_items.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_counter_items_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:42:\"field_ept_counter_items_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_counter_items_target_id\";a:1:{i:0;s:33:\"field_ept_counter_items_target_id\";}s:42:\"field_ept_counter_items_target_revision_id\";a:1:{i:0;s:42:\"field_ept_counter_items_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_counter_number',_binary 'a:2:{s:35:\"paragraph__field_ept_counter_number\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_counter_number.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_counter_number_value\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:44:\"paragraph_revision__field_ept_counter_number\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_counter_number.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_counter_number_value\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_counter_title',_binary 'a:2:{s:34:\"paragraph__field_ept_counter_title\";a:4:{s:11:\"description\";s:57:\"Data storage for paragraph field field_ept_counter_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_counter_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ept_counter_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_counter_title_format\";a:1:{i:0;s:30:\"field_ept_counter_title_format\";}}}s:43:\"paragraph_revision__field_ept_counter_title\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for paragraph field field_ept_counter_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_counter_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ept_counter_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_counter_title_format\";a:1:{i:0;s:30:\"field_ept_counter_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_cta_column_image',_binary 'a:2:{s:37:\"paragraph__field_ept_cta_column_image\";a:4:{s:11:\"description\";s:60:\"Data storage for paragraph field field_ept_cta_column_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:36:\"field_ept_cta_column_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ept_cta_column_image_target_id\";a:1:{i:0;s:36:\"field_ept_cta_column_image_target_id\";}}}s:46:\"paragraph_revision__field_ept_cta_column_image\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for paragraph field field_ept_cta_column_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:36:\"field_ept_cta_column_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ept_cta_column_image_target_id\";a:1:{i:0;s:36:\"field_ept_cta_column_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_cta_link',_binary 'a:2:{s:29:\"paragraph__field_ept_cta_link\";a:4:{s:11:\"description\";s:52:\"Data storage for paragraph field field_ept_cta_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:22:\"field_ept_cta_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:24:\"field_ept_cta_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:26:\"field_ept_cta_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"field_ept_cta_link_uri\";a:1:{i:0;a:2:{i:0;s:22:\"field_ept_cta_link_uri\";i:1;i:30;}}}}s:38:\"paragraph_revision__field_ept_cta_link\";a:4:{s:11:\"description\";s:64:\"Revision archive storage for paragraph field field_ept_cta_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:22:\"field_ept_cta_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:24:\"field_ept_cta_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:26:\"field_ept_cta_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"field_ept_cta_link_uri\";a:1:{i:0;a:2:{i:0;s:22:\"field_ept_cta_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_cta_second_link',_binary 'a:2:{s:36:\"paragraph__field_ept_cta_second_link\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ept_cta_second_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_cta_second_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:31:\"field_ept_cta_second_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:33:\"field_ept_cta_second_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_cta_second_link_uri\";a:1:{i:0;a:2:{i:0;s:29:\"field_ept_cta_second_link_uri\";i:1;i:30;}}}}s:45:\"paragraph_revision__field_ept_cta_second_link\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ept_cta_second_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_cta_second_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:31:\"field_ept_cta_second_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:33:\"field_ept_cta_second_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_cta_second_link_uri\";a:1:{i:0;a:2:{i:0;s:29:\"field_ept_cta_second_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_gallery_item',_binary 'a:2:{s:33:\"paragraph__field_ept_gallery_item\";a:4:{s:11:\"description\";s:56:\"Data storage for paragraph field field_ept_gallery_item.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_gallery_item_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_gallery_item_target_id\";a:1:{i:0;s:32:\"field_ept_gallery_item_target_id\";}}}s:42:\"paragraph_revision__field_ept_gallery_item\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for paragraph field field_ept_gallery_item.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_gallery_item_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_gallery_item_target_id\";a:1:{i:0;s:32:\"field_ept_gallery_item_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_gallery_item_text',_binary 'a:2:{s:38:\"paragraph__field_ept_gallery_item_text\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_gallery_item_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_gallery_item_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_gallery_item_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_gallery_item_text_format\";a:1:{i:0;s:34:\"field_ept_gallery_item_text_format\";}}}s:47:\"paragraph_revision__field_ept_gallery_item_text\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_gallery_item_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_gallery_item_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_gallery_item_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_gallery_item_text_format\";a:1:{i:0;s:34:\"field_ept_gallery_item_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_hero_column_image',_binary 'a:2:{s:38:\"paragraph__field_ept_hero_column_image\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_hero_column_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:37:\"field_ept_hero_column_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_ept_hero_column_image_target_id\";a:1:{i:0;s:37:\"field_ept_hero_column_image_target_id\";}}}s:47:\"paragraph_revision__field_ept_hero_column_image\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_hero_column_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:37:\"field_ept_hero_column_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_ept_hero_column_image_target_id\";a:1:{i:0;s:37:\"field_ept_hero_column_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_hero_link',_binary 'a:2:{s:30:\"paragraph__field_ept_hero_link\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ept_hero_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:23:\"field_ept_hero_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:25:\"field_ept_hero_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:27:\"field_ept_hero_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:23:\"field_ept_hero_link_uri\";a:1:{i:0;a:2:{i:0;s:23:\"field_ept_hero_link_uri\";i:1;i:30;}}}}s:39:\"paragraph_revision__field_ept_hero_link\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ept_hero_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:23:\"field_ept_hero_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:25:\"field_ept_hero_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:27:\"field_ept_hero_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:23:\"field_ept_hero_link_uri\";a:1:{i:0;a:2:{i:0;s:23:\"field_ept_hero_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_hero_second_link',_binary 'a:2:{s:37:\"paragraph__field_ept_hero_second_link\";a:4:{s:11:\"description\";s:60:\"Data storage for paragraph field field_ept_hero_second_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_hero_second_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:32:\"field_ept_hero_second_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:34:\"field_ept_hero_second_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_hero_second_link_uri\";a:1:{i:0;a:2:{i:0;s:30:\"field_ept_hero_second_link_uri\";i:1;i:30;}}}}s:46:\"paragraph_revision__field_ept_hero_second_link\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for paragraph field field_ept_hero_second_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_hero_second_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:32:\"field_ept_hero_second_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:34:\"field_ept_hero_second_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_hero_second_link_uri\";a:1:{i:0;a:2:{i:0;s:30:\"field_ept_hero_second_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_hero_title_prefix',_binary 'a:2:{s:38:\"paragraph__field_ept_hero_title_prefix\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_hero_title_prefix.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_hero_title_prefix_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_hero_title_prefix_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_hero_title_prefix_format\";a:1:{i:0;s:34:\"field_ept_hero_title_prefix_format\";}}}s:47:\"paragraph_revision__field_ept_hero_title_prefix\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_hero_title_prefix.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_hero_title_prefix_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_hero_title_prefix_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_hero_title_prefix_format\";a:1:{i:0;s:34:\"field_ept_hero_title_prefix_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_image',_binary 'a:2:{s:26:\"paragraph__field_ept_image\";a:4:{s:11:\"description\";s:49:\"Data storage for paragraph field field_ept_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_image_target_id\";a:1:{i:0;s:25:\"field_ept_image_target_id\";}}}s:35:\"paragraph_revision__field_ept_image\";a:4:{s:11:\"description\";s:61:\"Revision archive storage for paragraph field field_ept_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_image_target_id\";a:1:{i:0;s:25:\"field_ept_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_image_caption',_binary 'a:2:{s:34:\"paragraph__field_ept_image_caption\";a:4:{s:11:\"description\";s:57:\"Data storage for paragraph field field_ept_image_caption.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_image_caption_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ept_image_caption_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_image_caption_format\";a:1:{i:0;s:30:\"field_ept_image_caption_format\";}}}s:43:\"paragraph_revision__field_ept_image_caption\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for paragraph field field_ept_image_caption.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_image_caption_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ept_image_caption_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_image_caption_format\";a:1:{i:0;s:30:\"field_ept_image_caption_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_image_gallery',_binary 'a:2:{s:34:\"paragraph__field_ept_image_gallery\";a:4:{s:11:\"description\";s:57:\"Data storage for paragraph field field_ept_image_gallery.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_image_gallery_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_image_gallery_target_id\";a:1:{i:0;s:33:\"field_ept_image_gallery_target_id\";}}}s:43:\"paragraph_revision__field_ept_image_gallery\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for paragraph field field_ept_image_gallery.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_image_gallery_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_image_gallery_target_id\";a:1:{i:0;s:33:\"field_ept_image_gallery_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_image_link',_binary 'a:2:{s:31:\"paragraph__field_ept_image_link\";a:4:{s:11:\"description\";s:54:\"Data storage for paragraph field field_ept_image_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_image_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:26:\"field_ept_image_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:28:\"field_ept_image_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ept_image_link_uri\";a:1:{i:0;a:2:{i:0;s:24:\"field_ept_image_link_uri\";i:1;i:30;}}}}s:40:\"paragraph_revision__field_ept_image_link\";a:4:{s:11:\"description\";s:66:\"Revision archive storage for paragraph field field_ept_image_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_image_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:26:\"field_ept_image_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:28:\"field_ept_image_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ept_image_link_uri\";a:1:{i:0;a:2:{i:0;s:24:\"field_ept_image_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_micromodal_title',_binary 'a:2:{s:37:\"paragraph__field_ept_micromodal_title\";a:4:{s:11:\"description\";s:60:\"Data storage for paragraph field field_ept_micromodal_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_micromodal_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:33:\"field_ept_micromodal_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_micromodal_title_format\";a:1:{i:0;s:33:\"field_ept_micromodal_title_format\";}}}s:46:\"paragraph_revision__field_ept_micromodal_title\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for paragraph field field_ept_micromodal_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_micromodal_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:33:\"field_ept_micromodal_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ept_micromodal_title_format\";a:1:{i:0;s:33:\"field_ept_micromodal_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_quote_author',_binary 'a:2:{s:33:\"paragraph__field_ept_quote_author\";a:4:{s:11:\"description\";s:56:\"Data storage for paragraph field field_ept_quote_author.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_quote_author_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:29:\"field_ept_quote_author_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_quote_author_format\";a:1:{i:0;s:29:\"field_ept_quote_author_format\";}}}s:42:\"paragraph_revision__field_ept_quote_author\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for paragraph field field_ept_quote_author.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_quote_author_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:29:\"field_ept_quote_author_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_quote_author_format\";a:1:{i:0;s:29:\"field_ept_quote_author_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_quote_image',_binary 'a:2:{s:32:\"paragraph__field_ept_quote_image\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_ept_quote_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_quote_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_quote_image_target_id\";a:1:{i:0;s:31:\"field_ept_quote_image_target_id\";}}}s:41:\"paragraph_revision__field_ept_quote_image\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_ept_quote_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_quote_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_quote_image_target_id\";a:1:{i:0;s:31:\"field_ept_quote_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_settings',_binary 'a:2:{s:29:\"paragraph__field_ept_settings\";a:4:{s:11:\"description\";s:52:\"Data storage for paragraph field field_ept_settings.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_settings_ept_settings\";a:5:{s:11:\"description\";s:34:\"Serialized paragraph settings data\";s:4:\"type\";s:4:\"blob\";s:9:\"serialize\";b:1;s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:38:\"paragraph_revision__field_ept_settings\";a:4:{s:11:\"description\";s:64:\"Revision archive storage for paragraph field field_ept_settings.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_settings_ept_settings\";a:5:{s:11:\"description\";s:34:\"Serialized paragraph settings data\";s:4:\"type\";s:4:\"blob\";s:9:\"serialize\";b:1;s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slick_slider',_binary 'a:2:{s:33:\"paragraph__field_ept_slick_slider\";a:4:{s:11:\"description\";s:56:\"Data storage for paragraph field field_ept_slick_slider.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_slick_slider_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:41:\"field_ept_slick_slider_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_slick_slider_target_id\";a:1:{i:0;s:32:\"field_ept_slick_slider_target_id\";}s:41:\"field_ept_slick_slider_target_revision_id\";a:1:{i:0;s:41:\"field_ept_slick_slider_target_revision_id\";}}}s:42:\"paragraph_revision__field_ept_slick_slider\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for paragraph field field_ept_slick_slider.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ept_slick_slider_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:41:\"field_ept_slick_slider_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_slick_slider_target_id\";a:1:{i:0;s:32:\"field_ept_slick_slider_target_id\";}s:41:\"field_ept_slick_slider_target_revision_id\";a:1:{i:0;s:41:\"field_ept_slick_slider_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slick_slider_image',_binary 'a:2:{s:39:\"paragraph__field_ept_slick_slider_image\";a:4:{s:11:\"description\";s:62:\"Data storage for paragraph field field_ept_slick_slider_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:38:\"field_ept_slick_slider_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:38:\"field_ept_slick_slider_image_target_id\";a:1:{i:0;s:38:\"field_ept_slick_slider_image_target_id\";}}}s:48:\"paragraph_revision__field_ept_slick_slider_image\";a:4:{s:11:\"description\";s:74:\"Revision archive storage for paragraph field field_ept_slick_slider_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:38:\"field_ept_slick_slider_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:38:\"field_ept_slick_slider_image_target_id\";a:1:{i:0;s:38:\"field_ept_slick_slider_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slick_slider_link',_binary 'a:2:{s:38:\"paragraph__field_ept_slick_slider_link\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_slick_slider_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_slick_slider_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:33:\"field_ept_slick_slider_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:35:\"field_ept_slick_slider_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_slick_slider_link_uri\";a:1:{i:0;a:2:{i:0;s:31:\"field_ept_slick_slider_link_uri\";i:1;i:30;}}}}s:47:\"paragraph_revision__field_ept_slick_slider_link\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_slick_slider_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_slick_slider_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:33:\"field_ept_slick_slider_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:35:\"field_ept_slick_slider_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_slick_slider_link_uri\";a:1:{i:0;a:2:{i:0;s:31:\"field_ept_slick_slider_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slick_slider_text',_binary 'a:2:{s:38:\"paragraph__field_ept_slick_slider_text\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_slick_slider_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_slick_slider_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_slick_slider_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_slick_slider_text_format\";a:1:{i:0;s:34:\"field_ept_slick_slider_text_format\";}}}s:47:\"paragraph_revision__field_ept_slick_slider_text\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_slick_slider_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_slick_slider_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_slick_slider_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_slick_slider_text_format\";a:1:{i:0;s:34:\"field_ept_slick_slider_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slideshow',_binary 'a:2:{s:30:\"paragraph__field_ept_slideshow\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ept_slideshow.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_slideshow_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:38:\"field_ept_slideshow_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_slideshow_target_id\";a:1:{i:0;s:29:\"field_ept_slideshow_target_id\";}s:38:\"field_ept_slideshow_target_revision_id\";a:1:{i:0;s:38:\"field_ept_slideshow_target_revision_id\";}}}s:39:\"paragraph_revision__field_ept_slideshow\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ept_slideshow.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_slideshow_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:38:\"field_ept_slideshow_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_slideshow_target_id\";a:1:{i:0;s:29:\"field_ept_slideshow_target_id\";}s:38:\"field_ept_slideshow_target_revision_id\";a:1:{i:0;s:38:\"field_ept_slideshow_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slideshow_link',_binary 'a:2:{s:35:\"paragraph__field_ept_slideshow_link\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_slideshow_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_slideshow_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:30:\"field_ept_slideshow_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:32:\"field_ept_slideshow_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_slideshow_link_uri\";a:1:{i:0;a:2:{i:0;s:28:\"field_ept_slideshow_link_uri\";i:1;i:30;}}}}s:44:\"paragraph_revision__field_ept_slideshow_link\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_slideshow_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_slideshow_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:30:\"field_ept_slideshow_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:32:\"field_ept_slideshow_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_slideshow_link_uri\";a:1:{i:0;a:2:{i:0;s:28:\"field_ept_slideshow_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slideshow_slide',_binary 'a:2:{s:36:\"paragraph__field_ept_slideshow_slide\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ept_slideshow_slide.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ept_slideshow_slide_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:35:\"field_ept_slideshow_slide_target_id\";a:1:{i:0;s:35:\"field_ept_slideshow_slide_target_id\";}}}s:45:\"paragraph_revision__field_ept_slideshow_slide\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ept_slideshow_slide.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ept_slideshow_slide_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:35:\"field_ept_slideshow_slide_target_id\";a:1:{i:0;s:35:\"field_ept_slideshow_slide_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slideshow_text',_binary 'a:2:{s:35:\"paragraph__field_ept_slideshow_text\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ept_slideshow_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_slideshow_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:31:\"field_ept_slideshow_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_slideshow_text_format\";a:1:{i:0;s:31:\"field_ept_slideshow_text_format\";}}}s:44:\"paragraph_revision__field_ept_slideshow_text\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ept_slideshow_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_slideshow_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:31:\"field_ept_slideshow_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_slideshow_text_format\";a:1:{i:0;s:31:\"field_ept_slideshow_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_slideshow_title',_binary 'a:2:{s:36:\"paragraph__field_ept_slideshow_title\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ept_slideshow_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_slideshow_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ept_slideshow_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_slideshow_title_format\";a:1:{i:0;s:32:\"field_ept_slideshow_title_format\";}}}s:45:\"paragraph_revision__field_ept_slideshow_title\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ept_slideshow_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_slideshow_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ept_slideshow_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_slideshow_title_format\";a:1:{i:0;s:32:\"field_ept_slideshow_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_stats',_binary 'a:2:{s:26:\"paragraph__field_ept_stats\";a:4:{s:11:\"description\";s:49:\"Data storage for paragraph field field_ept_stats.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_stats_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:34:\"field_ept_stats_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_stats_target_id\";a:1:{i:0;s:25:\"field_ept_stats_target_id\";}s:34:\"field_ept_stats_target_revision_id\";a:1:{i:0;s:34:\"field_ept_stats_target_revision_id\";}}}s:35:\"paragraph_revision__field_ept_stats\";a:4:{s:11:\"description\";s:61:\"Revision archive storage for paragraph field field_ept_stats.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_stats_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:34:\"field_ept_stats_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_stats_target_id\";a:1:{i:0;s:25:\"field_ept_stats_target_id\";}s:34:\"field_ept_stats_target_revision_id\";a:1:{i:0;s:34:\"field_ept_stats_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_stats_item_image',_binary 'a:2:{s:37:\"paragraph__field_ept_stats_item_image\";a:4:{s:11:\"description\";s:60:\"Data storage for paragraph field field_ept_stats_item_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:36:\"field_ept_stats_item_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ept_stats_item_image_target_id\";a:1:{i:0;s:36:\"field_ept_stats_item_image_target_id\";}}}s:46:\"paragraph_revision__field_ept_stats_item_image\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for paragraph field field_ept_stats_item_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:36:\"field_ept_stats_item_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ept_stats_item_image_target_id\";a:1:{i:0;s:36:\"field_ept_stats_item_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_stats_item_link',_binary 'a:2:{s:36:\"paragraph__field_ept_stats_item_link\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ept_stats_item_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_stats_item_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:31:\"field_ept_stats_item_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:33:\"field_ept_stats_item_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_stats_item_link_uri\";a:1:{i:0;a:2:{i:0;s:29:\"field_ept_stats_item_link_uri\";i:1;i:30;}}}}s:45:\"paragraph_revision__field_ept_stats_item_link\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ept_stats_item_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_stats_item_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:31:\"field_ept_stats_item_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:33:\"field_ept_stats_item_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_stats_item_link_uri\";a:1:{i:0;a:2:{i:0;s:29:\"field_ept_stats_item_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_stats_item_number',_binary 'a:2:{s:38:\"paragraph__field_ept_stats_item_number\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_stats_item_number.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_stats_item_number_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_stats_item_number_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_stats_item_number_format\";a:1:{i:0;s:34:\"field_ept_stats_item_number_format\";}}}s:47:\"paragraph_revision__field_ept_stats_item_number\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_stats_item_number.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ept_stats_item_number_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ept_stats_item_number_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ept_stats_item_number_format\";a:1:{i:0;s:34:\"field_ept_stats_item_number_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_stats_item_text',_binary 'a:2:{s:36:\"paragraph__field_ept_stats_item_text\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ept_stats_item_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_stats_item_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ept_stats_item_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_stats_item_text_format\";a:1:{i:0;s:32:\"field_ept_stats_item_text_format\";}}}s:45:\"paragraph_revision__field_ept_stats_item_text\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ept_stats_item_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_stats_item_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ept_stats_item_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ept_stats_item_text_format\";a:1:{i:0;s:32:\"field_ept_stats_item_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tabs',_binary 'a:2:{s:25:\"paragraph__field_ept_tabs\";a:4:{s:11:\"description\";s:48:\"Data storage for paragraph field field_ept_tabs.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_tabs_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:33:\"field_ept_tabs_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ept_tabs_target_id\";a:1:{i:0;s:24:\"field_ept_tabs_target_id\";}s:33:\"field_ept_tabs_target_revision_id\";a:1:{i:0;s:33:\"field_ept_tabs_target_revision_id\";}}}s:34:\"paragraph_revision__field_ept_tabs\";a:4:{s:11:\"description\";s:60:\"Revision archive storage for paragraph field field_ept_tabs.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_tabs_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:33:\"field_ept_tabs_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ept_tabs_target_id\";a:1:{i:0;s:24:\"field_ept_tabs_target_id\";}s:33:\"field_ept_tabs_target_revision_id\";a:1:{i:0;s:33:\"field_ept_tabs_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tab_block',_binary 'a:2:{s:30:\"paragraph__field_ept_tab_block\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ept_tab_block.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_tab_block_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:28:\"field_ept_tab_block_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_tab_block_plugin_id\";a:1:{i:0;s:29:\"field_ept_tab_block_plugin_id\";}}}s:39:\"paragraph_revision__field_ept_tab_block\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ept_tab_block.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_tab_block_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:28:\"field_ept_tab_block_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_tab_block_plugin_id\";a:1:{i:0;s:29:\"field_ept_tab_block_plugin_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tab_content',_binary 'a:2:{s:32:\"paragraph__field_ept_tab_content\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_ept_tab_content.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ept_tab_content_value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ept_tab_content_value\";a:1:{i:0;s:27:\"field_ept_tab_content_value\";}}}s:41:\"paragraph_revision__field_ept_tab_content\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_ept_tab_content.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ept_tab_content_value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ept_tab_content_value\";a:1:{i:0;s:27:\"field_ept_tab_content_value\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tab_page',_binary 'a:2:{s:29:\"paragraph__field_ept_tab_page\";a:4:{s:11:\"description\";s:52:\"Data storage for paragraph field field_ept_tab_page.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_tab_page_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_tab_page_target_id\";a:1:{i:0;s:28:\"field_ept_tab_page_target_id\";}}}s:38:\"paragraph_revision__field_ept_tab_page\";a:4:{s:11:\"description\";s:64:\"Revision archive storage for paragraph field field_ept_tab_page.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ept_tab_page_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_tab_page_target_id\";a:1:{i:0;s:28:\"field_ept_tab_page_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tab_text',_binary 'a:2:{s:29:\"paragraph__field_ept_tab_text\";a:4:{s:11:\"description\";s:52:\"Data storage for paragraph field field_ept_tab_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_tab_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:25:\"field_ept_tab_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_tab_text_format\";a:1:{i:0;s:25:\"field_ept_tab_text_format\";}}}s:38:\"paragraph_revision__field_ept_tab_text\";a:4:{s:11:\"description\";s:64:\"Revision archive storage for paragraph field field_ept_tab_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_tab_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:25:\"field_ept_tab_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_tab_text_format\";a:1:{i:0;s:25:\"field_ept_tab_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tab_title',_binary 'a:2:{s:30:\"paragraph__field_ept_tab_title\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ept_tab_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_tab_title_value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:26:\"field_ept_tab_title_format\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"field_ept_tab_title_format\";a:1:{i:0;s:26:\"field_ept_tab_title_format\";}}}s:39:\"paragraph_revision__field_ept_tab_title\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ept_tab_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_tab_title_value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:26:\"field_ept_tab_title_format\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"field_ept_tab_title_format\";a:1:{i:0;s:26:\"field_ept_tab_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tab_views',_binary 'a:2:{s:30:\"paragraph__field_ept_tab_views\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ept_tab_views.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_tab_views_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:30:\"field_ept_tab_views_display_id\";a:4:{s:11:\"description\";s:22:\"The ID of the display.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:24:\"field_ept_tab_views_data\";a:4:{s:11:\"description\";s:16:\"Serialized data.\";s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_tab_views_target_id\";a:1:{i:0;s:29:\"field_ept_tab_views_target_id\";}s:30:\"field_ept_tab_views_display_id\";a:1:{i:0;s:30:\"field_ept_tab_views_display_id\";}}}s:39:\"paragraph_revision__field_ept_tab_views\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ept_tab_views.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ept_tab_views_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:30:\"field_ept_tab_views_display_id\";a:4:{s:11:\"description\";s:22:\"The ID of the display.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:24:\"field_ept_tab_views_data\";a:4:{s:11:\"description\";s:16:\"Serialized data.\";s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ept_tab_views_target_id\";a:1:{i:0;s:29:\"field_ept_tab_views_target_id\";}s:30:\"field_ept_tab_views_display_id\";a:1:{i:0;s:30:\"field_ept_tab_views_display_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_text',_binary 'a:2:{s:25:\"paragraph__field_ept_text\";a:4:{s:11:\"description\";s:48:\"Data storage for paragraph field field_ept_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_ept_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:21:\"field_ept_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:21:\"field_ept_text_format\";a:1:{i:0;s:21:\"field_ept_text_format\";}}}s:34:\"paragraph_revision__field_ept_text\";a:4:{s:11:\"description\";s:60:\"Revision archive storage for paragraph field field_ept_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_ept_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:21:\"field_ept_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:21:\"field_ept_text_format\";a:1:{i:0;s:21:\"field_ept_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tiles',_binary 'a:2:{s:26:\"paragraph__field_ept_tiles\";a:4:{s:11:\"description\";s:49:\"Data storage for paragraph field field_ept_tiles.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_tiles_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:34:\"field_ept_tiles_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_tiles_target_id\";a:1:{i:0;s:25:\"field_ept_tiles_target_id\";}s:34:\"field_ept_tiles_target_revision_id\";a:1:{i:0;s:34:\"field_ept_tiles_target_revision_id\";}}}s:35:\"paragraph_revision__field_ept_tiles\";a:4:{s:11:\"description\";s:61:\"Revision archive storage for paragraph field field_ept_tiles.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_tiles_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:34:\"field_ept_tiles_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_tiles_target_id\";a:1:{i:0;s:25:\"field_ept_tiles_target_id\";}s:34:\"field_ept_tiles_target_revision_id\";a:1:{i:0;s:34:\"field_ept_tiles_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tiles_image',_binary 'a:2:{s:32:\"paragraph__field_ept_tiles_image\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_ept_tiles_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_tiles_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_tiles_image_target_id\";a:1:{i:0;s:31:\"field_ept_tiles_image_target_id\";}}}s:41:\"paragraph_revision__field_ept_tiles_image\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_ept_tiles_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ept_tiles_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ept_tiles_image_target_id\";a:1:{i:0;s:31:\"field_ept_tiles_image_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tiles_link',_binary 'a:2:{s:31:\"paragraph__field_ept_tiles_link\";a:4:{s:11:\"description\";s:54:\"Data storage for paragraph field field_ept_tiles_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_tiles_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:26:\"field_ept_tiles_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:28:\"field_ept_tiles_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ept_tiles_link_uri\";a:1:{i:0;a:2:{i:0;s:24:\"field_ept_tiles_link_uri\";i:1;i:30;}}}}s:40:\"paragraph_revision__field_ept_tiles_link\";a:4:{s:11:\"description\";s:66:\"Revision archive storage for paragraph field field_ept_tiles_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ept_tiles_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:26:\"field_ept_tiles_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:28:\"field_ept_tiles_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ept_tiles_link_uri\";a:1:{i:0;a:2:{i:0;s:24:\"field_ept_tiles_link_uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tiles_text',_binary 'a:2:{s:31:\"paragraph__field_ept_tiles_text\";a:4:{s:11:\"description\";s:54:\"Data storage for paragraph field field_ept_tiles_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:26:\"field_ept_tiles_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:27:\"field_ept_tiles_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ept_tiles_text_format\";a:1:{i:0;s:27:\"field_ept_tiles_text_format\";}}}s:40:\"paragraph_revision__field_ept_tiles_text\";a:4:{s:11:\"description\";s:66:\"Revision archive storage for paragraph field field_ept_tiles_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:26:\"field_ept_tiles_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:27:\"field_ept_tiles_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ept_tiles_text_format\";a:1:{i:0;s:27:\"field_ept_tiles_text_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_tiles_title',_binary 'a:2:{s:32:\"paragraph__field_ept_tiles_title\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_ept_tiles_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ept_tiles_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:28:\"field_ept_tiles_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_tiles_title_format\";a:1:{i:0;s:28:\"field_ept_tiles_title_format\";}}}s:41:\"paragraph_revision__field_ept_tiles_title\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_ept_tiles_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ept_tiles_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:28:\"field_ept_tiles_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ept_tiles_title_format\";a:1:{i:0;s:28:\"field_ept_tiles_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_title',_binary 'a:2:{s:26:\"paragraph__field_ept_title\";a:4:{s:11:\"description\";s:49:\"Data storage for paragraph field field_ept_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:21:\"field_ept_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:22:\"field_ept_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"field_ept_title_format\";a:1:{i:0;s:22:\"field_ept_title_format\";}}}s:35:\"paragraph_revision__field_ept_title\";a:4:{s:11:\"description\";s:61:\"Revision archive storage for paragraph field field_ept_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:21:\"field_ept_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:22:\"field_ept_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"field_ept_title_format\";a:1:{i:0;s:22:\"field_ept_title_format\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_video',_binary 'a:2:{s:26:\"paragraph__field_ept_video\";a:4:{s:11:\"description\";s:49:\"Data storage for paragraph field field_ept_video.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_video_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_video_target_id\";a:1:{i:0;s:25:\"field_ept_video_target_id\";}}}s:35:\"paragraph_revision__field_ept_video\";a:4:{s:11:\"description\";s:61:\"Revision archive storage for paragraph field field_ept_video.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ept_video_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ept_video_target_id\";a:1:{i:0;s:25:\"field_ept_video_target_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_videos_and_images',_binary 'a:2:{s:38:\"paragraph__field_ept_videos_and_images\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ept_videos_and_images.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:37:\"field_ept_videos_and_images_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:46:\"field_ept_videos_and_images_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_ept_videos_and_images_target_id\";a:1:{i:0;s:37:\"field_ept_videos_and_images_target_id\";}s:46:\"field_ept_videos_and_images_target_revision_id\";a:1:{i:0;s:46:\"field_ept_videos_and_images_target_revision_id\";}}}s:47:\"paragraph_revision__field_ept_videos_and_images\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ept_videos_and_images.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:37:\"field_ept_videos_and_images_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:46:\"field_ept_videos_and_images_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_ept_videos_and_images_target_id\";a:1:{i:0;s:37:\"field_ept_videos_and_images_target_id\";}s:46:\"field_ept_videos_and_images_target_revision_id\";a:1:{i:0;s:46:\"field_ept_videos_and_images_target_revision_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.field_ept_views_view',_binary 'a:2:{s:31:\"paragraph__field_ept_views_view\";a:4:{s:11:\"description\";s:54:\"Data storage for paragraph field field_ept_views_view.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_views_view_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:31:\"field_ept_views_view_display_id\";a:4:{s:11:\"description\";s:22:\"The ID of the display.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:25:\"field_ept_views_view_data\";a:4:{s:11:\"description\";s:16:\"Serialized data.\";s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_views_view_target_id\";a:1:{i:0;s:30:\"field_ept_views_view_target_id\";}s:31:\"field_ept_views_view_display_id\";a:1:{i:0;s:31:\"field_ept_views_view_display_id\";}}}s:40:\"paragraph_revision__field_ept_views_view\";a:4:{s:11:\"description\";s:66:\"Revision archive storage for paragraph field field_ept_views_view.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ept_views_view_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:31:\"field_ept_views_view_display_id\";a:4:{s:11:\"description\";s:22:\"The ID of the display.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:25:\"field_ept_views_view_data\";a:4:{s:11:\"description\";s:16:\"Serialized data.\";s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ept_views_view_target_id\";a:1:{i:0;s:30:\"field_ept_views_view_target_id\";}s:31:\"field_ept_views_view_display_id\";a:1:{i:0;s:31:\"field_ept_views_view_display_id\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.id',_binary 'a:4:{s:15:\"paragraphs_item\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"paragraphs_item_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.langcode',_binary 'a:4:{s:15:\"paragraphs_item\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:24:\"paragraphs_item_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.parent_field_name',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:17:\"parent_field_name\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:17:\"parent_field_name\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.parent_id',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:9:\"parent_id\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:9:\"parent_id\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.parent_type',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"parent_type\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"parent_type\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.revision_default',_binary 'a:1:{s:24:\"paragraphs_item_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.revision_id',_binary 'a:4:{s:15:\"paragraphs_item\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"paragraphs_item_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.revision_translation_affected',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.status',_binary 'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.type',_binary 'a:2:{s:15:\"paragraphs_item\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:32:\"paragraph_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}s:26:\"paragraphs_item_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:32:\"paragraph_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}}'),('entity.storage_schema.sql','paragraph.field_schema_data.uuid',_binary 'a:1:{s:15:\"paragraphs_item\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:28:\"paragraph_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','path_alias.entity_schema_data',_binary 'a:2:{s:10:\"path_alias\";a:3:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:7:\"indexes\";a:2:{s:36:\"path_alias__alias_langcode_id_status\";a:4:{i:0;s:5:\"alias\";i:1;s:8:\"langcode\";i:2;s:2:\"id\";i:3;s:6:\"status\";}s:35:\"path_alias__path_langcode_id_status\";a:4:{i:0;s:4:\"path\";i:1;s:8:\"langcode\";i:2;s:2:\"id\";i:3;s:6:\"status\";}}s:11:\"unique keys\";a:1:{s:23:\"path_alias__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:19:\"path_alias_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:14:\"path_alias__id\";a:1:{i:0;s:2:\"id\";}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.alias',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:5:\"alias\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:5:\"alias\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.id',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.langcode',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.path',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:4:\"path\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"path\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.revision_default',_binary 'a:1:{s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.revision_id',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.status',_binary 'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','path_alias.field_schema_data.uuid',_binary 'a:1:{s:10:\"path_alias\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:29:\"path_alias_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','shortcut.entity_schema_data',_binary 'a:2:{s:8:\"shortcut\";a:1:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}}s:19:\"shortcut_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:40:\"shortcut__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.default_langcode',_binary 'a:1:{s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.id',_binary 'a:2:{s:8:\"shortcut\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.langcode',_binary 'a:2:{s:8:\"shortcut\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.link',_binary 'a:1:{s:19:\"shortcut_field_data\";a:2:{s:6:\"fields\";a:3:{s:9:\"link__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:11:\"link__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:13:\"link__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:25:\"shortcut_field__link__uri\";a:1:{i:0;a:2:{i:0;s:9:\"link__uri\";i:1;i:30;}}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.shortcut_set',_binary 'a:2:{s:8:\"shortcut\";a:2:{s:6:\"fields\";a:1:{s:12:\"shortcut_set\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:39:\"shortcut_field__shortcut_set__target_id\";a:1:{i:0;s:12:\"shortcut_set\";}}}s:19:\"shortcut_field_data\";a:2:{s:6:\"fields\";a:1:{s:12:\"shortcut_set\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:39:\"shortcut_field__shortcut_set__target_id\";a:1:{i:0;s:12:\"shortcut_set\";}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.title',_binary 'a:1:{s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.uuid',_binary 'a:1:{s:8:\"shortcut\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:27:\"shortcut_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','shortcut.field_schema_data.weight',_binary 'a:1:{s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"weight\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.entity_schema_data',_binary 'a:5:{s:18:\"taxonomy_term_data\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"tid\";}s:11:\"unique keys\";a:1:{s:26:\"taxonomy_term__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:22:\"taxonomy_term_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:18:\"taxonomy_term__tid\";a:1:{i:0;s:3:\"tid\";}}}s:24:\"taxonomy_term_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"tid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:5:{s:45:\"taxonomy_term__id__default_langcode__langcode\";a:3:{i:0;s:3:\"tid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:26:\"taxonomy_term__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"taxonomy_term__status_vid\";a:3:{i:0;s:6:\"status\";i:1;s:3:\"vid\";i:2;s:3:\"tid\";}s:19:\"taxonomy_term__tree\";a:3:{i:0;s:3:\"vid\";i:1;s:6:\"weight\";i:2;s:4:\"name\";}s:23:\"taxonomy_term__vid_name\";a:2:{i:0;s:3:\"vid\";i:1;s:4:\"name\";}}}s:28:\"taxonomy_term_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:45:\"taxonomy_term__id__default_langcode__langcode\";a:3:{i:0;s:3:\"tid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}s:14:\"taxonomy_index\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"nid\";i:1;s:3:\"tid\";}s:7:\"indexes\";a:1:{s:9:\"term_node\";a:4:{i:0;s:3:\"tid\";i:1;s:6:\"status\";i:2;s:6:\"sticky\";i:3;s:7:\"created\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.changed',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.default_langcode',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.description',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:2:{s:6:\"fields\";a:2:{s:18:\"description__value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:19:\"description__format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:0:{}}s:28:\"taxonomy_term_field_revision\";a:2:{s:6:\"fields\";a:2:{s:18:\"description__value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:19:\"description__format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:40:\"taxonomy_term_field__description__format\";a:1:{i:0;s:19:\"description__format\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.langcode',_binary 'a:4:{s:18:\"taxonomy_term_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.name',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:25:\"taxonomy_term_field__name\";a:1:{i:0;s:4:\"name\";}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.parent',_binary 'a:2:{s:21:\"taxonomy_term__parent\";a:4:{s:11:\"description\";s:44:\"Data storage for taxonomy_term field parent.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:16:\"parent_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:16:\"parent_target_id\";a:1:{i:0;s:16:\"parent_target_id\";}s:22:\"bundle_delta_target_id\";a:3:{i:0;s:6:\"bundle\";i:1;s:5:\"delta\";i:2;s:16:\"parent_target_id\";}}}s:30:\"taxonomy_term_revision__parent\";a:4:{s:11:\"description\";s:56:\"Revision archive storage for taxonomy_term field parent.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:16:\"parent_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:16:\"parent_target_id\";a:1:{i:0;s:16:\"parent_target_id\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_created',_binary 'a:1:{s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_default',_binary 'a:1:{s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_id',_binary 'a:4:{s:18:\"taxonomy_term_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_log_message',_binary 'a:1:{s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:20:\"revision_log_message\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_translation_affected',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.revision_user',_binary 'a:1:{s:22:\"taxonomy_term_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:45:\"taxonomy_term_field__revision_user__target_id\";a:1:{i:0;s:13:\"revision_user\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.status',_binary 'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.tid',_binary 'a:4:{s:18:\"taxonomy_term_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.uuid',_binary 'a:1:{s:18:\"taxonomy_term_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:32:\"taxonomy_term_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.vid',_binary 'a:2:{s:18:\"taxonomy_term_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:35:\"taxonomy_term_field__vid__target_id\";a:1:{i:0;s:3:\"vid\";}}}s:24:\"taxonomy_term_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:0:{}}}'),('entity.storage_schema.sql','taxonomy_term.field_schema_data.weight',_binary 'a:1:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"weight\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.entity_schema_data',_binary 'a:2:{s:5:\"users\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"uid\";}}s:16:\"users_field_data\";a:3:{s:11:\"primary key\";a:2:{i:0;s:3:\"uid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:36:\"user__id__default_langcode__langcode\";a:3:{i:0;s:3:\"uid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}s:11:\"unique keys\";a:1:{s:10:\"user__name\";a:2:{i:0;s:4:\"name\";i:1;s:8:\"langcode\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.access',_binary 'a:1:{s:16:\"users_field_data\";a:2:{s:6:\"fields\";a:1:{s:6:\"access\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:18:\"user_field__access\";a:1:{i:0;s:6:\"access\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.changed',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.created',_binary 'a:1:{s:16:\"users_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"user_field__created\";a:1:{i:0;s:7:\"created\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.default_langcode',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.field_schema_data.init',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"init\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.langcode',_binary 'a:2:{s:5:\"users\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.field_schema_data.login',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"login\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.mail',_binary 'a:1:{s:16:\"users_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"mail\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:16:\"user_field__mail\";a:1:{i:0;s:4:\"mail\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.name',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:60;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.field_schema_data.pass',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"pass\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.preferred_admin_langcode',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:24:\"preferred_admin_langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.preferred_langcode',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:18:\"preferred_langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.roles',_binary 'a:1:{s:11:\"user__roles\";a:4:{s:11:\"description\";s:34:\"Data storage for user field roles.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:114:\"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:15:\"roles_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:15:\"roles_target_id\";a:1:{i:0;s:15:\"roles_target_id\";}}}}'),('entity.storage_schema.sql','user.field_schema_data.status',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.timezone',_binary 'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"timezone\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),('entity.storage_schema.sql','user.field_schema_data.uid',_binary 'a:2:{s:5:\"users\";a:1:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),('entity.storage_schema.sql','user.field_schema_data.user_picture',_binary 'a:1:{s:18:\"user__user_picture\";a:5:{s:11:\"description\";s:41:\"Data storage for user field user_picture.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:114:\"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:22:\"user_picture_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:16:\"user_picture_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:18:\"user_picture_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:18:\"user_picture_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:19:\"user_picture_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"user_picture_target_id\";a:1:{i:0;s:22:\"user_picture_target_id\";}}s:12:\"foreign keys\";a:1:{s:22:\"user_picture_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:22:\"user_picture_target_id\";s:3:\"fid\";}}}}}'),('entity.storage_schema.sql','user.field_schema_data.uuid',_binary 'a:1:{s:5:\"users\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:23:\"user_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),('entity_autocomplete','1RT8y00hnAegbkaPudRd6YNSms1XNHvM2c1YrFBVIR4',_binary 'a:4:{s:14:\"target_bundles\";N;s:11:\"auto_create\";i:0;s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}'),('entity_autocomplete','2XDZ3WZw73Y9kz8zINAAoqxEP21BQ18RDPNosE-CqwI',_binary 'a:2:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}'),('entity_autocomplete','mpfP6MRe74zWeoDZY2ZwHHQis-BMS4R54yzulVW88-4',_binary 'a:1:{s:17:\"include_anonymous\";b:0;}'),('entity_autocomplete','oCqAyICgycaLPyCC8BNsNQZgB6PNKexF5iPnrFBqfno',_binary 'a:0:{}'),('entity_autocomplete','s_Loi9pxw-H3eIRltdkO9vM8BPTQDIOXN-j95bVTQt0',_binary 'a:1:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}}'),('entity_autocomplete','TvzAUhftHwThqOCt8qicSUsWf_OzQQ0SDSVs6yU6vcI',_binary 'a:6:{s:14:\"target_bundles\";a:1:{s:4:\"page\";s:4:\"page\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}'),('entity_autocomplete','ulRlcN57k02bDcfVxigoTUL10-L_7C_oc9uW_ONqlws',_binary 'a:4:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}'),('entity_autocomplete','xUIbH_IjXNRLB3lbMNe7gNhIY7fMYTXmIHUOcmSMJDU',_binary 'a:5:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:1;s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}');
INSERT INTO `key_value` VALUES ('media','oembed_providers',_binary 'a:2:{s:4:\"data\";a:323:{s:4:\"23HQ\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"23HQ\";s:6:\"\0*\0url\";s:19:\"http://www.23hq.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"http://www.23hq.com/23/oembed\";s:11:\"\0*\0provider\";r:3;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"http://www.23hq.com/*/photo/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:2:\"3Q\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:2:\"3Q\";s:6:\"\0*\0url\";s:17:\"https://3q.video/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://playout.3qsdn.com/oembed\";s:11:\"\0*\0provider\";r:14;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"https://playout.3qsdn.com/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Abraia\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Abraia\";s:6:\"\0*\0url\";s:17:\"https://abraia.me\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://api.abraia.me/oembed\";s:11:\"\0*\0provider\";r:25;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"https://store.abraia.me/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Acast\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Acast\";s:6:\"\0*\0url\";s:23:\"https://embed.acast.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://oembed.acast.com/v1/embed-player\";s:11:\"\0*\0provider\";r:36;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://play.acast.com/s/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"ActBlue\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"ActBlue\";s:6:\"\0*\0url\";s:26:\"https://secure.actblue.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://secure.actblue.com/cf/oembed\";s:11:\"\0*\0provider\";r:48;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"https://secure.actblue.com/donate/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Adilo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Adilo\";s:6:\"\0*\0url\";s:28:\"https://adilo.bigcommand.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://adilo.bigcommand.com/web/oembed\";s:11:\"\0*\0provider\";r:59;s:10:\"\0*\0schemes\";a:1:{i:0;s:36:\"https://adilo.bigcommand.com/watch/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"afreecaTV\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"afreecaTV\";s:6:\"\0*\0url\";s:25:\"https://www.afreecatv.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:46:\"https://openapi.afreecatv.com/oembed/embedinfo\";s:11:\"\0*\0provider\";r:71;s:10:\"\0*\0schemes\";a:5:{i:0;s:33:\"https://vod.afreecatv.com/player/\";i:1;s:22:\"https://v.afree.ca/ST/\";i:2;s:29:\"https://vod.afreecatv.com/ST/\";i:3;s:41:\"https://vod.afreecatv.com/PLAYER/STATION/\";i:4;s:27:\"https://play.afreecatv.com/\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Altium LLC\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Altium LLC\";s:6:\"\0*\0url\";s:18:\"https://altium.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://viewer.altium.com/shell/oembed\";s:11:\"\0*\0provider\";r:86;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://altium.com/viewer/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Altru\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Altru\";s:6:\"\0*\0url\";s:25:\"https://www.altrulabs.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:46:\"https://api.altrulabs.com/api/v1/social/oembed\";s:11:\"\0*\0provider\";r:98;s:10:\"\0*\0schemes\";a:2:{i:0;s:41:\"https://app.altrulabs.com/*/*?answer_id=*\";i:1;s:34:\"https://app.altrulabs.com/player/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:20:\"amCharts Live Editor\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:20:\"amCharts Live Editor\";s:6:\"\0*\0url\";s:26:\"https://live.amcharts.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://live.amcharts.com/oembed\";s:11:\"\0*\0provider\";r:111;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"http://live.amcharts.com/*\";i:1;s:27:\"https://live.amcharts.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"Amtraker\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Amtraker\";s:6:\"\0*\0url\";s:20:\"https://amtraker.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://api.amtraker.com/v3/oembed\";s:11:\"\0*\0provider\";r:123;s:10:\"\0*\0schemes\";a:4:{i:0;s:29:\"https://amtraker.com/trains/*\";i:1;s:31:\"https://amtraker.com/trains/*/*\";i:2;s:31:\"https://*.amtraker.com/trains/*\";i:3;s:33:\"https://*.amtraker.com/trains/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Animatron\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Animatron\";s:6:\"\0*\0url\";s:26:\"https://www.animatron.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://animatron.com/oembed/json\";s:11:\"\0*\0provider\";r:137;s:10:\"\0*\0schemes\";a:2:{i:0;s:35:\"https://www.animatron.com/project/*\";i:1;s:31:\"https://animatron.com/project/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Animoto\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Animoto\";s:6:\"\0*\0url\";s:19:\"http://animoto.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"http://animoto.com/oembeds/create\";s:11:\"\0*\0provider\";r:149;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"http://animoto.com/play/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"AnnieMusic\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"AnnieMusic\";s:6:\"\0*\0url\";s:22:\"https://anniemusic.app\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://api.anniemusic.app/api/v1/oembed\";s:11:\"\0*\0provider\";r:160;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://anniemusic.app/t/*\";i:1;s:26:\"https://anniemusic.app/p/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:16:\"ArcGIS StoryMaps\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"ArcGIS StoryMaps\";s:6:\"\0*\0url\";s:28:\"https://storymaps.arcgis.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://storymaps.arcgis.com/oembed\";s:11:\"\0*\0provider\";r:172;s:10:\"\0*\0schemes\";a:1:{i:0;s:38:\"https://storymaps.arcgis.com/stories/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Archivos\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Archivos\";s:6:\"\0*\0url\";s:28:\"https://app.archivos.digital\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://app.archivos.digital/oembed/\";s:11:\"\0*\0provider\";r:183;s:10:\"\0*\0schemes\";a:1:{i:0;s:39:\"https://app.archivos.digital/app/view/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:13:\"AssemblrWorld\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"AssemblrWorld\";s:6:\"\0*\0url\";s:26:\"https://assemblrworld.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://studio.assemblrworld.com/api/oembed\";s:11:\"\0*\0provider\";r:194;s:10:\"\0*\0schemes\";a:16:{i:0;s:44:\"http://*.studio.assemblrworld.com/creation/*\";i:1;s:42:\"http://studio.assemblrworld.com/creation/*\";i:2;s:45:\"http://*.app-edu.assemblrworld.com/Creation/*\";i:3;s:43:\"http://app-edu.assemblrworld.com/Creation/*\";i:4;s:23:\"http://assemblr.world/*\";i:5;s:33:\"http://editor.assemblrworld.com/*\";i:6;s:37:\"http://*.assemblrworld.com/creation/*\";i:7;s:37:\"http://*.assemblrworld.com/Creation/*\";i:8;s:45:\"https://*.studio.assemblrworld.com/creation/*\";i:9;s:43:\"https://studio.assemblrworld.com/creation/*\";i:10;s:46:\"https://*.app-edu.assemblrworld.com/Creation/*\";i:11;s:44:\"https://app-edu.assemblrworld.com/Creation/*\";i:12;s:24:\"https://assemblr.world/*\";i:13;s:34:\"https://editor.assemblrworld.com/*\";i:14;s:38:\"https://*.assemblrworld.com/creation/*\";i:15;s:38:\"https://*.assemblrworld.com/Creation/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"audio.com\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"audio.com\";s:6:\"\0*\0url\";s:18:\"https://audio.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://api.audio.com/oembed\";s:11:\"\0*\0provider\";r:220;s:10:\"\0*\0schemes\";a:4:{i:0;s:19:\"https://audio.com/*\";i:1;s:23:\"https://www.audio.com/*\";i:2;s:18:\"http://audio.com/*\";i:3;s:22:\"http://www.audio.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Audioboom\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Audioboom\";s:6:\"\0*\0url\";s:21:\"https://audioboom.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://audioboom.com/publishing/oembed.json\";s:11:\"\0*\0provider\";r:234;s:10:\"\0*\0schemes\";a:7:{i:0;s:32:\"https://audioboom.com/channels/*\";i:1;s:31:\"https://audioboom.com/channel/*\";i:2;s:33:\"https://audioboom.com/playlists/*\";i:3;s:32:\"https://audioboom.com/podcasts/*\";i:4;s:31:\"https://audioboom.com/podcast/*\";i:5;s:29:\"https://audioboom.com/posts/*\";i:6;s:32:\"https://audioboom.com/episodes/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:9:\"AudioClip\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"AudioClip\";s:6:\"\0*\0url\";s:27:\"https://audioclip.naver.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://audioclip.naver.com/oembed\";s:11:\"\0*\0provider\";r:253;s:10:\"\0*\0schemes\";a:2:{i:0;s:46:\"https://audioclip.naver.com/channels/*/clips/*\";i:1;s:40:\"https://audioclip.naver.com/audiobooks/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Audiomack\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Audiomack\";s:6:\"\0*\0url\";s:21:\"https://audiomack.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://audiomack.com/oembed\";s:11:\"\0*\0provider\";r:265;s:10:\"\0*\0schemes\";a:3:{i:0;s:30:\"https://audiomack.com/*/song/*\";i:1;s:31:\"https://audiomack.com/*/album/*\";i:2;s:34:\"https://audiomack.com/*/playlist/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Audiomeans\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Audiomeans\";s:6:\"\0*\0url\";s:21:\"https://audiomeans.fr\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:46:\"https://podcasts.audiomeans.fr/services/oembed\";s:11:\"\0*\0provider\";r:278;s:10:\"\0*\0schemes\";a:1:{i:0;s:32:\"https://podcasts.audiomeans.fr/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Backtracks\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Backtracks\";s:6:\"\0*\0url\";s:21:\"https://backtracks.fm\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://backtracks.fm/oembed\";s:11:\"\0*\0provider\";r:290;s:10:\"\0*\0schemes\";a:5:{i:0;s:29:\"https://backtracks.fm/*/*/e/*\";i:1;s:29:\"https://backtracks.fm/*/s/*/*\";i:2;s:35:\"https://backtracks.fm/*/*/*/*/e/*/*\";i:3;s:23:\"https://backtracks.fm/*\";i:4;s:22:\"http://backtracks.fm/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:14:\"Balsamiq Cloud\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Balsamiq Cloud\";s:6:\"\0*\0url\";s:23:\"https://balsamiq.cloud/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://balsamiq.cloud/oembed\";s:11:\"\0*\0provider\";r:305;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://balsamiq.cloud/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Beams.fm\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Beams.fm\";s:6:\"\0*\0url\";s:15:\"http://beams.fm\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://api.beams.fm/oEmbed\";s:11:\"\0*\0provider\";r:316;s:10:\"\0*\0schemes\";a:1:{i:0;s:18:\"https://beams.fm/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"Beautiful.AI\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Beautiful.AI\";s:6:\"\0*\0url\";s:25:\"https://www.beautiful.ai/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.beautiful.ai/api/oembed\";s:11:\"\0*\0provider\";r:327;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Behance\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Behance\";s:6:\"\0*\0url\";s:23:\"https://www.behance.net\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://www.behance.net/services/oembed\";s:11:\"\0*\0provider\";r:337;s:10:\"\0*\0schemes\";a:2:{i:0;s:35:\"https://www.behance.net/gallery/*/*\";i:1;s:38:\"https://www.behance.net/*/services/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"biqnetwork\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"biqnetwork\";s:6:\"\0*\0url\";s:19:\"https://biqapp.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://biqapp.com/api/v1/video/oembed\";s:11:\"\0*\0provider\";r:350;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://cloud.biqapp.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"Blackfire.io\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Blackfire.io\";s:6:\"\0*\0url\";s:20:\"https://blackfire.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://blackfire.io/oembed\";s:11:\"\0*\0provider\";r:361;s:10:\"\0*\0schemes\";a:2:{i:0;s:37:\"https://blackfire.io/profiles/*/graph\";i:1;s:45:\"https://blackfire.io/profiles/compare/*/graph\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Blogcast\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Blogcast\";s:6:\"\0*\0url\";s:22:\"https://blogcast.host/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://blogcast.host/oembed\";s:11:\"\0*\0provider\";r:373;s:10:\"\0*\0schemes\";a:2:{i:0;s:29:\"https://blogcast.host/embed/*\";i:1;s:31:\"https://blogcast.host/embedly/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:14:\"Bluesky Social\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Bluesky Social\";s:6:\"\0*\0url\";s:16:\"https://bsky.app\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://embed.bsky.app/oembed\";s:11:\"\0*\0provider\";r:385;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"https://bsky.app/profile/*/post/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Bookingmood\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Bookingmood\";s:6:\"\0*\0url\";s:27:\"https://www.bookingmood.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://bookingmood.com/api/oembed\";s:11:\"\0*\0provider\";r:396;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"https://www.bookingmood.com/embed/*/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:14:\"Box Office Buz\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Box Office Buz\";s:6:\"\0*\0url\";s:23:\"http://boxofficebuz.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"http://boxofficebuz.com/oembed\";s:11:\"\0*\0provider\";r:409;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"BrioVR\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"BrioVR\";s:6:\"\0*\0url\";s:24:\"https://view.briovr.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:45:\"https://view.briovr.com/api/v1/worlds/oembed/\";s:11:\"\0*\0provider\";r:419;s:10:\"\0*\0schemes\";a:1:{i:0;s:46:\"https://view.briovr.com/api/v1/worlds/oembed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Bumper\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Bumper\";s:6:\"\0*\0url\";s:21:\"http://www.bumper.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://www.bumper.com/oembed/bumper\";s:11:\"\0*\0provider\";r:430;s:10:\"\0*\0schemes\";a:2:{i:0;s:36:\"https://www.bumper.com/oembed/bumper\";i:1;s:38:\"https://www.bumper.com/oembed-s/bumper\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Bunny\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Bunny\";s:6:\"\0*\0url\";s:18:\"https://bunny.net/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://video.bunnycdn.com/OEmbed\";s:11:\"\0*\0provider\";r:442;s:10:\"\0*\0schemes\";a:4:{i:0;s:34:\"https://iframe.mediadelivery.net/*\";i:1;s:33:\"http://iframe.mediadelivery.net/*\";i:2;s:28:\"https://video.bunnycdn.com/*\";i:3;s:27:\"http://video.bunnycdn.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Buttondown\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Buttondown\";s:6:\"\0*\0url\";s:25:\"https://buttondown.email/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://buttondown.email/embed\";s:11:\"\0*\0provider\";r:457;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://buttondown.email/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:14:\"Byzart Project\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Byzart Project\";s:6:\"\0*\0url\";s:21:\"https://cmc.byzart.eu\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://cmc.byzart.eu/oembed/\";s:11:\"\0*\0provider\";r:469;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://cmc.byzart.eu/files/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Cacoo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Cacoo\";s:6:\"\0*\0url\";s:17:\"https://cacoo.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://cacoo.com/oembed.json\";s:11:\"\0*\0provider\";r:480;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://cacoo.com/diagrams/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Canva\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Canva\";s:6:\"\0*\0url\";s:21:\"https://www.canva.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://www.canva.com/_oembed\";s:11:\"\0*\0provider\";r:491;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"https://www.canva.com/design/*/view\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:13:\"Cardinal Blue\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Cardinal Blue\";s:6:\"\0*\0url\";s:26:\"https://minesweeper.today/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://minesweeper.today/api/oembed\";s:11:\"\0*\0provider\";r:502;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"http://minesweeper.today/*\";i:1;s:27:\"https://minesweeper.today/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"CatBoat\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"CatBoat\";s:6:\"\0*\0url\";s:20:\"http://img.catbo.at/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"http://img.catbo.at/oembed.json\";s:11:\"\0*\0provider\";r:514;s:10:\"\0*\0schemes\";a:1:{i:0;s:21:\"http://img.catbo.at/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Celero\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Celero\";s:6:\"\0*\0url\";s:21:\"https://www.celero.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://api.celero.io/api/oembed\";s:11:\"\0*\0provider\";r:526;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://embeds.celero.io/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Ceros\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Ceros\";s:6:\"\0*\0url\";s:21:\"http://www.ceros.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://view.ceros.com/oembed\";s:11:\"\0*\0provider\";r:538;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"http://view.ceros.com/*\";i:1;s:24:\"https://view.ceros.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Chainflix\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Chainflix\";s:6:\"\0*\0url\";s:21:\"https://chainflix.net\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://www.chainflix.net/video/oembed\";s:11:\"\0*\0provider\";r:550;s:10:\"\0*\0schemes\";a:4:{i:0;s:29:\"https://chainflix.net/video/*\";i:1;s:35:\"https://chainflix.net/video/embed/*\";i:2;s:31:\"https://*.chainflix.net/video/*\";i:3;s:37:\"https://*.chainflix.net/video/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"ChartBlocks\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"ChartBlocks\";s:6:\"\0*\0url\";s:27:\"http://www.chartblocks.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"http://embed.chartblocks.com/1.0/oembed\";s:11:\"\0*\0provider\";r:564;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"http://public.chartblocks.com/c/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"chirbit.com\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"chirbit.com\";s:6:\"\0*\0url\";s:23:\"http://www.chirbit.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"http://chirb.it/oembed.json\";s:11:\"\0*\0provider\";r:575;s:10:\"\0*\0schemes\";a:1:{i:0;s:17:\"http://chirb.it/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"CHROCO\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"CHROCO\";s:6:\"\0*\0url\";s:19:\"https://chroco.ooo/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:24:\"https://chroco.ooo/embed\";s:11:\"\0*\0provider\";r:586;s:10:\"\0*\0schemes\";a:2:{i:0;s:27:\"https://chroco.ooo/mypage/*\";i:1;s:26:\"https://chroco.ooo/story/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"CircuitLab\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"CircuitLab\";s:6:\"\0*\0url\";s:27:\"https://www.circuitlab.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"https://www.circuitlab.com/circuit/oembed/\";s:11:\"\0*\0provider\";r:598;s:10:\"\0*\0schemes\";a:1:{i:0;s:36:\"https://www.circuitlab.com/circuit/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Clipland\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Clipland\";s:6:\"\0*\0url\";s:24:\"http://www.clipland.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.clipland.com/api/oembed\";s:11:\"\0*\0provider\";r:609;s:10:\"\0*\0schemes\";a:2:{i:0;s:27:\"http://www.clipland.com/v/*\";i:1;s:28:\"https://www.clipland.com/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"Clyp\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Clyp\";s:6:\"\0*\0url\";s:15:\"http://clyp.it/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"http://api.clyp.it/oembed/\";s:11:\"\0*\0provider\";r:621;s:10:\"\0*\0schemes\";a:2:{i:0;s:16:\"http://clyp.it/*\";i:1;s:25:\"http://clyp.it/playlist/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"CoCo Corp\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"CoCo Corp\";s:6:\"\0*\0url\";s:23:\"https://ilovecoco.video\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://app.ilovecoco.video/api/oembed.json\";s:11:\"\0*\0provider\";r:633;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"https://app.ilovecoco.video/*/embed\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"CodeHS\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"CodeHS\";s:6:\"\0*\0url\";s:21:\"http://www.codehs.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:46:\"https://codehs.com/api/sharedprogram/1/oembed/\";s:11:\"\0*\0provider\";r:644;s:10:\"\0*\0schemes\";a:1:{i:0;s:40:\"https://codehs.com/editor/share_abacus/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"CodePen\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"CodePen\";s:6:\"\0*\0url\";s:18:\"https://codepen.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://codepen.io/api/oembed\";s:11:\"\0*\0provider\";r:655;s:10:\"\0*\0schemes\";a:2:{i:0;s:19:\"http://codepen.io/*\";i:1;s:20:\"https://codepen.io/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Codepoints\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Codepoints\";s:6:\"\0*\0url\";s:22:\"https://codepoints.net\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://codepoints.net/api/v1/oembed\";s:11:\"\0*\0provider\";r:667;s:10:\"\0*\0schemes\";a:4:{i:0;s:23:\"http://codepoints.net/*\";i:1;s:24:\"https://codepoints.net/*\";i:2;s:27:\"http://www.codepoints.net/*\";i:3;s:28:\"https://www.codepoints.net/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"CodeSandbox\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"CodeSandbox\";s:6:\"\0*\0url\";s:22:\"https://codesandbox.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://codesandbox.io/oembed\";s:11:\"\0*\0provider\";r:681;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://codesandbox.io/s/*\";i:1;s:30:\"https://codesandbox.io/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"CollegeHumor\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"CollegeHumor\";s:6:\"\0*\0url\";s:28:\"http://www.collegehumor.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"http://www.collegehumor.com/oembed.json\";s:11:\"\0*\0provider\";r:693;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"http://www.collegehumor.com/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Commaful\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Commaful\";s:6:\"\0*\0url\";s:20:\"https://commaful.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://commaful.com/api/oembed/\";s:11:\"\0*\0provider\";r:704;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://commaful.com/play/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:4:\"Coub\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Coub\";s:6:\"\0*\0url\";s:16:\"http://coub.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"http://coub.com/api/oembed.json\";s:11:\"\0*\0provider\";r:715;s:10:\"\0*\0schemes\";a:2:{i:0;s:22:\"http://coub.com/view/*\";i:1;s:23:\"http://coub.com/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:13:\"Crowd Ranking\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Crowd Ranking\";s:6:\"\0*\0url\";s:23:\"http://crowdranking.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"http://crowdranking.com/api/oembed.json\";s:11:\"\0*\0provider\";r:727;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"http://crowdranking.com/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"Crumb.sh\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Crumb.sh\";s:6:\"\0*\0url\";s:16:\"https://crumb.sh\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:24:\"https://crumb.sh/oembed/\";s:11:\"\0*\0provider\";r:738;s:10:\"\0*\0schemes\";a:1:{i:0;s:18:\"https://crumb.sh/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:16:\"Cueup DJ Booking\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"Cueup DJ Booking\";s:6:\"\0*\0url\";s:16:\"https://cueup.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://gql.cueup.io/oembed\";s:11:\"\0*\0provider\";r:749;s:10:\"\0*\0schemes\";a:1:{i:0;s:32:\"https://cueup.io/user/*/sounds/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Curated\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Curated\";s:6:\"\0*\0url\";s:19:\"https://curated.co/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://api.curated.co/oembed\";s:11:\"\0*\0provider\";r:760;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://*.curated.co/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"CustomerDB\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"CustomerDB\";s:6:\"\0*\0url\";s:22:\"http://customerdb.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://app.customerdb.com/embed\";s:11:\"\0*\0provider\";r:772;s:10:\"\0*\0schemes\";a:1:{i:0;s:34:\"https://app.customerdb.com/share/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"dadan\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"dadan\";s:6:\"\0*\0url\";s:20:\"https://www.dadan.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://app.dadan.io/api/video/oembed\";s:11:\"\0*\0provider\";r:783;s:10:\"\0*\0schemes\";a:2:{i:0;s:22:\"https://app.dadan.io/*\";i:1;s:24:\"https://stage.dadan.io/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Dailymotion\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Dailymotion\";s:6:\"\0*\0url\";s:27:\"https://www.dailymotion.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://www.dailymotion.com/services/oembed\";s:11:\"\0*\0provider\";r:797;s:10:\"\0*\0schemes\";a:2:{i:0;s:35:\"https://www.dailymotion.com/video/*\";i:1;s:47:\"https://geo.dailymotion.com/player.html?video=*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"DALEXNI\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"DALEXNI\";s:6:\"\0*\0url\";s:20:\"https://dalexni.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://dalexni.com/oembed/\";s:11:\"\0*\0provider\";r:809;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://dalexni.com/i/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Datawrapper\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Datawrapper\";s:6:\"\0*\0url\";s:25:\"http://www.datawrapper.de\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://api.datawrapper.de/v3/oembed/\";s:11:\"\0*\0provider\";r:820;s:10:\"\0*\0schemes\";a:1:{i:0;s:31:\"https://datawrapper.dwcdn.net/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"Deseret News\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Deseret News\";s:6:\"\0*\0url\";s:23:\"https://www.deseret.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://embed.deseret.com/\";s:11:\"\0*\0provider\";r:831;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://*.deseret.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:14:\"Deviantart.com\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Deviantart.com\";s:6:\"\0*\0url\";s:25:\"http://www.deviantart.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"http://backend.deviantart.com/oembed\";s:11:\"\0*\0provider\";r:842;s:10:\"\0*\0schemes\";a:8:{i:0;s:29:\"http://*.deviantart.com/art/*\";i:1;s:29:\"http://*.deviantart.com/*#/d*\";i:2;s:15:\"http://fav.me/*\";i:3;s:15:\"http://sta.sh/*\";i:4;s:30:\"https://*.deviantart.com/art/*\";i:5;s:32:\"https://*.deviantart.com/*/art/*\";i:6;s:16:\"https://sta.sh/*\";i:7;s:30:\"https://*.deviantart.com/*#/d*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"Digiteka\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Digiteka\";s:6:\"\0*\0url\";s:26:\"https://www.ultimedia.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://www.ultimedia.com/api/search/oembed\";s:11:\"\0*\0provider\";r:860;s:10:\"\0*\0schemes\";a:3:{i:0;s:61:\"https://www.ultimedia.com/central/video/edit/id/*/topic_id/*/\";i:1;s:78:\"https://www.ultimedia.com/default/index/videogeneric/id/*/showtitle/1/viewnc/1\";i:2;s:57:\"https://www.ultimedia.com/default/index/videogeneric/id/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"DocDroid\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"DocDroid\";s:6:\"\0*\0url\";s:25:\"https://www.docdroid.net/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.docdroid.net/api/oembed\";s:11:\"\0*\0provider\";r:873;s:10:\"\0*\0schemes\";a:6:{i:0;s:24:\"https://*.docdroid.net/*\";i:1;s:23:\"http://*.docdroid.net/*\";i:2;s:19:\"https://docdro.id/*\";i:3;s:18:\"http://docdro.id/*\";i:4;s:24:\"https://*.docdroid.com/*\";i:5;s:23:\"http://*.docdroid.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Docswell\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Docswell\";s:6:\"\0*\0url\";s:20:\"https://docswell.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://www.docswell.com/service/oembed\";s:11:\"\0*\0provider\";r:890;s:10:\"\0*\0schemes\";a:4:{i:0;s:25:\"http://docswell.com/s/*/*\";i:1;s:26:\"https://docswell.com/s/*/*\";i:2;s:29:\"http://www.docswell.com/s/*/*\";i:3;s:30:\"https://www.docswell.com/s/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Dotsub\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Dotsub\";s:6:\"\0*\0url\";s:18:\"http://dotsub.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"http://dotsub.com/services/oembed\";s:11:\"\0*\0provider\";r:905;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"http://dotsub.com/view/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"Dream Broker\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Dream Broker\";s:6:\"\0*\0url\";s:23:\"https://dreambroker.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://dreambroker.com/channel/oembed\";s:11:\"\0*\0provider\";r:916;s:10:\"\0*\0schemes\";a:1:{i:0;s:39:\"https://www.dreambroker.com/channel/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"DTube\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"DTube\";s:6:\"\0*\0url\";s:15:\"https://d.tube/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://api.d.tube/oembed\";s:11:\"\0*\0provider\";r:927;s:10:\"\0*\0schemes\";a:1:{i:0;s:18:\"https://d.tube/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"EchoesHQ\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"EchoesHQ\";s:6:\"\0*\0url\";s:20:\"https://echoeshq.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://api.echoeshq.com/oembed\";s:11:\"\0*\0provider\";r:938;s:10:\"\0*\0schemes\";a:1:{i:0;s:31:\"http://app.echoeshq.com/embed/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"eduMedia\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"eduMedia\";s:6:\"\0*\0url\";s:34:\"https://www.edumedia-sciences.com/\";s:12:\"\0*\0endpoints\";a:2:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:45:\"https://www.edumedia-sciences.com/oembed.json\";s:11:\"\0*\0provider\";r:951;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}i:1;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://www.edumedia-sciences.com/oembed.xml\";s:11:\"\0*\0provider\";r:951;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"EgliseInfo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"EgliseInfo\";s:6:\"\0*\0url\";s:32:\"http://egliseinfo.catholique.fr/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"http://egliseinfo.catholique.fr/api/oembed\";s:11:\"\0*\0provider\";r:967;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"http://egliseinfo.catholique.fr/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Embedery\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Embedery\";s:6:\"\0*\0url\";s:21:\"https://embedery.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://embedery.com/api/oembed\";s:11:\"\0*\0provider\";r:978;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://embedery.com/widget/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Ethfiddle\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Ethfiddle\";s:6:\"\0*\0url\";s:26:\"https://www.ethfiddle.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://ethfiddle.com/services/oembed/\";s:11:\"\0*\0provider\";r:989;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://ethfiddle.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"EventLive\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"EventLive\";s:6:\"\0*\0url\";s:21:\"https://eventlive.pro\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://evt.live/api/oembed\";s:11:\"\0*\0provider\";r:1000;s:10:\"\0*\0schemes\";a:4:{i:0;s:18:\"https://evt.live/*\";i:1;s:20:\"https://evt.live/*/*\";i:2;s:28:\"https://live.eventlive.pro/*\";i:3;s:30:\"https://live.eventlive.pro/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"everviz\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"everviz\";s:6:\"\0*\0url\";s:19:\"https://everviz.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://api.everviz.com/oembed\";s:11:\"\0*\0provider\";r:1014;s:10:\"\0*\0schemes\";a:2:{i:0;s:31:\"https://app.everviz.com/embed/*\";i:1;s:30:\"http://app.everviz.com/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Ex.Co\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Ex.Co\";s:6:\"\0*\0url\";s:13:\"https://ex.co\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://oembed.ex.co/item\";s:11:\"\0*\0provider\";r:1026;s:10:\"\0*\0schemes\";a:2:{i:0;s:27:\"https://app.ex.co/stories/*\";i:1;s:26:\"https://www.playbuzz.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Eyrie\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Eyrie\";s:6:\"\0*\0url\";s:17:\"https://eyrie.io/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://eyrie.io/v1/oembed\";s:11:\"\0*\0provider\";r:1038;s:10:\"\0*\0schemes\";a:2:{i:0;s:24:\"https://eyrie.io/board/*\";i:1;s:27:\"https://eyrie.io/sparkfun/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Facebook\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Facebook\";s:6:\"\0*\0url\";s:25:\"https://www.facebook.com/\";s:12:\"\0*\0endpoints\";a:3:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://graph.facebook.com/v16.0/oembed_post\";s:11:\"\0*\0provider\";r:1050;s:10:\"\0*\0schemes\";a:9:{i:0;s:34:\"https://www.facebook.com/*/posts/*\";i:1;s:37:\"https://www.facebook.com/*/activity/*\";i:2;s:35:\"https://www.facebook.com/*/photos/*\";i:3;s:41:\"https://www.facebook.com/photo.php?fbid=*\";i:4;s:33:\"https://www.facebook.com/photos/*\";i:5;s:51:\"https://www.facebook.com/permalink.php?story_fbid=*\";i:6;s:40:\"https://www.facebook.com/media/set?set=*\";i:7;s:36:\"https://www.facebook.com/questions/*\";i:8;s:36:\"https://www.facebook.com/notes/*/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}i:1;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:45:\"https://graph.facebook.com/v16.0/oembed_video\";s:11:\"\0*\0provider\";r:1050;s:10:\"\0*\0schemes\";a:3:{i:0;s:35:\"https://www.facebook.com/*/videos/*\";i:1;s:39:\"https://www.facebook.com/video.php?id=*\";i:2;s:38:\"https://www.facebook.com/video.php?v=*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}i:2;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://graph.facebook.com/v16.0/oembed_page\";s:11:\"\0*\0provider\";r:1050;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://www.facebook.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Fader\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Fader\";s:6:\"\0*\0url\";s:24:\"https://app.getfader.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://app.getfader.com/api/oembed\";s:11:\"\0*\0provider\";r:1085;s:10:\"\0*\0schemes\";a:1:{i:0;s:43:\"https://app.getfader.com/projects/*/publish\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"Faithlife TV\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Faithlife TV\";s:6:\"\0*\0url\";s:23:\"https://faithlifetv.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://faithlifetv.com/api/oembed\";s:11:\"\0*\0provider\";r:1097;s:10:\"\0*\0schemes\";a:5:{i:0;s:31:\"https://faithlifetv.com/items/*\";i:1;s:42:\"https://faithlifetv.com/items/resource/*/*\";i:2;s:31:\"https://faithlifetv.com/media/*\";i:3;s:38:\"https://faithlifetv.com/media/assets/*\";i:4;s:42:\"https://faithlifetv.com/media/resource/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Figma\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Figma\";s:6:\"\0*\0url\";s:21:\"https://www.figma.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://www.figma.com/api/oembed\";s:11:\"\0*\0provider\";r:1112;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://www.figma.com/file/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Firework\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Firework\";s:6:\"\0*\0url\";s:23:\"https://fireworktv.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://www.fireworktv.com/oembed\";s:11:\"\0*\0provider\";r:1123;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://*.fireworktv.com/*\";i:1;s:36:\"https://*.fireworktv.com/embed/*/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"FITE\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"FITE\";s:6:\"\0*\0url\";s:20:\"https://www.fite.tv/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://www.fite.tv/oembed\";s:11:\"\0*\0provider\";r:1135;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://www.fite.tv/watch/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"Flat\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Flat\";s:6:\"\0*\0url\";s:15:\"https://flat.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://flat.io/services/oembed\";s:11:\"\0*\0provider\";r:1146;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"https://flat.io/score/*\";i:1;s:25:\"https://*.flat.io/score/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Flickr\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Flickr\";s:6:\"\0*\0url\";s:23:\"https://www.flickr.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://www.flickr.com/services/oembed/\";s:11:\"\0*\0provider\";r:1158;s:10:\"\0*\0schemes\";a:8:{i:0;s:28:\"http://*.flickr.com/photos/*\";i:1;s:18:\"http://flic.kr/p/*\";i:2;s:18:\"http://flic.kr/s/*\";i:3;s:29:\"https://*.flickr.com/photos/*\";i:4;s:19:\"https://flic.kr/p/*\";i:5;s:19:\"https://flic.kr/s/*\";i:6;s:26:\"https://*.*.flickr.com/*/*\";i:7;s:25:\"http://*.*.flickr.com/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Flourish\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Flourish\";s:6:\"\0*\0url\";s:24:\"https://flourish.studio/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://app.flourish.studio/api/v1/oembed\";s:11:\"\0*\0provider\";r:1176;s:10:\"\0*\0schemes\";a:2:{i:0;s:46:\"https://public.flourish.studio/visualisation/*\";i:1;s:38:\"https://public.flourish.studio/story/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"FlowHubOrg\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"FlowHubOrg\";s:6:\"\0*\0url\";s:25:\"https://flows.flowhub.org\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://flowhub.org/o/embed\";s:11:\"\0*\0provider\";r:1188;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"https://flowhub.org/f/*\";i:1;s:23:\"https://flowhub.org/s/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Fooday\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Fooday\";s:6:\"\0*\0url\";s:18:\"https://fooday.app\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://fooday.app/oembed\";s:11:\"\0*\0provider\";r:1200;s:10:\"\0*\0schemes\";a:2:{i:0;s:30:\"https://fooday.app/*/reviews/*\";i:1;s:28:\"https://fooday.app/*/spots/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:20:\"FOX SPORTS Australia\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:20:\"FOX SPORTS Australia\";s:6:\"\0*\0url\";s:27:\"http://www.foxsports.com.au\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://fiso.foxsports.com.au/oembed\";s:11:\"\0*\0provider\";r:1212;s:10:\"\0*\0schemes\";a:2:{i:0;s:48:\"http://fiso.foxsports.com.au/isomorphic-widget/*\";i:1;s:49:\"https://fiso.foxsports.com.au/isomorphic-widget/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:9:\"Framatube\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Framatube\";s:6:\"\0*\0url\";s:22:\"https://framatube.org/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://framatube.org/services/oembed\";s:11:\"\0*\0provider\";r:1224;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"https://framatube.org/w/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:9:\"FrameBuzz\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"FrameBuzz\";s:6:\"\0*\0url\";s:22:\"https://framebuzz.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://framebuzz.com/oembed/\";s:11:\"\0*\0provider\";r:1235;s:10:\"\0*\0schemes\";a:2:{i:0;s:24:\"http://framebuzz.com/v/*\";i:1;s:25:\"https://framebuzz.com/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Framer\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Framer\";s:6:\"\0*\0url\";s:22:\"https://www.framer.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://api.framer.com/web/oembed\";s:11:\"\0*\0provider\";r:1247;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://framer.com/share/*\";i:1;s:26:\"https://framer.com/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:28:\"Geograph Britain and Ireland\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:28:\"Geograph Britain and Ireland\";s:6:\"\0*\0url\";s:28:\"https://www.geograph.org.uk/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"http://api.geograph.org.uk/api/oembed\";s:11:\"\0*\0provider\";r:1259;s:10:\"\0*\0schemes\";a:4:{i:0;s:26:\"http://*.geograph.org.uk/*\";i:1;s:25:\"http://*.geograph.co.uk/*\";i:2;s:22:\"http://*.geograph.ie/*\";i:3;s:42:\"http://*.wikimedia.org/*_geograph.org.uk_*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:24:\"Geograph Channel Islands\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:24:\"Geograph Channel Islands\";s:6:\"\0*\0url\";s:36:\"http://channel-islands.geograph.org/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"http://www.geograph.org.gg/api/oembed\";s:11:\"\0*\0provider\";r:1273;s:10:\"\0*\0schemes\";a:5:{i:0;s:26:\"http://*.geograph.org.gg/*\";i:1;s:26:\"http://*.geograph.org.je/*\";i:2;s:37:\"http://channel-islands.geograph.org/*\";i:3;s:38:\"http://channel-islands.geographs.org/*\";i:4;s:32:\"http://*.channel.geographs.org/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:16:\"Geograph Germany\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"Geograph Germany\";s:6:\"\0*\0url\";s:23:\"http://geo-en.hlipp.de/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"http://geo.hlipp.de/restapi.php/api/oembed\";s:11:\"\0*\0provider\";r:1288;s:10:\"\0*\0schemes\";a:3:{i:0;s:24:\"http://geo-en.hlipp.de/*\";i:1;s:21:\"http://geo.hlipp.de/*\";i:2;s:29:\"http://germany.geograph.org/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"Getty Images\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Getty Images\";s:6:\"\0*\0url\";s:27:\"http://www.gettyimages.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"http://embed.gettyimages.com/oembed\";s:11:\"\0*\0provider\";r:1301;s:10:\"\0*\0schemes\";a:1:{i:0;s:15:\"http://gty.im/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Gifnote\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Gifnote\";s:6:\"\0*\0url\";s:24:\"https://www.gifnote.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://www.gifnote.com/services/oembed\";s:11:\"\0*\0provider\";r:1313;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://www.gifnote.com/play/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"GIPHY\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"GIPHY\";s:6:\"\0*\0url\";s:17:\"https://giphy.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://giphy.com/services/oembed\";s:11:\"\0*\0provider\";r:1324;s:10:\"\0*\0schemes\";a:4:{i:0;s:24:\"https://giphy.com/gifs/*\";i:1;s:25:\"https://giphy.com/clips/*\";i:2;s:15:\"http://gph.is/*\";i:3;s:41:\"https://media.giphy.com/media/*/giphy.gif\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"GloriaTV\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"GloriaTV\";s:6:\"\0*\0url\";s:18:\"https://gloria.tv/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://gloria.tv/oembed/\";s:11:\"\0*\0provider\";r:1338;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"GMetri\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"GMetri\";s:6:\"\0*\0url\";s:23:\"https://www.gmetri.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://embed.gmetri.com/oembed/\";s:11:\"\0*\0provider\";r:1348;s:10:\"\0*\0schemes\";a:2:{i:0;s:25:\"https://view.gmetri.com/*\";i:1;s:22:\"https://*.gmetri.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"Gong\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Gong\";s:6:\"\0*\0url\";s:20:\"https://www.gong.io/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://app.gong.io/oembed\";s:11:\"\0*\0provider\";r:1360;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://app.gong.io/call?id=*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Grain\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Grain\";s:6:\"\0*\0url\";s:17:\"https://grain.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://api.grain.com/_/api/oembed\";s:11:\"\0*\0provider\";r:1372;s:10:\"\0*\0schemes\";a:3:{i:0;s:28:\"https://grain.co/highlight/*\";i:1;s:24:\"https://grain.co/share/*\";i:2;s:25:\"https://grain.com/share/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"GT Channel\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"GT Channel\";s:6:\"\0*\0url\";s:21:\"https://gtchannel.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://api.luminery.com/oembed\";s:11:\"\0*\0provider\";r:1385;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://gtchannel.com/watch/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Gumlet\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Gumlet\";s:6:\"\0*\0url\";s:23:\"https://www.gumlet.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://api.gumlet.com/v1/oembed\";s:11:\"\0*\0provider\";r:1396;s:10:\"\0*\0schemes\";a:3:{i:0;s:25:\"https://gumlet.tv/watch/*\";i:1;s:30:\"https://www.gumlet.com/watch/*\";i:2;s:30:\"https://play.gumlet.io/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Gyazo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Gyazo\";s:6:\"\0*\0url\";s:17:\"https://gyazo.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://api.gyazo.com/api/oembed\";s:11:\"\0*\0provider\";r:1409;s:10:\"\0*\0schemes\";a:1:{i:0;s:19:\"https://gyazo.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:4:\"HASH\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"HASH\";s:6:\"\0*\0url\";s:15:\"https://hash.ai\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://api.hash.ai/oembed\";s:11:\"\0*\0provider\";r:1421;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://core.hash.ai/@*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"hearthis.at\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"hearthis.at\";s:6:\"\0*\0url\";s:20:\"https://hearthis.at/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://hearthis.at/oembed/?format=json\";s:11:\"\0*\0provider\";r:1432;s:10:\"\0*\0schemes\";a:2:{i:0;s:24:\"https://hearthis.at/*/*/\";i:1;s:28:\"https://hearthis.at/*/set/*/\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Heyzine\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Heyzine\";s:6:\"\0*\0url\";s:19:\"https://heyzine.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://heyzine.com/api1/oembed\";s:11:\"\0*\0provider\";r:1444;s:10:\"\0*\0schemes\";a:3:{i:0;s:31:\"https://heyzine.com/flip-book/*\";i:1;s:20:\"https://*.hflip.co/*\";i:2;s:20:\"https://*.aflip.in/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"hihaho\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"hihaho\";s:6:\"\0*\0url\";s:22:\"https://www.hihaho.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://player.hihaho.com/services/oembed\";s:11:\"\0*\0provider\";r:1457;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://player.hihaho.com/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"HippoVideo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"HippoVideo\";s:6:\"\0*\0url\";s:21:\"https://hippovideo.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://www.hippovideo.io/services/oembed\";s:11:\"\0*\0provider\";r:1470;s:10:\"\0*\0schemes\";a:2:{i:0;s:24:\"http://*.hippovideo.io/*\";i:1;s:25:\"https://*.hippovideo.io/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Homey\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Homey\";s:6:\"\0*\0url\";s:17:\"https://homey.app\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://homey.app/api/oembed/flow\";s:11:\"\0*\0provider\";r:1482;s:10:\"\0*\0schemes\";a:2:{i:0;s:21:\"https://homey.app/f/*\";i:1;s:26:\"https://homey.app/*/flow/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Hopvue\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Hopvue\";s:6:\"\0*\0url\";s:22:\"https://www.hopvue.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://portal.hopvue.com/api/oembed/\";s:11:\"\0*\0provider\";r:1494;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://*.hopvue.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"HuffDuffer\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"HuffDuffer\";s:6:\"\0*\0url\";s:21:\"http://huffduffer.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://huffduffer.com/oembed\";s:11:\"\0*\0provider\";r:1505;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"http://huffduffer.com/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:4:\"Hulu\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Hulu\";s:6:\"\0*\0url\";s:20:\"http://www.hulu.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"http://www.hulu.com/api/oembed.json\";s:11:\"\0*\0provider\";r:1516;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"http://www.hulu.com/watch/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Ideamapper\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Ideamapper\";s:6:\"\0*\0url\";s:23:\"https://ideamapper.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://oembed.ideamapper.com/oembed\";s:11:\"\0*\0provider\";r:1527;s:10:\"\0*\0schemes\";a:1:{i:0;s:31:\"https://oembed.ideamapper.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Idomoo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Idomoo\";s:6:\"\0*\0url\";s:19:\"https://idomoo.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://oembed.idomoo.com/oembed\";s:11:\"\0*\0provider\";r:1538;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://*.idomoo.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"iFixit\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"iFixit\";s:6:\"\0*\0url\";s:21:\"http://www.iFixit.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"http://www.ifixit.com/Embed\";s:11:\"\0*\0provider\";r:1550;s:10:\"\0*\0schemes\";a:1:{i:0;s:34:\"http://www.ifixit.com/Guide/View/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"IFTTT\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"IFTTT\";s:6:\"\0*\0url\";s:21:\"http://www.ifttt.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://www.ifttt.com/oembed/\";s:11:\"\0*\0provider\";r:1561;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"http://ifttt.com/recipes/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"iHeartRadio\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"iHeartRadio\";s:6:\"\0*\0url\";s:22:\"https://www.iheart.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://www.iheart.com/oembed\";s:11:\"\0*\0provider\";r:1572;s:10:\"\0*\0schemes\";a:1:{i:0;s:34:\"https://www.iheart.com/podcast/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"iMenuPro\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"iMenuPro\";s:6:\"\0*\0url\";s:20:\"https://imenupro.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://qr.imenupro.com/api/oembed\";s:11:\"\0*\0provider\";r:1583;s:10:\"\0*\0schemes\";a:2:{i:0;s:24:\"http://qr.imenupro.com/*\";i:1;s:25:\"https://qr.imenupro.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Incredible\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Incredible\";s:6:\"\0*\0url\";s:22:\"https://incredible.dev\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://oembed.incredible.dev/oembed\";s:11:\"\0*\0provider\";r:1596;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://incredible.dev/watch/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Indaco\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Indaco\";s:6:\"\0*\0url\";s:30:\"https://player.indacolive.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:45:\"https://player.indacolive.com/services/oembed\";s:11:\"\0*\0provider\";r:1608;s:10:\"\0*\0schemes\";a:1:{i:0;s:50:\"https://player.indacolive.com/player/jwp/clients/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"Infogram\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Infogram\";s:6:\"\0*\0url\";s:21:\"https://infogram.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://infogram.com/oembed\";s:11:\"\0*\0provider\";r:1620;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://infogram.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:9:\"Infoveave\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Infoveave\";s:6:\"\0*\0url\";s:22:\"https://infoveave.net/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://infoveave.net/services/oembed/\";s:11:\"\0*\0provider\";r:1631;s:10:\"\0*\0schemes\";a:2:{i:0;s:27:\"https://*.infoveave.net/E/*\";i:1;s:27:\"https://*.infoveave.net/P/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Injurymap\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Injurymap\";s:6:\"\0*\0url\";s:26:\"https://www.injurymap.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://www.injurymap.com/services/oembed\";s:11:\"\0*\0provider\";r:1643;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"https://www.injurymap.com/exercises/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Inoreader\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Inoreader\";s:6:\"\0*\0url\";s:25:\"https://www.inoreader.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://www.inoreader.com/oembed/api/\";s:11:\"\0*\0provider\";r:1654;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"https://www.inoreader.com/oembed/\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"inphood\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"inphood\";s:6:\"\0*\0url\";s:19:\"http://inphood.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"http://api.inphood.com/oembed\";s:11:\"\0*\0provider\";r:1665;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"http://*.inphood.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:13:\"Insight Timer\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Insight Timer\";s:6:\"\0*\0url\";s:25:\"https://insighttimer.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:48:\"https://widgets.insighttimer.com/services/oembed\";s:11:\"\0*\0provider\";r:1677;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://insighttimer.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Instagram\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Instagram\";s:6:\"\0*\0url\";s:21:\"https://instagram.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:49:\"https://graph.facebook.com/v16.0/instagram_oembed\";s:11:\"\0*\0provider\";r:1688;s:10:\"\0*\0schemes\";a:26:{i:0;s:27:\"http://instagram.com/*/p/*,\";i:1;s:31:\"http://www.instagram.com/*/p/*,\";i:2;s:28:\"https://instagram.com/*/p/*,\";i:3;s:32:\"https://www.instagram.com/*/p/*,\";i:4;s:24:\"http://instagram.com/p/*\";i:5;s:21:\"http://instagr.am/p/*\";i:6;s:28:\"http://www.instagram.com/p/*\";i:7;s:25:\"http://www.instagr.am/p/*\";i:8;s:25:\"https://instagram.com/p/*\";i:9;s:22:\"https://instagr.am/p/*\";i:10;s:29:\"https://www.instagram.com/p/*\";i:11;s:26:\"https://www.instagr.am/p/*\";i:12;s:25:\"http://instagram.com/tv/*\";i:13;s:22:\"http://instagr.am/tv/*\";i:14;s:29:\"http://www.instagram.com/tv/*\";i:15;s:26:\"http://www.instagr.am/tv/*\";i:16;s:26:\"https://instagram.com/tv/*\";i:17;s:23:\"https://instagr.am/tv/*\";i:18;s:30:\"https://www.instagram.com/tv/*\";i:19;s:27:\"https://www.instagr.am/tv/*\";i:20;s:31:\"http://www.instagram.com/reel/*\";i:21;s:32:\"https://www.instagram.com/reel/*\";i:22;s:27:\"http://instagram.com/reel/*\";i:23;s:28:\"https://instagram.com/reel/*\";i:24;s:24:\"http://instagr.am/reel/*\";i:25;s:25:\"https://instagr.am/reel/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:14:\"Insticator Inc\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Insticator Inc\";s:6:\"\0*\0url\";s:27:\"https://www.insticator.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://www.insticator.com/oembed\";s:11:\"\0*\0provider\";r:1725;s:10:\"\0*\0schemes\";a:1:{i:0;s:39:\"https://ppa.insticator.com/embed-unit/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Issuu\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Issuu\";s:6:\"\0*\0url\";s:18:\"https://issuu.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:24:\"https://issuu.com/oembed\";s:11:\"\0*\0provider\";r:1736;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://issuu.com/*/docs/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:16:\"Itabtech infosys\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"Itabtech infosys\";s:6:\"\0*\0url\";s:34:\"https://samay.itabtechinfosys.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://samay.itabtechinfosys.com/oembed/\";s:11:\"\0*\0provider\";r:1747;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"https://samay.itabtechinfosys.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:13:\"itemis CREATE\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"itemis CREATE\";s:6:\"\0*\0url\";s:22:\"https://play.itemis.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:46:\"https://create.storage.api.itemis.io/api/embed\";s:11:\"\0*\0provider\";r:1758;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://play.itemis.io/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Jovian\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Jovian\";s:6:\"\0*\0url\";s:19:\"https://jovian.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://api.jovian.com/oembed.json\";s:11:\"\0*\0provider\";r:1769;s:10:\"\0*\0schemes\";a:9:{i:0;s:19:\"https://jovian.ml/*\";i:1;s:25:\"https://jovian.ml/viewer*\";i:2;s:21:\"https://*.jovian.ml/*\";i:3;s:19:\"https://jovian.ai/*\";i:4;s:25:\"https://jovian.ai/viewer*\";i:5;s:21:\"https://*.jovian.ai/*\";i:6;s:20:\"https://jovian.com/*\";i:7;s:26:\"https://jovian.com/viewer*\";i:8;s:22:\"https://*.jovian.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"KakaoTv\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"KakaoTv\";s:6:\"\0*\0url\";s:21:\"https://tv.kakao.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://tv.kakao.com/oembed\";s:11:\"\0*\0provider\";r:1788;s:10:\"\0*\0schemes\";a:6:{i:0;s:41:\"https://tv.kakao.com/channel/*/cliplink/*\";i:1;s:43:\"https://tv.kakao.com/m/channel/*/cliplink/*\";i:2;s:32:\"https://tv.kakao.com/channel/v/*\";i:3;s:41:\"https://tv.kakao.com/channel/*/livelink/*\";i:4;s:43:\"https://tv.kakao.com/m/channel/*/livelink/*\";i:5;s:32:\"https://tv.kakao.com/channel/l/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Kickstarter\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Kickstarter\";s:6:\"\0*\0url\";s:26:\"http://www.kickstarter.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"http://www.kickstarter.com/services/oembed\";s:11:\"\0*\0provider\";r:1804;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"http://www.kickstarter.com/projects/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Kidoju\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Kidoju\";s:6:\"\0*\0url\";s:23:\"https://www.kidoju.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://www.kidoju.com/api/oembed\";s:11:\"\0*\0provider\";r:1815;s:10:\"\0*\0schemes\";a:2:{i:0;s:31:\"https://www.kidoju.com/en/x/*/*\";i:1;s:31:\"https://www.kidoju.com/fr/x/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"Kirim.Email\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Kirim.Email\";s:6:\"\0*\0url\";s:20:\"https://kirim.email/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://halaman.email/service/oembed\";s:11:\"\0*\0provider\";r:1827;s:10:\"\0*\0schemes\";a:2:{i:0;s:28:\"https://halaman.email/form/*\";i:1;s:35:\"https://aplikasi.kirim.email/form/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:3:\"Kit\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:3:\"Kit\";s:6:\"\0*\0url\";s:15:\"https://kit.co/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://embed.kit.co/oembed\";s:11:\"\0*\0provider\";r:1839;s:10:\"\0*\0schemes\";a:2:{i:0;s:17:\"http://kit.co/*/*\";i:1;s:18:\"https://kit.co/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Kitchenbowl\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Kitchenbowl\";s:6:\"\0*\0url\";s:26:\"http://www.kitchenbowl.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"http://www.kitchenbowl.com/oembed\";s:11:\"\0*\0provider\";r:1851;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"http://www.kitchenbowl.com/recipe/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"kmdr\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"kmdr\";s:6:\"\0*\0url\";s:15:\"https://kmdr.sh\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://api.kmdr.sh/services/oembed\";s:11:\"\0*\0provider\";r:1862;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"https://app.kmdr.sh/h/*\";i:1;s:29:\"https://app.kmdr.sh/history/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Knacki\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Knacki\";s:6:\"\0*\0url\";s:22:\"http://jdr.knacki.info\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://jdr.knacki.info/oembed\";s:11:\"\0*\0provider\";r:1874;s:10:\"\0*\0schemes\";a:2:{i:0;s:29:\"http://jdr.knacki.info/meuh/*\";i:1;s:30:\"https://jdr.knacki.info/meuh/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:13:\"Knowledge Pad\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Knowledge Pad\";s:6:\"\0*\0url\";s:24:\"https://knowledgepad.co/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://api.spoonacular.com/knowledge/oembed\";s:11:\"\0*\0provider\";r:1886;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"https://knowledgepad.co/#/knowledge/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Kooapp\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Kooapp\";s:6:\"\0*\0url\";s:18:\"https://kooapp.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://embed.kooapp.com/services/oembed\";s:11:\"\0*\0provider\";r:1898;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://*.kooapp.com/koo/*\";i:1;s:25:\"http://*.kooapp.com/koo/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Kurozora\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Kurozora\";s:6:\"\0*\0url\";s:21:\"https://kurozora.app/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://kurozora.app/oembed\";s:11:\"\0*\0provider\";r:1910;s:10:\"\0*\0schemes\";a:2:{i:0;s:31:\"https://kurozora.app/episodes/*\";i:1;s:28:\"https://kurozora.app/songs/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:16:\"LearningApps.org\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"LearningApps.org\";s:6:\"\0*\0url\";s:24:\"http://learningapps.org/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"http://learningapps.org/oembed.php\";s:11:\"\0*\0provider\";r:1922;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"http://learningapps.org/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"LeMans.Pod\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"LeMans.Pod\";s:6:\"\0*\0url\";s:36:\"https://umotion-test.univ-lemans.fr/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"https://umotion-test.univ-lemans.fr/oembed\";s:11:\"\0*\0provider\";r:1933;s:10:\"\0*\0schemes\";a:1:{i:0;s:43:\"https://umotion-test.univ-lemans.fr/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Lille.Pod\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Lille.Pod\";s:6:\"\0*\0url\";s:26:\"https://pod.univ-lille.fr/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://pod.univ-lille.fr/video/oembed\";s:11:\"\0*\0provider\";r:1944;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"https://pod.univ-lille.fr/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Line Place\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Line Place\";s:6:\"\0*\0url\";s:21:\"https://place.line.me\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://place.line.me/oembed\";s:11:\"\0*\0provider\";r:1955;s:10:\"\0*\0schemes\";a:1:{i:0;s:34:\"https://place.line.me/businesses/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Livestream\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Livestream\";s:6:\"\0*\0url\";s:23:\"https://livestream.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://livestream.com/oembed\";s:11:\"\0*\0provider\";r:1966;s:10:\"\0*\0schemes\";a:6:{i:0;s:42:\"https://livestream.com/accounts/*/events/*\";i:1;s:51:\"https://livestream.com/accounts/*/events/*/videos/*\";i:2;s:33:\"https://livestream.com/*/events/*\";i:3;s:42:\"https://livestream.com/*/events/*/videos/*\";i:4;s:26:\"https://livestream.com/*/*\";i:5;s:35:\"https://livestream.com/*/*/videos/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"LottieFiles\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"LottieFiles\";s:6:\"\0*\0url\";s:24:\"https://lottiefiles.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://embed.lottiefiles.com/oembed\";s:11:\"\0*\0provider\";r:1982;s:10:\"\0*\0schemes\";a:4:{i:0;s:25:\"https://lottiefiles.com/*\";i:1;s:27:\"https://*.lottiefiles.com/*\";i:2;s:23:\"https://*.lottie.host/*\";i:3;s:21:\"https://lottie.host/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Ludus\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Ludus\";s:6:\"\0*\0url\";s:17:\"https://ludus.one\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://app.ludus.one/oembed\";s:11:\"\0*\0provider\";r:1997;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://app.ludus.one/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Lumiere\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Lumiere\";s:6:\"\0*\0url\";s:16:\"https://latd.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://admin.lumiere.is/api/services/oembed\";s:11:\"\0*\0provider\";r:2009;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://*.lumiere.is/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"MathEmbed\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"MathEmbed\";s:6:\"\0*\0url\";s:20:\"http://mathembed.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"http://mathembed.com/oembed\";s:11:\"\0*\0provider\";r:2020;s:10:\"\0*\0schemes\";a:2:{i:0;s:38:\"http://mathembed.com/latex?inputText=*\";i:1;s:38:\"http://mathembed.com/latex?inputText=*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Matterport\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Matterport\";s:6:\"\0*\0url\";s:23:\"https://matterport.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:47:\"https://my.matterport.com/api/v1/models/oembed/\";s:11:\"\0*\0provider\";r:2032;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"me.me\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"me.me\";s:6:\"\0*\0url\";s:14:\"https://me.me/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:20:\"https://me.me/oembed\";s:11:\"\0*\0provider\";r:2043;s:10:\"\0*\0schemes\";a:1:{i:0;s:17:\"https://me.me/i/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Mediastream\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Mediastream\";s:6:\"\0*\0url\";s:19:\"https://mdstrm.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://mdstrm.com/oembed\";s:11:\"\0*\0provider\";r:2054;s:10:\"\0*\0schemes\";a:3:{i:0;s:26:\"https://mdstrm.com/embed/*\";i:1;s:32:\"https://mdstrm.com/live-stream/*\";i:2;s:26:\"https://mdstrm.com/image/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:58:\"Medienarchiv der Künste - Zürcher Hochschule der Künste\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:58:\"Medienarchiv der Künste - Zürcher Hochschule der Künste\";s:6:\"\0*\0url\";s:29:\"https://medienarchiv.zhdk.ch/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://medienarchiv.zhdk.ch/oembed.json\";s:11:\"\0*\0provider\";r:2067;s:10:\"\0*\0schemes\";a:1:{i:0;s:38:\"https://medienarchiv.zhdk.ch/entries/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Mermaid Ink\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Mermaid Ink\";s:6:\"\0*\0url\";s:19:\"https://mermaid.ink\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://mermaid.ink/services/oembed\";s:11:\"\0*\0provider\";r:2078;s:10:\"\0*\0schemes\";a:2:{i:0;s:25:\"https://mermaid.ink/img/*\";i:1;s:25:\"https://mermaid.ink/svg/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:16:\"Microsoft Stream\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"Microsoft Stream\";s:6:\"\0*\0url\";s:28:\"https://stream.microsoft.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://web.microsoftstream.com/oembed\";s:11:\"\0*\0provider\";r:2090;s:10:\"\0*\0schemes\";a:2:{i:0;s:37:\"https://*.microsoftstream.com/video/*\";i:1;s:39:\"https://*.microsoftstream.com/channel/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Minerva\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Minerva\";s:6:\"\0*\0url\";s:28:\"https://www.minervaknows.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://oembed.minervaknows.com\";s:11:\"\0*\0provider\";r:2102;s:10:\"\0*\0schemes\";a:5:{i:0;s:47:\"https://www.minervaknows.com/featured-recipes/*\";i:1;s:37:\"https://www.minervaknows.com/themes/*\";i:2;s:47:\"https://www.minervaknows.com/themes/*/recipes/*\";i:3;s:38:\"https://app.minervaknows.com/recipes/*\";i:4;s:45:\"https://app.minervaknows.com/recipes/*/follow\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"Miro\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Miro\";s:6:\"\0*\0url\";s:17:\"https://miro.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://miro.com/api/v1/oembed\";s:11:\"\0*\0provider\";r:2118;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://miro.com/app/board/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"MixCloud\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"MixCloud\";s:6:\"\0*\0url\";s:21:\"https://mixcloud.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://www.mixcloud.com/oembed/\";s:11:\"\0*\0provider\";r:2129;s:10:\"\0*\0schemes\";a:2:{i:0;s:28:\"http://www.mixcloud.com/*/*/\";i:1;s:29:\"https://www.mixcloud.com/*/*/\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"Mixpanel\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Mixpanel\";s:6:\"\0*\0url\";s:21:\"https://mixpanel.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"https://mixpanel.com/api/app/embed/oembed/\";s:11:\"\0*\0provider\";r:2141;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://mixpanel.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"Moby Picture\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Moby Picture\";s:6:\"\0*\0url\";s:26:\"http://www.mobypicture.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"http://api.mobypicture.com/oEmbed\";s:11:\"\0*\0provider\";r:2152;s:10:\"\0*\0schemes\";a:2:{i:0;s:40:\"http://www.mobypicture.com/user/*/view/*\";i:1;s:16:\"http://moby.to/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:17:\"Music Box Maniacs\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:17:\"Music Box Maniacs\";s:6:\"\0*\0url\";s:28:\"https://musicboxmaniacs.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://musicboxmaniacs.com/embed/\";s:11:\"\0*\0provider\";r:2164;s:10:\"\0*\0schemes\";a:1:{i:0;s:44:\"https://musicboxmaniacs.com/explore/melody/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"myBeweeg\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"myBeweeg\";s:6:\"\0*\0url\";s:20:\"https://mybeweeg.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://mybeweeg.com/services/oembed\";s:11:\"\0*\0provider\";r:2176;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://mybeweeg.com/w/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:20:\"MySQL Visual Explain\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:20:\"MySQL Visual Explain\";s:6:\"\0*\0url\";s:24:\"https://mysqlexplain.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://api.mysqlexplain.com/v2/oembed.json\";s:11:\"\0*\0provider\";r:2187;s:10:\"\0*\0schemes\";a:2:{i:0;s:34:\"https://mysqlexplain.com/explain/*\";i:1;s:40:\"https://embed.mysqlexplain.com/explain/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Namchey\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Namchey\";s:6:\"\0*\0url\";s:19:\"https://namchey.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://namchey.com/api/oembed\";s:11:\"\0*\0provider\";r:2200;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://namchey.com/embeds/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"nanoo.tv\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"nanoo.tv\";s:6:\"\0*\0url\";s:21:\"https://www.nanoo.tv/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://www.nanoo.tv/services/oembed\";s:11:\"\0*\0provider\";r:2213;s:10:\"\0*\0schemes\";a:12:{i:0;s:24:\"http://*.nanoo.tv/link/*\";i:1;s:22:\"http://nanoo.tv/link/*\";i:2;s:25:\"http://*.nanoo.pro/link/*\";i:3;s:23:\"http://nanoo.pro/link/*\";i:4;s:25:\"https://*.nanoo.tv/link/*\";i:5;s:23:\"https://nanoo.tv/link/*\";i:6;s:26:\"https://*.nanoo.pro/link/*\";i:7;s:24:\"https://nanoo.pro/link/*\";i:8;s:31:\"http://media.zhdk.ch/signatur/*\";i:9;s:35:\"http://new.media.zhdk.ch/signatur/*\";i:10;s:32:\"https://media.zhdk.ch/signatur/*\";i:11;s:36:\"https://new.media.zhdk.ch/signatur/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:19:\"Nasjonalbiblioteket\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:19:\"Nasjonalbiblioteket\";s:6:\"\0*\0url\";s:18:\"https://www.nb.no/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://api.nb.no/catalog/v1/oembed\";s:11:\"\0*\0provider\";r:2235;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"https://www.nb.no/items/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:13:\"Natural Atlas\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Natural Atlas\";s:6:\"\0*\0url\";s:25:\"https://naturalatlas.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://naturalatlas.com/oembed.json\";s:11:\"\0*\0provider\";r:2246;s:10:\"\0*\0schemes\";a:4:{i:0;s:26:\"https://naturalatlas.com/*\";i:1;s:28:\"https://naturalatlas.com/*/*\";i:2;s:30:\"https://naturalatlas.com/*/*/*\";i:3;s:32:\"https://naturalatlas.com/*/*/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:39:\"NDLA - Norwegian Digital Learning Arena\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:39:\"NDLA - Norwegian Digital Learning Arena\";s:6:\"\0*\0url\";s:15:\"https://ndla.no\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:22:\"https://ndla.no/oembed\";s:11:\"\0*\0provider\";r:2261;s:10:\"\0*\0schemes\";a:6:{i:0;s:17:\"https://ndla.no/*\";i:1;s:25:\"https://ndla.no/article/*\";i:2;s:23:\"https://ndla.no/audio/*\";i:3;s:25:\"https://ndla.no/concept/*\";i:4;s:23:\"https://ndla.no/image/*\";i:5;s:23:\"https://ndla.no/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Nebula\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Nebula\";s:6:\"\0*\0url\";s:17:\"https://nebula.tv\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://nebula.tv/api/oembed\";s:11:\"\0*\0provider\";r:2277;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://nebula.tv/videos/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"Nebula Beta\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Nebula Beta\";s:6:\"\0*\0url\";s:22:\"https://beta.nebula.tv\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://beta.nebula.tv/api/oembed\";s:11:\"\0*\0provider\";r:2289;s:10:\"\0*\0schemes\";a:1:{i:0;s:31:\"https://beta.nebula.tv/videos/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"neetoRecord\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"neetoRecord\";s:6:\"\0*\0url\";s:23:\"https://neetorecord.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://api.neetorecord.com/api/v1/oembed\";s:11:\"\0*\0provider\";r:2301;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"https://*.neetorecord.com/watch/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"nfb.ca\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"nfb.ca\";s:6:\"\0*\0url\";s:18:\"http://www.nfb.ca/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"http://www.nfb.ca/remote/services/oembed/\";s:11:\"\0*\0provider\";r:2312;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"http://*.nfb.ca/film/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"NoPaste\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"NoPaste\";s:6:\"\0*\0url\";s:18:\"https://nopaste.ml\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://oembed.nopaste.ml\";s:11:\"\0*\0provider\";r:2323;s:10:\"\0*\0schemes\";a:1:{i:0;s:20:\"https://nopaste.ml/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Observable\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Observable\";s:6:\"\0*\0url\";s:24:\"https://observablehq.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://api.observablehq.com/oembed\";s:11:\"\0*\0provider\";r:2334;s:10:\"\0*\0schemes\";a:3:{i:0;s:29:\"https://observablehq.com/@*/*\";i:1;s:28:\"https://observablehq.com/d/*\";i:2;s:32:\"https://observablehq.com/embed/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"Odds.com.au\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Odds.com.au\";s:6:\"\0*\0url\";s:23:\"https://www.odds.com.au\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.odds.com.au/api/oembed/\";s:11:\"\0*\0provider\";r:2348;s:10:\"\0*\0schemes\";a:2:{i:0;s:25:\"https://www.odds.com.au/*\";i:1;s:21:\"https://odds.com.au/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:26:\"Odesli (formerly Songlink)\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:26:\"Odesli (formerly Songlink)\";s:6:\"\0*\0url\";s:17:\"https://odesli.co\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:24:\"https://song.link/oembed\";s:11:\"\0*\0provider\";r:2360;s:10:\"\0*\0schemes\";a:7:{i:0;s:19:\"https://song.link/*\";i:1;s:20:\"https://album.link/*\";i:2;s:21:\"https://artist.link/*\";i:3;s:23:\"https://playlist.link/*\";i:4;s:19:\"https://pods.link/*\";i:5;s:21:\"https://mylink.page/*\";i:6;s:19:\"https://odesli.co/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Odysee\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Odysee\";s:6:\"\0*\0url\";s:18:\"https://odysee.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://odysee.com/$/oembed\";s:11:\"\0*\0provider\";r:2378;s:10:\"\0*\0schemes\";a:2:{i:0;s:22:\"https://odysee.com/*/*\";i:1;s:20:\"https://odysee.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Official FM\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Official FM\";s:6:\"\0*\0url\";s:18:\"http://official.fm\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"http://official.fm/services/oembed.json\";s:11:\"\0*\0provider\";r:2390;s:10:\"\0*\0schemes\";a:2:{i:0;s:27:\"http://official.fm/tracks/*\";i:1;s:30:\"http://official.fm/playlists/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:9:\"Omniscope\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Omniscope\";s:6:\"\0*\0url\";s:21:\"https://omniscope.me/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://omniscope.me/_global_/oembed/json\";s:11:\"\0*\0provider\";r:2402;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://omniscope.me/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"Omny Studio\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Omny Studio\";s:6:\"\0*\0url\";s:22:\"https://omnystudio.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:22:\"https://omny.fm/oembed\";s:11:\"\0*\0provider\";r:2414;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://omny.fm/shows/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Orbitvu\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Orbitvu\";s:6:\"\0*\0url\";s:18:\"https://orbitvu.co\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"http://orbitvu.co/service/oembed\";s:11:\"\0*\0provider\";r:2426;s:10:\"\0*\0schemes\";a:10:{i:0;s:36:\"https://orbitvu.co/001/*/ov3601/view\";i:1;s:38:\"https://orbitvu.co/001/*/ov3601/*/view\";i:2;s:38:\"https://orbitvu.co/001/*/ov3602/*/view\";i:3;s:43:\"https://orbitvu.co/001/*/2/orbittour/*/view\";i:4;s:45:\"https://orbitvu.co/001/*/1/2/orbittour/*/view\";i:5;s:35:\"http://orbitvu.co/001/*/ov3601/view\";i:6;s:37:\"http://orbitvu.co/001/*/ov3601/*/view\";i:7;s:37:\"http://orbitvu.co/001/*/ov3602/*/view\";i:8;s:42:\"http://orbitvu.co/001/*/2/orbittour/*/view\";i:9;s:44:\"http://orbitvu.co/001/*/1/2/orbittour/*/view\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Origits\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Origits\";s:6:\"\0*\0url\";s:20:\"https://origits.com/\";s:12:\"\0*\0endpoints\";a:2:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://origits.net/oembed\";s:11:\"\0*\0provider\";r:2446;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://origits.com/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}i:1;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://origits.com/oembed\";s:11:\"\0*\0provider\";r:2446;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://origits.com/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"Outplayed.tv\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Outplayed.tv\";s:6:\"\0*\0url\";s:21:\"https://outplayed.tv/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://outplayed.tv/oembed\";s:11:\"\0*\0provider\";r:2464;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://outplayed.tv/media/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Overflow\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Overflow\";s:6:\"\0*\0url\";s:19:\"https://overflow.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://overflow.io/services/oembed\";s:11:\"\0*\0provider\";r:2475;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"https://overflow.io/s/*\";i:1;s:27:\"https://overflow.io/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:2:\"OZ\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:2:\"OZ\";s:6:\"\0*\0url\";s:19:\"https://www.oz.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://core.oz.com/oembed\";s:11:\"\0*\0provider\";r:2487;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://www.oz.com/*/video/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Padlet\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Padlet\";s:6:\"\0*\0url\";s:19:\"https://padlet.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://padlet.com/oembed/\";s:11:\"\0*\0provider\";r:2500;s:10:\"\0*\0schemes\";a:1:{i:0;s:20:\"https://padlet.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Panda Video\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Panda Video\";s:6:\"\0*\0url\";s:23:\"https://pandavideo.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://api-v2.pandavideo.com.br/oembed\";s:11:\"\0*\0provider\";r:2511;s:10:\"\0*\0schemes\";a:3:{i:0;s:41:\"https://*.tv.pandavideo.com.br/embed/?v=*\";i:1;s:46:\"https://*.tv.pandavideo.com.br/*/playlist.m3u8\";i:2;s:46:\"https://dashboard.pandavideo.com.br/#/videos/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Pastery\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Pastery\";s:6:\"\0*\0url\";s:23:\"https://www.pastery.net\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://www.pastery.net/oembed\";s:11:\"\0*\0provider\";r:2524;s:10:\"\0*\0schemes\";a:4:{i:0;s:20:\"http://pastery.net/*\";i:1;s:21:\"https://pastery.net/*\";i:2;s:24:\"http://www.pastery.net/*\";i:3;s:25:\"https://www.pastery.net/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"PeerTube.TV\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"PeerTube.TV\";s:6:\"\0*\0url\";s:20:\"https://peertube.tv/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://peertube.tv/services/oembed\";s:11:\"\0*\0provider\";r:2538;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://peertube.tv/w/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Picturelfy\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Picturelfy\";s:6:\"\0*\0url\";s:27:\"https://www.picturelfy.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"https://api.picturelfy.com/service/oembed/\";s:11:\"\0*\0provider\";r:2549;s:10:\"\0*\0schemes\";a:2:{i:0;s:29:\"http://www.picturelfy.com/p/*\";i:1;s:30:\"https://www.picturelfy.com/p/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Piggy\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Piggy\";s:6:\"\0*\0url\";s:16:\"https://piggy.to\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:23:\"https://piggy.to/oembed\";s:11:\"\0*\0provider\";r:2561;s:10:\"\0*\0schemes\";a:2:{i:0;s:21:\"https://piggy.to/@*/*\";i:1;s:23:\"https://piggy.to/view/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Pikasso\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Pikasso\";s:6:\"\0*\0url\";s:27:\"https://builder.pikasso.xyz\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://builder.pikasso.xyz/api/oembed\";s:11:\"\0*\0provider\";r:2573;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"https://*.builder.pikasso.xyz/embed/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"PingVP\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"PingVP\";s:6:\"\0*\0url\";s:23:\"https://www.pingvp.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:45:\"https://beta.pingvp.com.kpnis.nl/p/oembed.php\";s:11:\"\0*\0provider\";r:2585;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Pinpoll\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Pinpoll\";s:6:\"\0*\0url\";s:38:\"https://www.pinpoll.com/products/tools\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://tools.pinpoll.com/oembed\";s:11:\"\0*\0provider\";r:2595;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"https://tools.pinpoll.com/embed/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Pinterest\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Pinterest\";s:6:\"\0*\0url\";s:25:\"https://www.pinterest.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://www.pinterest.com/oembed.json\";s:11:\"\0*\0provider\";r:2608;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://www.pinterest.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"PitchHub\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"PitchHub\";s:6:\"\0*\0url\";s:25:\"https://www.pitchhub.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://player.pitchhub.com/en/public/oembed\";s:11:\"\0*\0provider\";r:2619;s:10:\"\0*\0schemes\";a:1:{i:0;s:46:\"https://player.pitchhub.com/en/public/player/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Pixdor\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Pixdor\";s:6:\"\0*\0url\";s:22:\"http://www.pixdor.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://store.pixdor.com/oembed\";s:11:\"\0*\0provider\";r:2630;s:10:\"\0*\0schemes\";a:2:{i:0;s:51:\"https://store.pixdor.com/place-marker-widget/*/show\";i:1;s:35:\"https://store.pixdor.com/map/*/show\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Plusdocs\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Plusdocs\";s:6:\"\0*\0url\";s:19:\"http://plusdocs.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://app.plusdocs.com/oembed\";s:11:\"\0*\0provider\";r:2644;s:10:\"\0*\0schemes\";a:3:{i:0;s:38:\"https://app.plusdocs.com/*/snapshots/*\";i:1;s:39:\"https://app.plusdocs.com/*/pages/edit/*\";i:2;s:40:\"https://app.plusdocs.com/*/pages/share/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Podbean\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Podbean\";s:6:\"\0*\0url\";s:18:\"http://podbean.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://api.podbean.com/v1/oembed\";s:11:\"\0*\0provider\";r:2658;s:10:\"\0*\0schemes\";a:2:{i:0;s:25:\"https://*.podbean.com/e/*\";i:1;s:24:\"http://*.podbean.com/e/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Poll Daddy\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Poll Daddy\";s:6:\"\0*\0url\";s:20:\"http://polldaddy.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://polldaddy.com/oembed/\";s:11:\"\0*\0provider\";r:2670;s:10:\"\0*\0schemes\";a:3:{i:0;s:26:\"http://*.polldaddy.com/s/*\";i:1;s:29:\"http://*.polldaddy.com/poll/*\";i:2;s:32:\"http://*.polldaddy.com/ratings/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Portfolium\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Portfolium\";s:6:\"\0*\0url\";s:22:\"https://portfolium.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://api.portfolium.com/oembed\";s:11:\"\0*\0provider\";r:2683;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://portfolium.com/entry/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Present\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Present\";s:6:\"\0*\0url\";s:18:\"https://present.do\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:47:\"https://gateway.cobalt.run/present/decks/oembed\";s:11:\"\0*\0provider\";r:2694;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://present.do/decks/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Prezi Video\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Prezi Video\";s:6:\"\0*\0url\";s:18:\"https://prezi.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://prezi.com/v/oembed\";s:11:\"\0*\0provider\";r:2706;s:10:\"\0*\0schemes\";a:2:{i:0;s:21:\"https://prezi.com/v/*\";i:1;s:23:\"https://*.prezi.com/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"QTpi\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"QTpi\";s:6:\"\0*\0url\";s:16:\"https://qtpi.gg/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://qtpi.gg/fashion/oembed\";s:11:\"\0*\0provider\";r:2718;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"https://qtpi.gg/fashion/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Quiz.biz\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Quiz.biz\";s:6:\"\0*\0url\";s:20:\"http://www.quiz.biz/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"http://www.quiz.biz/api/oembed\";s:11:\"\0*\0provider\";r:2729;s:10:\"\0*\0schemes\";a:1:{i:0;s:32:\"http://www.quiz.biz/quizz-*.html\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Quizz.biz\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Quizz.biz\";s:6:\"\0*\0url\";s:21:\"http://www.quizz.biz/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"http://www.quizz.biz/api/oembed\";s:11:\"\0*\0provider\";r:2740;s:10:\"\0*\0schemes\";a:1:{i:0;s:33:\"http://www.quizz.biz/quizz-*.html\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"RadioPublic\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"RadioPublic\";s:6:\"\0*\0url\";s:23:\"https://radiopublic.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://oembed.radiopublic.com/oembed\";s:11:\"\0*\0provider\";r:2751;s:10:\"\0*\0schemes\";a:7:{i:0;s:30:\"https://play.radiopublic.com/*\";i:1;s:25:\"https://radiopublic.com/*\";i:2;s:29:\"https://www.radiopublic.com/*\";i:3;s:29:\"http://play.radiopublic.com/*\";i:4;s:24:\"http://radiopublic.com/*\";i:5;s:28:\"http://www.radiopublic.com/*\";i:6;s:27:\"https://*.radiopublic.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Raindrop\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Raindrop\";s:6:\"\0*\0url\";s:19:\"https://raindrop.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://pub.raindrop.io/api/oembed\";s:11:\"\0*\0provider\";r:2768;s:10:\"\0*\0schemes\";a:4:{i:0;s:21:\"https://raindrop.io/*\";i:1;s:23:\"https://raindrop.io/*/*\";i:2;s:25:\"https://raindrop.io/*/*/*\";i:3;s:27:\"https://raindrop.io/*/*/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"rcvis\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"rcvis\";s:6:\"\0*\0url\";s:22:\"https://www.rcvis.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://animatron.com/oembed\";s:11:\"\0*\0provider\";r:2783;s:10:\"\0*\0schemes\";a:4:{i:0;s:25:\"https://www.rcvis.com/v/*\";i:1;s:33:\"https://www.rcvis.com/visualize=*\";i:2;s:26:\"https://www.rcvis.com/ve/*\";i:3;s:41:\"https://www.rcvis.com/visualizeEmbedded=*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Reddit\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Reddit\";s:6:\"\0*\0url\";s:19:\"https://reddit.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://www.reddit.com/oembed\";s:11:\"\0*\0provider\";r:2797;s:10:\"\0*\0schemes\";a:2:{i:0;s:35:\"https://reddit.com/r/*/comments/*/*\";i:1;s:39:\"https://www.reddit.com/r/*/comments/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"ReleaseWire\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"ReleaseWire\";s:6:\"\0*\0url\";s:27:\"http://www.releasewire.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"http://publisher.releasewire.com/oembed/\";s:11:\"\0*\0provider\";r:2809;s:10:\"\0*\0schemes\";a:1:{i:0;s:18:\"http://rwire.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Replit\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Replit\";s:6:\"\0*\0url\";s:19:\"https://replit.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://replit.com/data/oembed\";s:11:\"\0*\0provider\";r:2820;s:10:\"\0*\0schemes\";a:2:{i:0;s:20:\"https://repl.it/@*/*\";i:1;s:23:\"https://replit.com/@*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"ReverbNation\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"ReverbNation\";s:6:\"\0*\0url\";s:29:\"https://www.reverbnation.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.reverbnation.com/oembed\";s:11:\"\0*\0provider\";r:2832;s:10:\"\0*\0schemes\";a:2:{i:0;s:30:\"https://www.reverbnation.com/*\";i:1;s:38:\"https://www.reverbnation.com/*/songs/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Roomshare\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Roomshare\";s:6:\"\0*\0url\";s:19:\"http://roomshare.jp\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"http://roomshare.jp/en/oembed.json\";s:11:\"\0*\0provider\";r:2844;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"http://roomshare.jp/post/*\";i:1;s:29:\"http://roomshare.jp/en/post/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"RoosterTeeth\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"RoosterTeeth\";s:6:\"\0*\0url\";s:24:\"https://roosterteeth.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://roosterteeth.com/oembed\";s:11:\"\0*\0provider\";r:2856;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://roosterteeth.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Rumble\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Rumble\";s:6:\"\0*\0url\";s:19:\"https://rumble.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://rumble.com/api/Media/oembed.json\";s:11:\"\0*\0provider\";r:2868;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Runkit\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Runkit\";s:6:\"\0*\0url\";s:18:\"https://runkit.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://embed.runkit.com/oembed\";s:11:\"\0*\0provider\";r:2878;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"http://embed.runkit.com/*,\";i:1;s:27:\"https://embed.runkit.com/*,\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Saooti\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Saooti\";s:6:\"\0*\0url\";s:26:\"https://octopus.saooti.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://octopus.saooti.com/oembed\";s:11:\"\0*\0provider\";r:2891;s:10:\"\0*\0schemes\";a:1:{i:0;s:45:\"https://octopus.saooti.com/main/pub/podcast/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"Sapo Videos\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Sapo Videos\";s:6:\"\0*\0url\";s:21:\"http://videos.sapo.pt\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://videos.sapo.pt/oembed\";s:11:\"\0*\0provider\";r:2902;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"http://videos.sapo.pt/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Screen9\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Screen9\";s:6:\"\0*\0url\";s:23:\"http://www.screen9.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://api.screen9.com/oembed\";s:11:\"\0*\0provider\";r:2913;s:10:\"\0*\0schemes\";a:2:{i:0;s:29:\"https://console.screen9.com/*\";i:1;s:22:\"https://*.screen9.tv/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:14:\"Screencast.com\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"Screencast.com\";s:6:\"\0*\0url\";s:26:\"http://www.screencast.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"https://api.screencast.com/external/oembed\";s:11:\"\0*\0provider\";r:2925;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"http://www.screencast.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Screenr\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Screenr\";s:6:\"\0*\0url\";s:23:\"http://www.screenr.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"http://www.screenr.com/api/oembed.json\";s:11:\"\0*\0provider\";r:2936;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"http://www.screenr.com/*/\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:12:\"ScribbleMaps\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"ScribbleMaps\";s:6:\"\0*\0url\";s:24:\"https://scribblemaps.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:49:\"https://scribblemaps.com/api/services/oembed.json\";s:11:\"\0*\0provider\";r:2947;s:10:\"\0*\0schemes\";a:4:{i:0;s:39:\"http://www.scribblemaps.com/maps/view/*\";i:1;s:40:\"https://www.scribblemaps.com/maps/view/*\";i:2;s:35:\"http://scribblemaps.com/maps/view/*\";i:3;s:36:\"https://scribblemaps.com/maps/view/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Scribd\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Scribd\";s:6:\"\0*\0url\";s:22:\"http://www.scribd.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"http://www.scribd.com/services/oembed/\";s:11:\"\0*\0provider\";r:2961;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"http://www.scribd.com/doc/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"SendtoNews\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"SendtoNews\";s:6:\"\0*\0url\";s:26:\"http://www.sendtonews.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:44:\"https://embed.sendtonews.com/services/oembed\";s:11:\"\0*\0provider\";r:2972;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"https://embed.sendtonews.com/oembed/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"SharedFile\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"SharedFile\";s:6:\"\0*\0url\";s:42:\"https://shared-file-kappa.vercel.app/file/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:52:\"https://shared-file-kappa.vercel.app/file/api/oembed\";s:11:\"\0*\0provider\";r:2985;s:10:\"\0*\0schemes\";a:1:{i:0;s:43:\"https://shared-file-kappa.vercel.app/file/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Shopshare\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Shopshare\";s:6:\"\0*\0url\";s:20:\"https://shopshare.tv\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://shopshare.tv/api/shopcast/oembed\";s:11:\"\0*\0provider\";r:2996;s:10:\"\0*\0schemes\";a:2:{i:0;s:32:\"https://shopshare.tv/shopboard/*\";i:1;s:31:\"https://shopshare.tv/shopcast/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"ShortNote\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"ShortNote\";s:6:\"\0*\0url\";s:25:\"https://www.shortnote.jp/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://www.shortnote.jp/oembed/\";s:11:\"\0*\0provider\";r:3008;s:10:\"\0*\0schemes\";a:1:{i:0;s:37:\"https://www.shortnote.jp/view/notes/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Shoudio\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Shoudio\";s:6:\"\0*\0url\";s:18:\"http://shoudio.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"http://shoudio.com/api/oembed\";s:11:\"\0*\0provider\";r:3019;s:10:\"\0*\0schemes\";a:2:{i:0;s:20:\"http://shoudio.com/*\";i:1;s:17:\"http://shoud.io/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:16:\"Show by Animaker\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:16:\"Show by Animaker\";s:6:\"\0*\0url\";s:19:\"https://getshow.io/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://api.getshow.io/oembed.json\";s:11:\"\0*\0provider\";r:3031;s:10:\"\0*\0schemes\";a:2:{i:0;s:31:\"https://app.getshow.io/iframe/*\";i:1;s:28:\"https://*.getshow.io/share/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:38:\"Show the Way, actionable location info\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:38:\"Show the Way, actionable location info\";s:6:\"\0*\0url\";s:21:\"https://showtheway.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://showtheway.io/oembed\";s:11:\"\0*\0provider\";r:3043;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://showtheway.io/to/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Simplecast\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Simplecast\";s:6:\"\0*\0url\";s:22:\"https://simplecast.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://simplecast.com/oembed\";s:11:\"\0*\0provider\";r:3054;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"https://simplecast.com/s/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Sizzle\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Sizzle\";s:6:\"\0*\0url\";s:21:\"https://onsizzle.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://onsizzle.com/oembed\";s:11:\"\0*\0provider\";r:3066;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://onsizzle.com/i/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Sketchfab\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Sketchfab\";s:6:\"\0*\0url\";s:20:\"http://sketchfab.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"http://sketchfab.com/oembed\";s:11:\"\0*\0provider\";r:3077;s:10:\"\0*\0schemes\";a:3:{i:0;s:30:\"http://sketchfab.com/*models/*\";i:1;s:31:\"https://sketchfab.com/*models/*\";i:2;s:33:\"https://sketchfab.com/*/folders/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"SlideShare\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"SlideShare\";s:6:\"\0*\0url\";s:26:\"http://www.slideshare.net/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://www.slideshare.net/api/oembed/2\";s:11:\"\0*\0provider\";r:3091;s:10:\"\0*\0schemes\";a:10:{i:0;s:30:\"https://www.slideshare.net/*/*\";i:1;s:29:\"http://www.slideshare.net/*/*\";i:2;s:29:\"https://fr.slideshare.net/*/*\";i:3;s:28:\"http://fr.slideshare.net/*/*\";i:4;s:29:\"https://de.slideshare.net/*/*\";i:5;s:28:\"http://de.slideshare.net/*/*\";i:6;s:29:\"https://es.slideshare.net/*/*\";i:7;s:28:\"http://es.slideshare.net/*/*\";i:8;s:29:\"https://pt.slideshare.net/*/*\";i:9;s:28:\"http://pt.slideshare.net/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"SmashNotes\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"SmashNotes\";s:6:\"\0*\0url\";s:22:\"https://smashnotes.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://smashnotes.com/services/oembed\";s:11:\"\0*\0provider\";r:3111;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://smashnotes.com/p/*\";i:1;s:67:\"https://smashnotes.com/p/*/e/* - https://smashnotes.com/p/*/e/*/s/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Smeme\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Smeme\";s:6:\"\0*\0url\";s:17:\"https://smeme.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://open.smeme.com/api/oembed\";s:11:\"\0*\0provider\";r:3123;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://open.smeme.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Smrthi\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Smrthi\";s:6:\"\0*\0url\";s:22:\"https://www.smrthi.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://www.smrthi.com/api/oembed\";s:11:\"\0*\0provider\";r:3134;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://www.smrthi.com/book/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"SmugMug\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"SmugMug\";s:6:\"\0*\0url\";s:24:\"https://www.smugmug.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://api.smugmug.com/services/oembed/\";s:11:\"\0*\0provider\";r:3146;s:10:\"\0*\0schemes\";a:2:{i:0;s:22:\"http://*.smugmug.com/*\";i:1;s:23:\"https://*.smugmug.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:14:\"SocialExplorer\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"SocialExplorer\";s:6:\"\0*\0url\";s:31:\"https://www.socialexplorer.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:47:\"https://www.socialexplorer.com/services/oembed/\";s:11:\"\0*\0provider\";r:3158;s:10:\"\0*\0schemes\";a:4:{i:0;s:40:\"https://www.socialexplorer.com/*/explore\";i:1;s:37:\"https://www.socialexplorer.com/*/view\";i:2;s:37:\"https://www.socialexplorer.com/*/edit\";i:3;s:38:\"https://www.socialexplorer.com/*/embed\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"SoundCloud\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"SoundCloud\";s:6:\"\0*\0url\";s:22:\"http://soundcloud.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://soundcloud.com/oembed\";s:11:\"\0*\0provider\";r:3172;s:10:\"\0*\0schemes\";a:4:{i:0;s:23:\"http://soundcloud.com/*\";i:1;s:24:\"https://soundcloud.com/*\";i:2;s:27:\"https://on.soundcloud.com/*\";i:3;s:32:\"https://soundcloud.app.goog.gl/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"SpeakerDeck\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"SpeakerDeck\";s:6:\"\0*\0url\";s:23:\"https://speakerdeck.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://speakerdeck.com/oembed.json\";s:11:\"\0*\0provider\";r:3186;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"http://speakerdeck.com/*/*\";i:1;s:27:\"https://speakerdeck.com/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Spotify\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Spotify\";s:6:\"\0*\0url\";s:20:\"https://spotify.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://open.spotify.com/oembed\";s:11:\"\0*\0provider\";r:3199;s:10:\"\0*\0schemes\";a:3:{i:0;s:26:\"https://open.spotify.com/*\";i:1;s:9:\"spotify:*\";i:2;s:22:\"https://spotify.link/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Spotlightr\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Spotlightr\";s:6:\"\0*\0url\";s:22:\"https://spotlightr.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://api.spotlightr.com/getOEmbed\";s:11:\"\0*\0provider\";r:3212;s:10:\"\0*\0schemes\";a:4:{i:0;s:32:\"https://*.spotlightr.com/watch/*\";i:1;s:34:\"https://*.spotlightr.com/publish/*\";i:2;s:36:\"https://*.cdn.spotlightr.com/watch/*\";i:3;s:38:\"https://*.cdn.spotlightr.com/publish/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Spreaker\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Spreaker\";s:6:\"\0*\0url\";s:25:\"https://www.spreaker.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://api.spreaker.com/oembed\";s:11:\"\0*\0provider\";r:3226;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"http://*.spreaker.com/*\";i:1;s:24:\"https://*.spreaker.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"SproutVideo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"SproutVideo\";s:6:\"\0*\0url\";s:23:\"https://sproutvideo.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"http://sproutvideo.com/oembed.json\";s:11:\"\0*\0provider\";r:3238;s:10:\"\0*\0schemes\";a:2:{i:0;s:32:\"https://sproutvideo.com/videos/*\";i:1;s:26:\"https://*.vids.io/videos/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Spyke\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Spyke\";s:6:\"\0*\0url\";s:20:\"https://spyke.social\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://api.spyke.social/embed/oembed\";s:11:\"\0*\0provider\";r:3252;s:10:\"\0*\0schemes\";a:16:{i:0;s:23:\"http://spyke.social/p/*\";i:1;s:23:\"http://spyke.social/u/*\";i:2;s:23:\"http://spyke.social/g/*\";i:3;s:23:\"http://spyke.social/c/*\";i:4;s:24:\"https://spyke.social/p/*\";i:5;s:24:\"https://spyke.social/u/*\";i:6;s:24:\"https://spyke.social/g/*\";i:7;s:24:\"https://spyke.social/c/*\";i:8;s:27:\"http://www.spyke.social/p/*\";i:9;s:27:\"http://www.spyke.social/u/*\";i:10;s:27:\"http://www.spyke.social/g/*\";i:11;s:27:\"http://www.spyke.social/c/*\";i:12;s:28:\"https://www.spyke.social/p/*\";i:13;s:28:\"https://www.spyke.social/u/*\";i:14;s:28:\"https://www.spyke.social/g/*\";i:15;s:28:\"https://www.spyke.social/c/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:27:\"Stanford Digital Repository\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:27:\"Stanford Digital Repository\";s:6:\"\0*\0url\";s:26:\"https://purl.stanford.edu/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://purl.stanford.edu/embed.json\";s:11:\"\0*\0provider\";r:3279;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://purl.stanford.edu/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Streamable\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Streamable\";s:6:\"\0*\0url\";s:23:\"https://streamable.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:38:\"https://api.streamable.com/oembed.json\";s:11:\"\0*\0provider\";r:3290;s:10:\"\0*\0schemes\";a:2:{i:0;s:23:\"http://streamable.com/*\";i:1;s:24:\"https://streamable.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Streamio\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Streamio\";s:6:\"\0*\0url\";s:24:\"https://www.streamio.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://streamio.com/api/v1/oembed\";s:11:\"\0*\0provider\";r:3302;s:10:\"\0*\0schemes\";a:2:{i:0;s:16:\"https://s3m.io/*\";i:1;s:16:\"https://23m.io/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Subscribi\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Subscribi\";s:6:\"\0*\0url\";s:21:\"https://subscribi.io/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://subscribi.io/api/oembed\";s:11:\"\0*\0provider\";r:3314;s:10:\"\0*\0schemes\";a:1:{i:0;s:32:\"https://subscribi.io/api/oembed*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Sudomemo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Sudomemo\";s:6:\"\0*\0url\";s:25:\"https://www.sudomemo.net/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://www.sudomemo.net/oembed\";s:11:\"\0*\0provider\";r:3325;s:10:\"\0*\0schemes\";a:4:{i:0;s:32:\"https://www.sudomemo.net/watch/*\";i:1;s:31:\"http://www.sudomemo.net/watch/*\";i:2;s:20:\"https://flipnot.es/*\";i:3;s:19:\"http://flipnot.es/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Sutori\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Sutori\";s:6:\"\0*\0url\";s:23:\"https://www.sutori.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://www.sutori.com/api/oembed\";s:11:\"\0*\0provider\";r:3339;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://www.sutori.com/story/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"Sway\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Sway\";s:6:\"\0*\0url\";s:20:\"https://www.sway.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://sway.com/api/v1.0/oembed\";s:11:\"\0*\0provider\";r:3351;s:10:\"\0*\0schemes\";a:2:{i:0;s:18:\"https://sway.com/*\";i:1;s:22:\"https://www.sway.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"Sway Office\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Sway Office\";s:6:\"\0*\0url\";s:23:\"https://sway.office.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://sway.office.com/api/v1.0/oembed\";s:11:\"\0*\0provider\";r:3363;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"https://sway.office.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Synthesia\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Synthesia\";s:6:\"\0*\0url\";s:25:\"https://www.synthesia.io/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:69:\"https://69jr5v75rc.execute-api.eu-west-1.amazonaws.com/prod/v2/oembed\";s:11:\"\0*\0provider\";r:3374;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://share.synthesia.io/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:3:\"TED\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:3:\"TED\";s:6:\"\0*\0url\";s:19:\"https://www.ted.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://www.ted.com/services/v1/oembed.json\";s:11:\"\0*\0provider\";r:3386;s:10:\"\0*\0schemes\";a:3:{i:0;s:22:\"http://ted.com/talks/*\";i:1;s:23:\"https://ted.com/talks/*\";i:2;s:27:\"https://www.ted.com/talks/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:18:\"The New York Times\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:18:\"The New York Times\";s:6:\"\0*\0url\";s:23:\"https://www.nytimes.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:40:\"https://www.nytimes.com/svc/oembed/json/\";s:11:\"\0*\0provider\";r:3399;s:10:\"\0*\0schemes\";a:3:{i:0;s:34:\"https://www.nytimes.com/svc/oembed\";i:1;s:21:\"https://nytimes.com/*\";i:2;s:23:\"https://*.nytimes.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"They Said So\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"They Said So\";s:6:\"\0*\0url\";s:23:\"https://theysaidso.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://theysaidso.com/extensions/oembed/\";s:11:\"\0*\0provider\";r:3412;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://theysaidso.com/image/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:11:\"TickCounter\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"TickCounter\";s:6:\"\0*\0url\";s:27:\"https://www.tickcounter.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://www.tickcounter.com/oembed\";s:11:\"\0*\0provider\";r:3423;s:10:\"\0*\0schemes\";a:12:{i:0;s:35:\"http://www.tickcounter.com/widget/*\";i:1;s:38:\"http://www.tickcounter.com/countdown/*\";i:2;s:36:\"http://www.tickcounter.com/countup/*\";i:3;s:35:\"http://www.tickcounter.com/ticker/*\";i:4;s:34:\"http://www.tickcounter.com/clock/*\";i:5;s:39:\"http://www.tickcounter.com/worldclock/*\";i:6;s:36:\"https://www.tickcounter.com/widget/*\";i:7;s:39:\"https://www.tickcounter.com/countdown/*\";i:8;s:37:\"https://www.tickcounter.com/countup/*\";i:9;s:36:\"https://www.tickcounter.com/ticker/*\";i:10;s:35:\"https://www.tickcounter.com/clock/*\";i:11;s:40:\"https://www.tickcounter.com/worldclock/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"TikTok\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"TikTok\";s:6:\"\0*\0url\";s:22:\"http://www.tiktok.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://www.tiktok.com/oembed\";s:11:\"\0*\0provider\";r:3445;s:10:\"\0*\0schemes\";a:2:{i:0;s:24:\"https://www.tiktok.com/*\";i:1;s:32:\"https://www.tiktok.com/*/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:11:\"Tonic Audio\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:11:\"Tonic Audio\";s:6:\"\0*\0url\";s:23:\"https://tonicaudio.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://tonicaudio.com/oembed\";s:11:\"\0*\0provider\";r:3457;s:10:\"\0*\0schemes\";a:4:{i:0;s:29:\"https://tonicaudio.com/take/*\";i:1;s:29:\"https://tonicaudio.com/song/*\";i:2;s:22:\"https://tnic.io/song/*\";i:3;s:22:\"https://tnic.io/take/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Toornament\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Toornament\";s:6:\"\0*\0url\";s:27:\"https://www.toornament.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://widget.toornament.com/oembed\";s:11:\"\0*\0provider\";r:3472;s:10:\"\0*\0schemes\";a:4:{i:0;s:52:\"https://www.toornament.com/tournaments/*/information\";i:1;s:54:\"https://www.toornament.com/tournaments/*/registration/\";i:2;s:57:\"https://www.toornament.com/tournaments/*/matches/schedule\";i:3;s:50:\"https://www.toornament.com/tournaments/*/stages/*/\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"Topy\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Topy\";s:6:\"\0*\0url\";s:19:\"http://www.topy.se/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"http://www.topy.se/oembed/\";s:11:\"\0*\0provider\";r:3488;s:10:\"\0*\0schemes\";a:1:{i:0;s:26:\"http://www.topy.se/image/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Totango\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Totango\";s:6:\"\0*\0url\";s:19:\"https://totango.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://app-test.totango.com/oembed\";s:11:\"\0*\0provider\";r:3499;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://app-test.totango.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Trackspace\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Trackspace\";s:6:\"\0*\0url\";s:29:\"http://trackspace.upitup.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://trackspace.upitup.com/oembed\";s:11:\"\0*\0provider\";r:3510;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"http://trackspace.upitup.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:13:\"Trinity Audio\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Trinity Audio\";s:6:\"\0*\0url\";s:23:\"https://trinityaudio.ai\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"https://trinitymedia.ai/services/oembed\";s:11:\"\0*\0provider\";r:3521;s:10:\"\0*\0schemes\";a:3:{i:0;s:32:\"https://trinitymedia.ai/player/*\";i:1;s:34:\"https://trinitymedia.ai/player/*/*\";i:2;s:36:\"https://trinitymedia.ai/player/*/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Tumblr\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Tumblr\";s:6:\"\0*\0url\";s:22:\"https://www.tumblr.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://www.tumblr.com/oembed/1.0\";s:11:\"\0*\0provider\";r:3534;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://*.tumblr.com/post/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:4:\"Tuxx\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"Tuxx\";s:6:\"\0*\0url\";s:20:\"https://www.tuxx.be/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.tuxx.be/services/oembed\";s:11:\"\0*\0provider\";r:3545;s:10:\"\0*\0schemes\";a:1:{i:0;s:21:\"https://www.tuxx.be/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"tvcf\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"tvcf\";s:6:\"\0*\0url\";s:17:\"http://tvcf.co.kr\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://play.tvcf.co.kr/rest/oembed\";s:11:\"\0*\0provider\";r:3556;s:10:\"\0*\0schemes\";a:2:{i:0;s:25:\"https://play.tvcf.co.kr/*\";i:1;s:22:\"https://*.tvcf.co.kr/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:10:\"Twinmotion\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Twinmotion\";s:6:\"\0*\0url\";s:35:\"https://twinmotion.unrealengine.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:42:\"https://twinmotion.unrealengine.com/oembed\";s:11:\"\0*\0provider\";r:3568;s:10:\"\0*\0schemes\";a:2:{i:0;s:50:\"https://twinmotion.unrealengine.com/presentation/*\";i:1;s:46:\"https://twinmotion.unrealengine.com/panorama/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Twitter\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Twitter\";s:6:\"\0*\0url\";s:23:\"http://www.twitter.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:34:\"https://publish.twitter.com/oembed\";s:11:\"\0*\0provider\";r:3581;s:10:\"\0*\0schemes\";a:3:{i:0;s:21:\"https://twitter.com/*\";i:1;s:30:\"https://twitter.com/*/status/*\";i:2;s:32:\"https://*.twitter.com/*/status/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"TypeCast\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"TypeCast\";s:6:\"\0*\0url\";s:19:\"https://typecast.ai\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://play.typecast.ai/oembed\";s:11:\"\0*\0provider\";r:3594;s:10:\"\0*\0schemes\";a:3:{i:0;s:28:\"https://play.typecast.ai/s/*\";i:1;s:28:\"https://play.typecast.ai/e/*\";i:2;s:26:\"https://play.typecast.ai/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Typlog\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Typlog\";s:6:\"\0*\0url\";s:18:\"https://typlog.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://typlog.com/oembed\";s:11:\"\0*\0provider\";r:3607;s:10:\"\0*\0schemes\";a:0:{}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"UAPod\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"UAPod\";s:6:\"\0*\0url\";s:31:\"https://uapod.univ-antilles.fr/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://uapod.univ-antilles.fr/oembed\";s:11:\"\0*\0provider\";r:3617;s:10:\"\0*\0schemes\";a:1:{i:0;s:38:\"https://uapod.univ-antilles.fr/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:27:\"University of Cambridge Map\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:27:\"University of Cambridge Map\";s:6:\"\0*\0url\";s:21:\"https://map.cam.ac.uk\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:29:\"https://map.cam.ac.uk/oembed/\";s:11:\"\0*\0provider\";r:3628;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://map.cam.ac.uk/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:14:\"UnivParis1.Pod\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:14:\"UnivParis1.Pod\";s:6:\"\0*\0url\";s:35:\"https://mediatheque.univ-paris1.fr/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:41:\"https://mediatheque.univ-paris1.fr/oembed\";s:11:\"\0*\0provider\";r:3639;s:10:\"\0*\0schemes\";a:1:{i:0;s:42:\"https://mediatheque.univ-paris1.fr/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Upec.Pod\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Upec.Pod\";s:6:\"\0*\0url\";s:21:\"https://pod.u-pec.fr/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://pod.u-pec.fr/oembed\";s:11:\"\0*\0provider\";r:3650;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://pod.u-pec.fr/video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Ustream\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Ustream\";s:6:\"\0*\0url\";s:21:\"http://www.ustream.tv\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"http://www.ustream.tv/oembed\";s:11:\"\0*\0provider\";r:3661;s:10:\"\0*\0schemes\";a:2:{i:0;s:21:\"http://*.ustream.tv/*\";i:1;s:22:\"http://*.ustream.com/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:13:\"uStudio, Inc.\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"uStudio, Inc.\";s:6:\"\0*\0url\";s:23:\"https://www.ustudio.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://app.ustudio.com/api/v2/oembed\";s:11:\"\0*\0provider\";r:3674;s:10:\"\0*\0schemes\";a:2:{i:0;s:29:\"https://*.ustudio.com/embed/*\";i:1;s:31:\"https://*.ustudio.com/embed/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"VeeR VR\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"VeeR VR\";s:6:\"\0*\0url\";s:15:\"http://veer.tv/\";s:12:\"\0*\0endpoints\";a:2:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://api.veer.tv/oembed\";s:11:\"\0*\0provider\";r:3687;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"http://veer.tv/videos/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}i:1;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://api.veervr.tv/oembed\";s:11:\"\0*\0provider\";r:3687;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"http://veervr.tv/videos/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:4:\"VEVO\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:4:\"VEVO\";s:6:\"\0*\0url\";s:20:\"http://www.vevo.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://www.vevo.com/oembed\";s:11:\"\0*\0provider\";r:3705;s:10:\"\0*\0schemes\";a:2:{i:0;s:21:\"http://www.vevo.com/*\";i:1;s:22:\"https://www.vevo.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"Videfit\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Videfit\";s:6:\"\0*\0url\";s:20:\"https://videfit.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:26:\"https://videfit.com/oembed\";s:11:\"\0*\0provider\";r:3717;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://videfit.com/videos/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:8:\"VidMount\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"VidMount\";s:6:\"\0*\0url\";s:21:\"https://vidmount.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://vidmount.com/oembed\";s:11:\"\0*\0provider\";r:3728;s:10:\"\0*\0schemes\";a:1:{i:0;s:22:\"https://vidmount.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Vidyard\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Vidyard\";s:6:\"\0*\0url\";s:19:\"https://vidyard.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:45:\"https://api.vidyard.com/dashboard/v1.1/oembed\";s:11:\"\0*\0provider\";r:3739;s:10:\"\0*\0schemes\";a:4:{i:0;s:22:\"http://*.vidyard.com/*\";i:1;s:23:\"https://*.vidyard.com/*\";i:2;s:27:\"http://*.hubs.vidyard.com/*\";i:3;s:28:\"https://*.hubs.vidyard.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Vimeo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Vimeo\";s:6:\"\0*\0url\";s:18:\"https://vimeo.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://vimeo.com/api/oembed.json\";s:11:\"\0*\0provider\";r:3753;s:10:\"\0*\0schemes\";a:7:{i:0;s:19:\"https://vimeo.com/*\";i:1;s:33:\"https://vimeo.com/album/*/video/*\";i:2;s:30:\"https://vimeo.com/channels/*/*\";i:3;s:35:\"https://vimeo.com/groups/*/videos/*\";i:4;s:30:\"https://vimeo.com/ondemand/*/*\";i:5;s:32:\"https://player.vimeo.com/video/*\";i:6;s:27:\"https://vimeo.com/event/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Viostream\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Viostream\";s:6:\"\0*\0url\";s:25:\"https://www.viostream.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://play.viostream.com/oembed\";s:11:\"\0*\0provider\";r:3770;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://share.viostream.com/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"Viously\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"Viously\";s:6:\"\0*\0url\";s:23:\"https://www.viously.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://www.viously.com/oembed\";s:11:\"\0*\0provider\";r:3783;s:10:\"\0*\0schemes\";a:1:{i:0;s:27:\"https://www.viously.com/*/*\";}s:10:\"\0*\0formats\";a:2:{i:0;s:4:\"json\";i:1;s:3:\"xml\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Vizydrop\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Vizydrop\";s:6:\"\0*\0url\";s:20:\"https://vizydrop.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://vizydrop.com/oembed\";s:11:\"\0*\0provider\";r:3796;s:10:\"\0*\0schemes\";a:1:{i:0;s:29:\"https://vizydrop.com/shared/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:6:\"Vlipsy\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Vlipsy\";s:6:\"\0*\0url\";s:19:\"https://vlipsy.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:25:\"https://vlipsy.com/oembed\";s:11:\"\0*\0provider\";r:3807;s:10:\"\0*\0schemes\";a:1:{i:0;s:20:\"https://vlipsy.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"VLIVE\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"VLIVE\";s:6:\"\0*\0url\";s:20:\"https://www.vlive.tv\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://www.vlive.tv/oembed\";s:11:\"\0*\0provider\";r:3818;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://www.vlive.tv/video/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:5:\"Vouch\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Vouch\";s:6:\"\0*\0url\";s:25:\"https://www.vouchfor.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://embed.vouchfor.com/v1/oembed\";s:11:\"\0*\0provider\";r:3830;s:10:\"\0*\0schemes\";a:1:{i:0;s:24:\"https://*.vouchfor.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"VoxSnap\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"VoxSnap\";s:6:\"\0*\0url\";s:20:\"https://voxsnap.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://data.voxsnap.com/oembed\";s:11:\"\0*\0provider\";r:3841;s:10:\"\0*\0schemes\";a:1:{i:0;s:31:\"https://article.voxsnap.com/*/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Waltrack\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Waltrack\";s:6:\"\0*\0url\";s:20:\"https://waltrack/net\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://waltrack.net/oembed\";s:11:\"\0*\0provider\";r:3853;s:10:\"\0*\0schemes\";a:1:{i:0;s:30:\"https://waltrack.net/product/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:10:\"Wave.video\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:10:\"Wave.video\";s:6:\"\0*\0url\";s:18:\"https://wave.video\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://embed.wave.video/oembed\";s:11:\"\0*\0provider\";r:3864;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://watch.wave.video/*\";i:1;s:26:\"https://embed.wave.video/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:24:\"Web3 is Going Just Great\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:24:\"Web3 is Going Just Great\";s:6:\"\0*\0url\";s:33:\"https://www.web3isgoinggreat.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:43:\"https://www.web3isgoinggreat.com/api/oembed\";s:11:\"\0*\0provider\";r:3876;s:10:\"\0*\0schemes\";a:3:{i:0;s:38:\"https://www.web3isgoinggreat.com/?id=*\";i:1;s:41:\"https://www.web3isgoinggreat.com/single/*\";i:2;s:40:\"https://www.web3isgoinggreat.com/embed/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"wecandeo\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"wecandeo\";s:6:\"\0*\0url\";s:25:\"https://www.wecandeo.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:33:\"https://play.wecandeo.com/oembed/\";s:11:\"\0*\0provider\";r:3889;s:10:\"\0*\0schemes\";a:1:{i:0;s:35:\"https://play.wecandeo.com/video/v/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:9:\"Whimsical\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:9:\"Whimsical\";s:6:\"\0*\0url\";s:25:\"https://www.whimsical.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:32:\"https://whimsical.com/api/oembed\";s:11:\"\0*\0provider\";r:3900;s:10:\"\0*\0schemes\";a:1:{i:0;s:23:\"https://whimsical.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:12:\"Wistia, Inc.\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:12:\"Wistia, Inc.\";s:6:\"\0*\0url\";s:19:\"https://wistia.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://fast.wistia.com/oembed.json\";s:11:\"\0*\0provider\";r:3911;s:10:\"\0*\0schemes\";a:3:{i:0;s:38:\"https://fast.wistia.com/embed/iframe/*\";i:1;s:41:\"https://fast.wistia.com/embed/playlists/*\";i:2;s:29:\"https://*.wistia.com/medias/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"wizer.me\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"wizer.me\";s:6:\"\0*\0url\";s:21:\"https://www.wizer.me/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:36:\"https://app.wizer.me/api/oembed.json\";s:11:\"\0*\0provider\";r:3924;s:10:\"\0*\0schemes\";a:2:{i:0;s:26:\"https://*.wizer.me/learn/*\";i:1;s:28:\"https://*.wizer.me/preview/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"Wokwi\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"Wokwi\";s:6:\"\0*\0url\";s:17:\"https://wokwi.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://wokwi.com/api/oembed\";s:11:\"\0*\0provider\";r:3936;s:10:\"\0*\0schemes\";a:1:{i:0;s:25:\"https://wokwi.com/share/*\";}s:10:\"\0*\0formats\";a:1:{i:0;s:4:\"json\";}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:13:\"Wolfram Cloud\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"Wolfram Cloud\";s:6:\"\0*\0url\";s:28:\"https://www.wolframcloud.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:35:\"https://www.wolframcloud.com/oembed\";s:11:\"\0*\0provider\";r:3948;s:10:\"\0*\0schemes\";a:1:{i:0;s:28:\"https://*.wolframcloud.com/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:13:\"WordPress.com\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:13:\"WordPress.com\";s:6:\"\0*\0url\";s:22:\"https://wordpress.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:39:\"http://public-api.wordpress.com/oembed/\";s:11:\"\0*\0provider\";r:3959;s:10:\"\0*\0schemes\";a:8:{i:0;s:23:\"https://wordpress.com/*\";i:1;s:22:\"http://wordpress.com/*\";i:2;s:25:\"https://*.wordpress.com/*\";i:3;s:24:\"http://*.wordpress.com/*\";i:4;s:27:\"https://*.*.wordpress.com/*\";i:5;s:26:\"http://*.*.wordpress.com/*\";i:6;s:15:\"https://wp.me/*\";i:7;s:14:\"http://wp.me/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:1:\"X\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:1:\"X\";s:6:\"\0*\0url\";s:17:\"http://www.x.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:28:\"https://publish.x.com/oembed\";s:11:\"\0*\0provider\";r:3977;s:10:\"\0*\0schemes\";a:3:{i:0;s:15:\"https://x.com/*\";i:1;s:24:\"https://x.com/*/status/*\";i:2;s:26:\"https://*.x.com/*/status/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:0;}}}s:7:\"YouTube\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"YouTube\";s:6:\"\0*\0url\";s:24:\"https://www.youtube.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:30:\"https://www.youtube.com/oembed\";s:11:\"\0*\0provider\";r:3990;s:10:\"\0*\0schemes\";a:10:{i:0;s:28:\"https://*.youtube.com/watch*\";i:1;s:25:\"https://*.youtube.com/v/*\";i:2;s:18:\"https://youtu.be/*\";i:3;s:37:\"https://*.youtube.com/playlist?list=*\";i:4;s:35:\"https://youtube.com/playlist?list=*\";i:5;s:29:\"https://*.youtube.com/shorts*\";i:6;s:27:\"https://youtube.com/shorts*\";i:7;s:29:\"https://*.youtube.com/embed/*\";i:8;s:27:\"https://*.youtube.com/live*\";i:9;s:25:\"https://youtube.com/live*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:5:\"YUMPU\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:5:\"YUMPU\";s:6:\"\0*\0url\";s:22:\"https://www.yumpu.com/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:37:\"https://www.yumpu.com/services/oembed\";s:11:\"\0*\0provider\";r:4010;s:10:\"\0*\0schemes\";a:1:{i:0;s:41:\"https://www.yumpu.com/*/document/view/*/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:6:\"Zeplin\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:6:\"Zeplin\";s:6:\"\0*\0url\";s:17:\"https://zeplin.io\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:27:\"https://app.zeplin.io/embed\";s:11:\"\0*\0provider\";r:4021;s:10:\"\0*\0schemes\";a:4:{i:0;s:40:\"https://app.zeplin.io/project/*/screen/*\";i:1;s:50:\"https://app.zeplin.io/project/*/screen/*/version/*\";i:2;s:60:\"https://app.zeplin.io/project/*/styleguide/components?coid=*\";i:3;s:52:\"https://app.zeplin.io/styleguide/*/components?coid=*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"ZingSoft\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"ZingSoft\";s:6:\"\0*\0url\";s:24:\"https://app.zingsoft.com\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://app.zingsoft.com/oembed\";s:11:\"\0*\0provider\";r:4035;s:10:\"\0*\0schemes\";a:2:{i:0;s:32:\"https://app.zingsoft.com/embed/*\";i:1;s:31:\"https://app.zingsoft.com/view/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:7:\"ZnipeTV\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:7:\"ZnipeTV\";s:6:\"\0*\0url\";s:21:\"https://www.znipe.tv/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://api.znipe.tv/v3/oembed/\";s:11:\"\0*\0provider\";r:4047;s:10:\"\0*\0schemes\";a:1:{i:0;s:20:\"https://*.znipe.tv/*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}s:8:\"Zoomable\";O:28:\"Drupal\\media\\OEmbed\\Provider\":3:{s:7:\"\0*\0name\";s:8:\"Zoomable\";s:6:\"\0*\0url\";s:20:\"https://zoomable.ca/\";s:12:\"\0*\0endpoints\";a:1:{i:0;O:28:\"Drupal\\media\\OEmbed\\Endpoint\":5:{s:6:\"\0*\0url\";s:31:\"https://srv2.zoomable.ca/oembed\";s:11:\"\0*\0provider\";r:4058;s:10:\"\0*\0schemes\";a:1:{i:0;s:36:\"https://srv2.zoomable.ca/viewer.php*\";}s:10:\"\0*\0formats\";a:0:{}s:20:\"\0*\0supportsDiscovery\";b:1;}}}}s:7:\"expires\";i:1729454676;}'),('post_update','existing_updates',_binary 'a:179:{i:0;s:70:\"system_post_update_convert_empty_country_and_timezone_settings_to_null\";i:1;s:32:\"system_post_update_sdc_uninstall\";i:2;s:64:\"system_post_update_recalculate_configuration_entity_dependencies\";i:3;s:48:\"system_post_update_add_region_to_entity_displays\";i:4;s:37:\"system_post_update_hashes_clear_cache\";i:5;s:36:\"system_post_update_timestamp_plugins\";i:6;s:41:\"system_post_update_classy_message_library\";i:7;s:37:\"system_post_update_field_type_plugins\";i:8;s:48:\"system_post_update_field_formatter_entity_schema\";i:9;s:36:\"system_post_update_fix_jquery_extend\";i:10;s:40:\"system_post_update_change_action_plugins\";i:11;s:47:\"system_post_update_change_delete_action_plugins\";i:12;s:41:\"system_post_update_language_item_callback\";i:13;s:31:\"system_post_update_extra_fields\";i:14;s:37:\"system_post_update_states_clear_cache\";i:15;s:64:\"system_post_update_add_expand_all_items_key_in_system_menu_block\";i:16;s:35:\"system_post_update_clear_menu_cache\";i:17;s:46:\"system_post_update_layout_plugin_schema_change\";i:18;s:60:\"system_post_update_entity_reference_autocomplete_match_limit\";i:19;s:44:\"system_post_update_extra_fields_form_display\";i:20;s:39:\"system_post_update_uninstall_simpletest\";i:21;s:52:\"system_post_update_uninstall_entity_reference_module\";i:22;s:54:\"system_post_update_entity_revision_metadata_bc_cleanup\";i:23;s:35:\"system_post_update_uninstall_classy\";i:24;s:35:\"system_post_update_uninstall_stable\";i:25;s:44:\"system_post_update_claro_dropbutton_variants\";i:26;s:37:\"system_post_update_schema_version_int\";i:27;s:38:\"system_post_update_delete_rss_settings\";i:28;s:52:\"system_post_update_remove_key_value_expire_all_index\";i:29;s:44:\"system_post_update_service_advisory_settings\";i:30;s:44:\"system_post_update_delete_authorize_settings\";i:31;s:34:\"system_post_update_sort_all_config\";i:32;s:50:\"system_post_update_enable_provider_database_driver\";i:33;s:35:\"system_post_update_linkset_settings\";i:34;s:48:\"system_post_update_enable_password_compatibility\";i:35;s:39:\"system_post_update_remove_asset_entries\";i:36;s:44:\"system_post_update_remove_asset_query_string\";i:37;s:54:\"system_post_update_add_description_to_entity_view_mode\";i:38;s:54:\"system_post_update_add_description_to_entity_form_mode\";i:39;s:44:\"system_post_update_set_blank_log_url_to_null\";i:40;s:38:\"system_post_update_mailer_dsn_settings\";i:41;s:49:\"system_post_update_mailer_structured_dsn_settings\";i:42;s:47:\"system_post_update_amend_config_sync_readme_url\";i:43;s:44:\"system_post_update_mail_notification_setting\";i:44;s:54:\"system_post_update_set_cron_logging_setting_to_boolean\";i:45;s:56:\"system_post_update_move_development_settings_to_keyvalue\";i:46;s:58:\"system_post_update_add_langcode_to_all_translatable_config\";i:47;s:45:\"user_post_update_enforce_order_of_permissions\";i:48;s:29:\"user_post_update_update_roles\";i:49;s:33:\"user_post_update_sort_permissions\";i:50;s:39:\"user_post_update_sort_permissions_again\";i:51;s:51:\"path_alias_post_update_drop_path_alias_status_index\";i:52;s:62:\"contact_post_update_add_message_redirect_field_to_contact_form\";i:53;s:50:\"contact_post_update_set_empty_default_form_to_null\";i:54;s:35:\"help_post_update_help_topics_search\";i:55;s:38:\"help_post_update_help_topics_uninstall\";i:56;s:41:\"help_post_update_add_permissions_to_roles\";i:57;s:39:\"big_pipe_post_update_html5_placeholders\";i:58;s:49:\"dblog_post_update_convert_recent_messages_to_view\";i:59;s:29:\"search_post_update_block_page\";i:60;s:55:\"search_post_update_reindex_after_diacritics_rule_change\";i:61;s:54:\"block_post_update_disable_blocks_with_missing_contexts\";i:62;s:40:\"block_post_update_disabled_region_update\";i:63;s:42:\"block_post_update_fix_negate_in_conditions\";i:64;s:45:\"block_post_update_replace_node_type_condition\";i:65;s:46:\"field_post_update_save_custom_storage_property\";i:66;s:50:\"field_post_update_entity_reference_handler_setting\";i:67;s:43:\"field_post_update_email_widget_size_setting\";i:68;s:47:\"field_post_update_remove_handler_submit_setting\";i:69;s:31:\"filter_post_update_sort_filters\";i:70;s:44:\"filter_post_update_consolidate_filter_config\";i:71;s:42:\"text_post_update_add_required_summary_flag\";i:72;s:55:\"text_post_update_add_required_summary_flag_form_display\";i:73;s:32:\"text_post_update_allowed_formats\";i:74;s:51:\"block_content_post_update_add_views_reusable_filter\";i:75;s:51:\"block_content_post_update_entity_changed_constraint\";i:76;s:51:\"block_content_post_update_move_custom_block_library\";i:77;s:55:\"block_content_post_update_block_library_view_permission\";i:78;s:42:\"block_content_post_update_sort_permissions\";i:79;s:39:\"block_content_post_update_revision_type\";i:80;s:54:\"file_post_update_add_txt_if_allows_insecure_extensions\";i:81;s:41:\"file_post_update_add_permissions_to_roles\";i:82;s:64:\"file_post_update_add_default_filename_sanitization_configuration\";i:83;s:56:\"editor_post_update_clear_cache_for_file_reference_filter\";i:84;s:34:\"editor_post_update_image_lazy_load\";i:85;s:49:\"editor_post_update_sanitize_image_upload_settings\";i:86;s:39:\"ckeditor5_post_update_alignment_buttons\";i:87;s:40:\"ckeditor5_post_update_image_toolbar_item\";i:88;s:51:\"ckeditor5_post_update_plugins_settings_export_order\";i:89;s:32:\"ckeditor5_post_update_code_block\";i:90;s:37:\"ckeditor5_post_update_list_multiblock\";i:91;s:41:\"ckeditor5_post_update_list_start_reversed\";i:92;s:45:\"comment_post_update_enable_comment_admin_view\";i:93;s:42:\"comment_post_update_add_ip_address_setting\";i:94;s:48:\"contextual_post_update_fixed_endpoint_and_markup\";i:95;s:46:\"node_post_update_configure_status_field_widget\";i:96;s:41:\"node_post_update_node_revision_views_data\";i:97;s:40:\"node_post_update_glossary_view_published\";i:98;s:45:\"node_post_update_rebuild_node_revision_routes\";i:99;s:50:\"node_post_update_modify_base_field_author_override\";i:100;s:59:\"node_post_update_set_node_type_description_and_help_to_null\";i:101;s:42:\"image_post_update_image_style_dependencies\";i:102;s:50:\"image_post_update_scale_and_crop_effect_add_anchor\";i:103;s:41:\"image_post_update_image_loading_attribute\";i:104;s:47:\"views_post_update_views_data_argument_plugin_id\";i:105;s:46:\"views_post_update_update_cacheability_metadata\";i:106;s:46:\"views_post_update_cleanup_duplicate_views_data\";i:107;s:46:\"views_post_update_field_formatter_dependencies\";i:108;s:36:\"views_post_update_taxonomy_index_tid\";i:109;s:41:\"views_post_update_serializer_dependencies\";i:110;s:39:\"views_post_update_boolean_filter_values\";i:111;s:33:\"views_post_update_grouped_filters\";i:112;s:42:\"views_post_update_revision_metadata_fields\";i:113;s:33:\"views_post_update_entity_link_url\";i:114;s:34:\"views_post_update_bulk_field_moved\";i:115;s:41:\"views_post_update_filter_placeholder_text\";i:116;s:47:\"views_post_update_views_data_table_dependencies\";i:117;s:45:\"views_post_update_table_display_cache_max_age\";i:118;s:53:\"views_post_update_exposed_filter_blocks_label_display\";i:119;s:48:\"views_post_update_make_placeholders_translatable\";i:120;s:41:\"views_post_update_limit_operator_defaults\";i:121;s:33:\"views_post_update_remove_core_key\";i:122;s:51:\"views_post_update_field_names_for_multivalue_fields\";i:123;s:52:\"views_post_update_configuration_entity_relationships\";i:124;s:48:\"views_post_update_rename_default_display_setting\";i:125;s:50:\"views_post_update_remove_sorting_global_text_field\";i:126;s:36:\"views_post_update_title_translations\";i:127;s:33:\"views_post_update_sort_identifier\";i:128;s:53:\"views_post_update_provide_revision_table_relationship\";i:129;s:33:\"views_post_update_image_lazy_load\";i:130;s:39:\"views_post_update_boolean_custom_titles\";i:131;s:35:\"views_post_update_oembed_eager_load\";i:132;s:44:\"views_post_update_responsive_image_lazy_load\";i:133;s:37:\"views_post_update_timestamp_formatter\";i:134;s:38:\"views_post_update_fix_revision_id_part\";i:135;s:36:\"views_post_update_add_missing_labels\";i:136;s:43:\"views_post_update_remove_skip_cache_setting\";i:137;s:50:\"views_post_update_remove_default_argument_skip_url\";i:138;s:46:\"views_post_update_taxonomy_filter_user_context\";i:139;s:31:\"views_post_update_pager_heading\";i:140;s:54:\"views_post_update_rendered_entity_field_cache_metadata\";i:141;s:65:\"menu_link_content_post_update_make_menu_link_content_revisionable\";i:142;s:49:\"path_post_update_create_language_content_settings\";i:143;s:43:\"taxonomy_post_update_clear_views_data_cache\";i:144;s:64:\"taxonomy_post_update_clear_entity_bundle_field_definitions_cache\";i:145;s:63:\"taxonomy_post_update_handle_publishing_status_addition_in_views\";i:146;s:55:\"taxonomy_post_update_remove_hierarchy_from_vocabularies\";i:147;s:52:\"taxonomy_post_update_make_taxonomy_term_revisionable\";i:148;s:50:\"taxonomy_post_update_configure_status_field_widget\";i:149;s:65:\"taxonomy_post_update_clear_views_argument_validator_plugins_cache\";i:150;s:37:\"taxonomy_post_update_set_new_revision\";i:151;s:55:\"taxonomy_post_update_set_vocabulary_description_to_null\";i:152;s:45:\"olivero_post_update_add_olivero_primary_color\";i:153;s:34:\"media_post_update_collection_route\";i:154;s:33:\"media_post_update_storage_handler\";i:155;s:39:\"media_post_update_enable_standalone_url\";i:156;s:41:\"media_post_update_add_status_extra_filter\";i:157;s:51:\"media_post_update_modify_base_field_author_override\";i:158;s:42:\"media_post_update_oembed_loading_attribute\";i:159;s:49:\"media_post_update_set_blank_iframe_domain_to_null\";i:160;s:56:\"media_post_update_remove_mappings_targeting_source_field\";i:161;s:39:\"media_library_post_update_display_modes\";i:162;s:39:\"media_library_post_update_table_display\";i:163;s:55:\"media_library_post_update_add_media_library_image_style\";i:164;s:49:\"media_library_post_update_add_status_extra_filter\";i:165;s:50:\"media_library_post_update_add_buttons_to_page_view\";i:166;s:54:\"media_library_post_update_update_8001_checkbox_classes\";i:167;s:70:\"media_library_post_update_default_administrative_list_to_table_display\";i:168;s:46:\"media_library_post_update_add_langcode_filters\";i:169;s:59:\"admin_toolbar_tools_post_update_helper_added_config_factory\";i:170;s:42:\"gin_toolbar_post_update_gin_toolbar_beta19\";i:171;s:42:\"gin_toolbar_post_update_gin_toolbar_beta21\";i:172;s:42:\"gin_toolbar_post_update_gin_toolbar_beta22\";i:173;s:42:\"gin_toolbar_post_update_update_gin_alpha32\";i:174;s:44:\"paragraphs_post_update_rebuild_parent_fields\";i:175;s:51:\"paragraphs_post_update_set_paragraphs_parent_fields\";i:176;s:28:\"field_group_post_update_0001\";i:177;s:73:\"layout_discovery_post_update_recalculate_entity_form_display_dependencies\";i:178;s:73:\"layout_discovery_post_update_recalculate_entity_view_display_dependencies\";}'),('state','announcements_feed.last_fetch',_binary 'i:1729063111;'),('state','asset.css_js_query_string',_binary 's:6:\"slgsqr\";'),('state','comment.maintain_entity_statistics',_binary 'b:1;'),('state','comment.node_comment_statistics_scale',_binary 'd:1;'),('state','field.field.deleted',_binary 'a:0:{}'),('state','field.storage.deleted',_binary 'a:0:{}'),('state','help_search_unindexed_count',_binary 's:1:\"0\";'),('state','install_task',_binary 's:4:\"done\";'),('state','install_time',_binary 'i:1728225671;'),('state','node.min_max_update_time',_binary 'a:2:{s:11:\"min_created\";s:10:\"1728242588\";s:11:\"max_created\";s:10:\"1728242588\";}'),('state','router.path_roots',_binary 'a:34:{i:0;s:5:\"admin\";i:1;s:8:\"run-cron\";i:2;s:8:\"big_pipe\";i:3;s:14:\"block-category\";i:4;s:5:\"block\";i:5;s:9:\"ckeditor5\";i:6;s:7:\"comment\";i:7;s:8:\"comments\";i:8;s:7:\"contact\";i:9;s:4:\"user\";i:10;s:10:\"contextual\";i:11;s:6:\"editor\";i:12;s:4:\"file\";i:13;s:6:\"filter\";i:14;s:7:\"history\";i:15;s:5:\"sites\";i:16;s:6:\"system\";i:17;s:25:\"layout-paragraphs-builder\";i:18;s:5:\"media\";i:19;s:13:\"media-library\";i:20;s:4:\"node\";i:21;s:6:\"search\";i:22;s:4:\"cron\";i:23;s:0:\"\";i:24;s:9:\"<current>\";i:25;s:5:\"batch\";i:26;s:10:\"update.php\";i:27;s:29:\"entity_reference_autocomplete\";i:28;s:7:\"session\";i:29;s:8:\"taxonomy\";i:30;s:7:\"toolbar\";i:31;s:11:\".well-known\";i:32;s:7:\"rss.xml\";i:33;s:5:\"views\";}'),('state','routing.menu_masks.router',_binary 'a:52:{i:0;i:985;i:1;i:501;i:2;i:493;i:3;i:492;i:4;i:489;i:5;i:464;i:6;i:253;i:7;i:252;i:8;i:250;i:9;i:249;i:10;i:247;i:11;i:246;i:12;i:245;i:13;i:244;i:14;i:233;i:15;i:232;i:16;i:126;i:17;i:125;i:18;i:124;i:19;i:123;i:20;i:122;i:21;i:117;i:22;i:116;i:23;i:63;i:24;i:62;i:25;i:61;i:26;i:60;i:27;i:59;i:28;i:58;i:29;i:53;i:30;i:49;i:31;i:48;i:32;i:42;i:33;i:31;i:34;i:30;i:35;i:29;i:36;i:28;i:37;i:24;i:38;i:21;i:39;i:15;i:40;i:14;i:41;i:13;i:42;i:12;i:43;i:11;i:44;i:10;i:45;i:8;i:46;i:7;i:47;i:6;i:48;i:5;i:49;i:3;i:50;i:2;i:51;i:1;}'),('state','routing.non_admin_routes',_binary 'a:113:{i:0;s:22:\"admin_toolbar.run.cron\";i:1;s:13:\"big_pipe.nojs\";i:2;s:27:\"block.category_autocomplete\";i:3;s:22:\"block_content.add_page\";i:4;s:22:\"block_content.add_form\";i:5;s:31:\"ckeditor5.media_entity_metadata\";i:6;s:24:\"entity.comment.edit_form\";i:7;s:15:\"comment.approve\";i:8;s:24:\"entity.comment.canonical\";i:9;s:26:\"entity.comment.delete_form\";i:10;s:13:\"comment.reply\";i:11;s:31:\"comment.new_comments_node_links\";i:12;s:21:\"comment.node_redirect\";i:13;s:17:\"contact.site_page\";i:14;s:29:\"entity.contact_form.canonical\";i:15;s:24:\"entity.user.contact_form\";i:16;s:17:\"contextual.render\";i:17;s:17:\"editor.filter_xss\";i:18;s:18:\"file.ajax_progress\";i:19;s:15:\"filter.tips_all\";i:20;s:11:\"filter.tips\";i:21;s:26:\"history.get_last_node_view\";i:22;s:17:\"history.read_node\";i:23;s:18:\"image.style_public\";i:24;s:19:\"image.style_private\";i:25;s:35:\"layout_paragraphs.builder.formatter\";i:26;s:42:\"layout_paragraphs.builder.choose_component\";i:27;s:35:\"layout_paragraphs.builder.edit_item\";i:28;s:32:\"layout_paragraphs.builder.insert\";i:29;s:40:\"layout_paragraphs.builder.duplicate_item\";i:30;s:37:\"layout_paragraphs.builder.delete_item\";i:31;s:33:\"layout_paragraphs.builder.reorder\";i:32;s:19:\"media.oembed_iframe\";i:33;s:20:\"media.filter.preview\";i:34;s:16:\"media_library.ui\";i:35;s:13:\"node.add_page\";i:36;s:8:\"node.add\";i:37;s:19:\"entity.node.preview\";i:38;s:27:\"entity.node.version_history\";i:39;s:20:\"entity.node.revision\";i:40;s:28:\"node.revision_revert_confirm\";i:41;s:40:\"node.revision_revert_translation_confirm\";i:42;s:28:\"node.revision_delete_confirm\";i:43;s:11:\"search.view\";i:44;s:23:\"search.view_help_search\";i:45;s:23:\"search.help_help_search\";i:46;s:23:\"search.view_node_search\";i:47;s:23:\"search.help_node_search\";i:48;s:23:\"search.view_user_search\";i:49;s:23:\"search.help_user_search\";i:50;s:19:\"shortcut.set_switch\";i:51;s:16:\"system.css_asset\";i:52;s:15:\"system.js_asset\";i:53;s:10:\"system.401\";i:54;s:10:\"system.403\";i:55;s:10:\"system.404\";i:56;s:10:\"system.4xx\";i:57;s:11:\"system.cron\";i:58;s:12:\"system.files\";i:59;s:28:\"system.private_file_download\";i:60;s:16:\"system.temporary\";i:61;s:7:\"<front>\";i:62;s:6:\"<none>\";i:63;s:8:\"<nolink>\";i:64;s:8:\"<button>\";i:65;s:9:\"<current>\";i:66;s:15:\"system.timezone\";i:67;s:22:\"system.batch_page.html\";i:68;s:16:\"system.db_update\";i:69;s:26:\"system.entity_autocomplete\";i:70;s:16:\"system.csrftoken\";i:71;s:30:\"entity.taxonomy_term.edit_form\";i:72;s:32:\"entity.taxonomy_term.delete_form\";i:73;s:16:\"toolbar.subtrees\";i:74;s:13:\"user.register\";i:75;s:11:\"user.logout\";i:76;s:19:\"user.logout.confirm\";i:77;s:9:\"user.pass\";i:78;s:9:\"user.page\";i:79;s:9:\"user.edit\";i:80;s:10:\"user.login\";i:81;s:19:\"user.cancel_confirm\";i:82;s:16:\"user.reset.login\";i:83;s:10:\"user.reset\";i:84;s:15:\"user.reset.form\";i:85;s:31:\"user.well-known.change_password\";i:86;s:21:\"view.frontpage.feed_1\";i:87;s:21:\"view.frontpage.page_1\";i:88;s:25:\"view.taxonomy_term.feed_1\";i:89;s:25:\"view.taxonomy_term.page_1\";i:90;s:10:\"views.ajax\";i:91;s:23:\"entity.file.delete_form\";i:92;s:21:\"entity.media.add_page\";i:93;s:21:\"entity.media.add_form\";i:94;s:22:\"entity.media.canonical\";i:95;s:22:\"entity.media.edit_form\";i:96;s:24:\"entity.media.delete_form\";i:97;s:33:\"entity.media.delete_multiple_form\";i:98;s:28:\"entity.media.version_history\";i:99;s:21:\"entity.media.revision\";i:100;s:33:\"entity.media.revision_revert_form\";i:101;s:33:\"entity.media.revision_delete_form\";i:102;s:21:\"entity.node.canonical\";i:103;s:23:\"entity.node.delete_form\";i:104;s:21:\"entity.node.edit_form\";i:105;s:36:\"entity.taxonomy_term.version_history\";i:106;s:29:\"entity.taxonomy_term.revision\";i:107;s:41:\"entity.taxonomy_term.revision_revert_form\";i:108;s:41:\"entity.taxonomy_term.revision_delete_form\";i:109;s:21:\"entity.user.canonical\";i:110;s:21:\"entity.user.edit_form\";i:111;s:23:\"entity.user.cancel_form\";i:112;s:30:\"entity.taxonomy_term.canonical\";}'),('state','system.cron_key',_binary 's:74:\"3Mgpm8yeFKquH3xJ0co4IHN4uWiCfI-UUq-95wej3VNSj0F0za_e-QpaaWs8ILH25NKYMlQOUw\";'),('state','system.cron_last',_binary 'i:1729063111;'),('state','system.private_key',_binary 's:74:\"pYtrA91zgh_nDysu4T4CnnvzpZWXJwUqctYjV4XbnF7wHtM-QriFyxdnpc8YEsDY3VhfbBBQVw\";'),('state','system.profile.files',_binary 'a:18:{s:10:\"demo_umami\";s:44:\"core/profiles/demo_umami/demo_umami.info.yml\";s:4:\"fast\";s:27:\"profiles/fast/fast.info.yml\";s:7:\"minimal\";s:38:\"core/profiles/minimal/minimal.info.yml\";s:23:\"nightwatch_a11y_testing\";s:70:\"core/profiles/nightwatch_a11y_testing/nightwatch_a11y_testing.info.yml\";s:18:\"nightwatch_testing\";s:60:\"core/profiles/nightwatch_testing/nightwatch_testing.info.yml\";s:8:\"standard\";s:40:\"core/profiles/standard/standard.info.yml\";s:25:\"test_language_negotiation\";s:74:\"core/profiles/test_language_negotiation/test_language_negotiation.info.yml\";s:7:\"testing\";s:38:\"core/profiles/testing/testing.info.yml\";s:21:\"testing_config_import\";s:66:\"core/profiles/testing_config_import/testing_config_import.info.yml\";s:24:\"testing_config_overrides\";s:72:\"core/profiles/testing_config_overrides/testing_config_overrides.info.yml\";s:40:\"testing_install_profile_all_dependencies\";s:104:\"core/profiles/testing_install_profile_all_dependencies/testing_install_profile_all_dependencies.info.yml\";s:36:\"testing_install_profile_dependencies\";s:96:\"core/profiles/testing_install_profile_dependencies/testing_install_profile_dependencies.info.yml\";s:28:\"testing_missing_dependencies\";s:80:\"core/profiles/testing_missing_dependencies/testing_missing_dependencies.info.yml\";s:20:\"testing_multilingual\";s:64:\"core/profiles/testing_multilingual/testing_multilingual.info.yml\";s:33:\"testing_multilingual_with_english\";s:90:\"core/profiles/testing_multilingual_with_english/testing_multilingual_with_english.info.yml\";s:20:\"testing_requirements\";s:64:\"core/profiles/testing_requirements/testing_requirements.info.yml\";s:19:\"testing_site_config\";s:62:\"core/profiles/testing_site_config/testing_site_config.info.yml\";s:21:\"testing_themes_blocks\";s:66:\"core/profiles/testing_themes_blocks/testing_themes_blocks.info.yml\";}'),('state','twig_extension_hash_prefix',_binary 'a:2:{s:19:\"twig_extension_hash\";s:43:\"KnvTOzh5Tp6k1KNB7lYe1l27hdTp5Jz155Ig-v7nDi8\";s:17:\"twig_cache_prefix\";s:13:\"67101a922e1ea\";}'),('state','update.last_check',_binary 'i:1729063142;'),('state','views.view_route_names',_binary 'a:16:{s:13:\"watchdog.page\";s:14:\"dblog.overview\";s:24:\"user_admin_people.page_1\";s:22:\"entity.user.collection\";s:20:\"taxonomy_term.page_1\";s:30:\"entity.taxonomy_term.canonical\";s:21:\"media.media_page_list\";s:23:\"entity.media.collection\";s:14:\"content.page_1\";s:20:\"system.admin_content\";s:23:\"comment.page_unapproved\";s:22:\"comment.admin_approval\";s:22:\"comment.page_published\";s:13:\"comment.admin\";s:20:\"block_content.page_1\";s:31:\"entity.block_content.collection\";s:12:\"files.page_1\";s:17:\"view.files.page_1\";s:12:\"files.page_2\";s:17:\"view.files.page_2\";s:16:\"frontpage.feed_1\";s:21:\"view.frontpage.feed_1\";s:16:\"frontpage.page_1\";s:21:\"view.frontpage.page_1\";s:18:\"media_library.page\";s:23:\"view.media_library.page\";s:20:\"media_library.widget\";s:25:\"view.media_library.widget\";s:26:\"media_library.widget_table\";s:31:\"view.media_library.widget_table\";s:20:\"taxonomy_term.feed_1\";s:25:\"view.taxonomy_term.feed_1\";}'),('system.schema','admin_toolbar',_binary 'i:8003;'),('system.schema','admin_toolbar_tools',_binary 'i:8202;'),('system.schema','announcements_feed',_binary 'i:8000;'),('system.schema','automated_cron',_binary 'i:8000;'),('system.schema','better_exposed_filters',_binary 'i:10001;'),('system.schema','big_pipe',_binary 'i:8000;'),('system.schema','block',_binary 'i:8003;'),('system.schema','block_content',_binary 'i:10300;'),('system.schema','block_field',_binary 'i:8001;'),('system.schema','breakpoint',_binary 'i:8000;'),('system.schema','ckeditor5',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_auto_image',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_find_and_replace',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_font',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_highlight',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_indent_block',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_link_attributes',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_page_break',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_select_all',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_templates',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_text_transformation',_binary 'i:8000;'),('system.schema','ckeditor5_plugin_pack_todo_document_list',_binary 'i:8000;'),('system.schema','ckeditor5_premium_features_fullscreen',_binary 'i:8000;'),('system.schema','comment',_binary 'i:10100;'),('system.schema','config',_binary 'i:8000;'),('system.schema','contact',_binary 'i:8000;'),('system.schema','contextual',_binary 'i:8000;'),('system.schema','datetime',_binary 'i:8000;'),('system.schema','dblog',_binary 'i:10101;'),('system.schema','dynamic_page_cache',_binary 'i:8000;'),('system.schema','editor',_binary 'i:8001;'),('system.schema','entity_reference_revisions',_binary 'i:8000;'),('system.schema','ept_accordion',_binary 'i:8000;'),('system.schema','ept_basic_button',_binary 'i:8000;'),('system.schema','ept_block',_binary 'i:8000;'),('system.schema','ept_bootstrap_button',_binary 'i:8000;'),('system.schema','ept_carousel',_binary 'i:9102;'),('system.schema','ept_columns',_binary 'i:8000;'),('system.schema','ept_core',_binary 'i:8000;'),('system.schema','ept_core_starterkit',_binary 'i:8000;'),('system.schema','ept_countdown',_binary 'i:8000;'),('system.schema','ept_counter',_binary 'i:8000;'),('system.schema','ept_cta',_binary 'i:8000;'),('system.schema','ept_hero',_binary 'i:8000;'),('system.schema','ept_image',_binary 'i:8000;'),('system.schema','ept_image_gallery',_binary 'i:8000;'),('system.schema','ept_micromodal',_binary 'i:9001;'),('system.schema','ept_quote',_binary 'i:8000;'),('system.schema','ept_slick_slider',_binary 'i:8000;'),('system.schema','ept_slideshow',_binary 'i:8000;'),('system.schema','ept_stats',_binary 'i:8000;'),('system.schema','ept_tabs',_binary 'i:8000;'),('system.schema','ept_text',_binary 'i:8000;'),('system.schema','ept_tiles',_binary 'i:8000;'),('system.schema','ept_video',_binary 'i:8000;'),('system.schema','ept_video_and_image_gallery',_binary 'i:8000;'),('system.schema','ept_views',_binary 'i:8000;'),('system.schema','fast',_binary 'i:8000;'),('system.schema','field',_binary 'i:8500;'),('system.schema','field_group',_binary 'i:8303;'),('system.schema','field_ui',_binary 'i:8000;'),('system.schema','file',_binary 'i:8700;'),('system.schema','file_mdm',_binary 'i:8201;'),('system.schema','file_mdm_exif',_binary 'i:8000;'),('system.schema','file_mdm_font',_binary 'i:8000;'),('system.schema','filter',_binary 'i:8000;'),('system.schema','gin_toolbar',_binary 'i:8000;'),('system.schema','glightbox',_binary 'i:8000;'),('system.schema','glightbox_media_video',_binary 'i:8000;'),('system.schema','help',_binary 'i:10200;'),('system.schema','history',_binary 'i:10100;'),('system.schema','image',_binary 'i:8201;'),('system.schema','image_effects',_binary 'i:8203;'),('system.schema','jquery_ui',_binary 'i:8000;'),('system.schema','jquery_ui_accordion',_binary 'i:8000;'),('system.schema','jquery_ui_tabs',_binary 'i:8000;'),('system.schema','layout_discovery',_binary 'i:8000;'),('system.schema','layout_paragraphs',_binary 'i:9002;'),('system.schema','link',_binary 'i:8000;'),('system.schema','link_attributes',_binary 'i:9001;'),('system.schema','link_attributes_menu_link_content',_binary 'i:8000;'),('system.schema','media',_binary 'i:8700;'),('system.schema','media_library',_binary 'i:8704;'),('system.schema','media_library_edit',_binary 'i:8000;'),('system.schema','media_library_form_element',_binary 'i:8000;'),('system.schema','menu_link_content',_binary 'i:8601;'),('system.schema','menu_ui',_binary 'i:8000;'),('system.schema','node',_binary 'i:8700;'),('system.schema','options',_binary 'i:8000;'),('system.schema','page_cache',_binary 'i:8000;'),('system.schema','paragraphs',_binary 'i:8022;'),('system.schema','path',_binary 'i:8200;'),('system.schema','path_alias',_binary 'i:8000;'),('system.schema','search',_binary 'i:8000;'),('system.schema','shortcut',_binary 'i:8000;'),('system.schema','system',_binary 'i:10201;'),('system.schema','taxonomy',_binary 'i:10100;'),('system.schema','tb_megamenu',_binary 'i:8001;'),('system.schema','text',_binary 'i:8000;'),('system.schema','toolbar',_binary 'i:8000;'),('system.schema','twig_tweak',_binary 'i:8000;'),('system.schema','update',_binary 'i:8001;'),('system.schema','user',_binary 'i:10000;'),('system.schema','views',_binary 'i:8500;'),('system.schema','viewsreference',_binary 'i:8103;'),('system.schema','views_ui',_binary 'i:8000;'),('system.schema','views_year_filter',_binary 'i:8000;'),('update_fetch_task','better_exposed_filters',_binary 'a:6:{s:4:\"name\";s:22:\"better_exposed_filters\";s:4:\"info\";a:6:{s:4:\"name\";s:22:\"Better Exposed Filters\";s:7:\"package\";s:5:\"Views\";s:7:\"version\";s:5:\"7.0.2\";s:7:\"project\";s:22:\"better_exposed_filters\";s:9:\"datestamp\";i:1729001182;s:16:\"_info_file_ctime\";i:1729066392;}s:9:\"datestamp\";i:1729001182;s:8:\"includes\";a:1:{s:22:\"better_exposed_filters\";s:22:\"Better Exposed Filters\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}'),('update_fetch_task','views_year_filter',_binary 'a:6:{s:4:\"name\";s:17:\"views_year_filter\";s:4:\"info\";a:6:{s:4:\"name\";s:17:\"Views Year Filter\";s:7:\"package\";s:4:\"Date\";s:7:\"version\";s:5:\"2.1.5\";s:7:\"project\";s:17:\"views_year_filter\";s:9:\"datestamp\";i:1726675379;s:16:\"_info_file_ctime\";i:1729064379;}s:9:\"datestamp\";i:1726675379;s:8:\"includes\";a:1:{s:17:\"views_year_filter\";s:17:\"Views Year Filter\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}');
/*!40000 ALTER TABLE `key_value` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `key_value_expire`
--

DROP TABLE IF EXISTS `key_value_expire`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `key_value_expire` (
  `collection` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A named collection of key and value pairs.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The key of the key/value pair.',
  `value` longblob NOT NULL COMMENT 'The value of the key/value pair.',
  `expire` int NOT NULL DEFAULT '2147483647' COMMENT 'The time since Unix epoch in seconds when this item expires. Defaults to the maximum possible time.',
  PRIMARY KEY (`collection`,`name`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Generic key/value storage table with an expiration.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `key_value_expire`
--

LOCK TABLES `key_value_expire` WRITE;
/*!40000 ALTER TABLE `key_value_expire` DISABLE KEYS */;
INSERT INTO `key_value_expire` VALUES ('announcements_feed','announcements',_binary 'a:10:{i:0;a:7:{s:2:\"id\";s:7:\"3480615\";s:5:\"title\";s:58:\"DrupalCon Singapore 2024: What Awaits You in the Lion City\";s:12:\"content_html\";s:528:\"<p>It’s time to dust off those suitcases and start thinking about where your passport is - <a href=\"https://events.drupal.org/singapore2024\" rel=\"nofollow\">DrupalCon Singapore 2024</a> is just around the corner, and this year’s event promises to be amazing! From 9-11 December, our much-anticipated event will bring together the brightest minds and most passionate contributors from the Drupal community for three days of innovation, learning, and inspiration at the luxurious Parkroyal Collection Marina Bay, Singapore.</p>\";s:3:\"url\";s:105:\"https://www.drupal.org/about/announcements/blog/drupalcon-singapore-2024-what-awaits-you-in-the-lion-city\";s:13:\"date_modified\";s:25:\"2024-10-14T16:49:44+00:00\";s:14:\"date_published\";s:25:\"2024-10-14T16:49:44+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:1;a:7:{s:2:\"id\";s:7:\"3465580\";s:5:\"title\";s:18:\"Drupal 11 released\";s:12:\"content_html\";s:114:\"<p>Today is a big day for <a href=\"https://www.drupal.org/\">Drupal</a> as we officially released Drupal 11!</p>\n\";s:3:\"url\";s:46:\"https://www.drupal.org/blog/drupal-11-released\";s:13:\"date_modified\";s:25:\"2024-08-15T15:10:39+00:00\";s:14:\"date_published\";s:25:\"2024-08-01T22:57:58+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:1:\"*\";}}i:2;a:7:{s:2:\"id\";s:7:\"3456034\";s:5:\"title\";s:28:\"Drupal 10.3 is now available\";s:12:\"content_html\";s:370:\"<p>The <a href=\"https://www.drupal.org/project/drupal/releases/10.3.0\" rel=\"nofollow\">third and final feature release of Drupal 10</a> ships with a new experimental Navigation user interface, stable Workspaces functionality, stable Single-Directory Components support, simplified menu editing, taxonomy moderation support, new recipe and access policy APIs and more.</p>\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-3-0\";s:13:\"date_modified\";s:25:\"2024-09-05T23:00:47+00:00\";s:14:\"date_published\";s:25:\"2024-06-20T20:00:04+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:4;a:7:{s:2:\"id\";s:7:\"3427138\";s:5:\"title\";s:52:\"You\'re invited to DrupalCon Portland | 6-9 May, 2024\";s:12:\"content_html\";s:384:\"<p>DrupalCon is an event for developers, marketers/content editors, site owners, and the Drupal-curious to join with the community. You\'ll find incredible keynotes, session content from expert speakers who have helped to build Drupal, networking opportunities with your peers, fun social events, and the chance to deepen your connection by contributing to the open source project.</p>\";s:3:\"url\";s:96:\"https://www.drupal.org/about/announcements/blog/youre-invited-to-drupalcon-portland-6-9-may-2024\";s:13:\"date_modified\";s:25:\"2024-03-18T19:40:04+00:00\";s:14:\"date_published\";s:25:\"2024-03-11T16:49:53+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:5;a:7:{s:2:\"id\";s:7:\"3408836\";s:5:\"title\";s:28:\"Drupal 10.2 is now available\";s:12:\"content_html\";s:378:\"<p>The <a href=\"https://www.drupal.org/project/drupal/releases/10.2.0\">second feature release of Drupal 10</a> improves content modeling, block management, menu and taxonomy organization, and permission administration. New options to sanitize file names make it possible to clean up the names of uploaded files, and media item revisions now have a dedicated user interface.</p>\n\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-2-0\";s:13:\"date_modified\";s:25:\"2024-01-25T18:24:28+00:00\";s:14:\"date_published\";s:25:\"2023-12-15T18:27:47+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:6;a:7:{s:2:\"id\";s:7:\"3403229\";s:5:\"title\";s:75:\"Drupal 10 will be supported until the release of Drupal 12 in mid-late 2026\";s:12:\"content_html\";s:190:\"<p>Announcing a new major release schedule with long term support for Drupal 10 until mid-late 2026. Drupal 11 will be released in 2024 and work on the dedicated branch starts this week.</p>\";s:3:\"url\";s:103:\"https://www.drupal.org/blog/drupal-10-will-be-supported-until-the-release-of-drupal-12-in-mid-late-2026\";s:13:\"date_modified\";s:25:\"2024-01-25T18:31:05+00:00\";s:14:\"date_published\";s:25:\"2023-11-22T07:13:55+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:8;a:7:{s:2:\"id\";s:7:\"3368367\";s:5:\"title\";s:28:\"Drupal 10.1 is now available\";s:12:\"content_html\";s:257:\"<p>This first feature release of Drupal 10 is packed with amazing improvements! It makes customizing the look of your site easier, adds support for decoupled navigation, improves content modeling and editing, block management, performance and many more.</p>\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-1-0\";s:13:\"date_modified\";s:25:\"2023-10-30T16:22:24+00:00\";s:14:\"date_published\";s:25:\"2023-06-22T09:11:30+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:9;a:7:{s:2:\"id\";s:7:\"3347976\";s:5:\"title\";s:37:\"Contribute to Drupal and the Open Web\";s:12:\"content_html\";s:146:\"<p>Drupal is an open source project. But what does that mean? How can you as a site-owner participate in the project of building a better web?</p>\";s:3:\"url\";s:85:\"https://www.drupal.org/about/announcements/blog/contribute-to-drupal-and-the-open-web\";s:13:\"date_modified\";s:25:\"2023-03-14T19:43:12+00:00\";s:14:\"date_published\";s:25:\"2023-03-14T19:39:44+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:10;a:7:{s:2:\"id\";s:7:\"3343486\";s:5:\"title\";s:43:\"What to expect from the Announcements feed?\";s:12:\"content_html\";s:197:\"<p>Drupal is introducing a new project Announcements feature so that you can see news and updates about the Drupal project and community directly in your Drupal dashboard. Learn what to expect.</p>\";s:3:\"url\";s:90:\"https://www.drupal.org/about/announcements/blog/what-to-expect-from-the-announcements-feed\";s:13:\"date_modified\";s:25:\"2023-02-21T19:45:53+00:00\";s:14:\"date_published\";s:25:\"2023-02-21T19:45:53+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:11;a:7:{s:2:\"id\";s:7:\"3327047\";s:5:\"title\";s:26:\"Drupal 10.0.0 is available\";s:12:\"content_html\";s:296:\"<p>Thanks to 2129 contributors from 616 organizations resolving 4083 issues in the past two and a half years, Drupal 10.0.0 is available today! This new version sets Drupal up for continued stability and security for the longer term. All new features will be added to Drupal 10 going forward.</p>\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-0-0\";s:13:\"date_modified\";s:25:\"2023-10-30T16:21:38+00:00\";s:14:\"date_published\";s:25:\"2022-12-15T17:43:23+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}}',1729149511),('form','form-3c1tr2WeSa2XEkgXimvXkTyzNRa7bvUfgzN-hE6Xd68',_binary 'a:34:{s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:32:\"layout-paragraphs-component-form\";}s:20:\"data-drupal-selector\";s:32:\"layout-paragraphs-component-form\";}s:8:\"#parents\";a:0:{}s:21:\"field_ept_block_block\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:29:\"field_ept_block_block_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:23:\"field--type-block-field\";i:1;s:33:\"field--name-field-ept-block-block\";i:2;s:33:\"field--widget-block-field-default\";}}s:6:\"widget\";a:13:{i:0;a:10:{s:6:\"#title\";s:5:\"Block\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";O:37:\"Drupal\\Core\\Field\\FieldFilteredMarkup\":1:{s:9:\"\0*\0string\";s:25:\"Add existing Drupal Block\";}s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:1;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:9:\"plugin_id\";a:9:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";s:5:\"Block\";s:8:\"#options\";a:8:{s:4:\"core\";a:3:{s:16:\"page_title_block\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Page title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"local_actions_block\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Primary admin actions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"local_tasks_block\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Tabs\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:5:\"Forms\";a:2:{s:17:\"search_form_block\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Search form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"user_login_block\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"User login\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:4:\"Help\";a:1:{s:10:\"help_block\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Help\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:13:\"Lists (Views)\";a:4:{s:35:\"views_block:comments_recent-block_1\";s:15:\"Recent comments\";s:34:\"views_block:content_recent-block_1\";s:14:\"Recent content\";s:30:\"views_block:what_s_new-block_1\";s:10:\"What\'s New\";s:43:\"views_block:who_s_online-who_s_online_block\";s:12:\"Who\'s online\";}s:5:\"Menus\";a:6:{s:23:\"system_menu_block:admin\";s:14:\"Administration\";s:24:\"system_menu_block:footer\";s:6:\"Footer\";s:22:\"system_menu_block:main\";s:15:\"Main navigation\";s:9:\"shortcuts\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Shortcuts\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"system_menu_block:tools\";s:5:\"Tools\";s:25:\"system_menu_block:account\";s:17:\"User account menu\";}s:6:\"System\";a:6:{s:23:\"system_breadcrumb_block\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Breadcrumbs\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"system_main_block\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Main page content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:21:\"system_messages_block\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Messages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"system_powered_by_block\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Powered by Drupal\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:21:\"system_branding_block\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Site branding\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:20:\"node_syndicate_block\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Syndicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:4:\"User\";a:1:{s:29:\"views_block:who_s_new-block_1\";s:9:\"Who\'s new\";}s:5:\"Views\";a:1:{s:45:\"views_exposed_filter_block:what_s_new-block_1\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:31:\"Exposed form: @view-@display_id\";s:12:\"\0*\0arguments\";a:2:{s:5:\"@view\";s:10:\"what_s_new\";s:11:\"@display_id\";s:7:\"block_1\";}s:10:\"\0*\0options\";a:0:{}}}}s:13:\"#empty_option\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"- None -\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:9:\"#required\";b:1;s:5:\"#ajax\";a:2:{s:8:\"callback\";a:2:{i:0;O:60:\"Drupal\\block_field\\Plugin\\Field\\FieldWidget\\BlockFieldWidget\":10:{s:11:\"\0*\0pluginId\";s:19:\"block_field_default\";s:19:\"\0*\0pluginDefinition\";a:6:{s:11:\"field_types\";a:1:{i:0;s:11:\"block_field\";}s:15:\"multiple_values\";b:0;s:2:\"id\";s:19:\"block_field_default\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Block field\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"class\";s:60:\"Drupal\\block_field\\Plugin\\Field\\FieldWidget\\BlockFieldWidget\";s:8:\"provider\";s:11:\"block_field\";}s:16:\"\0*\0configuration\";a:0:{}s:14:\"\0*\0_serviceIds\";a:4:{s:17:\"stringTranslation\";s:18:\"string_translation\";s:17:\"contextRepository\";s:18:\"context.repository\";s:12:\"blockManager\";s:20:\"plugin.manager.block\";s:26:\"blockFieldSelectionManager\";s:36:\"plugin.manager.block_field_selection\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:12:\"\0*\0messenger\";N;s:11:\"\0*\0settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:24:\"\0*\0defaultSettingsMerged\";b:0;s:18:\"\0*\0fieldDefinition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:41:\"paragraph.ept_block.field_ept_block_block\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"9e49c287-a8e3-4673-b781-6db3e163c7f1\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Y5C1tDwIza9l7G1NAqWPtZndTwsI1uclqq7mOTUqmyg\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ept_block_block\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:41:\"paragraph.ept_block.field_ept_block_block\";s:13:\"\0*\0field_name\";s:21:\"field_ept_block_block\";s:13:\"\0*\0field_type\";s:11:\"block_field\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:9:\"ept_block\";s:8:\"\0*\0label\";s:5:\"Block\";s:14:\"\0*\0description\";s:25:\"Add existing Drupal Block\";s:11:\"\0*\0settings\";a:2:{s:9:\"selection\";s:10:\"categories\";s:18:\"selection_settings\";a:1:{s:10:\"categories\";a:11:{s:5:\"Block\";s:5:\"Block\";s:4:\"core\";s:4:\"core\";s:5:\"Forms\";s:5:\"Forms\";s:4:\"Help\";s:4:\"Help\";s:13:\"Lists (Views)\";s:13:\"Lists (Views)\";s:5:\"Menus\";s:5:\"Menus\";s:6:\"System\";s:6:\"System\";s:4:\"User\";s:4:\"User\";s:5:\"Views\";s:5:\"Views\";s:13:\"Announcements\";s:1:\"0\";s:12:\"TB Mega Menu\";s:1:\"0\";}}}s:11:\"\0*\0required\";b:1;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ept_block_block\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"58c5cc3e-9949-4686-882a-a56b59c60ea8\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hAESsXJ5KZsWYKr-KB5wJoHNBdcOTlIFJUomBW8VxoU\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ept_block_block\";s:13:\"\0*\0field_name\";s:21:\"field_ept_block_block\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:11:\"block_field\";s:9:\"\0*\0module\";s:11:\"block_field\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}i:1;s:17:\"configurationForm\";}s:7:\"wrapper\";s:32:\"field_ept_block_block-0-settings\";}s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";r:20;}s:8:\"settings\";a:13:{s:5:\"#type\";s:9:\"container\";s:11:\"#attributes\";a:1:{s:2:\"id\";s:32:\"field_ept_block_block-0-settings\";}s:5:\"#tree\";b:1;s:8:\"provider\";a:2:{s:5:\"#type\";s:5:\"value\";s:6:\"#value\";s:5:\"views\";}s:11:\"admin_label\";a:4:{s:5:\"#type\";s:4:\"item\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Block description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"#plain_text\";r:100;s:7:\"#access\";b:0;}s:5:\"label\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:10:\"#maxlength\";i:255;s:14:\"#default_value\";s:0:\"\";s:9:\"#required\";b:1;s:7:\"#access\";b:0;}s:13:\"label_display\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Display title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";b:1;s:13:\"#return_value\";s:7:\"visible\";}s:15:\"context_mapping\";a:0:{}s:2:\"id\";a:1:{s:7:\"#access\";b:0;}s:11:\"#pre_render\";a:1:{i:0;s:65:\"\\Drupal\\views\\Plugin\\views\\PluginBase::preRenderAddFieldsetMarkup\";}s:20:\"views_label_checkbox\";a:3:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Override title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";b:0;}s:20:\"views_label_fieldset\";a:2:{s:5:\"#type\";s:8:\"fieldset\";s:7:\"#states\";a:1:{s:7:\"visible\";a:1:{i:0;a:1:{s:45:\":input[name=\"settings[views_label_checkbox]\"]\";a:1:{s:7:\"checked\";b:1;}}}}}s:11:\"views_label\";a:6:{s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#type\";s:9:\"textfield\";s:14:\"#default_value\";s:10:\"What\'s New\";s:7:\"#states\";a:1:{s:7:\"visible\";a:1:{i:0;a:1:{s:45:\":input[name=\"settings[views_label_checkbox]\"]\";a:1:{s:7:\"checked\";b:1;}}}}s:9:\"#fieldset\";s:20:\"views_label_fieldset\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:127:\"Changing the title here means it cannot be dynamically altered anymore. (Try changing it directly in <a href=\":url\">@name</a>.)\";s:12:\"\0*\0arguments\";a:2:{s:4:\":url\";s:51:\"/admin/structure/views/view/what_s_new/edit/block_1\";s:5:\"@name\";s:10:\"What\'s New\";}s:10:\"\0*\0options\";a:0:{}}}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:114;i:1;s:8:\"validate\";}}}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:21:\"field_ept_block_block\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:1;s:6:\"#title\";s:5:\"Block\";s:12:\"#description\";r:20;s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:60:\"Drupal\\block_field\\Plugin\\Field\\FieldWidget\\BlockFieldWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:21:\"field_ept_block_block\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:3;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:60:\"config:field.field.paragraph.ept_block.field_ept_block_block\";i:1;s:52:\"config:field.storage.paragraph.field_ept_block_block\";}s:7:\"max-age\";i:-1;}}s:18:\"field_ept_settings\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:26:\"field_ept_settings_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:24:\"field--type-ept-settings\";i:1;s:30:\"field--name-field-ept-settings\";i:2;s:34:\"field--widget-ept-settings-default\";}}s:6:\"widget\";a:13:{i:0;a:9:{s:6:\"#title\";s:8:\"Settings\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";s:0:\"\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:0;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:9:\"#attached\";a:1:{s:7:\"library\";a:3:{i:0;s:20:\"ept_core/colorpicker\";i:1;s:35:\"field_group/element.horizontal_tabs\";i:2;s:21:\"ept_core/ept_settings\";}}s:12:\"ept_settings\";a:6:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Paragraph settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:1;s:26:\"pass_options_to_javascript\";a:2:{s:5:\"#type\";s:6:\"hidden\";s:6:\"#value\";b:0;}s:14:\"design_options\";a:5:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Design options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:0;s:4:\"box1\";a:8:{s:5:\"#type\";s:9:\"container\";s:11:\"#attributes\";a:1:{s:5:\"class\";s:26:\"design-options__margin-box\";}s:5:\"label\";a:3:{s:5:\"#type\";s:8:\"html_tag\";s:4:\"#tag\";s:5:\"label\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Margin\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"margin_top\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Top\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;O:65:\"Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\":10:{s:11:\"\0*\0pluginId\";s:20:\"ept_settings_default\";s:19:\"\0*\0pluginDefinition\";a:6:{s:11:\"field_types\";a:1:{i:0;s:12:\"ept_settings\";}s:15:\"multiple_values\";b:0;s:2:\"id\";s:20:\"ept_settings_default\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"EPT default paragraph settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"class\";s:65:\"Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\";s:8:\"provider\";s:8:\"ept_core\";}s:16:\"\0*\0configuration\";a:0:{}s:14:\"\0*\0_serviceIds\";a:1:{s:17:\"stringTranslation\";s:18:\"string_translation\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:12:\"\0*\0messenger\";N;s:11:\"\0*\0settings\";a:0:{}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:24:\"\0*\0defaultSettingsMerged\";b:0;s:18:\"\0*\0fieldDefinition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:38:\"paragraph.ept_block.field_ept_settings\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"2d995ad8-7b72-4241-8c5b-bfb64c7a936a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o3fZQjNNObe_TkbgxMWmav7VePiJKizuqf7wQm1RqgQ\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:38:\"paragraph.ept_block.field_ept_settings\";s:13:\"\0*\0field_name\";s:18:\"field_ept_settings\";s:13:\"\0*\0field_type\";s:12:\"ept_settings\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:9:\"ept_block\";s:8:\"\0*\0label\";s:8:\"Settings\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:0:{}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ept_settings\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"aed153c8-a66a-428a-be76-0d9ff9c57e30\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HvKMBmRf1ancerUpnNjtwfTeY-R4_vPBnsqEe9j-ovs\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ept_settings\";s:13:\"\0*\0field_name\";s:18:\"field_ept_settings\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:12:\"ept_settings\";s:9:\"\0*\0module\";s:8:\"ept_core\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}i:1;s:18:\"validateBoxElement\";}}}s:12:\"margin_right\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:18:\"validateBoxElement\";}}}s:13:\"margin_bottom\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Bottom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:18:\"validateBoxElement\";}}}s:11:\"margin_left\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:18:\"validateBoxElement\";}}}s:4:\"box2\";a:8:{s:5:\"#type\";s:9:\"container\";s:11:\"#attributes\";a:1:{s:5:\"class\";s:26:\"design-options__border-box\";}s:5:\"label\";a:3:{s:5:\"#type\";s:8:\"html_tag\";s:4:\"#tag\";s:5:\"label\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Border\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"border_top\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Top\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:18:\"validateBoxElement\";}}}s:12:\"border_right\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:18:\"validateBoxElement\";}}}s:13:\"border_bottom\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Bottom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:18:\"validateBoxElement\";}}}s:11:\"border_left\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:18:\"validateBoxElement\";}}}s:4:\"box3\";a:8:{s:5:\"#type\";s:9:\"container\";s:11:\"#attributes\";a:1:{s:5:\"class\";s:27:\"design-options__padding-box\";}s:5:\"label\";a:3:{s:5:\"#type\";s:8:\"html_tag\";s:4:\"#tag\";s:5:\"label\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Padding\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:11:\"padding_top\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Top\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:18:\"validateBoxElement\";}}}s:13:\"padding_right\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:18:\"validateBoxElement\";}}}s:14:\"padding_bottom\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Bottom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:18:\"validateBoxElement\";}}}s:12:\"padding_left\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:18:\"validateBoxElement\";}}}s:4:\"box4\";a:3:{s:5:\"#type\";s:9:\"container\";s:11:\"#attributes\";a:1:{s:5:\"class\";s:24:\"design-options__logo-box\";}s:5:\"label\";a:3:{s:5:\"#type\";s:8:\"html_tag\";s:4:\"#tag\";s:5:\"label\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"EPT\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Border Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Select Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:20:\"validateColorElement\";}}}s:12:\"border_style\";a:5:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Border Style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:12:{s:5:\"solid\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Solid\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"dashed\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Dashed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"dotted\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Dotted\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:4:\"none\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"None\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"hidden\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Hidden\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"initial\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Initial\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"inherit\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Inherit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"double\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Double\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"groove\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Groove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"ridge\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Ridge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"inset\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Inset\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"outset\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Outset\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:0:\"\";s:12:\"#description\";s:0:\"\";}s:13:\"border_radius\";a:4:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Border Radius\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:12:{s:4:\"none\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"None\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:3:\"1px\";s:3:\"1px\";s:3:\"2px\";s:3:\"2px\";s:3:\"3px\";s:3:\"3px\";s:3:\"4px\";s:3:\"4px\";s:3:\"5px\";s:3:\"5px\";s:4:\"10px\";s:4:\"10px\";s:4:\"15px\";s:4:\"15px\";s:4:\"20px\";s:4:\"20px\";s:4:\"25px\";s:4:\"25px\";s:4:\"30px\";s:4:\"30px\";s:4:\"35px\";s:4:\"35px\";}s:14:\"#default_value\";s:4:\"none\";}s:16:\"background_color\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Background Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Select Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:20:\"validateColorElement\";}}}s:16:\"background_media\";a:5:{s:5:\"#type\";s:13:\"media_library\";s:16:\"#allowed_bundles\";a:3:{i:0;s:5:\"image\";i:1;s:12:\"remote_video\";i:2;s:5:\"video\";}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Background Image/Video\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";N;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"Upload your image, video or Youtube video.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:25:\"background_video_settings\";a:17:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Background video options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:0;s:8:\"autoPlay\";a:3:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Autoplay\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;}s:12:\"showControls\";a:3:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Show controls\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:0;}s:4:\"mute\";a:3:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Mute\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;}s:7:\"startAt\";a:6:{s:5:\"#type\";s:6:\"number\";s:4:\"#min\";i:0;s:5:\"#step\";i:1;s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Start at\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:0;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:51:\"(number) Set the seconds the video should start at.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:7:\"opacity\";a:7:{s:5:\"#type\";s:6:\"number\";s:4:\"#min\";i:0;s:4:\"#max\";i:1;s:5:\"#step\";d:0.01;s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Opacity\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"0 to 1 (number) define the opacity of the video\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"addOverlay\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Add overlay\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Show or hide a overlay image over the video\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:12:\"overlayColor\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Overlay color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:7:\"#000000\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:65:\"RGB color for local videos, YouTube video uses image for overlay.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:395;i:1;s:20:\"validateColorElement\";}}}s:12:\"overlayAlpha\";a:7:{s:5:\"#type\";s:6:\"number\";s:4:\"#min\";i:0;s:4:\"#max\";i:1;s:5:\"#step\";d:0.01;s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Overlay opacity\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:3:\"0.3\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:55:\"For local videos, YouTube video uses image for overlay.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:4:\"loop\";a:3:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Loop\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;}s:15:\"stopMovieOnBlur\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Stop movie on blur\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:55:\"Activate the pause behavior when the window loose focus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"playOnlyIfVisible\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Play only if visible\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:0;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"Activate the pause behavior when the player is out of screen\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"coverImage\";a:5:{s:5:\"#type\";s:13:\"media_library\";s:16:\"#allowed_bundles\";a:1:{i:0;s:5:\"image\";}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Cover Image\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";N;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:117:\"Image used as background for the player if autoplay is set to false; if not set the player will show the first frame.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:11:\"useOnMobile\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Use on mobile\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"Define if the player should render on mobile devices\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:19:\"mobileFallbackImage\";a:5:{s:5:\"#type\";s:13:\"media_library\";s:16:\"#allowed_bundles\";a:1:{i:0;s:5:\"image\";}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Mobile fallback Image\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";N;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:110:\"Fallback image in case of background video on mobile devices and the “useOnMobile” option is set to false.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:25:\"background_image_settings\";a:6:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Background image options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:0;s:19:\"background_position\";a:4:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Background Image Position\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:11:{s:7:\"default\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Default\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"top left\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Top Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:3:\"top\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Top\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"top right\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Top Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"center left\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Center Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"center\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Center\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"center right\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Center Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"bottom left\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Bottom Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"bottom\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Bottom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"bottom right\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Bottom Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"custom\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Custom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:7:\"default\";}s:26:\"background_position_custom\";a:4:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Custom Background Position\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:99:\"See more information about CSS background-position <a href=\":ept_core_configuration_form\">here</a>.\";s:12:\"\0*\0arguments\";a:1:{s:28:\":ept_core_configuration_form\";s:68:\"https://developer.mozilla.org/en-US/docs/Web/CSS/background-position\";}s:10:\"\0*\0options\";a:0:{}}}s:22:\"background_size_custom\";a:4:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Custom Background Size\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:95:\"See more information about CSS background-size <a href=\":ept_core_configuration_form\">here</a>.\";s:12:\"\0*\0arguments\";a:1:{s:28:\":ept_core_configuration_form\";s:64:\"https://developer.mozilla.org/en-US/docs/Web/CSS/background-size\";}s:10:\"\0*\0options\";a:0:{}}}}s:22:\"background_image_style\";a:4:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Background Image Style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:5:{s:7:\"default\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"No repeat\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"parallax\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Parallax\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"cover\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Cover\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"contain\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Contain\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"repeat\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Repeat\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:7:\"default\";}s:12:\"edge_to_edge\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Edge to Edge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:0;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:111:\"If checked, the styles will be applied to the entire screen, starting from the left and extending to the right.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:15:\"container_width\";a:5:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Container Max Width\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:8:{s:4:\"auto\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Auto (100%)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"xxsmall\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"xxSmall\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"xsmall\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"xSmall\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"small\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Small\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"default\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Default\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"large\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Large\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"xlarge\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"xLarge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"xxlarge\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"xxLarge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:123:\"See <a href=\":ept_core_configuration_form\">EPT Core configuration form</a> to set Container Width and other default values.\";s:12:\"\0*\0arguments\";a:1:{s:28:\":ept_core_configuration_form\";s:30:\"/admin/config/content/ept-core\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:4:\"auto\";}}}s:13:\"title_options\";a:5:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Title options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:0;s:13:\"title_wrapper\";a:4:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Tag for Title wrapper\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:6:{s:4:\"none\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"None\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:2:\"h1\";s:2:\"H1\";s:2:\"h2\";s:2:\"H2\";s:2:\"h3\";s:2:\"H3\";s:2:\"h4\";s:2:\"H4\";s:2:\"h5\";s:2:\"H5\";}s:14:\"#default_value\";s:2:\"h2\";}s:10:\"strip_tags\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Strip Tags for Title field\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:70:\"Strip tags in title field wrappers, except span, br, i, img, svg tags.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:18:\"field_ept_settings\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:0;s:6:\"#title\";s:8:\"Settings\";s:12:\"#description\";s:0:\"\";s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:65:\"Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:4;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:57:\"config:field.field.paragraph.ept_block.field_ept_settings\";i:1;s:49:\"config:field.storage.paragraph.field_ept_settings\";}s:7:\"max-age\";i:-1;}}s:14:\"field_ept_text\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:22:\"field_ept_text_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:21:\"field--type-text-long\";i:1;s:26:\"field--name-field-ept-text\";i:2;s:27:\"field--widget-text-textarea\";}}s:6:\"widget\";a:13:{i:0;a:14:{s:6:\"#title\";s:4:\"Text\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";s:0:\"\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:0;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:5:\"#type\";s:11:\"text_format\";s:14:\"#default_value\";N;s:5:\"#rows\";i:5;s:12:\"#placeholder\";s:0:\"\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:2:{i:0;s:12:\"js-text-full\";i:1;s:9:\"text-full\";}s:37:\"data-media-embed-host-entity-langcode\";s:2:\"en\";}s:7:\"#format\";N;s:10:\"#base_type\";s:8:\"textarea\";}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:14:\"field_ept_text\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:0;s:6:\"#title\";s:4:\"Text\";s:12:\"#description\";s:0:\"\";s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:51:\"Drupal\\text\\Plugin\\Field\\FieldWidget\\TextareaWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:14:\"field_ept_text\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:2;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:53:\"config:field.field.paragraph.ept_block.field_ept_text\";i:1;s:45:\"config:field.storage.paragraph.field_ept_text\";}s:7:\"max-age\";i:-1;}}s:15:\"field_ept_title\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:23:\"field_ept_title_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:21:\"field--type-text-long\";i:1;s:27:\"field--name-field-ept-title\";i:2;s:27:\"field--widget-text-textarea\";}}s:6:\"widget\";a:13:{i:0;a:14:{s:6:\"#title\";s:5:\"Title\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";s:0:\"\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:0;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:5:\"#type\";s:11:\"text_format\";s:14:\"#default_value\";N;s:5:\"#rows\";i:2;s:12:\"#placeholder\";s:0:\"\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:2:{i:0;s:12:\"js-text-full\";i:1;s:9:\"text-full\";}s:37:\"data-media-embed-host-entity-langcode\";s:2:\"en\";}s:7:\"#format\";N;s:10:\"#base_type\";s:8:\"textarea\";}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:15:\"field_ept_title\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:0;s:6:\"#title\";s:5:\"Title\";s:12:\"#description\";s:0:\"\";s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:51:\"Drupal\\text\\Plugin\\Field\\FieldWidget\\TextareaWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:15:\"field_ept_title\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:1;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:54:\"config:field.field.paragraph.ept_block.field_ept_title\";i:1;s:46:\"config:field.storage.paragraph.field_ept_title\";}s:7:\"max-age\";i:-1;}}s:6:\"#cache\";a:3:{s:8:\"contexts\";a:1:{i:0;s:24:\"user.roles:authenticated\";}s:4:\"tags\";a:2:{i:0;s:59:\"config:core.entity_form_display.paragraph.ept_block.default\";i:1;s:42:\"CACHE_MISS_IF_UNCACHEABLE_HTTP_METHOD:form\";}s:7:\"max-age\";i:-1;}s:8:\"#process\";a:2:{i:0;a:2:{i:0;O:43:\"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay\":16:{s:7:\"\0*\0uuid\";s:36:\"063fafbf-a44a-44d9-b44e-e6b7f1c968f2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:9:\"\0*\0status\";b:1;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:53:\"field.field.paragraph.ept_block.field_ept_block_block\";i:1;s:50:\"field.field.paragraph.ept_block.field_ept_settings\";i:2;s:46:\"field.field.paragraph.ept_block.field_ept_text\";i:3;s:47:\"field.field.paragraph.ept_block.field_ept_title\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";}s:6:\"module\";a:4:{i:0;s:11:\"block_field\";i:1;s:8:\"ept_core\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:23:\"\0*\0third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:21:\"field_ept_block_block\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kf0CKi0lVMCHZKEFVJNSYNl5CpKFKRH7JLsGDr_mt24\";}s:5:\"\0*\0id\";s:27:\"paragraph.ept_block.default\";s:19:\"\0*\0targetEntityType\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:9:\"ept_block\";s:7:\"\0*\0mode\";s:7:\"default\";s:10:\"\0*\0content\";a:4:{s:21:\"field_ept_block_block\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:9:\"\0*\0hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}s:15:\"\0*\0entityTypeId\";s:19:\"entity_form_display\";s:15:\"\0*\0enforceIsNew\";N;s:15:\"_serializedKeys\";a:16:{i:0;s:4:\"uuid\";i:1;s:8:\"langcode\";i:2;s:6:\"status\";i:3;s:12:\"dependencies\";i:4;s:20:\"third_party_settings\";i:5;s:5:\"_core\";i:6;s:2:\"id\";i:7;s:16:\"targetEntityType\";i:8;s:6:\"bundle\";i:9;s:4:\"mode\";i:10;s:7:\"content\";i:11;s:6:\"hidden\";i:12;s:12:\"entityTypeId\";i:13;s:12:\"enforceIsNew\";i:14;s:15:\"_serializedKeys\";i:15;s:11:\"initialized\";}s:14:\"\0*\0initialized\";b:1;}i:1;s:11:\"processForm\";}i:1;a:2:{i:0;s:34:\"Drupal\\field_group\\FormatterHelper\";i:1;s:11:\"formProcess\";}}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Create new @type\";s:12:\"\0*\0arguments\";a:1:{s:5:\"@type\";s:9:\"EPT Block\";}s:10:\"\0*\0options\";a:0:{}}s:10:\"#paragraph\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:23:\"_layoutParagraphsLayout\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"63\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1729064555\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729064448\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729064555\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"568\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:2:\"19\";s:8:\"revision\";s:2:\"63\";s:4:\"uuid\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"63\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:1:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:1444;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:1443;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"568\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":9:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1789;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_views\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"38\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"568\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_views\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729064495\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:20:\"field_ept_views_view\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:9:\"target_id\";s:10:\"what_s_new\";s:10:\"display_id\";s:7:\"block_1\";s:4:\"data\";s:95:\"a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}\";}}}s:14:\"_referringItem\";r:1789;s:23:\"_layoutParagraphsLayout\";r:1442;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_views\";s:2:\"id\";s:2:\"38\";s:4:\"uuid\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";s:8:\"revision\";s:3:\"568\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"568\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}s:5:\"\0*\0id\";N;s:14:\"\0*\0revision_id\";N;}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"1577eb324628e7a33f238d1dd2ccd784\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_block\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729065292;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:0:{}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:0:{}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:21:\"field_ept_block_block\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:9:\"plugin_id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:8:\"settings\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:0:{}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:2:{s:6:\"bundle\";s:9:\"ept_block\";s:8:\"revision\";N;}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:0;s:20:\"\0*\0stringTranslation\";N;}s:8:\"#display\";r:1297;s:5:\"#tree\";b:1;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;O:49:\"Drupal\\layout_paragraphs\\Form\\InsertComponentForm\":19:{s:15:\"\0*\0requestStack\";N;s:13:\"\0*\0routeMatch\";N;s:14:\"\0*\0_serviceIds\";a:8:{s:13:\"configFactory\";s:14:\"config.factory\";s:17:\"stringTranslation\";s:18:\"string_translation\";s:9:\"tempstore\";s:38:\"layout_paragraphs.tempstore_repository\";s:17:\"entityTypeManager\";s:19:\"entity_type.manager\";s:19:\"layoutPluginManager\";s:26:\"plugin.manager.core.layout\";s:13:\"moduleHandler\";s:14:\"module_handler\";s:16:\"entityRepository\";s:17:\"entity.repository\";s:15:\"eventDispatcher\";s:16:\"event_dispatcher\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:16:\"\0*\0loggerFactory\";N;s:12:\"\0*\0messenger\";N;s:22:\"\0*\0redirectDestination\";N;s:16:\"\0*\0paragraphType\";O:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\":23:{s:15:\"\0*\0entityTypeId\";s:15:\"paragraphs_type\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:9:\"ept_block\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"698fe7c4-0789-4365-b3ce-d8bbd2d7d879\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hSup62OW-6glALkcPyijfub_HXz0FNzEQuWRhyhtdXk\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:2:\"id\";s:9:\"ept_block\";s:5:\"label\";s:9:\"EPT Block\";s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Block\";s:12:\"\0*\0icon_uuid\";N;s:15:\"\0*\0icon_default\";N;s:16:\"behavior_plugins\";a:1:{s:17:\"layout_paragraphs\";a:1:{s:17:\"available_layouts\";a:0:{}}}}s:12:\"\0*\0paragraph\";r:1432;s:11:\"\0*\0formMode\";s:7:\"default\";s:25:\"\0*\0layoutParagraphsLayout\";r:1442;s:33:\"\0*\0originalLayoutParagraphsLayout\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";r:1444;s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";r:1666;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:1:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:1790;s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:2283;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"568\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":9:{s:13:\"\0*\0definition\";r:1931;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2292;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";r:1972;s:5:\"\0*\0id\";N;s:14:\"\0*\0revision_id\";N;}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";N;s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:14:\"\0*\0domSelector\";s:50:\"[data-uuid=\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\"]\";s:20:\"\0*\0paragraphDefaults\";a:0:{}s:9:\"\0*\0method\";s:6:\"before\";s:13:\"\0*\0parentUuid\";s:0:\"\";s:9:\"\0*\0region\";s:0:\"\";s:12:\"\0*\0placement\";s:6:\"before\";s:14:\"\0*\0siblingUuid\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}i:1;s:10:\"afterBuild\";}}s:9:\"#attached\";a:2:{s:7:\"library\";a:1:{i:0;s:32:\"layout_paragraphs/component_form\";}s:12:\"placeholders\";a:1:{s:55:\"form_action_p_pvdeGsVG5zNF_XLGPTvYSKCf43t8qZYSwcfZl2uzM\";a:1:{s:13:\"#lazy_builder\";a:2:{i:0;s:40:\"form_builder:renderPlaceholderFormAction\";i:1;a:0:{}}}}}s:7:\"actions\";a:4:{s:7:\"#weight\";i:100;s:5:\"#type\";s:7:\"actions\";s:6:\"submit\";a:5:{s:5:\"#type\";s:6:\"submit\";s:7:\"#weight\";i:100;s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Save\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#ajax\";a:2:{s:8:\"callback\";s:12:\"::ajaxSubmit\";s:8:\"progress\";s:4:\"none\";}s:11:\"#attributes\";a:2:{s:5:\"class\";a:2:{i:0;s:13:\"lpb-btn--save\";i:1;s:15:\"button--primary\";}s:20:\"data-disable-refocus\";s:4:\"true\";}}s:6:\"cancel\";a:6:{s:5:\"#type\";s:6:\"button\";s:7:\"#weight\";i:200;s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Cancel\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:24:\"#limit_validation_errors\";a:0:{}s:5:\"#ajax\";a:2:{s:8:\"callback\";s:8:\"::cancel\";s:8:\"progress\";s:4:\"none\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:13:\"dialog-cancel\";i:1;s:15:\"lpb-btn--cancel\";}}}}s:12:\"#fieldgroups\";a:3:{s:10:\"group_tabs\";O:8:\"stdClass\":12:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}s:10:\"group_name\";s:10:\"group_tabs\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:7:\"context\";s:4:\"form\";s:4:\"mode\";s:7:\"default\";}s:13:\"group_content\";O:8:\"stdClass\":12:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:21:\"field_ept_block_block\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}s:10:\"group_name\";s:13:\"group_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:7:\"context\";s:4:\"form\";s:4:\"mode\";s:7:\"default\";}s:14:\"group_settings\";O:8:\"stdClass\":12:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}s:10:\"group_name\";s:14:\"group_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_block\";s:7:\"context\";s:4:\"form\";s:4:\"mode\";s:7:\"default\";}}s:15:\"#group_children\";a:6:{s:13:\"group_content\";s:10:\"group_tabs\";s:14:\"group_settings\";s:10:\"group_tabs\";s:15:\"field_ept_title\";s:13:\"group_content\";s:14:\"field_ept_text\";s:13:\"group_content\";s:21:\"field_ept_block_block\";s:13:\"group_content\";s:18:\"field_ept_settings\";s:14:\"group_settings\";}s:12:\"#entity_type\";s:9:\"paragraph\";s:8:\"#form_id\";s:32:\"layout_paragraphs_component_form\";s:9:\"#build_id\";s:48:\"form-3c1tr2WeSa2XEkgXimvXkTyzNRa7bvUfgzN-hE6Xd68\";s:5:\"#type\";s:4:\"form\";s:7:\"#action\";s:55:\"form_action_p_pvdeGsVG5zNF_XLGPTvYSKCf43t8qZYSwcfZl2uzM\";s:13:\"form_build_id\";a:5:{s:5:\"#type\";s:6:\"hidden\";s:6:\"#value\";s:48:\"form-3c1tr2WeSa2XEkgXimvXkTyzNRa7bvUfgzN-hE6Xd68\";s:3:\"#id\";s:48:\"form-3c1tr2WeSa2XEkgXimvXkTyzNRa7bvUfgzN-hE6Xd68\";s:5:\"#name\";s:13:\"form_build_id\";s:8:\"#parents\";a:1:{i:0;s:13:\"form_build_id\";}}s:6:\"#token\";s:66:\"form_token_placeholder_s2YfxV6fJyGjndqPaiT_BWYnNHuH1rQKMkaXixiHD6k\";s:10:\"form_token\";a:6:{s:3:\"#id\";s:61:\"edit-layout-paragraphs-component-form-form-token--ch0NVvtxkQ8\";s:5:\"#type\";s:5:\"token\";s:14:\"#default_value\";s:66:\"form_token_placeholder_s2YfxV6fJyGjndqPaiT_BWYnNHuH1rQKMkaXixiHD6k\";s:8:\"#parents\";a:1:{i:0;s:10:\"form_token\";}s:9:\"#attached\";a:1:{s:12:\"placeholders\";a:1:{s:66:\"form_token_placeholder_s2YfxV6fJyGjndqPaiT_BWYnNHuH1rQKMkaXixiHD6k\";a:1:{s:13:\"#lazy_builder\";a:2:{i:0;s:39:\"form_builder:renderFormTokenPlaceholder\";i:1;a:1:{i:0;s:66:\"form_token_placeholder_s2YfxV6fJyGjndqPaiT_BWYnNHuH1rQKMkaXixiHD6k\";}}}}}s:6:\"#cache\";a:1:{s:7:\"max-age\";i:0;}}s:7:\"form_id\";a:4:{s:5:\"#type\";s:6:\"hidden\";s:6:\"#value\";s:32:\"layout_paragraphs_component_form\";s:3:\"#id\";s:50:\"edit-layout-paragraphs-component-form--D1_JAi0CBc0\";s:8:\"#parents\";a:1:{i:0;s:7:\"form_id\";}}s:3:\"#id\";s:45:\"layout-paragraphs-component-form--JYowA5xSBxc\";s:7:\"#method\";s:4:\"post\";s:15:\"#theme_wrappers\";a:1:{i:0;s:4:\"form\";}s:16:\"#defaults_loaded\";b:1;s:9:\"#validate\";a:1:{i:0;s:14:\"::validateForm\";}s:7:\"#submit\";a:1:{i:0;s:12:\"::submitForm\";}s:6:\"#theme\";a:1:{i:0;s:32:\"layout_paragraphs_component_form\";}s:12:\"#cache_token\";s:43:\"6hnLZfh-UY1scD5xwp6fsiJvmCOR_S-6jvUzbpEr7oU\";}',1729086937),('form','form-CbEyRCXFiwYhjJqVDd9JbESXcfdYqS_x2x6Y1H_CfMc',_binary 'a:34:{s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:32:\"layout-paragraphs-component-form\";}s:20:\"data-drupal-selector\";s:32:\"layout-paragraphs-component-form\";}s:8:\"#parents\";a:0:{}s:18:\"field_ept_settings\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:26:\"field_ept_settings_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:24:\"field--type-ept-settings\";i:1;s:30:\"field--name-field-ept-settings\";i:2;s:34:\"field--widget-ept-settings-default\";}}s:6:\"widget\";a:13:{i:0;a:9:{s:6:\"#title\";s:8:\"Settings\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";s:0:\"\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:0;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:9:\"#attached\";a:1:{s:7:\"library\";a:3:{i:0;s:20:\"ept_core/colorpicker\";i:1;s:35:\"field_group/element.horizontal_tabs\";i:2;s:21:\"ept_core/ept_settings\";}}s:12:\"ept_settings\";a:6:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Paragraph settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:1;s:26:\"pass_options_to_javascript\";a:2:{s:5:\"#type\";s:6:\"hidden\";s:6:\"#value\";b:0;}s:14:\"design_options\";a:5:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Design options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:0;s:4:\"box1\";a:8:{s:5:\"#type\";s:9:\"container\";s:11:\"#attributes\";a:1:{s:5:\"class\";s:26:\"design-options__margin-box\";}s:5:\"label\";a:3:{s:5:\"#type\";s:8:\"html_tag\";s:4:\"#tag\";s:5:\"label\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Margin\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"margin_top\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Top\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;O:65:\"Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\":10:{s:11:\"\0*\0pluginId\";s:20:\"ept_settings_default\";s:19:\"\0*\0pluginDefinition\";a:6:{s:11:\"field_types\";a:1:{i:0;s:12:\"ept_settings\";}s:15:\"multiple_values\";b:0;s:2:\"id\";s:20:\"ept_settings_default\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"EPT default paragraph settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"class\";s:65:\"Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\";s:8:\"provider\";s:8:\"ept_core\";}s:16:\"\0*\0configuration\";a:0:{}s:14:\"\0*\0_serviceIds\";a:1:{s:17:\"stringTranslation\";s:18:\"string_translation\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:12:\"\0*\0messenger\";N;s:11:\"\0*\0settings\";a:0:{}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:24:\"\0*\0defaultSettingsMerged\";b:0;s:18:\"\0*\0fieldDefinition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:38:\"paragraph.ept_views.field_ept_settings\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"0cd4c4a7-feca-4fb7-9e8b-02984559941b\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qvGJxPRaclSHVbrfz5Je86o0KNtcIYQhWoZtkWbYOeY\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:38:\"paragraph.ept_views.field_ept_settings\";s:13:\"\0*\0field_name\";s:18:\"field_ept_settings\";s:13:\"\0*\0field_type\";s:12:\"ept_settings\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:9:\"ept_views\";s:8:\"\0*\0label\";s:8:\"Settings\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:0:{}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ept_settings\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"aed153c8-a66a-428a-be76-0d9ff9c57e30\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HvKMBmRf1ancerUpnNjtwfTeY-R4_vPBnsqEe9j-ovs\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ept_settings\";s:13:\"\0*\0field_name\";s:18:\"field_ept_settings\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:12:\"ept_settings\";s:9:\"\0*\0module\";s:8:\"ept_core\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}i:1;s:18:\"validateBoxElement\";}}}s:12:\"margin_right\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:18:\"validateBoxElement\";}}}s:13:\"margin_bottom\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Bottom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:18:\"validateBoxElement\";}}}s:11:\"margin_left\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:18:\"validateBoxElement\";}}}s:4:\"box2\";a:8:{s:5:\"#type\";s:9:\"container\";s:11:\"#attributes\";a:1:{s:5:\"class\";s:26:\"design-options__border-box\";}s:5:\"label\";a:3:{s:5:\"#type\";s:8:\"html_tag\";s:4:\"#tag\";s:5:\"label\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Border\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"border_top\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Top\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:18:\"validateBoxElement\";}}}s:12:\"border_right\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:18:\"validateBoxElement\";}}}s:13:\"border_bottom\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Bottom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:18:\"validateBoxElement\";}}}s:11:\"border_left\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:18:\"validateBoxElement\";}}}s:4:\"box3\";a:8:{s:5:\"#type\";s:9:\"container\";s:11:\"#attributes\";a:1:{s:5:\"class\";s:27:\"design-options__padding-box\";}s:5:\"label\";a:3:{s:5:\"#type\";s:8:\"html_tag\";s:4:\"#tag\";s:5:\"label\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Padding\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:11:\"padding_top\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Top\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:18:\"validateBoxElement\";}}}s:13:\"padding_right\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:18:\"validateBoxElement\";}}}s:14:\"padding_bottom\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Bottom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:18:\"validateBoxElement\";}}}s:12:\"padding_left\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:18:\"validateBoxElement\";}}}s:4:\"box4\";a:3:{s:5:\"#type\";s:9:\"container\";s:11:\"#attributes\";a:1:{s:5:\"class\";s:24:\"design-options__logo-box\";}s:5:\"label\";a:3:{s:5:\"#type\";s:8:\"html_tag\";s:4:\"#tag\";s:5:\"label\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"EPT\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Border Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Select Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:20:\"validateColorElement\";}}}s:12:\"border_style\";a:5:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Border Style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:12:{s:5:\"solid\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Solid\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"dashed\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Dashed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"dotted\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Dotted\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:4:\"none\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"None\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"hidden\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Hidden\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"initial\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Initial\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"inherit\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Inherit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"double\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Double\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"groove\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Groove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"ridge\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Ridge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"inset\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Inset\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"outset\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Outset\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:0:\"\";s:12:\"#description\";s:0:\"\";}s:13:\"border_radius\";a:4:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Border Radius\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:12:{s:4:\"none\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"None\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:3:\"1px\";s:3:\"1px\";s:3:\"2px\";s:3:\"2px\";s:3:\"3px\";s:3:\"3px\";s:3:\"4px\";s:3:\"4px\";s:3:\"5px\";s:3:\"5px\";s:4:\"10px\";s:4:\"10px\";s:4:\"15px\";s:4:\"15px\";s:4:\"20px\";s:4:\"20px\";s:4:\"25px\";s:4:\"25px\";s:4:\"30px\";s:4:\"30px\";s:4:\"35px\";s:4:\"35px\";}s:14:\"#default_value\";s:4:\"none\";}s:16:\"background_color\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Background Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Select Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:20:\"validateColorElement\";}}}s:16:\"background_media\";a:5:{s:5:\"#type\";s:13:\"media_library\";s:16:\"#allowed_bundles\";a:3:{i:0;s:5:\"image\";i:1;s:12:\"remote_video\";i:2;s:5:\"video\";}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Background Image/Video\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";N;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"Upload your image, video or Youtube video.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:25:\"background_video_settings\";a:17:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Background video options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:0;s:8:\"autoPlay\";a:3:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Autoplay\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;}s:12:\"showControls\";a:3:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Show controls\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:0;}s:4:\"mute\";a:3:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Mute\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;}s:7:\"startAt\";a:6:{s:5:\"#type\";s:6:\"number\";s:4:\"#min\";i:0;s:5:\"#step\";i:1;s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Start at\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:0;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:51:\"(number) Set the seconds the video should start at.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:7:\"opacity\";a:7:{s:5:\"#type\";s:6:\"number\";s:4:\"#min\";i:0;s:4:\"#max\";i:1;s:5:\"#step\";d:0.01;s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Opacity\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"0 to 1 (number) define the opacity of the video\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"addOverlay\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Add overlay\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Show or hide a overlay image over the video\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:12:\"overlayColor\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Overlay color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:7:\"#000000\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:65:\"RGB color for local videos, YouTube video uses image for overlay.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:69;i:1;s:20:\"validateColorElement\";}}}s:12:\"overlayAlpha\";a:7:{s:5:\"#type\";s:6:\"number\";s:4:\"#min\";i:0;s:4:\"#max\";i:1;s:5:\"#step\";d:0.01;s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Overlay opacity\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:3:\"0.3\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:55:\"For local videos, YouTube video uses image for overlay.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:4:\"loop\";a:3:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Loop\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;}s:15:\"stopMovieOnBlur\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Stop movie on blur\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:55:\"Activate the pause behavior when the window loose focus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"playOnlyIfVisible\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Play only if visible\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:0;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"Activate the pause behavior when the player is out of screen\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"coverImage\";a:5:{s:5:\"#type\";s:13:\"media_library\";s:16:\"#allowed_bundles\";a:1:{i:0;s:5:\"image\";}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Cover Image\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";N;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:117:\"Image used as background for the player if autoplay is set to false; if not set the player will show the first frame.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:11:\"useOnMobile\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Use on mobile\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"Define if the player should render on mobile devices\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:19:\"mobileFallbackImage\";a:5:{s:5:\"#type\";s:13:\"media_library\";s:16:\"#allowed_bundles\";a:1:{i:0;s:5:\"image\";}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Mobile fallback Image\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";N;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:110:\"Fallback image in case of background video on mobile devices and the “useOnMobile” option is set to false.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:25:\"background_image_settings\";a:6:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Background image options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:0;s:19:\"background_position\";a:4:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Background Image Position\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:11:{s:7:\"default\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Default\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"top left\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Top Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:3:\"top\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Top\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"top right\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Top Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"center left\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Center Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"center\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Center\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"center right\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Center Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"bottom left\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Bottom Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"bottom\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Bottom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"bottom right\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Bottom Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"custom\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Custom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:7:\"default\";}s:26:\"background_position_custom\";a:4:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Custom Background Position\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:99:\"See more information about CSS background-position <a href=\":ept_core_configuration_form\">here</a>.\";s:12:\"\0*\0arguments\";a:1:{s:28:\":ept_core_configuration_form\";s:68:\"https://developer.mozilla.org/en-US/docs/Web/CSS/background-position\";}s:10:\"\0*\0options\";a:0:{}}}s:22:\"background_size_custom\";a:4:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Custom Background Size\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:95:\"See more information about CSS background-size <a href=\":ept_core_configuration_form\">here</a>.\";s:12:\"\0*\0arguments\";a:1:{s:28:\":ept_core_configuration_form\";s:64:\"https://developer.mozilla.org/en-US/docs/Web/CSS/background-size\";}s:10:\"\0*\0options\";a:0:{}}}}s:22:\"background_image_style\";a:4:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Background Image Style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:5:{s:7:\"default\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"No repeat\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"parallax\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Parallax\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"cover\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Cover\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"contain\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Contain\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"repeat\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Repeat\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:7:\"default\";}s:12:\"edge_to_edge\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Edge to Edge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:0;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:111:\"If checked, the styles will be applied to the entire screen, starting from the left and extending to the right.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:15:\"container_width\";a:5:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Container Max Width\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:8:{s:4:\"auto\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Auto (100%)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"xxsmall\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"xxSmall\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"xsmall\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"xSmall\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"small\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Small\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"default\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Default\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"large\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Large\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"xlarge\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"xLarge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"xxlarge\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"xxLarge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:123:\"See <a href=\":ept_core_configuration_form\">EPT Core configuration form</a> to set Container Width and other default values.\";s:12:\"\0*\0arguments\";a:1:{s:28:\":ept_core_configuration_form\";s:30:\"/admin/config/content/ept-core\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:4:\"auto\";}}}s:13:\"title_options\";a:5:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Title options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:0;s:13:\"title_wrapper\";a:4:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Tag for Title wrapper\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:6:{s:4:\"none\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"None\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:2:\"h1\";s:2:\"H1\";s:2:\"h2\";s:2:\"H2\";s:2:\"h3\";s:2:\"H3\";s:2:\"h4\";s:2:\"H4\";s:2:\"h5\";s:2:\"H5\";}s:14:\"#default_value\";s:2:\"h2\";}s:10:\"strip_tags\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Strip Tags for Title field\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:70:\"Strip tags in title field wrappers, except span, br, i, img, svg tags.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:18:\"field_ept_settings\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:0;s:6:\"#title\";s:8:\"Settings\";s:12:\"#description\";s:0:\"\";s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:65:\"Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:2;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:57:\"config:field.field.paragraph.ept_views.field_ept_settings\";i:1;s:49:\"config:field.storage.paragraph.field_ept_settings\";}s:7:\"max-age\";i:-1;}}s:14:\"field_ept_text\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:22:\"field_ept_text_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:21:\"field--type-text-long\";i:1;s:26:\"field--name-field-ept-text\";i:2;s:27:\"field--widget-text-textarea\";}}s:6:\"widget\";a:13:{i:0;a:14:{s:6:\"#title\";s:4:\"Text\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";s:0:\"\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:0;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:5:\"#type\";s:11:\"text_format\";s:14:\"#default_value\";N;s:5:\"#rows\";i:5;s:12:\"#placeholder\";s:0:\"\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:2:{i:0;s:12:\"js-text-full\";i:1;s:9:\"text-full\";}s:37:\"data-media-embed-host-entity-langcode\";s:2:\"en\";}s:7:\"#format\";N;s:10:\"#base_type\";s:8:\"textarea\";}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:14:\"field_ept_text\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:0;s:6:\"#title\";s:4:\"Text\";s:12:\"#description\";s:0:\"\";s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:51:\"Drupal\\text\\Plugin\\Field\\FieldWidget\\TextareaWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:14:\"field_ept_text\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:2;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:53:\"config:field.field.paragraph.ept_views.field_ept_text\";i:1;s:45:\"config:field.storage.paragraph.field_ept_text\";}s:7:\"max-age\";i:-1;}}s:15:\"field_ept_title\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:23:\"field_ept_title_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:21:\"field--type-text-long\";i:1;s:27:\"field--name-field-ept-title\";i:2;s:27:\"field--widget-text-textarea\";}}s:6:\"widget\";a:13:{i:0;a:14:{s:6:\"#title\";s:5:\"Title\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";s:0:\"\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:0;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:5:\"#type\";s:11:\"text_format\";s:14:\"#default_value\";N;s:5:\"#rows\";i:2;s:12:\"#placeholder\";s:0:\"\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:2:{i:0;s:12:\"js-text-full\";i:1;s:9:\"text-full\";}s:37:\"data-media-embed-host-entity-langcode\";s:2:\"en\";}s:7:\"#format\";N;s:10:\"#base_type\";s:8:\"textarea\";}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:15:\"field_ept_title\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:0;s:6:\"#title\";s:5:\"Title\";s:12:\"#description\";s:0:\"\";s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:51:\"Drupal\\text\\Plugin\\Field\\FieldWidget\\TextareaWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:15:\"field_ept_title\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:1;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:54:\"config:field.field.paragraph.ept_views.field_ept_title\";i:1;s:46:\"config:field.storage.paragraph.field_ept_title\";}s:7:\"max-age\";i:-1;}}s:9:\"#validate\";a:2:{i:0;a:2:{i:0;O:67:\"Drupal\\viewsreference\\Plugin\\Field\\FieldWidget\\ViewsReferenceWidget\":10:{s:11:\"\0*\0pluginId\";s:27:\"viewsreference_autocomplete\";s:19:\"\0*\0pluginDefinition\";a:7:{s:11:\"field_types\";a:1:{i:0;s:14:\"viewsreference\";}s:15:\"multiple_values\";b:0;s:2:\"id\";s:27:\"viewsreference_autocomplete\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Views reference autocomplete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"An autocomplete views reference field.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"class\";s:67:\"Drupal\\viewsreference\\Plugin\\Field\\FieldWidget\\ViewsReferenceWidget\";s:8:\"provider\";s:14:\"viewsreference\";}s:16:\"\0*\0configuration\";a:0:{}s:14:\"\0*\0_serviceIds\";a:1:{s:17:\"stringTranslation\";s:18:\"string_translation\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:12:\"\0*\0messenger\";N;s:11:\"\0*\0settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:24:\"\0*\0defaultSettingsMerged\";b:0;s:18:\"\0*\0fieldDefinition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:40:\"paragraph.ept_views.field_ept_views_view\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ef74c15e-0e9f-4f8c-82b1-f7cec4763c50\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qezCi3E0L14u6YMFPeJ3FisM_AyqNacTs3hFkLyN-Bk\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ept_views_view\";i:1;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:40:\"paragraph.ept_views.field_ept_views_view\";s:13:\"\0*\0field_name\";s:20:\"field_ept_views_view\";s:13:\"\0*\0field_type\";s:14:\"viewsreference\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:9:\"ept_views\";s:8:\"\0*\0label\";s:4:\"View\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}s:12:\"plugin_types\";a:1:{s:5:\"block\";s:5:\"block\";}s:15:\"preselect_views\";a:0:{}s:16:\"enabled_settings\";a:0:{}}s:11:\"\0*\0required\";b:1;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"paragraph.field_ept_views_view\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"8622c9ec-6687-4349-af19-885f22d99285\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GjkDxormsrh0OTX-iAPBLiJLIDg3h8b7yPlpgyt-kM\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"paragraph.field_ept_views_view\";s:13:\"\0*\0field_name\";s:20:\"field_ept_views_view\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:14:\"viewsreference\";s:9:\"\0*\0module\";s:14:\"viewsreference\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}i:1;s:15:\"elementValidate\";}i:1;s:14:\"::validateForm\";}s:20:\"field_ept_views_view\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:28:\"field_ept_views_view_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:26:\"field--type-viewsreference\";i:1;s:32:\"field--name-field-ept-views-view\";i:2;s:41:\"field--widget-viewsreference-autocomplete\";}}s:6:\"widget\";a:13:{i:0;a:7:{s:7:\"#prefix\";s:46:\"<div id=\"field-ept-views-view-0--_OhJ2eSC2eY\">\";s:7:\"#suffix\";s:6:\"</div>\";s:11:\"#wrapper_id\";s:35:\"field-ept-views-view-0--_OhJ2eSC2eY\";s:9:\"target_id\";a:18:{s:6:\"#title\";s:4:\"View\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";s:0:\"\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:1;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:5:\"#type\";s:19:\"entity_autocomplete\";s:12:\"#target_type\";s:4:\"view\";s:18:\"#selection_handler\";s:12:\"default:view\";s:19:\"#selection_settings\";a:4:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}s:19:\"#validate_reference\";b:0;s:10:\"#maxlength\";i:1024;s:14:\"#default_value\";N;s:5:\"#size\";i:60;s:12:\"#placeholder\";s:0:\"\";s:24:\"#limit_validation_errors\";a:0:{}s:5:\"#ajax\";a:4:{s:8:\"callback\";a:2:{i:0;s:67:\"Drupal\\viewsreference\\Plugin\\Field\\FieldWidget\\ViewsReferenceWidget\";i:1;s:15:\"itemAjaxRefresh\";}s:5:\"event\";s:21:\"viewsreference-select\";s:7:\"wrapper\";s:35:\"field-ept-views-view-0--_OhJ2eSC2eY\";s:8:\"progress\";a:2:{s:4:\"type\";s:8:\"throbber\";s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Getting display IDs...\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:10:\"display_id\";a:10:{s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#type\";s:6:\"select\";s:8:\"#options\";a:1:{s:7:\"block_1\";s:5:\"Block\";}s:14:\"#default_value\";s:0:\"\";s:13:\"#empty_option\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"- Select -\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"#empty_value\";s:0:\"\";s:7:\"#weight\";i:10;s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:25:\"viewsreference-display-id\";}}s:7:\"#states\";a:2:{s:7:\"visible\";a:1:{s:49:\":input[name=\"field_ept_views_view[0][target_id]\"]\";a:1:{s:6:\"filled\";b:1;}}s:8:\"required\";a:1:{s:49:\":input[name=\"field_ept_views_view[0][target_id]\"]\";a:1:{s:6:\"filled\";b:1;}}}s:5:\"#ajax\";a:4:{s:8:\"callback\";a:2:{i:0;s:67:\"Drupal\\viewsreference\\Plugin\\Field\\FieldWidget\\ViewsReferenceWidget\";i:1;s:15:\"itemAjaxRefresh\";}s:5:\"event\";s:21:\"viewsreference-select\";s:7:\"wrapper\";s:35:\"field-ept-views-view-0--_OhJ2eSC2eY\";s:8:\"progress\";a:2:{s:4:\"type\";s:8:\"throbber\";s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Getting options...\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"#attached\";a:1:{s:7:\"library\";a:1:{i:0;s:29:\"viewsreference/viewsreference\";}}s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:67:\"Drupal\\viewsreference\\Plugin\\Field\\FieldWidget\\ViewsReferenceWidget\";i:1;s:15:\"itemResetValues\";}}}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:20:\"field_ept_views_view\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:1;s:6:\"#title\";s:4:\"View\";s:12:\"#description\";s:0:\"\";s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:67:\"Drupal\\viewsreference\\Plugin\\Field\\FieldWidget\\ViewsReferenceWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:20:\"field_ept_views_view\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:3;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:59:\"config:field.field.paragraph.ept_views.field_ept_views_view\";i:1;s:51:\"config:field.storage.paragraph.field_ept_views_view\";}s:7:\"max-age\";i:-1;}}s:6:\"#cache\";a:3:{s:8:\"contexts\";a:1:{i:0;s:24:\"user.roles:authenticated\";}s:4:\"tags\";a:2:{i:0;s:59:\"config:core.entity_form_display.paragraph.ept_views.default\";i:1;s:42:\"CACHE_MISS_IF_UNCACHEABLE_HTTP_METHOD:form\";}s:7:\"max-age\";i:-1;}s:8:\"#process\";a:2:{i:0;a:2:{i:0;O:43:\"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay\":16:{s:7:\"\0*\0uuid\";s:36:\"5f9fd1ed-53a9-4349-8202-c90230a11f12\";s:11:\"\0*\0langcode\";s:2:\"en\";s:9:\"\0*\0status\";b:1;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:50:\"field.field.paragraph.ept_views.field_ept_settings\";i:1;s:46:\"field.field.paragraph.ept_views.field_ept_text\";i:2;s:47:\"field.field.paragraph.ept_views.field_ept_title\";i:3;s:52:\"field.field.paragraph.ept_views.field_ept_views_view\";i:4;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:4:{i:0;s:8:\"ept_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";i:3;s:14:\"viewsreference\";}}s:23:\"\0*\0third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:20:\"field_ept_views_view\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_i5XjlBN7MBo2rHWjbgIick135me8C2QqOcKTkr7Sx0\";}s:5:\"\0*\0id\";s:27:\"paragraph.ept_views.default\";s:19:\"\0*\0targetEntityType\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:9:\"ept_views\";s:7:\"\0*\0mode\";s:7:\"default\";s:10:\"\0*\0content\";a:4:{s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:20:\"ept_settings_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ept_views_view\";a:5:{s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:9:\"\0*\0hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}s:15:\"\0*\0entityTypeId\";s:19:\"entity_form_display\";s:15:\"\0*\0enforceIsNew\";N;s:15:\"_serializedKeys\";a:16:{i:0;s:4:\"uuid\";i:1;s:8:\"langcode\";i:2;s:6:\"status\";i:3;s:12:\"dependencies\";i:4;s:20:\"third_party_settings\";i:5;s:5:\"_core\";i:6;s:2:\"id\";i:7;s:16:\"targetEntityType\";i:8;s:6:\"bundle\";i:9;s:4:\"mode\";i:10;s:7:\"content\";i:11;s:6:\"hidden\";i:12;s:12:\"entityTypeId\";i:13;s:12:\"enforceIsNew\";i:14;s:15:\"_serializedKeys\";i:15;s:11:\"initialized\";}s:14:\"\0*\0initialized\";b:1;}i:1;s:11:\"processForm\";}i:1;a:2:{i:0;s:34:\"Drupal\\field_group\\FormatterHelper\";i:1;s:11:\"formProcess\";}}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Create new @type\";s:12:\"\0*\0arguments\";a:1:{s:5:\"@type\";s:9:\"EPT Views\";}s:10:\"\0*\0options\";a:0:{}}s:10:\"#paragraph\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:23:\"_layoutParagraphsLayout\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:3:\"vid\";a:1:{s:9:\"x-default\";a:0:{}}s:3:\"nid\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"523c8068-709e-45c1-81d6-c1a12a1eb399\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:4:\"page\";}}}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729064448;}}}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";a:0:{}}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:3:\"uid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:1:\"1\";}}}s:5:\"title\";a:1:{s:9:\"x-default\";a:0:{}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729064448;}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729064448;}}}s:7:\"promote\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:6:\"sticky\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"path\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:8:\"langcode\";s:2:\"en\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:2:{s:6:\"bundle\";s:4:\"page\";s:8:\"revision\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:0:{}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"2d173e6416d251d4c425343bb4686802\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_views\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729064495;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:0:{}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:0:{}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:0:{}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}s:20:\"field_ept_views_view\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:2:{s:6:\"bundle\";s:9:\"ept_views\";s:8:\"revision\";N;}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:0;s:20:\"\0*\0stringTranslation\";N;}s:8:\"#display\";r:1204;s:5:\"#tree\";b:1;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;O:49:\"Drupal\\layout_paragraphs\\Form\\InsertComponentForm\":19:{s:15:\"\0*\0requestStack\";N;s:13:\"\0*\0routeMatch\";N;s:14:\"\0*\0_serviceIds\";a:8:{s:13:\"configFactory\";s:14:\"config.factory\";s:17:\"stringTranslation\";s:18:\"string_translation\";s:9:\"tempstore\";s:38:\"layout_paragraphs.tempstore_repository\";s:17:\"entityTypeManager\";s:19:\"entity_type.manager\";s:19:\"layoutPluginManager\";s:26:\"plugin.manager.core.layout\";s:13:\"moduleHandler\";s:14:\"module_handler\";s:16:\"entityRepository\";s:17:\"entity.repository\";s:15:\"eventDispatcher\";s:16:\"event_dispatcher\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:16:\"\0*\0loggerFactory\";N;s:12:\"\0*\0messenger\";N;s:22:\"\0*\0redirectDestination\";N;s:16:\"\0*\0paragraphType\";O:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\":23:{s:15:\"\0*\0entityTypeId\";s:15:\"paragraphs_type\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:9:\"ept_views\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7ac88ec9-7da9-488c-ac70-492b5bcfde08\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JfY6zZuA9cpemb4U-YVMX2rzmT1pm_Pr1YpT7xaSxeA\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:2:\"id\";s:9:\"ept_views\";s:5:\"label\";s:9:\"EPT Views\";s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Views\";s:12:\"\0*\0icon_uuid\";N;s:15:\"\0*\0icon_default\";N;s:16:\"behavior_plugins\";a:1:{s:17:\"layout_paragraphs\";a:1:{s:17:\"available_layouts\";a:0:{}}}}s:12:\"\0*\0paragraph\";r:1340;s:11:\"\0*\0formMode\";s:7:\"default\";s:25:\"\0*\0layoutParagraphsLayout\";r:1350;s:33:\"\0*\0originalLayoutParagraphsLayout\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";r:1352;s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";r:1574;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:0:{}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";N;s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:14:\"\0*\0domSelector\";s:48:\"[data-lpb-id=\"2d173e6416d251d4c425343bb4686802\"]\";s:20:\"\0*\0paragraphDefaults\";a:0:{}s:9:\"\0*\0method\";s:7:\"prepend\";s:13:\"\0*\0parentUuid\";s:0:\"\";s:9:\"\0*\0region\";s:0:\"\";s:12:\"\0*\0placement\";s:0:\"\";s:14:\"\0*\0siblingUuid\";s:0:\"\";}i:1;s:10:\"afterBuild\";}}s:9:\"#attached\";a:2:{s:7:\"library\";a:1:{i:0;s:32:\"layout_paragraphs/component_form\";}s:12:\"placeholders\";a:1:{s:55:\"form_action_p_pvdeGsVG5zNF_XLGPTvYSKCf43t8qZYSwcfZl2uzM\";a:1:{s:13:\"#lazy_builder\";a:2:{i:0;s:40:\"form_builder:renderPlaceholderFormAction\";i:1;a:0:{}}}}}s:7:\"actions\";a:4:{s:7:\"#weight\";i:100;s:5:\"#type\";s:7:\"actions\";s:6:\"submit\";a:5:{s:5:\"#type\";s:6:\"submit\";s:7:\"#weight\";i:100;s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Save\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#ajax\";a:2:{s:8:\"callback\";s:12:\"::ajaxSubmit\";s:8:\"progress\";s:4:\"none\";}s:11:\"#attributes\";a:2:{s:5:\"class\";a:2:{i:0;s:13:\"lpb-btn--save\";i:1;s:15:\"button--primary\";}s:20:\"data-disable-refocus\";s:4:\"true\";}}s:6:\"cancel\";a:6:{s:5:\"#type\";s:6:\"button\";s:7:\"#weight\";i:200;s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Cancel\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:24:\"#limit_validation_errors\";a:0:{}s:5:\"#ajax\";a:2:{s:8:\"callback\";s:8:\"::cancel\";s:8:\"progress\";s:4:\"none\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:13:\"dialog-cancel\";i:1;s:15:\"lpb-btn--cancel\";}}}}s:12:\"#fieldgroups\";a:3:{s:10:\"group_tabs\";O:8:\"stdClass\":12:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}s:10:\"group_name\";s:10:\"group_tabs\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:7:\"context\";s:4:\"form\";s:4:\"mode\";s:7:\"default\";}s:13:\"group_content\";O:8:\"stdClass\":12:{s:8:\"children\";a:3:{i:0;s:15:\"field_ept_title\";i:1;s:14:\"field_ept_text\";i:2;s:20:\"field_ept_views_view\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}s:10:\"group_name\";s:13:\"group_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:7:\"context\";s:4:\"form\";s:4:\"mode\";s:7:\"default\";}s:14:\"group_settings\";O:8:\"stdClass\":12:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:7;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}s:10:\"group_name\";s:14:\"group_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:9:\"ept_views\";s:7:\"context\";s:4:\"form\";s:4:\"mode\";s:7:\"default\";}}s:15:\"#group_children\";a:6:{s:13:\"group_content\";s:10:\"group_tabs\";s:14:\"group_settings\";s:10:\"group_tabs\";s:15:\"field_ept_title\";s:13:\"group_content\";s:14:\"field_ept_text\";s:13:\"group_content\";s:20:\"field_ept_views_view\";s:13:\"group_content\";s:18:\"field_ept_settings\";s:14:\"group_settings\";}s:12:\"#entity_type\";s:9:\"paragraph\";s:8:\"#form_id\";s:32:\"layout_paragraphs_component_form\";s:9:\"#build_id\";s:48:\"form-CbEyRCXFiwYhjJqVDd9JbESXcfdYqS_x2x6Y1H_CfMc\";s:5:\"#type\";s:4:\"form\";s:7:\"#action\";s:55:\"form_action_p_pvdeGsVG5zNF_XLGPTvYSKCf43t8qZYSwcfZl2uzM\";s:13:\"form_build_id\";a:5:{s:5:\"#type\";s:6:\"hidden\";s:6:\"#value\";s:48:\"form-CbEyRCXFiwYhjJqVDd9JbESXcfdYqS_x2x6Y1H_CfMc\";s:3:\"#id\";s:48:\"form-CbEyRCXFiwYhjJqVDd9JbESXcfdYqS_x2x6Y1H_CfMc\";s:5:\"#name\";s:13:\"form_build_id\";s:8:\"#parents\";a:1:{i:0;s:13:\"form_build_id\";}}s:6:\"#token\";s:66:\"form_token_placeholder_s2YfxV6fJyGjndqPaiT_BWYnNHuH1rQKMkaXixiHD6k\";s:10:\"form_token\";a:6:{s:3:\"#id\";s:61:\"edit-layout-paragraphs-component-form-form-token--p-7DJdiOwZ8\";s:5:\"#type\";s:5:\"token\";s:14:\"#default_value\";s:66:\"form_token_placeholder_s2YfxV6fJyGjndqPaiT_BWYnNHuH1rQKMkaXixiHD6k\";s:8:\"#parents\";a:1:{i:0;s:10:\"form_token\";}s:9:\"#attached\";a:1:{s:12:\"placeholders\";a:1:{s:66:\"form_token_placeholder_s2YfxV6fJyGjndqPaiT_BWYnNHuH1rQKMkaXixiHD6k\";a:1:{s:13:\"#lazy_builder\";a:2:{i:0;s:39:\"form_builder:renderFormTokenPlaceholder\";i:1;a:1:{i:0;s:66:\"form_token_placeholder_s2YfxV6fJyGjndqPaiT_BWYnNHuH1rQKMkaXixiHD6k\";}}}}}s:6:\"#cache\";a:1:{s:7:\"max-age\";i:0;}}s:7:\"form_id\";a:4:{s:5:\"#type\";s:6:\"hidden\";s:6:\"#value\";s:32:\"layout_paragraphs_component_form\";s:3:\"#id\";s:50:\"edit-layout-paragraphs-component-form--QxKaJu-HuDw\";s:8:\"#parents\";a:1:{i:0;s:7:\"form_id\";}}s:3:\"#id\";s:45:\"layout-paragraphs-component-form--jxsA3OSZwWc\";s:7:\"#method\";s:4:\"post\";s:15:\"#theme_wrappers\";a:1:{i:0;s:4:\"form\";}s:16:\"#defaults_loaded\";b:1;s:7:\"#submit\";a:1:{i:0;s:12:\"::submitForm\";}s:6:\"#theme\";a:1:{i:0;s:32:\"layout_paragraphs_component_form\";}s:12:\"#cache_token\";s:43:\"6hnLZfh-UY1scD5xwp6fsiJvmCOR_S-6jvUzbpEr7oU\";}',1729086119),('form','form-DS3On2XI3AuPlhswpYnhJKxvNUtU5NGdLm1lU5WcFyg',_binary 'a:37:{s:11:\"#attributes\";a:2:{s:5:\"class\";a:1:{i:0;s:32:\"layout-paragraphs-component-form\";}s:20:\"data-drupal-selector\";s:32:\"layout-paragraphs-component-form\";}s:8:\"#parents\";a:0:{}s:27:\"field_ept_hero_column_image\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:35:\"field_ept_hero_column_image_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:28:\"field--type-entity-reference\";i:1;s:39:\"field--name-field-ept-hero-column-image\";i:2;s:34:\"field--widget-media-library-widget\";}}s:6:\"widget\";a:22:{s:6:\"#title\";s:12:\"Column Image\";s:12:\"#description\";s:25:\"One media item remaining.\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:0;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:5:\"#type\";s:8:\"fieldset\";s:12:\"#cardinality\";i:1;s:15:\"#target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:11:\"#attributes\";a:2:{s:2:\"id\";s:49:\"field_ept_hero_column_image-media-library-wrapper\";s:5:\"class\";a:1:{i:0;s:23:\"js-media-library-widget\";}}s:11:\"#pre_render\";a:1:{i:0;a:2:{i:0;O:64:\"Drupal\\media_library\\Plugin\\Field\\FieldWidget\\MediaLibraryWidget\":10:{s:11:\"\0*\0pluginId\";s:20:\"media_library_widget\";s:19:\"\0*\0pluginDefinition\";a:8:{s:5:\"class\";s:64:\"Drupal\\media_library\\Plugin\\Field\\FieldWidget\\MediaLibraryWidget\";s:8:\"provider\";s:13:\"media_library\";s:2:\"id\";s:20:\"media_library_widget\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Media library\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"Allows you to select items from the media library.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"field_types\";a:1:{i:0;s:16:\"entity_reference\";}s:15:\"multiple_values\";b:1;s:6:\"weight\";N;}s:16:\"\0*\0configuration\";a:0:{}s:14:\"\0*\0_serviceIds\";a:4:{s:17:\"stringTranslation\";s:18:\"string_translation\";s:17:\"entityTypeManager\";s:19:\"entity_type.manager\";s:11:\"currentUser\";s:12:\"current_user\";s:13:\"moduleHandler\";s:14:\"module_handler\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:12:\"\0*\0messenger\";N;s:11:\"\0*\0settings\";a:1:{s:11:\"media_types\";a:0:{}}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:24:\"\0*\0defaultSettingsMerged\";b:0;s:18:\"\0*\0fieldDefinition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:46:\"paragraph.ept_hero.field_ept_hero_column_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"b46ea217-84f7-4321-912a-7446b534bb92\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_3eydYXoFUtHpVqERbj-NUTxfjmRpY41GlotzDaiMHw\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:51:\"field.storage.paragraph.field_ept_hero_column_image\";i:1;s:16:\"media.type.image\";i:2;s:35:\"paragraphs.paragraphs_type.ept_hero\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:46:\"paragraph.ept_hero.field_ept_hero_column_image\";s:13:\"\0*\0field_name\";s:27:\"field_ept_hero_column_image\";s:13:\"\0*\0field_type\";s:16:\"entity_reference\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:8:\"ept_hero\";s:8:\"\0*\0label\";s:12:\"Column Image\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ept_hero_column_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"0bd5b0b1-4d3b-472e-ac51-086416f9360a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"knr6QfLVidPHSzwjlRdOZ6PqAiVNnXT73--qFC4pZqo\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ept_hero_column_image\";s:13:\"\0*\0field_name\";s:27:\"field_ept_hero_column_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}i:1;s:15:\"preRenderWidget\";}}s:9:\"#attached\";a:1:{s:7:\"library\";a:1:{i:0;s:20:\"media_library/widget\";}}s:15:\"#theme_wrappers\";a:1:{i:0;s:30:\"fieldset__media_library_widget\";}s:13:\"#field_prefix\";a:1:{s:15:\"empty_selection\";a:1:{s:7:\"#markup\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"No media items are selected.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:9:\"selection\";a:3:{s:5:\"#type\";s:9:\"container\";s:15:\"#theme_wrappers\";a:1:{i:0;s:41:\"container__media_library_widget_selection\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:26:\"js-media-library-selection\";}}}s:11:\"open_button\";a:7:{s:5:\"#type\";s:6:\"button\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#name\";s:53:\"field_ept_hero_column_image-media-library-open-button\";s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:28:\"js-media-library-open-button\";}}s:20:\"#media_library_state\";O:38:\"Drupal\\media_library\\MediaLibraryState\":1:{s:13:\"\0*\0parameters\";a:6:{s:23:\"media_library_opener_id\";s:33:\"media_library.opener.field_widget\";s:27:\"media_library_allowed_types\";a:1:{s:5:\"image\";s:5:\"image\";}s:27:\"media_library_selected_type\";s:5:\"image\";s:23:\"media_library_remaining\";i:1;s:31:\"media_library_opener_parameters\";a:4:{s:15:\"field_widget_id\";s:27:\"field_ept_hero_column_image\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:10:\"field_name\";s:27:\"field_ept_hero_column_image\";}s:4:\"hash\";s:43:\"bSalQrvdbBCKxEeWpBHqlu-Ga63Lc7d64hgHh6bnP_o\";}}s:5:\"#ajax\";a:2:{s:8:\"callback\";a:2:{i:0;s:64:\"Drupal\\media_library\\Plugin\\Field\\FieldWidget\\MediaLibraryWidget\";i:1;s:16:\"openMediaLibrary\";}s:8:\"progress\";a:2:{s:4:\"type\";s:8:\"throbber\";s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Opening media library.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:24:\"#limit_validation_errors\";a:0:{}}s:23:\"media_library_selection\";a:2:{s:5:\"#type\";s:6:\"hidden\";s:11:\"#attributes\";a:1:{s:31:\"data-media-library-widget-value\";s:27:\"field_ept_hero_column_image\";}}s:27:\"media_library_update_widget\";a:8:{s:5:\"#type\";s:6:\"submit\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#name\";s:48:\"field_ept_hero_column_image-media-library-update\";s:5:\"#ajax\";a:3:{s:8:\"callback\";a:2:{i:0;s:64:\"Drupal\\media_library\\Plugin\\Field\\FieldWidget\\MediaLibraryWidget\";i:1;s:12:\"updateWidget\";}s:7:\"wrapper\";s:49:\"field_ept_hero_column_image-media-library-wrapper\";s:8:\"progress\";a:2:{s:4:\"type\";s:8:\"throbber\";s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Adding selection.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:11:\"#attributes\";a:2:{s:32:\"data-media-library-widget-update\";s:27:\"field_ept_hero_column_image\";s:5:\"class\";a:1:{i:0;s:7:\"js-hide\";}}s:9:\"#validate\";a:1:{i:0;a:2:{i:0;s:64:\"Drupal\\media_library\\Plugin\\Field\\FieldWidget\\MediaLibraryWidget\";i:1;s:13:\"validateItems\";}}s:7:\"#submit\";a:1:{i:0;a:2:{i:0;s:64:\"Drupal\\media_library\\Plugin\\Field\\FieldWidget\\MediaLibraryWidget\";i:1;s:8:\"addItems\";}}s:24:\"#limit_validation_errors\";a:0:{}}s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:64:\"Drupal\\media_library\\Plugin\\Field\\FieldWidget\\MediaLibraryWidget\";i:1;s:10:\"afterBuild\";}}s:11:\"#field_name\";s:27:\"field_ept_hero_column_image\";s:8:\"#parents\";a:1:{i:0;s:27:\"field_ept_hero_column_image\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:4;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:65:\"config:field.field.paragraph.ept_hero.field_ept_hero_column_image\";i:1;s:58:\"config:field.storage.paragraph.field_ept_hero_column_image\";}s:7:\"max-age\";i:-1;}}s:19:\"field_ept_hero_link\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:27:\"field_ept_hero_link_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:16:\"field--type-link\";i:1;s:31:\"field--name-field-ept-hero-link\";i:2;s:26:\"field--widget-link-default\";}}s:6:\"widget\";a:13:{i:0;a:12:{s:6:\"#title\";s:4:\"Link\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";s:0:\"\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:0;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:3:\"uri\";a:13:{s:5:\"#type\";s:19:\"entity_autocomplete\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"URL\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"#placeholder\";s:0:\"\";s:14:\"#default_value\";N;s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;s:47:\"Drupal\\link\\Plugin\\Field\\FieldWidget\\LinkWidget\";i:1;s:18:\"validateUriElement\";}}s:10:\"#maxlength\";i:2048;s:9:\"#required\";b:0;s:10:\"#link_type\";i:17;s:12:\"#target_type\";s:4:\"node\";s:11:\"#attributes\";a:1:{s:43:\"data-autocomplete-first-character-blacklist\";s:3:\"/#?\";}s:22:\"#process_default_value\";b:0;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:287:\"Start typing the title of a piece of content to select it. You can also enter an internal path such as %add-node or an external URL such as %url. Enter %front to link to the front page. Enter %nolink to display link text only. Enter %button to display keyboard-accessible link text only.\";s:12:\"\0*\0arguments\";a:5:{s:6:\"%front\";s:7:\"<front>\";s:9:\"%add-node\";s:9:\"/node/add\";s:4:\"%url\";s:19:\"https://example.com\";s:7:\"%nolink\";s:8:\"<nolink>\";s:7:\"%button\";s:8:\"<button>\";}s:10:\"\0*\0options\";a:0:{}}s:7:\"#states\";a:1:{s:8:\"required\";a:1:{s:44:\":input[name=\"field_ept_hero_link[0][title]\"]\";a:1:{s:6:\"filled\";b:1;}}}}s:5:\"title\";a:7:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Link text\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"#placeholder\";s:0:\"\";s:14:\"#default_value\";N;s:10:\"#maxlength\";i:255;s:7:\"#access\";b:1;s:9:\"#required\";b:0;}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;s:47:\"Drupal\\link\\Plugin\\Field\\FieldWidget\\LinkWidget\";i:1;s:19:\"validateTitleNoLink\";}}s:10:\"attributes\";a:4:{s:5:\"#type\";s:5:\"value\";s:5:\"#tree\";b:1;s:6:\"#value\";a:0:{}s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:28:\"link-field-widget-attributes\";}}}s:5:\"#type\";s:8:\"fieldset\";}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:19:\"field_ept_hero_link\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:0;s:6:\"#title\";s:4:\"Link\";s:12:\"#description\";s:0:\"\";s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:47:\"Drupal\\link\\Plugin\\Field\\FieldWidget\\LinkWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:19:\"field_ept_hero_link\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:5;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:57:\"config:field.field.paragraph.ept_hero.field_ept_hero_link\";i:1;s:50:\"config:field.storage.paragraph.field_ept_hero_link\";}s:7:\"max-age\";i:-1;}}s:26:\"field_ept_hero_second_link\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:34:\"field_ept_hero_second_link_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:16:\"field--type-link\";i:1;s:38:\"field--name-field-ept-hero-second-link\";i:2;s:26:\"field--widget-link-default\";}}s:6:\"widget\";a:13:{i:0;a:12:{s:6:\"#title\";s:11:\"Second link\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";s:0:\"\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:0;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:3:\"uri\";a:13:{s:5:\"#type\";s:19:\"entity_autocomplete\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"URL\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"#placeholder\";s:0:\"\";s:14:\"#default_value\";N;s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;s:47:\"Drupal\\link\\Plugin\\Field\\FieldWidget\\LinkWidget\";i:1;s:18:\"validateUriElement\";}}s:10:\"#maxlength\";i:2048;s:9:\"#required\";b:0;s:10:\"#link_type\";i:17;s:12:\"#target_type\";s:4:\"node\";s:11:\"#attributes\";a:1:{s:43:\"data-autocomplete-first-character-blacklist\";s:3:\"/#?\";}s:22:\"#process_default_value\";b:0;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:287:\"Start typing the title of a piece of content to select it. You can also enter an internal path such as %add-node or an external URL such as %url. Enter %front to link to the front page. Enter %nolink to display link text only. Enter %button to display keyboard-accessible link text only.\";s:12:\"\0*\0arguments\";a:5:{s:6:\"%front\";s:7:\"<front>\";s:9:\"%add-node\";s:9:\"/node/add\";s:4:\"%url\";s:19:\"https://example.com\";s:7:\"%nolink\";s:8:\"<nolink>\";s:7:\"%button\";s:8:\"<button>\";}s:10:\"\0*\0options\";a:0:{}}s:7:\"#states\";a:1:{s:8:\"required\";a:1:{s:51:\":input[name=\"field_ept_hero_second_link[0][title]\"]\";a:1:{s:6:\"filled\";b:1;}}}}s:5:\"title\";a:8:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Link text\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"#placeholder\";s:0:\"\";s:14:\"#default_value\";N;s:10:\"#maxlength\";i:255;s:7:\"#access\";b:1;s:9:\"#required\";b:0;s:7:\"#states\";a:1:{s:8:\"required\";a:1:{s:49:\":input[name=\"field_ept_hero_second_link[0][uri]\"]\";a:1:{s:6:\"filled\";b:1;}}}}s:17:\"#element_validate\";a:2:{i:0;a:2:{i:0;s:47:\"Drupal\\link\\Plugin\\Field\\FieldWidget\\LinkWidget\";i:1;s:20:\"validateTitleElement\";}i:1;a:2:{i:0;s:47:\"Drupal\\link\\Plugin\\Field\\FieldWidget\\LinkWidget\";i:1;s:19:\"validateTitleNoLink\";}}s:10:\"attributes\";a:4:{s:5:\"#type\";s:5:\"value\";s:5:\"#tree\";b:1;s:6:\"#value\";a:0:{}s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:28:\"link-field-widget-attributes\";}}}s:5:\"#type\";s:8:\"fieldset\";}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:26:\"field_ept_hero_second_link\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:0;s:6:\"#title\";s:11:\"Second link\";s:12:\"#description\";s:0:\"\";s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:47:\"Drupal\\link\\Plugin\\Field\\FieldWidget\\LinkWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:26:\"field_ept_hero_second_link\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:6;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:64:\"config:field.field.paragraph.ept_hero.field_ept_hero_second_link\";i:1;s:57:\"config:field.storage.paragraph.field_ept_hero_second_link\";}s:7:\"max-age\";i:-1;}}s:27:\"field_ept_hero_title_prefix\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:35:\"field_ept_hero_title_prefix_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:21:\"field--type-text-long\";i:1;s:39:\"field--name-field-ept-hero-title-prefix\";i:2;s:27:\"field--widget-text-textarea\";}}s:6:\"widget\";a:13:{i:0;a:14:{s:6:\"#title\";s:12:\"Title prefix\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";s:0:\"\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:0;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:5:\"#type\";s:11:\"text_format\";s:14:\"#default_value\";N;s:5:\"#rows\";i:5;s:12:\"#placeholder\";s:0:\"\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:2:{i:0;s:12:\"js-text-full\";i:1;s:9:\"text-full\";}s:37:\"data-media-embed-host-entity-langcode\";s:2:\"en\";}s:7:\"#format\";N;s:10:\"#base_type\";s:8:\"textarea\";}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:27:\"field_ept_hero_title_prefix\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:0;s:6:\"#title\";s:12:\"Title prefix\";s:12:\"#description\";s:0:\"\";s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:51:\"Drupal\\text\\Plugin\\Field\\FieldWidget\\TextareaWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:27:\"field_ept_hero_title_prefix\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:2;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:65:\"config:field.field.paragraph.ept_hero.field_ept_hero_title_prefix\";i:1;s:58:\"config:field.storage.paragraph.field_ept_hero_title_prefix\";}s:7:\"max-age\";i:-1;}}s:18:\"field_ept_settings\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:26:\"field_ept_settings_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:24:\"field--type-ept-settings\";i:1;s:30:\"field--name-field-ept-settings\";i:2;s:31:\"field--widget-ept-settings-hero\";}}s:6:\"widget\";a:13:{i:0;a:10:{s:6:\"#title\";s:8:\"Settings\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";s:0:\"\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:0;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:9:\"#attached\";a:1:{s:7:\"library\";a:5:{i:0;s:20:\"ept_core/colorpicker\";i:1;s:35:\"field_group/element.horizontal_tabs\";i:2;s:21:\"ept_core/ept_settings\";i:3;s:20:\"ept_core/colorpicker\";i:4;s:38:\"ept_basic_button/ept_basic_button_form\";}}s:12:\"ept_settings\";a:16:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Paragraph settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:1;s:26:\"pass_options_to_javascript\";a:2:{s:5:\"#type\";s:6:\"hidden\";s:6:\"#value\";b:0;}s:14:\"design_options\";a:6:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Design options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:0;s:4:\"box1\";a:8:{s:5:\"#type\";s:9:\"container\";s:11:\"#attributes\";a:1:{s:5:\"class\";s:26:\"design-options__margin-box\";}s:5:\"label\";a:3:{s:5:\"#type\";s:8:\"html_tag\";s:4:\"#tag\";s:5:\"label\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Margin\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"margin_top\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Top\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;O:62:\"Drupal\\ept_hero\\Plugin\\Field\\FieldWidget\\EptSettingsHeroWidget\":11:{s:11:\"\0*\0pluginId\";s:17:\"ept_settings_hero\";s:19:\"\0*\0pluginDefinition\";a:6:{s:11:\"field_types\";a:1:{i:0;s:12:\"ept_settings\";}s:15:\"multiple_values\";b:0;s:2:\"id\";s:17:\"ept_settings_hero\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"EPT Hero settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"class\";s:62:\"Drupal\\ept_hero\\Plugin\\Field\\FieldWidget\\EptSettingsHeroWidget\";s:8:\"provider\";s:8:\"ept_hero\";}s:16:\"\0*\0configuration\";a:0:{}s:14:\"\0*\0_serviceIds\";a:1:{s:17:\"stringTranslation\";s:18:\"string_translation\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:12:\"\0*\0messenger\";N;s:11:\"\0*\0settings\";a:0:{}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:24:\"\0*\0defaultSettingsMerged\";b:0;s:18:\"\0*\0fieldDefinition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.ept_hero.field_ept_settings\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"9610a78c-d4d5-4d29-9221-2b862f3b5c9d\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jlfCaG2VGA8ar8Pw_-7SqeS8qRs_HrOK0KBRLdRLQGw\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ept_settings\";i:1;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:1:{i:0;s:8:\"ept_core\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.ept_hero.field_ept_settings\";s:13:\"\0*\0field_name\";s:18:\"field_ept_settings\";s:13:\"\0*\0field_type\";s:12:\"ept_settings\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:8:\"ept_hero\";s:8:\"\0*\0label\";s:8:\"Settings\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:0:{}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ept_settings\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"aed153c8-a66a-428a-be76-0d9ff9c57e30\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HvKMBmRf1ancerUpnNjtwfTeY-R4_vPBnsqEe9j-ovs\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:8:\"ept_core\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ept_settings\";s:13:\"\0*\0field_name\";s:18:\"field_ept_settings\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:12:\"ept_settings\";s:9:\"\0*\0module\";s:8:\"ept_core\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:9:\"\0*\0config\";O:34:\"Drupal\\Core\\Config\\ImmutableConfig\":13:{s:7:\"\0*\0name\";s:17:\"ept_core.settings\";s:7:\"\0*\0data\";a:12:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYlqpNn_5W04WVeLB4bYW404IYbkVrx7N9zxzBAJ-Io\";}s:26:\"ept_core_mobile_breakpoint\";s:3:\"640\";s:26:\"ept_core_tablet_breakpoint\";s:4:\"1020\";s:27:\"ept_core_desktop_breakpoint\";s:4:\"1320\";s:22:\"ept_core_xxsmall_width\";s:3:\"480\";s:21:\"ept_core_xsmall_width\";s:3:\"640\";s:20:\"ept_core_small_width\";s:3:\"768\";s:22:\"ept_core_default_width\";s:3:\"960\";s:20:\"ept_core_large_width\";s:4:\"1100\";s:21:\"ept_core_xlarge_width\";s:4:\"1320\";s:22:\"ept_core_xxlarge_width\";s:4:\"1600\";s:25:\"ept_core_background_color\";s:7:\"#0d77b5\";}s:14:\"\0*\0_serviceIds\";a:3:{s:7:\"storage\";s:14:\"config.storage\";s:18:\"typedConfigManager\";s:12:\"config.typed\";s:15:\"eventDispatcher\";s:16:\"event_dispatcher\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:16:\"\0*\0schemaWrapper\";N;s:8:\"\0*\0isNew\";b:0;s:15:\"\0*\0originalData\";a:12:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYlqpNn_5W04WVeLB4bYW404IYbkVrx7N9zxzBAJ-Io\";}s:26:\"ept_core_mobile_breakpoint\";s:3:\"640\";s:26:\"ept_core_tablet_breakpoint\";s:4:\"1020\";s:27:\"ept_core_desktop_breakpoint\";s:4:\"1320\";s:22:\"ept_core_xxsmall_width\";s:3:\"480\";s:21:\"ept_core_xsmall_width\";s:3:\"640\";s:20:\"ept_core_small_width\";s:3:\"768\";s:22:\"ept_core_default_width\";s:3:\"960\";s:20:\"ept_core_large_width\";s:4:\"1100\";s:21:\"ept_core_xlarge_width\";s:4:\"1320\";s:22:\"ept_core_xxlarge_width\";s:4:\"1600\";s:25:\"ept_core_background_color\";s:7:\"#0d77b5\";}s:17:\"\0*\0overriddenData\";a:12:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYlqpNn_5W04WVeLB4bYW404IYbkVrx7N9zxzBAJ-Io\";}s:26:\"ept_core_mobile_breakpoint\";s:3:\"640\";s:26:\"ept_core_tablet_breakpoint\";s:4:\"1020\";s:27:\"ept_core_desktop_breakpoint\";s:4:\"1320\";s:22:\"ept_core_xxsmall_width\";s:3:\"480\";s:21:\"ept_core_xsmall_width\";s:3:\"640\";s:20:\"ept_core_small_width\";s:3:\"768\";s:22:\"ept_core_default_width\";s:3:\"960\";s:20:\"ept_core_large_width\";s:4:\"1100\";s:21:\"ept_core_xlarge_width\";s:4:\"1320\";s:22:\"ept_core_xxlarge_width\";s:4:\"1600\";s:25:\"ept_core_background_color\";s:7:\"#0d77b5\";}s:18:\"\0*\0moduleOverrides\";N;s:20:\"\0*\0settingsOverrides\";N;}}i:1;s:18:\"validateBoxElement\";}}}s:12:\"margin_right\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:18:\"validateBoxElement\";}}}s:13:\"margin_bottom\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Bottom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:18:\"validateBoxElement\";}}}s:11:\"margin_left\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:18:\"validateBoxElement\";}}}s:4:\"box2\";a:8:{s:5:\"#type\";s:9:\"container\";s:11:\"#attributes\";a:1:{s:5:\"class\";s:26:\"design-options__border-box\";}s:5:\"label\";a:3:{s:5:\"#type\";s:8:\"html_tag\";s:4:\"#tag\";s:5:\"label\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Border\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"border_top\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Top\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:18:\"validateBoxElement\";}}}s:12:\"border_right\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:18:\"validateBoxElement\";}}}s:13:\"border_bottom\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Bottom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:18:\"validateBoxElement\";}}}s:11:\"border_left\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:18:\"validateBoxElement\";}}}s:4:\"box3\";a:8:{s:5:\"#type\";s:9:\"container\";s:11:\"#attributes\";a:1:{s:5:\"class\";s:27:\"design-options__padding-box\";}s:5:\"label\";a:3:{s:5:\"#type\";s:8:\"html_tag\";s:4:\"#tag\";s:5:\"label\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Padding\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:11:\"padding_top\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Top\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:18:\"validateBoxElement\";}}}s:13:\"padding_right\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:18:\"validateBoxElement\";}}}s:14:\"padding_bottom\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Bottom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:18:\"validateBoxElement\";}}}s:12:\"padding_left\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";s:1:\"-\";}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:18:\"validateBoxElement\";}}}s:4:\"box4\";a:3:{s:5:\"#type\";s:9:\"container\";s:11:\"#attributes\";a:1:{s:5:\"class\";s:24:\"design-options__logo-box\";}s:5:\"label\";a:3:{s:5:\"#type\";s:8:\"html_tag\";s:4:\"#tag\";s:5:\"label\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"EPT\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Border Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Select Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:20:\"validateColorElement\";}}}s:12:\"border_style\";a:5:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Border Style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:12:{s:5:\"solid\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Solid\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"dashed\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Dashed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"dotted\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Dotted\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:4:\"none\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"None\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"hidden\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Hidden\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"initial\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Initial\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"inherit\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Inherit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"double\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Double\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"groove\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Groove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"ridge\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Ridge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"inset\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Inset\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"outset\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Outset\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:0:\"\";s:12:\"#description\";s:0:\"\";}s:13:\"border_radius\";a:4:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Border Radius\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:12:{s:4:\"none\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"None\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:3:\"1px\";s:3:\"1px\";s:3:\"2px\";s:3:\"2px\";s:3:\"3px\";s:3:\"3px\";s:3:\"4px\";s:3:\"4px\";s:3:\"5px\";s:3:\"5px\";s:4:\"10px\";s:4:\"10px\";s:4:\"15px\";s:4:\"15px\";s:4:\"20px\";s:4:\"20px\";s:4:\"25px\";s:4:\"25px\";s:4:\"30px\";s:4:\"30px\";s:4:\"35px\";s:4:\"35px\";}s:14:\"#default_value\";s:4:\"none\";}s:16:\"background_color\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Background Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Select Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:20:\"validateColorElement\";}}}s:16:\"background_media\";a:5:{s:5:\"#type\";s:13:\"media_library\";s:16:\"#allowed_bundles\";a:3:{i:0;s:5:\"image\";i:1;s:12:\"remote_video\";i:2;s:5:\"video\";}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Background Image/Video\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";N;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"Upload your image, video or Youtube video.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:25:\"background_video_settings\";a:17:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Background video options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:0;s:8:\"autoPlay\";a:3:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Autoplay\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;}s:12:\"showControls\";a:3:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Show controls\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:0;}s:4:\"mute\";a:3:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Mute\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;}s:7:\"startAt\";a:6:{s:5:\"#type\";s:6:\"number\";s:4:\"#min\";i:0;s:5:\"#step\";i:1;s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Start at\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:0;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:51:\"(number) Set the seconds the video should start at.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:7:\"opacity\";a:7:{s:5:\"#type\";s:6:\"number\";s:4:\"#min\";i:0;s:4:\"#max\";i:1;s:5:\"#step\";d:0.01;s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Opacity\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"0 to 1 (number) define the opacity of the video\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"addOverlay\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Add overlay\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Show or hide a overlay image over the video\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:12:\"overlayColor\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Overlay color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:7:\"#000000\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:65:\"RGB color for local videos, YouTube video uses image for overlay.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;r:568;i:1;s:20:\"validateColorElement\";}}}s:12:\"overlayAlpha\";a:7:{s:5:\"#type\";s:6:\"number\";s:4:\"#min\";i:0;s:4:\"#max\";i:1;s:5:\"#step\";d:0.01;s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Overlay opacity\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:3:\"0.3\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:55:\"For local videos, YouTube video uses image for overlay.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:4:\"loop\";a:3:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Loop\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;}s:15:\"stopMovieOnBlur\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Stop movie on blur\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:55:\"Activate the pause behavior when the window loose focus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"playOnlyIfVisible\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Play only if visible\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:0;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"Activate the pause behavior when the player is out of screen\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:10:\"coverImage\";a:5:{s:5:\"#type\";s:13:\"media_library\";s:16:\"#allowed_bundles\";a:1:{i:0;s:5:\"image\";}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Cover Image\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";N;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:117:\"Image used as background for the player if autoplay is set to false; if not set the player will show the first frame.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:11:\"useOnMobile\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Use on mobile\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"Define if the player should render on mobile devices\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:19:\"mobileFallbackImage\";a:5:{s:5:\"#type\";s:13:\"media_library\";s:16:\"#allowed_bundles\";a:1:{i:0;s:5:\"image\";}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Mobile fallback Image\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";N;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:110:\"Fallback image in case of background video on mobile devices and the “useOnMobile” option is set to false.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:25:\"background_image_settings\";a:6:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Background image options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:0;s:19:\"background_position\";a:4:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Background Image Position\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:11:{s:7:\"default\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Default\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"top left\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Top Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:3:\"top\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Top\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"top right\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Top Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"center left\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Center Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"center\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Center\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"center right\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Center Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"bottom left\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Bottom Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"bottom\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Bottom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"bottom right\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Bottom Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"custom\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Custom\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:7:\"default\";}s:26:\"background_position_custom\";a:4:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Custom Background Position\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:99:\"See more information about CSS background-position <a href=\":ept_core_configuration_form\">here</a>.\";s:12:\"\0*\0arguments\";a:1:{s:28:\":ept_core_configuration_form\";s:68:\"https://developer.mozilla.org/en-US/docs/Web/CSS/background-position\";}s:10:\"\0*\0options\";a:0:{}}}s:22:\"background_size_custom\";a:4:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Custom Background Size\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:95:\"See more information about CSS background-size <a href=\":ept_core_configuration_form\">here</a>.\";s:12:\"\0*\0arguments\";a:1:{s:28:\":ept_core_configuration_form\";s:64:\"https://developer.mozilla.org/en-US/docs/Web/CSS/background-size\";}s:10:\"\0*\0options\";a:0:{}}}}s:22:\"background_image_style\";a:4:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Background Image Style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:5:{s:7:\"default\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"No repeat\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"parallax\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Parallax\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"cover\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Cover\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"contain\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Contain\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"repeat\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Repeat\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:7:\"default\";}s:12:\"edge_to_edge\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Edge to Edge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:0;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:111:\"If checked, the styles will be applied to the entire screen, starting from the left and extending to the right.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:15:\"container_width\";a:5:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Container Max Width\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:8:{s:4:\"auto\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Auto (100%)\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"xxsmall\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"xxSmall\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"xsmall\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"xSmall\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"small\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Small\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"default\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Default\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"large\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Large\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"xlarge\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"xLarge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"xxlarge\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"xxLarge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:123:\"See <a href=\":ept_core_configuration_form\">EPT Core configuration form</a> to set Container Width and other default values.\";s:12:\"\0*\0arguments\";a:1:{s:28:\":ept_core_configuration_form\";s:30:\"/admin/config/content/ept-core\";}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:4:\"auto\";}}s:7:\"#weight\";i:-32;}s:13:\"title_options\";a:5:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Title options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#open\";b:0;s:13:\"title_wrapper\";a:4:{s:5:\"#type\";s:6:\"select\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Tag for Title wrapper\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"#options\";a:6:{s:4:\"none\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"None\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:2:\"h1\";s:2:\"H1\";s:2:\"h2\";s:2:\"H2\";s:2:\"h3\";s:2:\"H3\";s:2:\"h4\";s:2:\"H4\";s:2:\"h5\";s:2:\"H5\";}s:14:\"#default_value\";s:2:\"h2\";}s:10:\"strip_tags\";a:4:{s:5:\"#type\";s:8:\"checkbox\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Strip Tags for Title field\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";i:1;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:70:\"Strip tags in title field wrappers, except span, br, i, img, svg tags.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:12:\"link_options\";a:15:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Link options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"#weight\";i:0;s:15:\"open_in_new_tab\";a:3:{s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Open the link in a new tab\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#type\";s:8:\"checkbox\";s:14:\"#default_value\";N;}s:12:\"add_nofollow\";a:4:{s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"Add \"nofollow\" option to the link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#type\";s:8:\"checkbox\";s:14:\"#default_value\";N;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:132:\"The nofollow attribute is an HTML attribute in the link tag to tell search engines not to follow the link when crawling the web page\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:11:\"title_color\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Title Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:7:\"#ffffff\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Title Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;s:66:\"\\Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\";i:1;s:20:\"validateColorElement\";}}}s:16:\"background_color\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Background Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:7:\"#0d77b5\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Background Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;s:66:\"\\Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\";i:1;s:20:\"validateColorElement\";}}}s:19:\"custom_hover_colors\";a:5:{s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Custom hover colors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#type\";s:8:\"checkbox\";s:14:\"#default_value\";N;s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:29:\"ept-custom-hover-colors-field\";}}s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:96:\"If checked, you will be able to choose a color for both the \"Hover Title\" and \"Hover Background\"\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"hover_title_color\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Hover Title Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Hover Title Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:7:\"#states\";a:1:{s:9:\"invisible\";a:1:{s:36:\":input.ept-custom-hover-colors-field\";a:1:{s:7:\"checked\";b:0;}}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;s:66:\"\\Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\";i:1;s:20:\"validateColorElement\";}}}s:22:\"hover_background_color\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Hover Background Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Hover Background Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:7:\"#states\";a:1:{s:9:\"invisible\";a:1:{s:36:\":input.ept-custom-hover-colors-field\";a:1:{s:7:\"checked\";b:0;}}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;s:66:\"\\Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\";i:1;s:20:\"validateColorElement\";}}}s:9:\"alignment\";a:4:{s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Alignment\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#type\";s:6:\"radios\";s:8:\"#options\";a:3:{s:4:\"left\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"center\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Center\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"right\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:4:\"left\";}s:5:\"shape\";a:5:{s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Shape\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#type\";s:6:\"radios\";s:8:\"#options\";a:3:{s:6:\"square\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Square\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"round\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Round\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"circle\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Circle\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:6:\"square\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"<a href=\":shape_examples\">Click here</a> to view some examples of shapes\";s:12:\"\0*\0arguments\";a:1:{s:15:\":shape_examples\";s:65:\"/modules/contrib/ept_basic_button/images/help//shape-examples.png\";}s:10:\"\0*\0options\";a:0:{}}}s:4:\"size\";a:4:{s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Size\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#type\";s:6:\"radios\";s:8:\"#options\";a:3:{s:5:\"small\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Small\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"medium\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Medium\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"large\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Large\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:6:\"medium\";}s:9:\"stretched\";a:4:{s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Stretched\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#type\";s:8:\"checkbox\";s:14:\"#default_value\";N;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"Check if you want to stretch the width of the button\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:17:\"custom_class_name\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Custom class name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:0:\"\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:98:\"Customize the styling of this paragraph by adding CSS classes. Separate multiple classes by spaces\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;s:43:\"\\Drupal\\ept_core\\Helper\\EptGenericValidator\";i:1;s:20:\"validateClassElement\";}}}}s:13:\"button_styles\";a:4:{s:5:\"#type\";s:8:\"html_tag\";s:4:\"#tag\";s:2:\"h3\";s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Button styles:\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"#weight\";i:-1;}s:6:\"styles\";a:6:{s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Styles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#type\";s:6:\"radios\";s:8:\"#options\";a:2:{s:11:\"two_columns\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"2 Columns\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:10:\"one_column\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"One column\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:11:\"two_columns\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"Select predefined styles for Hero block.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"#weight\";i:-20;}s:7:\"overlay\";a:5:{s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Add overlay\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#type\";s:8:\"checkbox\";s:14:\"#default_value\";i:0;s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:46:\"Add overlay between background image and text.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"#weight\";i:-20;}s:13:\"overlay_color\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Overlay Color\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:7:\"#000000\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"Select RGB Color, for example #000000\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:7:\"#weight\";i:-20;}s:13:\"overlay_alpha\";a:8:{s:5:\"#type\";s:6:\"number\";s:4:\"#min\";i:0;s:4:\"#max\";i:1;s:5:\"#step\";d:0.01;s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Overlay opacity\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:3:\"0.6\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Opacity for overlay.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"#weight\";i:-20;}s:14:\"image_position\";a:6:{s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Image position\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#type\";s:6:\"radios\";s:8:\"#options\";a:2:{s:4:\"left\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Left\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"right\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Right\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:4:\"left\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"Image position in 2 columns layout.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"#weight\";i:-20;}s:18:\"image_order_mobile\";a:6:{s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Image position on mobile\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#type\";s:6:\"radios\";s:8:\"#options\";a:3:{s:11:\"image_first\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Image first\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:10:\"image_last\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Image last\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:10:\"hide_image\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Hide image\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:14:\"#default_value\";s:11:\"image_first\";s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:70:\"Image position in mobile version after transition from 2 to 1 columns.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"#weight\";i:-19;}s:17:\"mobile_breakpoint\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Mobile breakpoint\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"#default_value\";s:3:\"640\";s:11:\"#attributes\";a:1:{s:11:\"placeholder\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Enter breakpoint\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:12:\"#description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:61:\"Mobile breakpoint in pixels to switch 2 columns in one column\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"#weight\";i:-18;}s:13:\"link_options2\";a:15:{s:5:\"#type\";s:7:\"details\";s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Second Link options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"#weight\";i:3;s:15:\"open_in_new_tab\";a:3:{s:6:\"#title\";r:1396;s:5:\"#type\";s:8:\"checkbox\";s:14:\"#default_value\";N;}s:12:\"add_nofollow\";a:4:{s:6:\"#title\";r:1403;s:5:\"#type\";s:8:\"checkbox\";s:14:\"#default_value\";N;s:12:\"#description\";r:1409;}s:11:\"title_color\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";r:1415;s:14:\"#default_value\";N;s:11:\"#attributes\";a:1:{s:11:\"placeholder\";r:1421;}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;s:66:\"\\Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\";i:1;s:20:\"validateColorElement\";}}}s:16:\"background_color\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";r:1431;s:14:\"#default_value\";N;s:11:\"#attributes\";a:1:{s:11:\"placeholder\";r:1437;}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;s:66:\"\\Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\";i:1;s:20:\"validateColorElement\";}}}s:19:\"custom_hover_colors\";a:5:{s:6:\"#title\";r:1446;s:5:\"#type\";s:8:\"checkbox\";s:14:\"#default_value\";N;s:11:\"#attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:29:\"ept-custom-hover-colors-field\";}}s:12:\"#description\";r:1455;}s:17:\"hover_title_color\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";r:1461;s:14:\"#default_value\";N;s:11:\"#attributes\";a:1:{s:11:\"placeholder\";r:1467;}s:7:\"#states\";a:1:{s:9:\"invisible\";a:1:{s:36:\":input.ept-custom-hover-colors-field\";a:1:{s:7:\"checked\";b:0;}}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;s:66:\"\\Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\";i:1;s:20:\"validateColorElement\";}}}s:22:\"hover_background_color\";a:6:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";r:1481;s:14:\"#default_value\";N;s:11:\"#attributes\";a:1:{s:11:\"placeholder\";r:1487;}s:7:\"#states\";a:1:{s:9:\"invisible\";a:1:{s:36:\":input.ept-custom-hover-colors-field\";a:1:{s:7:\"checked\";b:0;}}}s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;s:66:\"\\Drupal\\ept_core\\Plugin\\Field\\FieldWidget\\EptSettingsDefaultWidget\";i:1;s:20:\"validateColorElement\";}}}s:9:\"alignment\";a:4:{s:6:\"#title\";r:1500;s:5:\"#type\";s:6:\"radios\";s:8:\"#options\";a:3:{s:4:\"left\";r:1506;s:6:\"center\";r:1510;s:5:\"right\";r:1514;}s:14:\"#default_value\";N;}s:5:\"shape\";a:5:{s:6:\"#title\";r:1520;s:5:\"#type\";s:6:\"radios\";s:8:\"#options\";a:3:{s:6:\"square\";r:1526;s:5:\"round\";r:1530;s:6:\"circle\";r:1534;}s:14:\"#default_value\";N;s:12:\"#description\";r:1539;}s:4:\"size\";a:4:{s:6:\"#title\";r:1545;s:5:\"#type\";s:6:\"radios\";s:8:\"#options\";a:3:{s:5:\"small\";r:1551;s:6:\"medium\";r:1555;s:5:\"large\";r:1559;}s:14:\"#default_value\";N;}s:9:\"stretched\";a:4:{s:6:\"#title\";r:1565;s:5:\"#type\";s:8:\"checkbox\";s:14:\"#default_value\";N;s:12:\"#description\";r:1571;}s:17:\"custom_class_name\";a:5:{s:5:\"#type\";s:9:\"textfield\";s:6:\"#title\";r:1577;s:14:\"#default_value\";s:0:\"\";s:12:\"#description\";r:1582;s:17:\"#element_validate\";a:1:{i:0;a:2:{i:0;s:43:\"\\Drupal\\ept_core\\Helper\\EptGenericValidator\";i:1;s:20:\"validateClassElement\";}}}}}s:12:\"ebt_settings\";a:1:{s:13:\"link_options2\";a:1:{s:17:\"custom_class_name\";a:1:{s:14:\"#default_value\";N;}}}}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:18:\"field_ept_settings\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:0;s:6:\"#title\";s:8:\"Settings\";s:12:\"#description\";s:0:\"\";s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:62:\"Drupal\\ept_hero\\Plugin\\Field\\FieldWidget\\EptSettingsHeroWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:4;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:56:\"config:field.field.paragraph.ept_hero.field_ept_settings\";i:1;s:49:\"config:field.storage.paragraph.field_ept_settings\";}s:7:\"max-age\";i:-1;}}s:14:\"field_ept_text\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:22:\"field_ept_text_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:21:\"field--type-text-long\";i:1;s:26:\"field--name-field-ept-text\";i:2;s:27:\"field--widget-text-textarea\";}}s:6:\"widget\";a:13:{i:0;a:14:{s:6:\"#title\";s:4:\"Text\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";s:0:\"\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:0;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:5:\"#type\";s:11:\"text_format\";s:14:\"#default_value\";N;s:5:\"#rows\";i:5;s:12:\"#placeholder\";s:0:\"\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:2:{i:0;s:12:\"js-text-full\";i:1;s:9:\"text-full\";}s:37:\"data-media-embed-host-entity-langcode\";s:2:\"en\";}s:7:\"#format\";N;s:10:\"#base_type\";s:8:\"textarea\";}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:14:\"field_ept_text\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:0;s:6:\"#title\";s:4:\"Text\";s:12:\"#description\";s:0:\"\";s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:51:\"Drupal\\text\\Plugin\\Field\\FieldWidget\\TextareaWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:14:\"field_ept_text\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:3;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:52:\"config:field.field.paragraph.ept_hero.field_ept_text\";i:1;s:45:\"config:field.storage.paragraph.field_ept_text\";}s:7:\"max-age\";i:-1;}}s:15:\"field_ept_title\";a:7:{s:5:\"#type\";s:9:\"container\";s:8:\"#parents\";a:1:{i:0;s:23:\"field_ept_title_wrapper\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:3:{i:0;s:21:\"field--type-text-long\";i:1;s:27:\"field--name-field-ept-title\";i:2;s:27:\"field--widget-text-textarea\";}}s:6:\"widget\";a:13:{i:0;a:14:{s:6:\"#title\";s:5:\"Title\";s:14:\"#title_display\";s:6:\"before\";s:12:\"#description\";s:0:\"\";s:14:\"#field_parents\";a:0:{}s:9:\"#required\";b:0;s:6:\"#delta\";i:0;s:7:\"#weight\";i:0;s:5:\"#type\";s:11:\"text_format\";s:14:\"#default_value\";N;s:5:\"#rows\";i:2;s:12:\"#placeholder\";s:0:\"\";s:11:\"#attributes\";a:2:{s:5:\"class\";a:2:{i:0;s:12:\"js-text-full\";i:1;s:9:\"text-full\";}s:37:\"data-media-embed-host-entity-langcode\";s:2:\"en\";}s:7:\"#format\";N;s:10:\"#base_type\";s:8:\"textarea\";}s:6:\"#theme\";s:25:\"field_multiple_value_form\";s:11:\"#field_name\";s:15:\"field_ept_title\";s:12:\"#cardinality\";i:1;s:21:\"#cardinality_multiple\";b:0;s:9:\"#required\";b:0;s:6:\"#title\";s:5:\"Title\";s:12:\"#description\";s:0:\"\";s:10:\"#max_delta\";i:0;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;s:51:\"Drupal\\text\\Plugin\\Field\\FieldWidget\\TextareaWidget\";i:1;s:10:\"afterBuild\";}}s:14:\"#field_parents\";a:0:{}s:8:\"#parents\";a:1:{i:0;s:15:\"field_ept_title\";}s:5:\"#tree\";b:1;}s:7:\"#access\";b:1;s:7:\"#weight\";i:1;s:6:\"#cache\";a:3:{s:8:\"contexts\";a:0:{}s:4:\"tags\";a:2:{i:0;s:53:\"config:field.field.paragraph.ept_hero.field_ept_title\";i:1;s:46:\"config:field.storage.paragraph.field_ept_title\";}s:7:\"max-age\";i:-1;}}s:6:\"#cache\";a:3:{s:8:\"contexts\";a:1:{i:0;s:24:\"user.roles:authenticated\";}s:4:\"tags\";a:2:{i:0;s:58:\"config:core.entity_form_display.paragraph.ept_hero.default\";i:1;s:42:\"CACHE_MISS_IF_UNCACHEABLE_HTTP_METHOD:form\";}s:7:\"max-age\";i:-1;}s:8:\"#process\";a:2:{i:0;a:2:{i:0;O:43:\"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay\":16:{s:7:\"\0*\0uuid\";s:36:\"be53fd67-518c-4b3c-ac43-3b2c15a8d954\";s:11:\"\0*\0langcode\";s:2:\"en\";s:9:\"\0*\0status\";b:1;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_column_image\";i:1;s:50:\"field.field.paragraph.ept_hero.field_ept_hero_link\";i:2;s:57:\"field.field.paragraph.ept_hero.field_ept_hero_second_link\";i:3;s:58:\"field.field.paragraph.ept_hero.field_ept_hero_title_prefix\";i:4;s:49:\"field.field.paragraph.ept_hero.field_ept_settings\";i:5;s:45:\"field.field.paragraph.ept_hero.field_ept_text\";i:6;s:46:\"field.field.paragraph.ept_hero.field_ept_title\";i:7;s:35:\"paragraphs.paragraphs_type.ept_hero\";}s:6:\"module\";a:5:{i:0;s:8:\"ept_hero\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:23:\"\0*\0third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:6:{i:0;s:15:\"field_ept_title\";i:1;s:27:\"field_ept_hero_title_prefix\";i:2;s:14:\"field_ept_text\";i:3;s:27:\"field_ept_hero_column_image\";i:4;s:19:\"field_ept_hero_link\";i:5;s:26:\"field_ept_hero_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jU5fU7CphqYF6ZSn4c9q-QZ0_XHfDeFV936TKmTKPIM\";}s:5:\"\0*\0id\";s:26:\"paragraph.ept_hero.default\";s:19:\"\0*\0targetEntityType\";s:9:\"paragraph\";s:9:\"\0*\0bundle\";s:8:\"ept_hero\";s:7:\"\0*\0mode\";s:7:\"default\";s:10:\"\0*\0content\";a:7:{s:27:\"field_ept_hero_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ept_hero_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ept_hero_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ept_hero_title_prefix\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ept_settings\";a:5:{s:4:\"type\";s:17:\"ept_settings_hero\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_ept_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ept_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:9:\"\0*\0hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}s:15:\"\0*\0entityTypeId\";s:19:\"entity_form_display\";s:15:\"\0*\0enforceIsNew\";N;s:15:\"_serializedKeys\";a:16:{i:0;s:4:\"uuid\";i:1;s:8:\"langcode\";i:2;s:6:\"status\";i:3;s:12:\"dependencies\";i:4;s:20:\"third_party_settings\";i:5;s:5:\"_core\";i:6;s:2:\"id\";i:7;s:16:\"targetEntityType\";i:8;s:6:\"bundle\";i:9;s:4:\"mode\";i:10;s:7:\"content\";i:11;s:6:\"hidden\";i:12;s:12:\"entityTypeId\";i:13;s:12:\"enforceIsNew\";i:14;s:15:\"_serializedKeys\";i:15;s:11:\"initialized\";}s:14:\"\0*\0initialized\";b:1;}i:1;s:11:\"processForm\";}i:1;a:2:{i:0;s:34:\"Drupal\\field_group\\FormatterHelper\";i:1;s:11:\"formProcess\";}}s:6:\"#title\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Create new @type\";s:12:\"\0*\0arguments\";a:1:{s:5:\"@type\";s:8:\"EPT Hero\";}s:10:\"\0*\0options\";a:0:{}}s:10:\"#paragraph\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:23:\"_layoutParagraphsLayout\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"64\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1729065353\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729064448\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729065353\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"569\";}i:1;a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"570\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:2:\"19\";s:8:\"revision\";s:2:\"64\";s:4:\"uuid\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"64\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:2:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:2152;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:2151;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"569\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":9:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2500;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_block\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"39\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"569\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_block\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729065292\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:21:\"field_ept_block_block\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:9:\"plugin_id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:8:\"settings\";a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:14:\"_referringItem\";r:2500;s:23:\"_layoutParagraphsLayout\";r:2150;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_block\";s:2:\"id\";s:2:\"39\";s:4:\"uuid\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";s:8:\"revision\";s:3:\"569\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"569\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}s:5:\"\0*\0id\";N;s:14:\"\0*\0revision_id\";N;}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:2501;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:2151;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"570\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":9:{s:13:\"\0*\0definition\";r:2642;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2847;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_views\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"38\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"570\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_views\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729064495\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:20:\"field_ept_views_view\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:9:\"target_id\";s:10:\"what_s_new\";s:10:\"display_id\";s:7:\"block_1\";s:4:\"data\";s:95:\"a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}\";}}}s:14:\"_referringItem\";r:2847;s:23:\"_layoutParagraphsLayout\";r:2150;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_views\";s:2:\"id\";s:2:\"38\";s:4:\"uuid\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";s:8:\"revision\";s:3:\"570\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"570\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}s:5:\"\0*\0id\";N;s:14:\"\0*\0revision_id\";N;}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"1f9e65806072427ebb23a82a18f9f122\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"93872b1e-0586-4e38-b8a5-5edca3c418e7\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:8:\"ept_hero\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729066868;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:0:{}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:0:{}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:27:\"field_ept_hero_column_image\";a:1:{s:9:\"x-default\";a:0:{}}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:3:\"uri\";N;}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:3:\"uri\";N;}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:0:{}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:2:{s:6:\"bundle\";s:8:\"ept_hero\";s:8:\"revision\";N;}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:0;s:20:\"\0*\0stringTranslation\";N;}s:8:\"#display\";r:1976;s:5:\"#tree\";b:1;s:12:\"#after_build\";a:1:{i:0;a:2:{i:0;O:49:\"Drupal\\layout_paragraphs\\Form\\InsertComponentForm\":19:{s:15:\"\0*\0requestStack\";N;s:13:\"\0*\0routeMatch\";N;s:14:\"\0*\0_serviceIds\";a:8:{s:13:\"configFactory\";s:14:\"config.factory\";s:17:\"stringTranslation\";s:18:\"string_translation\";s:9:\"tempstore\";s:38:\"layout_paragraphs.tempstore_repository\";s:17:\"entityTypeManager\";s:19:\"entity_type.manager\";s:19:\"layoutPluginManager\";s:26:\"plugin.manager.core.layout\";s:13:\"moduleHandler\";s:14:\"module_handler\";s:16:\"entityRepository\";s:17:\"entity.repository\";s:15:\"eventDispatcher\";s:16:\"event_dispatcher\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:16:\"\0*\0loggerFactory\";N;s:12:\"\0*\0messenger\";N;s:22:\"\0*\0redirectDestination\";N;s:16:\"\0*\0paragraphType\";O:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\":23:{s:15:\"\0*\0entityTypeId\";s:15:\"paragraphs_type\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:8:\"ept_hero\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ced6180f-b154-47b8-a7b7-61647c71db48\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kps1UJbRPEF2GuSjDQDJFWWG5EZ6qTHII92BJxLlwTk\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:2:\"id\";s:8:\"ept_hero\";s:5:\"label\";s:8:\"EPT Hero\";s:11:\"description\";s:36:\"Extra Paragraph Type (EPT): EPT Hero\";s:12:\"\0*\0icon_uuid\";N;s:15:\"\0*\0icon_default\";N;s:16:\"behavior_plugins\";a:1:{s:17:\"layout_paragraphs\";a:1:{s:17:\"available_layouts\";a:0:{}}}}s:12:\"\0*\0paragraph\";r:2140;s:11:\"\0*\0formMode\";s:7:\"default\";s:25:\"\0*\0layoutParagraphsLayout\";r:2150;s:33:\"\0*\0originalLayoutParagraphsLayout\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";r:2152;s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";r:2374;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:2:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:2501;s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:3186;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"569\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":9:{s:13:\"\0*\0definition\";r:2642;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:3195;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";r:2683;s:5:\"\0*\0id\";N;s:14:\"\0*\0revision_id\";N;}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:2501;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:3186;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"570\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":9:{s:13:\"\0*\0definition\";r:2642;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:3218;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";r:2867;s:5:\"\0*\0id\";N;s:14:\"\0*\0revision_id\";N;}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";N;s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:14:\"\0*\0domSelector\";s:50:\"[data-uuid=\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\"]\";s:20:\"\0*\0paragraphDefaults\";a:0:{}s:9:\"\0*\0method\";s:6:\"before\";s:13:\"\0*\0parentUuid\";s:0:\"\";s:9:\"\0*\0region\";s:0:\"\";s:12:\"\0*\0placement\";s:6:\"before\";s:14:\"\0*\0siblingUuid\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";}i:1;s:10:\"afterBuild\";}}s:9:\"#attached\";a:2:{s:7:\"library\";a:1:{i:0;s:32:\"layout_paragraphs/component_form\";}s:12:\"placeholders\";a:1:{s:55:\"form_action_p_pvdeGsVG5zNF_XLGPTvYSKCf43t8qZYSwcfZl2uzM\";a:1:{s:13:\"#lazy_builder\";a:2:{i:0;s:40:\"form_builder:renderPlaceholderFormAction\";i:1;a:0:{}}}}}s:7:\"actions\";a:4:{s:7:\"#weight\";i:100;s:5:\"#type\";s:7:\"actions\";s:6:\"submit\";a:5:{s:5:\"#type\";s:6:\"submit\";s:7:\"#weight\";i:100;s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Save\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:5:\"#ajax\";a:2:{s:8:\"callback\";s:12:\"::ajaxSubmit\";s:8:\"progress\";s:4:\"none\";}s:11:\"#attributes\";a:2:{s:5:\"class\";a:2:{i:0;s:13:\"lpb-btn--save\";i:1;s:15:\"button--primary\";}s:20:\"data-disable-refocus\";s:4:\"true\";}}s:6:\"cancel\";a:6:{s:5:\"#type\";s:6:\"button\";s:7:\"#weight\";i:200;s:6:\"#value\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Cancel\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:24:\"#limit_validation_errors\";a:0:{}s:5:\"#ajax\";a:2:{s:8:\"callback\";s:8:\"::cancel\";s:8:\"progress\";s:4:\"none\";}s:11:\"#attributes\";a:1:{s:5:\"class\";a:2:{i:0;s:13:\"dialog-cancel\";i:1;s:15:\"lpb-btn--cancel\";}}}}s:12:\"#fieldgroups\";a:3:{s:10:\"group_tabs\";O:8:\"stdClass\":12:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}s:10:\"group_name\";s:10:\"group_tabs\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:7:\"context\";s:4:\"form\";s:4:\"mode\";s:7:\"default\";}s:13:\"group_content\";O:8:\"stdClass\":12:{s:8:\"children\";a:6:{i:0;s:15:\"field_ept_title\";i:1;s:27:\"field_ept_hero_title_prefix\";i:2;s:14:\"field_ept_text\";i:3;s:27:\"field_ept_hero_column_image\";i:4;s:19:\"field_ept_hero_link\";i:5;s:26:\"field_ept_hero_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}s:10:\"group_name\";s:13:\"group_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:7:\"context\";s:4:\"form\";s:4:\"mode\";s:7:\"default\";}s:14:\"group_settings\";O:8:\"stdClass\":12:{s:8:\"children\";a:1:{i:0;s:18:\"field_ept_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}s:10:\"group_name\";s:14:\"group_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:8:\"ept_hero\";s:7:\"context\";s:4:\"form\";s:4:\"mode\";s:7:\"default\";}}s:15:\"#group_children\";a:9:{s:13:\"group_content\";s:10:\"group_tabs\";s:14:\"group_settings\";s:10:\"group_tabs\";s:15:\"field_ept_title\";s:13:\"group_content\";s:27:\"field_ept_hero_title_prefix\";s:13:\"group_content\";s:14:\"field_ept_text\";s:13:\"group_content\";s:27:\"field_ept_hero_column_image\";s:13:\"group_content\";s:19:\"field_ept_hero_link\";s:13:\"group_content\";s:26:\"field_ept_hero_second_link\";s:13:\"group_content\";s:18:\"field_ept_settings\";s:14:\"group_settings\";}s:12:\"#entity_type\";s:9:\"paragraph\";s:8:\"#form_id\";s:32:\"layout_paragraphs_component_form\";s:9:\"#build_id\";s:48:\"form-DS3On2XI3AuPlhswpYnhJKxvNUtU5NGdLm1lU5WcFyg\";s:5:\"#type\";s:4:\"form\";s:7:\"#action\";s:55:\"form_action_p_pvdeGsVG5zNF_XLGPTvYSKCf43t8qZYSwcfZl2uzM\";s:13:\"form_build_id\";a:5:{s:5:\"#type\";s:6:\"hidden\";s:6:\"#value\";s:48:\"form-DS3On2XI3AuPlhswpYnhJKxvNUtU5NGdLm1lU5WcFyg\";s:3:\"#id\";s:48:\"form-DS3On2XI3AuPlhswpYnhJKxvNUtU5NGdLm1lU5WcFyg\";s:5:\"#name\";s:13:\"form_build_id\";s:8:\"#parents\";a:1:{i:0;s:13:\"form_build_id\";}}s:6:\"#token\";s:66:\"form_token_placeholder_s2YfxV6fJyGjndqPaiT_BWYnNHuH1rQKMkaXixiHD6k\";s:10:\"form_token\";a:6:{s:3:\"#id\";s:61:\"edit-layout-paragraphs-component-form-form-token--dAC9W1HikUY\";s:5:\"#type\";s:5:\"token\";s:14:\"#default_value\";s:66:\"form_token_placeholder_s2YfxV6fJyGjndqPaiT_BWYnNHuH1rQKMkaXixiHD6k\";s:8:\"#parents\";a:1:{i:0;s:10:\"form_token\";}s:9:\"#attached\";a:1:{s:12:\"placeholders\";a:1:{s:66:\"form_token_placeholder_s2YfxV6fJyGjndqPaiT_BWYnNHuH1rQKMkaXixiHD6k\";a:1:{s:13:\"#lazy_builder\";a:2:{i:0;s:39:\"form_builder:renderFormTokenPlaceholder\";i:1;a:1:{i:0;s:66:\"form_token_placeholder_s2YfxV6fJyGjndqPaiT_BWYnNHuH1rQKMkaXixiHD6k\";}}}}}s:6:\"#cache\";a:1:{s:7:\"max-age\";i:0;}}s:7:\"form_id\";a:4:{s:5:\"#type\";s:6:\"hidden\";s:6:\"#value\";s:32:\"layout_paragraphs_component_form\";s:3:\"#id\";s:50:\"edit-layout-paragraphs-component-form--rrbWr24BJ7M\";s:8:\"#parents\";a:1:{i:0;s:7:\"form_id\";}}s:3:\"#id\";s:45:\"layout-paragraphs-component-form--2BsrXrOOGVA\";s:7:\"#method\";s:4:\"post\";s:15:\"#theme_wrappers\";a:1:{i:0;s:4:\"form\";}s:16:\"#defaults_loaded\";b:1;s:9:\"#validate\";a:1:{i:0;s:14:\"::validateForm\";}s:7:\"#submit\";a:1:{i:0;s:12:\"::submitForm\";}s:6:\"#theme\";a:1:{i:0;s:32:\"layout_paragraphs_component_form\";}s:12:\"#cache_token\";s:43:\"6hnLZfh-UY1scD5xwp6fsiJvmCOR_S-6jvUzbpEr7oU\";}',1729088483),('form_state','form-3c1tr2WeSa2XEkgXimvXkTyzNRa7bvUfgzN-hE6Xd68',_binary 'a:9:{s:10:\"build_info\";a:4:{s:4:\"args\";a:7:{i:0;O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"63\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1729064555\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729064448\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729064555\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"568\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:2:\"19\";s:8:\"revision\";s:2:\"63\";s:4:\"uuid\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"63\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:2:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:6;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:5;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:351;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_block\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:23:\"_layoutParagraphsLayout\";r:4;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_block\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729065292;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"19\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:21:\"field_ept_block_block\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:9:\"plugin_id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:8:\"settings\";a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:0:{}}s:14:\"_referringItem\";r:351;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:2:{s:6:\"bundle\";s:9:\"ept_block\";s:8:\"revision\";N;}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:6;}s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:5;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"568\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:706;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_views\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"38\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"568\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_views\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729064495\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:20:\"field_ept_views_view\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:9:\"target_id\";s:10:\"what_s_new\";s:10:\"display_id\";s:7:\"block_1\";s:4:\"data\";s:95:\"a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}\";}}}s:14:\"_referringItem\";r:706;s:23:\"_layoutParagraphsLayout\";r:4;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_views\";s:2:\"id\";s:2:\"38\";s:4:\"uuid\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";s:8:\"revision\";s:3:\"568\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"568\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"1577eb324628e7a33f238d1dd2ccd784\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}i:1;O:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\":23:{s:15:\"\0*\0entityTypeId\";s:15:\"paragraphs_type\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:9:\"ept_block\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"698fe7c4-0789-4365-b3ce-d8bbd2d7d879\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hSup62OW-6glALkcPyijfub_HXz0FNzEQuWRhyhtdXk\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:2:\"id\";s:9:\"ept_block\";s:5:\"label\";s:9:\"EPT Block\";s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Block\";s:12:\"\0*\0icon_uuid\";N;s:15:\"\0*\0icon_default\";N;s:16:\"behavior_plugins\";a:0:{}}i:2;s:0:\"\";i:3;s:0:\"\";i:4;s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";i:5;s:6:\"before\";i:6;a:0:{}}s:5:\"files\";a:0:{}s:15:\"callback_object\";O:49:\"Drupal\\layout_paragraphs\\Form\\InsertComponentForm\":19:{s:15:\"\0*\0requestStack\";N;s:13:\"\0*\0routeMatch\";N;s:14:\"\0*\0_serviceIds\";a:8:{s:13:\"configFactory\";s:14:\"config.factory\";s:17:\"stringTranslation\";s:18:\"string_translation\";s:9:\"tempstore\";s:38:\"layout_paragraphs.tempstore_repository\";s:17:\"entityTypeManager\";s:19:\"entity_type.manager\";s:19:\"layoutPluginManager\";s:26:\"plugin.manager.core.layout\";s:13:\"moduleHandler\";s:14:\"module_handler\";s:16:\"entityRepository\";s:17:\"entity.repository\";s:15:\"eventDispatcher\";s:16:\"event_dispatcher\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:16:\"\0*\0loggerFactory\";N;s:12:\"\0*\0messenger\";N;s:22:\"\0*\0redirectDestination\";N;s:16:\"\0*\0paragraphType\";O:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\":23:{s:15:\"\0*\0entityTypeId\";s:15:\"paragraphs_type\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:9:\"ept_block\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"698fe7c4-0789-4365-b3ce-d8bbd2d7d879\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hSup62OW-6glALkcPyijfub_HXz0FNzEQuWRhyhtdXk\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:2:\"id\";s:9:\"ept_block\";s:5:\"label\";s:9:\"EPT Block\";s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Block\";s:12:\"\0*\0icon_uuid\";N;s:15:\"\0*\0icon_default\";N;s:16:\"behavior_plugins\";a:1:{s:17:\"layout_paragraphs\";a:1:{s:17:\"available_layouts\";a:0:{}}}}s:12:\"\0*\0paragraph\";r:547;s:11:\"\0*\0formMode\";s:7:\"default\";s:25:\"\0*\0layoutParagraphsLayout\";r:4;s:33:\"\0*\0originalLayoutParagraphsLayout\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";r:6;s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";r:228;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:1:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:352;s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:1138;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"568\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":9:{s:13:\"\0*\0definition\";r:493;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1147;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_views\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";r:902;}s:5:\"\0*\0id\";N;s:14:\"\0*\0revision_id\";N;}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";N;s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:14:\"\0*\0domSelector\";s:50:\"[data-uuid=\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\"]\";s:20:\"\0*\0paragraphDefaults\";a:0:{}s:9:\"\0*\0method\";s:6:\"before\";s:13:\"\0*\0parentUuid\";s:0:\"\";s:9:\"\0*\0region\";s:0:\"\";s:12:\"\0*\0placement\";s:6:\"before\";s:14:\"\0*\0siblingUuid\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}s:7:\"form_id\";s:32:\"layout_paragraphs_component_form\";}s:8:\"response\";N;s:10:\"programmed\";b:0;s:30:\"programmed_bypass_access_check\";b:1;s:13:\"process_input\";b:1;s:16:\"has_file_element\";N;s:7:\"storage\";a:3:{s:23:\"entity_default_langcode\";s:2:\"en\";s:8:\"langcode\";s:2:\"en\";s:13:\"field_storage\";a:1:{s:8:\"#parents\";a:1:{s:7:\"#fields\";a:4:{s:21:\"field_ept_block_block\";a:3:{s:11:\"items_count\";i:0;s:13:\"array_parents\";a:2:{i:0;s:21:\"field_ept_block_block\";i:1;s:6:\"widget\";}s:15:\"original_deltas\";a:1:{i:0;i:0;}}s:18:\"field_ept_settings\";a:3:{s:11:\"items_count\";i:1;s:13:\"array_parents\";a:2:{i:0;s:18:\"field_ept_settings\";i:1;s:6:\"widget\";}s:15:\"original_deltas\";a:1:{i:0;i:0;}}s:14:\"field_ept_text\";a:2:{s:11:\"items_count\";i:0;s:13:\"array_parents\";a:2:{i:0;s:14:\"field_ept_text\";i:1;s:6:\"widget\";}}s:15:\"field_ept_title\";a:2:{s:11:\"items_count\";i:0;s:13:\"array_parents\";a:2:{i:0;s:15:\"field_ept_title\";i:1;s:6:\"widget\";}}}}}}s:5:\"cache\";b:1;s:8:\"no_cache\";N;}',1729086937),('form_state','form-CbEyRCXFiwYhjJqVDd9JbESXcfdYqS_x2x6Y1H_CfMc',_binary 'a:9:{s:10:\"build_info\";a:4:{s:4:\"args\";a:7:{i:0;O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:3:\"vid\";a:1:{s:9:\"x-default\";a:0:{}}s:3:\"nid\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"523c8068-709e-45c1-81d6-c1a12a1eb399\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:4:\"page\";}}}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729064448;}}}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";a:0:{}}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:3:\"uid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:1:\"1\";}}}s:5:\"title\";a:1:{s:9:\"x-default\";a:0:{}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729064448;}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729064448;}}}s:7:\"promote\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:6:\"sticky\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"path\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:8:\"langcode\";s:2:\"en\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:3:{s:6:\"bundle\";s:4:\"page\";s:8:\"revision\";N;s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:1:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:6;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:5;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:351;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_views\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:23:\"_layoutParagraphsLayout\";r:4;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_views\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729064495;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_views_view\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:9:\"target_id\";s:10:\"what_s_new\";s:10:\"display_id\";s:7:\"block_1\";s:4:\"data\";s:95:\"a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:2:{s:6:\"bundle\";s:9:\"ept_views\";s:8:\"revision\";N;}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:0:{}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"2d173e6416d251d4c425343bb4686802\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}i:1;O:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\":23:{s:15:\"\0*\0entityTypeId\";s:15:\"paragraphs_type\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:9:\"ept_views\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7ac88ec9-7da9-488c-ac70-492b5bcfde08\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JfY6zZuA9cpemb4U-YVMX2rzmT1pm_Pr1YpT7xaSxeA\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:2:\"id\";s:9:\"ept_views\";s:5:\"label\";s:9:\"EPT Views\";s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Views\";s:12:\"\0*\0icon_uuid\";N;s:15:\"\0*\0icon_default\";N;s:16:\"behavior_plugins\";a:0:{}}i:2;s:0:\"\";i:3;s:0:\"\";i:4;s:0:\"\";i:5;s:0:\"\";i:6;a:0:{}}s:5:\"files\";a:0:{}s:15:\"callback_object\";O:49:\"Drupal\\layout_paragraphs\\Form\\InsertComponentForm\":19:{s:15:\"\0*\0requestStack\";N;s:13:\"\0*\0routeMatch\";N;s:14:\"\0*\0_serviceIds\";a:8:{s:13:\"configFactory\";s:14:\"config.factory\";s:17:\"stringTranslation\";s:18:\"string_translation\";s:9:\"tempstore\";s:38:\"layout_paragraphs.tempstore_repository\";s:17:\"entityTypeManager\";s:19:\"entity_type.manager\";s:19:\"layoutPluginManager\";s:26:\"plugin.manager.core.layout\";s:13:\"moduleHandler\";s:14:\"module_handler\";s:16:\"entityRepository\";s:17:\"entity.repository\";s:15:\"eventDispatcher\";s:16:\"event_dispatcher\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:16:\"\0*\0loggerFactory\";N;s:12:\"\0*\0messenger\";N;s:22:\"\0*\0redirectDestination\";N;s:16:\"\0*\0paragraphType\";O:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\":23:{s:15:\"\0*\0entityTypeId\";s:15:\"paragraphs_type\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:9:\"ept_views\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7ac88ec9-7da9-488c-ac70-492b5bcfde08\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JfY6zZuA9cpemb4U-YVMX2rzmT1pm_Pr1YpT7xaSxeA\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:2:\"id\";s:9:\"ept_views\";s:5:\"label\";s:9:\"EPT Views\";s:11:\"description\";s:33:\"Extra Paragraph Type (EPT): Views\";s:12:\"\0*\0icon_uuid\";N;s:15:\"\0*\0icon_default\";N;s:16:\"behavior_plugins\";a:1:{s:17:\"layout_paragraphs\";a:1:{s:17:\"available_layouts\";a:0:{}}}}s:12:\"\0*\0paragraph\";r:547;s:11:\"\0*\0formMode\";s:7:\"default\";s:25:\"\0*\0layoutParagraphsLayout\";r:4;s:33:\"\0*\0originalLayoutParagraphsLayout\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";r:6;s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";r:228;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:0:{}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";N;s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:14:\"\0*\0domSelector\";s:48:\"[data-lpb-id=\"2d173e6416d251d4c425343bb4686802\"]\";s:20:\"\0*\0paragraphDefaults\";a:0:{}s:9:\"\0*\0method\";s:7:\"prepend\";s:13:\"\0*\0parentUuid\";s:0:\"\";s:9:\"\0*\0region\";s:0:\"\";s:12:\"\0*\0placement\";s:0:\"\";s:14:\"\0*\0siblingUuid\";s:0:\"\";}s:7:\"form_id\";s:32:\"layout_paragraphs_component_form\";}s:8:\"response\";N;s:10:\"programmed\";b:0;s:30:\"programmed_bypass_access_check\";b:1;s:13:\"process_input\";b:1;s:16:\"has_file_element\";N;s:7:\"storage\";a:3:{s:23:\"entity_default_langcode\";s:2:\"en\";s:8:\"langcode\";s:2:\"en\";s:13:\"field_storage\";a:1:{s:8:\"#parents\";a:1:{s:7:\"#fields\";a:4:{s:18:\"field_ept_settings\";a:3:{s:11:\"items_count\";i:1;s:13:\"array_parents\";a:2:{i:0;s:18:\"field_ept_settings\";i:1;s:6:\"widget\";}s:15:\"original_deltas\";a:1:{i:0;i:0;}}s:14:\"field_ept_text\";a:2:{s:11:\"items_count\";i:0;s:13:\"array_parents\";a:2:{i:0;s:14:\"field_ept_text\";i:1;s:6:\"widget\";}}s:15:\"field_ept_title\";a:2:{s:11:\"items_count\";i:0;s:13:\"array_parents\";a:2:{i:0;s:15:\"field_ept_title\";i:1;s:6:\"widget\";}}s:20:\"field_ept_views_view\";a:3:{s:11:\"items_count\";i:0;s:13:\"array_parents\";a:2:{i:0;s:20:\"field_ept_views_view\";i:1;s:6:\"widget\";}s:15:\"original_deltas\";a:1:{i:0;i:0;}}}}}}s:5:\"cache\";b:1;s:8:\"no_cache\";N;}',1729086119),('form_state','form-DS3On2XI3AuPlhswpYnhJKxvNUtU5NGdLm1lU5WcFyg',_binary 'a:9:{s:10:\"build_info\";a:4:{s:4:\"args\";a:7:{i:0;O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"64\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1729065353\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729064448\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729065353\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"569\";}i:1;a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"570\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:2:\"19\";s:8:\"revision\";s:2:\"64\";s:4:\"uuid\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"64\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:6;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:5;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:354;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:23:\"_layoutParagraphsLayout\";r:4;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"93872b1e-0586-4e38-b8a5-5edca3c418e7\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:8:\"ept_hero\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729066868;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"19\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:27:\"field_ept_hero_column_image\";a:1:{s:9:\"x-default\";a:0:{}}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:0:{}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:19:\"<p>Listing Page</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Stay tuned!</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:17:\"<p>What\'s New</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:354;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:2:{s:6:\"bundle\";s:8:\"ept_hero\";s:8:\"revision\";N;}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:355;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:5;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"569\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:496;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:761;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_block\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"39\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"569\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_block\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729065292\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:21:\"field_ept_block_block\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:9:\"plugin_id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:8:\"settings\";a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:14:\"_referringItem\";r:761;s:23:\"_layoutParagraphsLayout\";r:4;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_block\";s:2:\"id\";s:2:\"39\";s:4:\"uuid\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";s:8:\"revision\";s:3:\"569\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"569\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:6;}s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:5;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"570\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:943;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_views\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"38\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"570\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_views\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729064495\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:20:\"field_ept_views_view\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:9:\"target_id\";s:10:\"what_s_new\";s:10:\"display_id\";s:7:\"block_1\";s:4:\"data\";s:95:\"a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}\";}}}s:14:\"_referringItem\";r:943;s:23:\"_layoutParagraphsLayout\";r:4;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_views\";s:2:\"id\";s:2:\"38\";s:4:\"uuid\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";s:8:\"revision\";s:3:\"570\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"570\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"1f9e65806072427ebb23a82a18f9f122\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}i:1;O:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\":23:{s:15:\"\0*\0entityTypeId\";s:15:\"paragraphs_type\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:8:\"ept_hero\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ced6180f-b154-47b8-a7b7-61647c71db48\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kps1UJbRPEF2GuSjDQDJFWWG5EZ6qTHII92BJxLlwTk\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:2:\"id\";s:8:\"ept_hero\";s:5:\"label\";s:8:\"EPT Hero\";s:11:\"description\";s:36:\"Extra Paragraph Type (EPT): EPT Hero\";s:12:\"\0*\0icon_uuid\";N;s:15:\"\0*\0icon_default\";N;s:16:\"behavior_plugins\";a:0:{}}i:2;s:0:\"\";i:3;s:0:\"\";i:4;s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";i:5;s:6:\"before\";i:6;a:0:{}}s:5:\"files\";a:0:{}s:15:\"callback_object\";O:49:\"Drupal\\layout_paragraphs\\Form\\InsertComponentForm\":19:{s:15:\"\0*\0requestStack\";N;s:13:\"\0*\0routeMatch\";N;s:14:\"\0*\0_serviceIds\";a:8:{s:13:\"configFactory\";s:14:\"config.factory\";s:17:\"stringTranslation\";s:18:\"string_translation\";s:9:\"tempstore\";s:38:\"layout_paragraphs.tempstore_repository\";s:17:\"entityTypeManager\";s:19:\"entity_type.manager\";s:19:\"layoutPluginManager\";s:26:\"plugin.manager.core.layout\";s:13:\"moduleHandler\";s:14:\"module_handler\";s:16:\"entityRepository\";s:17:\"entity.repository\";s:15:\"eventDispatcher\";s:16:\"event_dispatcher\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:16:\"\0*\0loggerFactory\";N;s:12:\"\0*\0messenger\";N;s:22:\"\0*\0redirectDestination\";N;s:16:\"\0*\0paragraphType\";O:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\":23:{s:15:\"\0*\0entityTypeId\";s:15:\"paragraphs_type\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:8:\"ept_hero\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ced6180f-b154-47b8-a7b7-61647c71db48\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kps1UJbRPEF2GuSjDQDJFWWG5EZ6qTHII92BJxLlwTk\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:2:\"id\";s:8:\"ept_hero\";s:5:\"label\";s:8:\"EPT Hero\";s:11:\"description\";s:36:\"Extra Paragraph Type (EPT): EPT Hero\";s:12:\"\0*\0icon_uuid\";N;s:15:\"\0*\0icon_default\";N;s:16:\"behavior_plugins\";a:1:{s:17:\"layout_paragraphs\";a:1:{s:17:\"available_layouts\";a:0:{}}}}s:12:\"\0*\0paragraph\";r:550;s:11:\"\0*\0formMode\";s:7:\"default\";s:25:\"\0*\0layoutParagraphsLayout\";r:4;s:33:\"\0*\0originalLayoutParagraphsLayout\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";r:6;s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";r:228;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:2:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:355;s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:1375;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"569\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":9:{s:13:\"\0*\0definition\";r:496;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1384;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_block\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";r:794;}s:5:\"\0*\0id\";N;s:14:\"\0*\0revision_id\";N;}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:355;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:1375;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"570\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":9:{s:13:\"\0*\0definition\";r:496;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1420;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_views\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";r:1139;}s:5:\"\0*\0id\";N;s:14:\"\0*\0revision_id\";N;}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";N;s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:14:\"\0*\0domSelector\";s:50:\"[data-uuid=\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\"]\";s:20:\"\0*\0paragraphDefaults\";a:0:{}s:9:\"\0*\0method\";s:6:\"before\";s:13:\"\0*\0parentUuid\";s:0:\"\";s:9:\"\0*\0region\";s:0:\"\";s:12:\"\0*\0placement\";s:6:\"before\";s:14:\"\0*\0siblingUuid\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";}s:7:\"form_id\";s:32:\"layout_paragraphs_component_form\";}s:8:\"response\";N;s:10:\"programmed\";b:0;s:30:\"programmed_bypass_access_check\";b:1;s:13:\"process_input\";b:1;s:16:\"has_file_element\";N;s:7:\"storage\";a:3:{s:23:\"entity_default_langcode\";s:2:\"en\";s:8:\"langcode\";s:2:\"en\";s:13:\"field_storage\";a:1:{s:8:\"#parents\";a:1:{s:7:\"#fields\";a:7:{s:27:\"field_ept_hero_column_image\";a:3:{s:11:\"items_count\";i:0;s:13:\"array_parents\";a:2:{i:0;s:27:\"field_ept_hero_column_image\";i:1;s:6:\"widget\";}s:5:\"items\";a:0:{}}s:19:\"field_ept_hero_link\";a:2:{s:11:\"items_count\";i:0;s:13:\"array_parents\";a:2:{i:0;s:19:\"field_ept_hero_link\";i:1;s:6:\"widget\";}}s:26:\"field_ept_hero_second_link\";a:2:{s:11:\"items_count\";i:0;s:13:\"array_parents\";a:2:{i:0;s:26:\"field_ept_hero_second_link\";i:1;s:6:\"widget\";}}s:27:\"field_ept_hero_title_prefix\";a:3:{s:11:\"items_count\";i:0;s:13:\"array_parents\";a:2:{i:0;s:27:\"field_ept_hero_title_prefix\";i:1;s:6:\"widget\";}s:15:\"original_deltas\";a:1:{i:0;i:0;}}s:18:\"field_ept_settings\";a:3:{s:11:\"items_count\";i:1;s:13:\"array_parents\";a:2:{i:0;s:18:\"field_ept_settings\";i:1;s:6:\"widget\";}s:15:\"original_deltas\";a:1:{i:0;i:0;}}s:14:\"field_ept_text\";a:3:{s:11:\"items_count\";i:0;s:13:\"array_parents\";a:2:{i:0;s:14:\"field_ept_text\";i:1;s:6:\"widget\";}s:15:\"original_deltas\";a:1:{i:0;i:0;}}s:15:\"field_ept_title\";a:3:{s:11:\"items_count\";i:0;s:13:\"array_parents\";a:2:{i:0;s:15:\"field_ept_title\";i:1;s:6:\"widget\";}s:15:\"original_deltas\";a:1:{i:0;i:0;}}}}}}s:5:\"cache\";b:1;s:8:\"no_cache\";N;}',1729088483),('system','advisories_response',_binary 'a:0:{}',1729084711),('tempstore.private.layout_paragraphs','1:05812a8052ecbea7e981cbe71fcff6ff',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"20\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728883324\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728883324\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"59\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"60\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"64\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"20\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"20\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:4:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"59\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"59\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"59\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"59\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"60\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:759;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"60\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:759;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"60\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"60\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"64\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:937;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"64\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"61\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"62\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"63\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:937;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"64\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"64\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1126;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:23:\"_layoutParagraphsLayout\";r:3;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_stats\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728883680;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:16:\"stats_in_squares\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:5:{s:7:\"subform\";a:4:{s:26:\"field_ept_stats_item_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:25:\"field_ept_stats_item_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:27:\"field_ept_stats_item_number\";a:1:{i:0;a:2:{s:5:\"value\";s:551:\"<p><span style=\"background-color:rgb(255,255,255);color:rgb(34,34,34);\"><span style=\"-webkit-text-stroke-width:0px;display:inline !important;float:none;font-family:NotoSans, system-ui, sans-serif;font-size:16px;font-style:normal;font-variant-caps:normal;font-variant-ligatures:normal;font-weight:400;letter-spacing:normal;orphans:2;text-align:right;text-decoration-color:initial;text-decoration-style:initial;text-decoration-thickness:initial;text-indent:0px;text-transform:none;white-space:normal;widows:2;word-spacing:0px;\">721,320</span></span></p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_stats_item_text\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Websites use Drupal</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:18:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"26311542-79cb-4dbd-afae-5eaaa37c8c3e\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_stats_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728883680;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_stats\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_stats_item_image\";a:1:{s:9:\"x-default\";a:0:{}}s:25:\"field_ept_stats_item_link\";a:1:{s:9:\"x-default\";a:0:{}}s:27:\"field_ept_stats_item_number\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:551:\"<p><span style=\"background-color:rgb(255,255,255);color:rgb(34,34,34);\"><span style=\"-webkit-text-stroke-width:0px;display:inline !important;float:none;font-family:NotoSans, system-ui, sans-serif;font-size:16px;font-style:normal;font-variant-caps:normal;font-variant-ligatures:normal;font-weight:400;letter-spacing:normal;orphans:2;text-align:right;text-decoration-color:initial;text-decoration-style:initial;text-decoration-thickness:initial;text-indent:0px;text-transform:none;white-space:normal;widows:2;word-spacing:0px;\">721,320</span></span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_stats_item_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Websites use Drupal</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_stats_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"26311542-79cb-4dbd-afae-5eaaa37c8c3e\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:4:{s:26:\"field_ept_stats_item_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:25:\"field_ept_stats_item_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:27:\"field_ept_stats_item_number\";a:1:{i:0;a:2:{s:5:\"value\";s:14:\"<p>238,556</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_stats_item_text\";a:1:{i:0;a:2:{s:5:\"value\";s:45:\"<p>Usage statistics for Paragraphs module</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:18:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"13a0b97c-311e-4742-821b-d4d27041731f\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_stats_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728883680;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_stats\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_stats_item_image\";a:1:{s:9:\"x-default\";a:0:{}}s:25:\"field_ept_stats_item_link\";a:1:{s:9:\"x-default\";a:0:{}}s:27:\"field_ept_stats_item_number\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:14:\"<p>238,556</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_stats_item_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:45:\"<p>Usage statistics for Paragraphs module</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_stats_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"13a0b97c-311e-4742-821b-d4d27041731f\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:368:\"<p>Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:34:\"<p>What Are Drupal Paragraphs?</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1126;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:8:\"revision\";N;s:2:\"id\";N;s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"05812a8052ecbea7e981cbe71fcff6ff\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728883773;}',1729488573),('tempstore.private.layout_paragraphs','1:0817ee79309c823f971e697e8f7a65c5',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"16\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728819951\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819951\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"35\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"36\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"40\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"16\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"16\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"35\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"35\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"35\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"35\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"36\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:759;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"36\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:759;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"36\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"36\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"40\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:937;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"40\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_tiles\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"37\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"3\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"37\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"3\";s:4:\"uuid\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";s:8:\"revision\";s:2:\"37\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"37\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:0;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"38\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"4\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"38\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"4\";s:4:\"uuid\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";s:8:\"revision\";s:2:\"38\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"38\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"39\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"5\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"39\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"5\";s:4:\"uuid\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";s:8:\"revision\";s:2:\"39\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"39\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:14:\"_referringItem\";r:937;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"40\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"40\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"0817ee79309c823f971e697e8f7a65c5\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728820014;}',1729424814),('tempstore.private.layout_paragraphs','1:0a59e37a70fa5e25c6ac94e11bd8c318',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"13\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728819415\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819415\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"17\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"18\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"22\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"13\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"13\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"17\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"17\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"17\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"17\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"18\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:759;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"18\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:759;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"18\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"18\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"22\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:937;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"22\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_tiles\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"19\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"3\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"19\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"3\";s:4:\"uuid\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";s:8:\"revision\";s:2:\"19\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"19\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:0;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"20\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"4\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"20\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"4\";s:4:\"uuid\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";s:8:\"revision\";s:2:\"20\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"20\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"21\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"5\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"21\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"5\";s:4:\"uuid\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";s:8:\"revision\";s:2:\"21\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"21\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:14:\"_referringItem\";r:937;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"22\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"22\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"0a59e37a70fa5e25c6ac94e11bd8c318\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728819461;}',1729424261),('tempstore.private.layout_paragraphs','1:0c856996ef27dd410a698f8cddf53a07',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"17\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728820014\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728820014\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"41\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"42\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"46\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"17\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"17\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"41\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"41\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"41\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"41\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"42\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:759;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"42\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:759;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"42\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"42\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"46\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:937;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"46\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"43\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"44\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"45\";}}}s:14:\"_referringItem\";r:937;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"46\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"46\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"0c856996ef27dd410a698f8cddf53a07\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728850157;}',1729454957),('tempstore.private.layout_paragraphs','1:0d04e3ea871cbe3b9cc87fd026d5d710',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728809849\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728809849\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"13\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"14\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"11\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"11\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:2:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"13\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:353;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:24:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"13\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:8:\"ept_hero\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242667\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:5:\"title\";s:17:\"EPT Documentation\";s:10:\"attributes\";a:0:{}s:7:\"options\";a:0:{}s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:5:\"title\";s:8:\"Download\";s:10:\"attributes\";a:0:{}s:7:\"options\";a:0:{}s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";}}}s:14:\"_referringItem\";r:353;s:23:\"_layoutParagraphsLayout\";r:3;s:27:\"field_ept_hero_column_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"13\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"13\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:354;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"14\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:495;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:784;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"14\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:784;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"14\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"14\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"0d04e3ea871cbe3b9cc87fd026d5d710\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728817647;}',1729422447),('tempstore.private.layout_paragraphs','1:1577eb324628e7a33f238d1dd2ccd784',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"63\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1729064555\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729064448\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729064555\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"568\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:2:\"19\";s:8:\"revision\";s:2:\"63\";s:4:\"uuid\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"63\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:2:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:350;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_block\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:23:\"_layoutParagraphsLayout\";r:3;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_block\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729065292;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"19\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:21:\"field_ept_block_block\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:9:\"plugin_id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:8:\"settings\";a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:0:{}}s:14:\"_referringItem\";r:350;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:3:{s:6:\"bundle\";s:9:\"ept_block\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"568\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:706;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_views\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"38\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"568\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_views\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729064495\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:20:\"field_ept_views_view\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:9:\"target_id\";s:10:\"what_s_new\";s:10:\"display_id\";s:7:\"block_1\";s:4:\"data\";s:95:\"a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}\";}}}s:14:\"_referringItem\";r:706;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_views\";s:2:\"id\";s:2:\"38\";s:4:\"uuid\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";s:8:\"revision\";s:3:\"568\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"568\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"1577eb324628e7a33f238d1dd2ccd784\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1729065353;}',1729670153),('tempstore.private.layout_paragraphs','1:1e9434ede0d737c390a835e5b3f31e02',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"27\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728885677\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728885677\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:5:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"122\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"123\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"127\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"130\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"131\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"27\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"27\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:5:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"122\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:362;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"122\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:362;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"122\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"122\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"123\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:765;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"123\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:765;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"123\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"123\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"127\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:943;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"127\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"124\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"125\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"126\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:943;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"127\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"127\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"130\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1132;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"130\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"128\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"129\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1132;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"130\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"130\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"131\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1323;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"10\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"131\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_image_gallery\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728884868\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:5:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"4\";s:6:\"weight\";s:1:\"0\";}i:1;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"5\";s:6:\"weight\";s:1:\"1\";}i:2;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"6\";s:6:\"weight\";s:1:\"2\";}i:3;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"7\";s:6:\"weight\";s:1:\"3\";}i:4;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"9\";s:6:\"weight\";s:1:\"4\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1323;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"131\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"131\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"1e9434ede0d737c390a835e5b3f31e02\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728885900;}',1729490700),('tempstore.private.layout_paragraphs','1:1f9e65806072427ebb23a82a18f9f122',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"64\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1729065353\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729064448\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729065353\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"569\";}i:1;a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"570\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:2:\"19\";s:8:\"revision\";s:2:\"64\";s:4:\"uuid\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"64\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:353;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:23:\"_layoutParagraphsLayout\";r:3;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"93872b1e-0586-4e38-b8a5-5edca3c418e7\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:8:\"ept_hero\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729066868;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"19\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:27:\"field_ept_hero_column_image\";a:1:{s:9:\"x-default\";a:0:{}}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:0:{}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:19:\"<p>Listing Page</p>\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:18:\"<p>Stay tuned!</p>\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:17:\"<p>What\'s New</p>\";}}}s:14:\"_referringItem\";r:353;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:3:{s:6:\"bundle\";s:8:\"ept_hero\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"93872b1e-0586-4e38-b8a5-5edca3c418e7\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:354;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"569\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:495;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:761;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_block\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"39\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"569\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_block\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729065292\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:21:\"field_ept_block_block\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:9:\"plugin_id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:8:\"settings\";a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:14:\"_referringItem\";r:761;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_block\";s:2:\"id\";s:2:\"39\";s:4:\"uuid\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";s:8:\"revision\";s:3:\"569\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"569\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"570\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:943;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_views\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"38\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"570\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_views\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729064495\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:20:\"field_ept_views_view\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:9:\"target_id\";s:10:\"what_s_new\";s:10:\"display_id\";s:7:\"block_1\";s:4:\"data\";s:95:\"a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}\";}}}s:14:\"_referringItem\";r:943;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_views\";s:2:\"id\";s:2:\"38\";s:4:\"uuid\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";s:8:\"revision\";s:3:\"570\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"570\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"1f9e65806072427ebb23a82a18f9f122\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1729066913;}',1729671713),('tempstore.private.layout_paragraphs','1:2218d465315bbbaec14a9cf69819036d',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"34\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728934139\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728934139\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:8:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"198\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"199\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"203\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"206\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"207\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"208\";}i:6;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"209\";}i:7;a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"220\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"34\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"34\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:8:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"198\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:371;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"198\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:371;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"198\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"198\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"199\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:774;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"199\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:774;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"199\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"199\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"203\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:952;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"203\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"200\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"201\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"202\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:952;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"203\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"203\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"206\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1141;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"206\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"204\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"205\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1141;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"206\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"206\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"207\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1332;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"207\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1332;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"207\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"207\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"208\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1534;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"208\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1534;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"208\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"208\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"209\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1775;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"209\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_quote\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728933345\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"18\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1775;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"209\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"209\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:7;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:7;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"220\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1969;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:12:\"ept_carousel\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"23\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"220\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:12:\"ept_carousel\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728934054\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_carousel\";a:1:{s:9:\"x-default\";a:10:{i:0;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>EPT Counter</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"15\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"13\";s:18:\"target_revision_id\";s:3:\"210\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"13\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"210\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"28a6aa54-d81c-41d1-8295-fe11ca28099a\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728933651\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"23\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>EPT Counter</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2081;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"15\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:2:\"id\";s:2:\"13\";s:4:\"uuid\";s:36:\"28a6aa54-d81c-41d1-8295-fe11ca28099a\";s:8:\"revision\";s:3:\"210\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"210\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:15:\"<p>EPT Text</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"14\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"14\";s:18:\"target_revision_id\";s:3:\"211\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"14\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"211\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"a4eac7aa-822e-4fa3-9455-c1bb581a624f\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728933677\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"23\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:15:\"<p>EPT Text</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2240;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"14\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:2:\"id\";s:2:\"14\";s:4:\"uuid\";s:36:\"a4eac7aa-822e-4fa3-9455-c1bb581a624f\";s:8:\"revision\";s:3:\"211\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"211\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:16:\"<p>EPT Tiles</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"13\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"15\";s:18:\"target_revision_id\";s:3:\"212\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"15\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"212\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"d1b58918-ffa2-4bce-bfbc-c9deb44b5867\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728933705\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"23\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:16:\"<p>EPT Tiles</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2399;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"13\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:2:\"id\";s:2:\"15\";s:4:\"uuid\";s:36:\"d1b58918-ffa2-4bce-bfbc-c9deb44b5867\";s:8:\"revision\";s:3:\"212\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"212\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:3;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:23:\"<p>EPT Slick Slider</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"9\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"16\";s:18:\"target_revision_id\";s:3:\"213\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"16\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"213\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"468f6ab7-7312-46ae-bcf6-ef603e838f68\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728933742\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"23\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:23:\"<p>EPT Slick Slider</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2558;s:6:\"weight\";i:0;s:9:\"target_id\";s:1:\"9\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:2:\"id\";s:2:\"16\";s:4:\"uuid\";s:36:\"468f6ab7-7312-46ae-bcf6-ef603e838f68\";s:8:\"revision\";s:3:\"213\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"213\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:4;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:25:\"<p>EPT Call to action</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"6\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"17\";s:18:\"target_revision_id\";s:3:\"214\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"17\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"214\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"8b37f259-e19c-4f81-822b-4ab3f83ede48\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728933774\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"23\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:25:\"<p>EPT Call to action</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2717;s:6:\"weight\";i:0;s:9:\"target_id\";s:1:\"6\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:2:\"id\";s:2:\"17\";s:4:\"uuid\";s:36:\"8b37f259-e19c-4f81-822b-4ab3f83ede48\";s:8:\"revision\";s:3:\"214\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"214\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:5;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>EPT Image Gallery</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"4\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"18\";s:18:\"target_revision_id\";s:3:\"215\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"18\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"215\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"b4ee429d-8ae5-494d-8349-f1d7bc895fac\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728933815\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"23\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>EPT Image Gallery</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2876;s:6:\"weight\";i:0;s:9:\"target_id\";s:1:\"4\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:2:\"id\";s:2:\"18\";s:4:\"uuid\";s:36:\"b4ee429d-8ae5-494d-8349-f1d7bc895fac\";s:8:\"revision\";s:3:\"215\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"215\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:6;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:15:\"<p>EPT Tabs</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"7\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"19\";s:18:\"target_revision_id\";s:3:\"216\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"19\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"216\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"e1a17a42-8975-45f0-ad79-d1e16708218e\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728933850\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"23\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:15:\"<p>EPT Tabs</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:3035;s:6:\"weight\";i:0;s:9:\"target_id\";s:1:\"7\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:2:\"id\";s:2:\"19\";s:4:\"uuid\";s:36:\"e1a17a42-8975-45f0-ad79-d1e16708218e\";s:8:\"revision\";s:3:\"216\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"216\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:7;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>EPT Accordion/FAQ</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"5\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"20\";s:18:\"target_revision_id\";s:3:\"217\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"20\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"217\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"290eb5f2-3408-46ba-9d87-618c1395cd44\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728933885\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"23\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>EPT Accordion/FAQ</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:3194;s:6:\"weight\";i:0;s:9:\"target_id\";s:1:\"5\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:2:\"id\";s:2:\"20\";s:4:\"uuid\";s:36:\"290eb5f2-3408-46ba-9d87-618c1395cd44\";s:8:\"revision\";s:3:\"217\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"217\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:8;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:19:\"<p>EPT Carousel</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"10\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"21\";s:18:\"target_revision_id\";s:3:\"218\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"21\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"218\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"7e05ae91-dba8-4b5b-8a2e-3bf8b09bf8cf\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728933921\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"23\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:19:\"<p>EPT Carousel</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:3353;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"10\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:2:\"id\";s:2:\"21\";s:4:\"uuid\";s:36:\"7e05ae91-dba8-4b5b-8a2e-3bf8b09bf8cf\";s:8:\"revision\";s:3:\"218\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"218\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:9;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:16:\"<p>EPT Quote</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"12\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"22\";s:18:\"target_revision_id\";s:3:\"219\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"22\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"219\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"eeac7ad1-b0a3-4898-a4e2-4e0aadfa2e09\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728933949\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"23\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:16:\"<p>EPT Quote</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:3512;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"12\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:2:\"id\";s:2:\"22\";s:4:\"uuid\";s:36:\"eeac7ad1-b0a3-4898-a4e2-4e0aadfa2e09\";s:8:\"revision\";s:3:\"219\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"219\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:50:\"<p>Find and download your Extra Paragraph Type</p>\";}}}s:14:\"_referringItem\";r:1969;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:12:\"ept_carousel\";s:2:\"id\";s:2:\"23\";s:4:\"uuid\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";s:8:\"revision\";s:3:\"220\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"220\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"2218d465315bbbaec14a9cf69819036d\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728934262;}',1729539062),('tempstore.private.layout_paragraphs','1:236f4628282937c064618101a3937ead',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728809719\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728809719\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:1:\"9\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"10\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:1:\"9\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:1:\"9\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:2:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:1:\"9\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:353;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:353;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:1:\"9\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:1:\"9\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:354;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"10\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:495;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:756;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"2\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"10\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:8:\"ept_text\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728809668\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";}}}s:14:\"_referringItem\";r:756;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"10\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"10\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"236f4628282937c064618101a3937ead\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728809815;}',1729414615),('tempstore.private.layout_paragraphs','1:2bb9ff995909bac749e2e7cc0c016ba8',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728883069\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728883069\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"53\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"54\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"58\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"19\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"19\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"53\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"53\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"53\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"53\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"54\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:759;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"54\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:759;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"54\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"54\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"58\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:937;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"58\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_tiles\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"55\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"3\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"55\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"3\";s:4:\"uuid\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";s:8:\"revision\";s:2:\"55\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"55\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:0;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"56\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"4\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"56\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"4\";s:4:\"uuid\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";s:8:\"revision\";s:2:\"56\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"56\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"57\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"5\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"57\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"5\";s:4:\"uuid\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";s:8:\"revision\";s:2:\"57\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"57\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:937;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"58\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"58\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"2bb9ff995909bac749e2e7cc0c016ba8\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728883324;}',1729488124),('tempstore.private.layout_paragraphs','1:2d173e6416d251d4c425343bb4686802',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:3:\"vid\";a:1:{s:9:\"x-default\";a:0:{}}s:3:\"nid\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"523c8068-709e-45c1-81d6-c1a12a1eb399\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:4:\"page\";}}}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729064448;}}}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";a:0:{}}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:3:\"uid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:1:\"1\";}}}s:5:\"title\";a:1:{s:9:\"x-default\";a:0:{}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729064448;}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729064448;}}}s:7:\"promote\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:6:\"sticky\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"path\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:8:\"langcode\";s:2:\"en\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:3:{s:6:\"bundle\";s:4:\"page\";s:8:\"revision\";N;s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:1:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:350;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_views\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:23:\"_layoutParagraphsLayout\";r:3;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_views\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729064495;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_views_view\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:9:\"target_id\";s:10:\"what_s_new\";s:10:\"display_id\";s:7:\"block_1\";s:4:\"data\";s:95:\"a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}\";}}}s:14:\"_referringItem\";r:350;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:3:{s:6:\"bundle\";s:9:\"ept_views\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"2d173e6416d251d4c425343bb4686802\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1729064555;}',1729669355);
INSERT INTO `key_value_expire` VALUES ('tempstore.private.layout_paragraphs','1:33a3831c762c04d4aea973e3b3307af9',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"14\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728819461\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819461\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"23\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"24\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"28\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"14\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"14\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"23\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"23\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"23\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"23\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"24\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:759;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"24\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:759;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"24\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"24\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"28\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:937;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"28\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_tiles\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"25\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"3\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"25\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"3\";s:4:\"uuid\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";s:8:\"revision\";s:2:\"25\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"25\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:0;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"26\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"4\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"26\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"4\";s:4:\"uuid\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";s:8:\"revision\";s:2:\"26\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"26\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"27\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"5\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"27\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"5\";s:4:\"uuid\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";s:8:\"revision\";s:2:\"27\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"27\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:14:\"_referringItem\";r:937;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"28\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"28\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"33a3831c762c04d4aea973e3b3307af9\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728819683;}',1729424483),('tempstore.private.layout_paragraphs','1:3d9b153ea079de3b0a2407fdf008eeb4',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"28\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728885900\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728885900\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:5:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"132\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"133\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"137\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"140\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"141\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"28\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"28\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:5:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"132\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:362;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"132\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:362;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"132\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"132\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"133\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:765;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"133\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:765;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"133\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"133\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"137\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:943;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"137\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"134\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"135\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"136\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:943;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"137\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"137\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"140\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1132;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"140\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"138\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"139\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1132;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"140\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"140\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"141\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1323;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"10\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"141\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_image_gallery\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728884868\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"4\";s:6:\"weight\";s:1:\"0\";}i:1;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"5\";s:6:\"weight\";s:1:\"1\";}i:2;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"6\";s:6:\"weight\";s:1:\"2\";}i:3;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"7\";s:6:\"weight\";s:1:\"3\";}i:4;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"9\";s:6:\"weight\";s:1:\"4\";}i:5;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"10\";s:6:\"weight\";s:1:\"5\";}i:6;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"11\";s:6:\"weight\";s:1:\"6\";}i:7;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"12\";s:6:\"weight\";s:1:\"7\";}i:8;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"13\";s:6:\"weight\";s:1:\"8\";}i:9;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"14\";s:6:\"weight\";s:1:\"9\";}i:10;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"15\";s:6:\"weight\";s:2:\"10\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1323;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"141\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"141\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"3d9b153ea079de3b0a2407fdf008eeb4\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728888389;}',1729493189),('tempstore.private.layout_paragraphs','1:3fcb00f7637f20b098ef339c61d8f273',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"17\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728820014\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728820014\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"41\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"42\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"46\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"17\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"17\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"41\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"41\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"41\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"41\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:0;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"42\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:754;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"42\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:754;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"42\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"42\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:0;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"46\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:927;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"46\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"43\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"44\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"45\";}}}s:14:\"_referringItem\";r:927;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"46\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"46\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:0;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"3fcb00f7637f20b098ef339c61d8f273\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728849887;}',1729454687),('tempstore.private.layout_paragraphs','1:4142838c55990c5f9c7b34ed36774835',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"26\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728885506\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728885506\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:5:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"112\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"113\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"117\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"120\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"121\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"26\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"26\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:5:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"112\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:362;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"112\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:362;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"112\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"112\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"113\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:765;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"113\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:765;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"113\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"113\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"117\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:943;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"117\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_tiles\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"114\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"3\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"114\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"3\";s:4:\"uuid\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";s:8:\"revision\";s:3:\"114\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"114\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:0;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"115\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"4\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"115\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"4\";s:4:\"uuid\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";s:8:\"revision\";s:3:\"115\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"115\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"116\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"5\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"116\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"5\";s:4:\"uuid\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";s:8:\"revision\";s:3:\"116\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"116\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";}}}s:14:\"_referringItem\";r:943;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"117\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"117\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"120\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1658;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"120\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"118\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"119\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1658;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"120\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"120\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"121\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1849;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"121\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:4:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1849;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"121\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"121\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"4142838c55990c5f9c7b34ed36774835\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728885677;}',1729490477),('tempstore.private.layout_paragraphs','1:49ea8e7105ebcddae8e59f783498deb7',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"33\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728933474\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728933474\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:7:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"186\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"187\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"191\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"194\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"195\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"196\";}i:6;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"197\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"33\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"33\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:8:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"186\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:368;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"186\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:368;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"186\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"186\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:369;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"187\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:510;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:771;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"187\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:771;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"187\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"187\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:369;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"191\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:510;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:949;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"191\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"188\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"189\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"190\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:949;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"191\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"191\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:369;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"194\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:510;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1138;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"194\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"192\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"193\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1138;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"194\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"194\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:369;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"195\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:510;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1329;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"195\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1329;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"195\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"195\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:369;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"196\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:510;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1531;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"196\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1531;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"196\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"196\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:369;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"197\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:510;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1772;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"197\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_quote\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728933345\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"18\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1772;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"197\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"197\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:7;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:7;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1966;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:12:\"ept_carousel\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:23:\"_layoutParagraphsLayout\";r:3;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:12:\"ept_carousel\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728934054;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_carousel\";a:1:{s:9:\"x-default\";a:10:{i:0;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>EPT Counter</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"15\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:16:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"28a6aa54-d81c-41d1-8295-fe11ca28099a\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728933651;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>EPT Counter</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2232;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"15\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"28a6aa54-d81c-41d1-8295-fe11ca28099a\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:15:\"<p>EPT Text</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"14\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:16:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"a4eac7aa-822e-4fa3-9455-c1bb581a624f\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728933677;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:15:\"<p>EPT Text</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2371;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"14\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"a4eac7aa-822e-4fa3-9455-c1bb581a624f\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:16:\"<p>EPT Tiles</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"13\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:16:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"d1b58918-ffa2-4bce-bfbc-c9deb44b5867\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728933705;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:16:\"<p>EPT Tiles</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2510;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"13\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"d1b58918-ffa2-4bce-bfbc-c9deb44b5867\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:3;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:23:\"<p>EPT Slick Slider</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"9\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:16:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"468f6ab7-7312-46ae-bcf6-ef603e838f68\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728933742;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:23:\"<p>EPT Slick Slider</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2649;s:6:\"weight\";i:0;s:9:\"target_id\";s:1:\"9\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"468f6ab7-7312-46ae-bcf6-ef603e838f68\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:4;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:25:\"<p>EPT Call to action</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"6\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:16:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"8b37f259-e19c-4f81-822b-4ab3f83ede48\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728933774;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:25:\"<p>EPT Call to action</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2788;s:6:\"weight\";i:0;s:9:\"target_id\";s:1:\"6\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"8b37f259-e19c-4f81-822b-4ab3f83ede48\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:5;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>EPT Image Gallery</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"4\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:16:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"b4ee429d-8ae5-494d-8349-f1d7bc895fac\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728933815;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>EPT Image Gallery</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2927;s:6:\"weight\";i:0;s:9:\"target_id\";s:1:\"4\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"b4ee429d-8ae5-494d-8349-f1d7bc895fac\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:6;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:15:\"<p>EPT Tabs</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"7\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:16:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"e1a17a42-8975-45f0-ad79-d1e16708218e\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728933850;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:15:\"<p>EPT Tabs</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:3066;s:6:\"weight\";i:0;s:9:\"target_id\";s:1:\"7\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"e1a17a42-8975-45f0-ad79-d1e16708218e\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:7;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>EPT Accordion/FAQ</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"5\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:16:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"290eb5f2-3408-46ba-9d87-618c1395cd44\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728933885;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>EPT Accordion/FAQ</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:3205;s:6:\"weight\";i:0;s:9:\"target_id\";s:1:\"5\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"290eb5f2-3408-46ba-9d87-618c1395cd44\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:8;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:19:\"<p>EPT Carousel</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"10\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:16:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"7e05ae91-dba8-4b5b-8a2e-3bf8b09bf8cf\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728933921;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:19:\"<p>EPT Carousel</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:3344;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"10\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"7e05ae91-dba8-4b5b-8a2e-3bf8b09bf8cf\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:9;a:5:{s:7:\"subform\";a:2:{s:26:\"field_ept_carousel_caption\";a:1:{i:0;a:2:{s:5:\"value\";s:16:\"<p>EPT Quote</p>\";s:6:\"format\";s:9:\"full_html\";}}s:24:\"field_ept_carousel_image\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"12\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:16:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"eeac7ad1-b0a3-4898-a4e2-4e0aadfa2e09\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_carousel_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728933949;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:18:\"field_ept_carousel\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_carousel_caption\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:16:\"<p>EPT Quote</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_carousel_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:3483;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"12\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_carousel_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"eeac7ad1-b0a3-4898-a4e2-4e0aadfa2e09\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:50:\"<p>Find and download your Extra Paragraph Type</p>\";}}}s:14:\"_referringItem\";r:1966;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:3:{s:6:\"bundle\";s:12:\"ept_carousel\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"49ea8e7105ebcddae8e59f783498deb7\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728934139;}',1729538939),('tempstore.private.layout_paragraphs','1:4a5753ec5792a61c788d39abccf6cd61',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"32\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728933423\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728933423\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:7:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"174\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"175\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"179\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"182\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"183\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"184\";}i:6;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"185\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"32\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"32\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:7:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"174\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:368;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"174\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:368;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"174\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"174\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:369;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"175\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:510;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:771;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"175\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:771;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"175\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"175\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:369;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"179\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:510;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:949;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"179\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"176\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"177\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"178\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:949;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"179\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"179\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:369;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"182\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:510;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1138;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"182\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"180\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"181\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1138;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"182\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"182\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:369;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"183\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:510;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1329;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"183\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1329;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"183\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"183\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:369;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"184\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:510;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1531;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"184\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1531;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"184\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"184\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:369;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"185\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:510;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1772;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"12\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"185\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_quote\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728933345\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:18:\"<p>Hockey Club</p>\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"18\";s:6:\"weight\";i:0;}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";}}}s:14:\"_referringItem\";r:1772;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"185\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"185\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"4a5753ec5792a61c788d39abccf6cd61\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728933474;}',1729538274),('tempstore.private.layout_paragraphs','1:4e6d3d83db299d55dcf5b21043950244',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"65\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1729066913\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729064448\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729066913\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:2:\"40\";s:18:\"target_revision_id\";s:3:\"571\";}i:1;a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"572\";}i:2;a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"573\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:2:\"19\";s:8:\"revision\";s:2:\"65\";s:4:\"uuid\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"65\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"40\";s:18:\"target_revision_id\";s:3:\"571\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:24:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"40\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"571\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:8:\"ept_hero\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"93872b1e-0586-4e38-b8a5-5edca3c418e7\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729066868\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"19\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:19:\"<p>Listing Page</p>\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"50\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"50\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:18:\"<p>Stay tuned!</p>\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:17:\"<p>What\'s New</p>\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;s:27:\"field_ept_hero_column_image\";a:1:{s:9:\"x-default\";a:0:{}}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:2:\"40\";s:4:\"uuid\";s:36:\"93872b1e-0586-4e38-b8a5-5edca3c418e7\";s:8:\"revision\";s:3:\"571\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"571\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"572\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:781;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_block\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"39\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"572\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_block\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729065292\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:21:\"field_ept_block_block\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:9:\"plugin_id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:8:\"settings\";a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:14:\"_referringItem\";r:781;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_block\";s:2:\"id\";s:2:\"39\";s:4:\"uuid\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";s:8:\"revision\";s:3:\"572\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"572\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"573\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:963;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_views\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"38\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"573\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_views\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729064495\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:20:\"field_ept_views_view\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:9:\"target_id\";s:10:\"what_s_new\";s:10:\"display_id\";s:7:\"block_1\";s:4:\"data\";s:95:\"a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}\";}}}s:14:\"_referringItem\";r:963;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_views\";s:2:\"id\";s:2:\"38\";s:4:\"uuid\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";s:8:\"revision\";s:3:\"573\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"573\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"4e6d3d83db299d55dcf5b21043950244\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1729066954;}',1729671754),('tempstore.private.layout_paragraphs','1:56ae822963db901ec62d4655bae33c66',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"17\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728820014\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728820014\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"41\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"42\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"46\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"17\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"17\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"41\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"41\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"41\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"41\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:0;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"42\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:754;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"42\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:754;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"42\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"42\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:0;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"46\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:927;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"46\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"43\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"44\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"45\";}}}s:14:\"_referringItem\";r:927;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"46\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"46\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:0;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"56ae822963db901ec62d4655bae33c66\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728850078;}',1729454878),('tempstore.private.layout_paragraphs','1:5be51c9487ed3049330e24c9273730c9',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"30\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728889242\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728889242\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:6:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"152\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"153\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"157\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"160\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"161\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"162\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"30\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"30\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:6:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"152\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:365;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"152\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:365;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"152\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"152\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"153\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:768;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"153\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:768;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"153\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"153\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"157\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:946;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"157\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"154\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"155\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"156\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:946;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"157\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"157\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"160\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1135;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"160\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"158\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"159\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1135;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"160\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"160\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"161\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1326;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"161\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1326;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"161\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"161\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"162\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1528;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"11\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"162\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:7:\"ept_cta\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728888715\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"16\";s:6:\"weight\";i:0;}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:5:\"title\";s:16:\"GLightbox module\";s:10:\"attributes\";a:0:{}s:7:\"options\";a:0:{}s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:5:\"title\";s:14:\"GLightbox site\";s:10:\"attributes\";a:0:{}s:7:\"options\";a:0:{}s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";}}}s:14:\"_referringItem\";r:1528;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"162\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"162\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"5be51c9487ed3049330e24c9273730c9\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728889330;}',1729494130),('tempstore.private.layout_paragraphs','1:5e2f383b5dbed22f204590d9ca2cf60e',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"39\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728936888\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728936888\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"330\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"331\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"335\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"338\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"339\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"340\";}i:6;a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"344\";}i:7;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"345\";}i:8;a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"356\";}i:9;a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"359\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"39\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"39\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:11:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"330\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:377;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"330\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:377;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"330\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"330\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"331\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:780;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"331\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:780;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"331\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"331\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"335\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:958;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"335\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"332\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"333\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"334\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:958;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"335\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"335\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"338\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1147;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"338\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"336\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"337\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1147;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"338\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"338\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"339\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1338;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"339\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1338;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"339\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"339\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"340\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1540;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"340\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1540;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"340\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"340\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"344\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1781;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:13:\"ept_slideshow\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"30\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"344\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:13:\"ept_slideshow\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728936575\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}}}}s:19:\"field_ept_slideshow\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:2:\"27\";s:18:\"target_revision_id\";s:3:\"341\";}i:1;a:2:{s:9:\"target_id\";s:2:\"28\";s:18:\"target_revision_id\";s:3:\"342\";}i:2;a:2:{s:9:\"target_id\";s:2:\"29\";s:18:\"target_revision_id\";s:3:\"343\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:40:\"<p>Each EPT module has rich settings</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1781;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_slideshow\";s:2:\"id\";s:2:\"30\";s:4:\"uuid\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";s:8:\"revision\";s:3:\"344\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"344\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:7;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:7;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"345\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1998;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"345\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_quote\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728933345\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"18\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1998;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"345\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"345\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:8;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:8;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"356\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2192;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:12:\"ept_carousel\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"23\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"356\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:12:\"ept_carousel\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728934054\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_carousel\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:2:\"13\";s:18:\"target_revision_id\";s:3:\"346\";}i:1;a:2:{s:9:\"target_id\";s:2:\"14\";s:18:\"target_revision_id\";s:3:\"347\";}i:2;a:2:{s:9:\"target_id\";s:2:\"15\";s:18:\"target_revision_id\";s:3:\"348\";}i:3;a:2:{s:9:\"target_id\";s:2:\"16\";s:18:\"target_revision_id\";s:3:\"349\";}i:4;a:2:{s:9:\"target_id\";s:2:\"17\";s:18:\"target_revision_id\";s:3:\"350\";}i:5;a:2:{s:9:\"target_id\";s:2:\"18\";s:18:\"target_revision_id\";s:3:\"351\";}i:6;a:2:{s:9:\"target_id\";s:2:\"19\";s:18:\"target_revision_id\";s:3:\"352\";}i:7;a:2:{s:9:\"target_id\";s:2:\"20\";s:18:\"target_revision_id\";s:3:\"353\";}i:8;a:2:{s:9:\"target_id\";s:2:\"21\";s:18:\"target_revision_id\";s:3:\"354\";}i:9;a:2:{s:9:\"target_id\";s:2:\"22\";s:18:\"target_revision_id\";s:3:\"355\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<p>Find and download your Extra Paragraph Type</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2192;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:12:\"ept_carousel\";s:2:\"id\";s:2:\"23\";s:4:\"uuid\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";s:8:\"revision\";s:3:\"356\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"356\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:9;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:9;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"359\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2472;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:11:\"ept_counter\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"26\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"359\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:11:\"ept_counter\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728935787\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_counter_items\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"24\";s:18:\"target_revision_id\";s:3:\"357\";}i:1;a:2:{s:9:\"target_id\";s:2:\"25\";s:18:\"target_revision_id\";s:3:\"358\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>Number of modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2472;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:11:\"ept_counter\";s:2:\"id\";s:2:\"26\";s:4:\"uuid\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";s:8:\"revision\";s:3:\"359\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"359\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:10;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:10;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2671;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_tabs\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:23:\"_layoutParagraphsLayout\";r:3;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"bc10cacf-328a-491e-9ba0-4d72f49bdd4c\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:8:\"ept_tabs\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728937075;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}}}}s:14:\"field_ept_tabs\";a:1:{s:9:\"x-default\";a:2:{i:0;a:5:{s:7:\"subform\";a:6:{s:19:\"field_ept_tab_block\";a:1:{i:0;a:1:{s:9:\"plugin_id\";s:0:\"\";}}s:21:\"field_ept_tab_content\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"text\";}}s:18:\"field_ept_tab_page\";a:1:{i:0;a:1:{s:9:\"target_id\";N;}}s:18:\"field_ept_tab_text\";a:1:{i:0;a:2:{s:5:\"value\";s:2647:\"<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}s:19:\"field_ept_tab_title\";a:1:{i:0;a:2:{s:5:\"value\";s:11:\"EPT modules\";s:6:\"format\";s:9:\"full_html\";}}s:19:\"field_ept_tab_views\";a:1:{i:0;a:2:{s:9:\"target_id\";N;s:10:\"display_id\";s:0:\"\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"03e1362a-b7df-4469-b71d-5195bdeb4904\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:13:\"ept_tabs_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728937075;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:14:\"field_ept_tabs\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:19:\"field_ept_tab_block\";a:1:{s:9:\"x-default\";a:0:{}}s:21:\"field_ept_tab_content\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"text\";}}}s:18:\"field_ept_tab_page\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_tab_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:2647:\"<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}}s:19:\"field_ept_tab_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:11:\"EPT modules\";s:6:\"format\";s:9:\"full_html\";}}}s:19:\"field_ept_tab_views\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_tabs_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"03e1362a-b7df-4469-b71d-5195bdeb4904\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:6:{s:19:\"field_ept_tab_block\";a:1:{i:0;a:1:{s:9:\"plugin_id\";s:0:\"\";}}s:21:\"field_ept_tab_content\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"text\";}}s:18:\"field_ept_tab_page\";a:1:{i:0;a:1:{s:9:\"target_id\";N;}}s:18:\"field_ept_tab_text\";a:1:{i:0;a:2:{s:5:\"value\";s:2635:\"<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}s:19:\"field_ept_tab_title\";a:1:{i:0;a:2:{s:5:\"value\";s:11:\"EBT Modules\";s:6:\"format\";s:9:\"full_html\";}}s:19:\"field_ept_tab_views\";a:1:{i:0;a:2:{s:9:\"target_id\";N;s:10:\"display_id\";s:0:\"\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"3747fc91-691d-4dac-a4df-e51cf0a0d5a1\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:13:\"ept_tabs_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728937075;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:14:\"field_ept_tabs\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:19:\"field_ept_tab_block\";a:1:{s:9:\"x-default\";a:0:{}}s:21:\"field_ept_tab_content\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"text\";}}}s:18:\"field_ept_tab_page\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_tab_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:2635:\"<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}}s:19:\"field_ept_tab_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:11:\"EBT Modules\";s:6:\"format\";s:9:\"full_html\";}}}s:19:\"field_ept_tab_views\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_tabs_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"3747fc91-691d-4dac-a4df-e51cf0a0d5a1\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:80:\"<p>List of all Extra Paragraph Types (EPT) and Extra Block Types (EBT)&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2671;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_tabs\";s:8:\"revision\";N;s:2:\"id\";N;s:4:\"uuid\";s:36:\"bc10cacf-328a-491e-9ba0-4d72f49bdd4c\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"5e2f383b5dbed22f204590d9ca2cf60e\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728937164;}',1729541964),('tempstore.private.layout_paragraphs','1:6249f8f7d0c8d3d8ab7ed4eee8216519',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728817647\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728817647\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"15\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"16\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"12\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"12\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:2:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"15\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:353;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"15\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:353;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"15\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"15\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:354;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"16\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:495;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:756;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"16\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:756;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"16\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"16\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"6249f8f7d0c8d3d8ab7ed4eee8216519\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728818327;}',1729423127),('tempstore.private.layout_paragraphs','1:62606d2bc15b54eadd3565f9b8d32b3b',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"42\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1729020152\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729020152\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:11:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"426\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"427\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"431\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"434\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"435\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"436\";}i:6;a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"440\";}i:7;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"441\";}i:8;a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"452\";}i:9;a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"455\";}i:10;a:2:{s:9:\"target_id\";s:2:\"33\";s:18:\"target_revision_id\";s:3:\"458\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"42\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"42\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:12:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"426\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:380;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"426\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:380;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"426\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"426\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"427\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:783;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"427\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:783;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"427\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"427\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"431\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:961;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"431\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"428\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"429\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"430\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:961;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"431\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"431\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"434\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1150;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"434\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"432\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"433\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1150;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"434\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"434\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"435\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1341;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"435\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1341;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"435\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"435\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"436\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1543;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"436\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1543;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"436\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"436\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"440\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1784;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:13:\"ept_slideshow\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"30\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"440\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:13:\"ept_slideshow\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728936575\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}}}}s:19:\"field_ept_slideshow\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:2:\"27\";s:18:\"target_revision_id\";s:3:\"437\";}i:1;a:2:{s:9:\"target_id\";s:2:\"28\";s:18:\"target_revision_id\";s:3:\"438\";}i:2;a:2:{s:9:\"target_id\";s:2:\"29\";s:18:\"target_revision_id\";s:3:\"439\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:40:\"<p>Each EPT module has rich settings</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1784;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_slideshow\";s:2:\"id\";s:2:\"30\";s:4:\"uuid\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";s:8:\"revision\";s:3:\"440\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"440\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:7;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:7;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"441\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2001;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"441\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_quote\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728933345\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"18\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2001;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"441\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"441\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:8;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:8;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"452\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2195;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:12:\"ept_carousel\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"23\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"452\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:12:\"ept_carousel\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728934054\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_carousel\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:2:\"13\";s:18:\"target_revision_id\";s:3:\"442\";}i:1;a:2:{s:9:\"target_id\";s:2:\"14\";s:18:\"target_revision_id\";s:3:\"443\";}i:2;a:2:{s:9:\"target_id\";s:2:\"15\";s:18:\"target_revision_id\";s:3:\"444\";}i:3;a:2:{s:9:\"target_id\";s:2:\"16\";s:18:\"target_revision_id\";s:3:\"445\";}i:4;a:2:{s:9:\"target_id\";s:2:\"17\";s:18:\"target_revision_id\";s:3:\"446\";}i:5;a:2:{s:9:\"target_id\";s:2:\"18\";s:18:\"target_revision_id\";s:3:\"447\";}i:6;a:2:{s:9:\"target_id\";s:2:\"19\";s:18:\"target_revision_id\";s:3:\"448\";}i:7;a:2:{s:9:\"target_id\";s:2:\"20\";s:18:\"target_revision_id\";s:3:\"449\";}i:8;a:2:{s:9:\"target_id\";s:2:\"21\";s:18:\"target_revision_id\";s:3:\"450\";}i:9;a:2:{s:9:\"target_id\";s:2:\"22\";s:18:\"target_revision_id\";s:3:\"451\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<p>Find and download your Extra Paragraph Type</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2195;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:12:\"ept_carousel\";s:2:\"id\";s:2:\"23\";s:4:\"uuid\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";s:8:\"revision\";s:3:\"452\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"452\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:9;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:9;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"455\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2475;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:11:\"ept_counter\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"26\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"455\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:11:\"ept_counter\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728935787\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_counter_items\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"24\";s:18:\"target_revision_id\";s:3:\"453\";}i:1;a:2:{s:9:\"target_id\";s:2:\"25\";s:18:\"target_revision_id\";s:3:\"454\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>Number of modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2475;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:11:\"ept_counter\";s:2:\"id\";s:2:\"26\";s:4:\"uuid\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";s:8:\"revision\";s:3:\"455\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"455\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:10;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:10;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"33\";s:18:\"target_revision_id\";s:3:\"458\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2674;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_tabs\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"33\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"458\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_tabs\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"bc10cacf-328a-491e-9ba0-4d72f49bdd4c\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728937075\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}}}}s:14:\"field_ept_tabs\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"31\";s:18:\"target_revision_id\";s:3:\"456\";}i:1;a:2:{s:9:\"target_id\";s:2:\"32\";s:18:\"target_revision_id\";s:3:\"457\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:77:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2674;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_tabs\";s:2:\"id\";s:2:\"33\";s:4:\"uuid\";s:36:\"bc10cacf-328a-491e-9ba0-4d72f49bdd4c\";s:8:\"revision\";s:3:\"458\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"458\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:11;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:11;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2865;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:13:\"ept_accordion\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:23:\"_layoutParagraphsLayout\";r:3;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"c1d65509-37e9-4ef2-9c23-fbd78fe17204\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:13:\"ept_accordion\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729022156;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:19:\"field_ept_accordion\";a:1:{s:9:\"x-default\";a:2:{i:0;a:5:{s:7:\"subform\";a:2:{s:24:\"field_ept_accordion_text\";a:1:{i:0;a:2:{s:5:\"value\";s:579:\"<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_accordion_title\";a:1:{i:0;a:2:{s:5:\"value\";s:48:\"<p>Cool! Can I create my own EPT/EBT module?</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:16:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"37923327-88d4-4fe3-84e9-3d4b9eef2c3e\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:21:\"ept_accordion_section\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729022156;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_accordion\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_accordion_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:579:\"<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_accordion_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:48:\"<p>Cool! Can I create my own EPT/EBT module?</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:21:\"ept_accordion_section\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"37923327-88d4-4fe3-84e9-3d4b9eef2c3e\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:2:{s:24:\"field_ept_accordion_text\";a:1:{i:0;a:2:{s:5:\"value\";s:419:\"<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\">DrupalBook</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_accordion_title\";a:1:{i:0;a:2:{s:5:\"value\";s:44:\"<p>Send feedback or idea for EPT modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:16:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"05578525-caa1-4526-aa56-56d6d3e9b6fc\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:21:\"ept_accordion_section\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729022156;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_accordion\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_accordion_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:419:\"<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\">DrupalBook</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_accordion_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:44:\"<p>Send feedback or idea for EPT modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:21:\"ept_accordion_section\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"05578525-caa1-4526-aa56-56d6d3e9b6fc\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:12:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"40\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"plus_minus_left\";s:11:\"collapsible\";i:1;s:6:\"closed\";i:1;s:6:\"opened\";i:0;s:16:\"closed_in_tablet\";i:0;s:16:\"closed_in_mobile\";i:0;s:6:\"active\";s:0:\"\";s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:10:\"<p>FAQ</p>\";}}}s:14:\"_referringItem\";r:2865;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_accordion\";s:8:\"revision\";N;s:2:\"id\";N;s:4:\"uuid\";s:36:\"c1d65509-37e9-4ef2-9c23-fbd78fe17204\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"62606d2bc15b54eadd3565f9b8d32b3b\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1729022518;}',1729627318),('tempstore.private.layout_paragraphs','1:69d91e43e1dba48851aa07fef7eee0b2',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"15\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728819683\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819683\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"29\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"30\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"34\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"15\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"15\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"29\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"29\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"29\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"29\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"30\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:759;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"30\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:759;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"30\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"30\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"34\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:937;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"34\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_tiles\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"31\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"3\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"31\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"3\";s:4:\"uuid\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";s:8:\"revision\";s:2:\"31\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"31\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:0;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"32\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"4\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"32\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"4\";s:4:\"uuid\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";s:8:\"revision\";s:2:\"32\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"32\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"33\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"5\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"33\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"5\";s:4:\"uuid\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";s:8:\"revision\";s:2:\"33\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"33\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:14:\"_referringItem\";r:937;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"34\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"34\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"69d91e43e1dba48851aa07fef7eee0b2\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728819951;}',1729424751),('tempstore.private.layout_paragraphs','1:700c3a89e2d56c630aa0c4da628e607f',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"67\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1729067014\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729064448\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729067014\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:2:\"40\";s:18:\"target_revision_id\";s:3:\"577\";}i:1;a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"578\";}i:2;a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"579\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:2:\"19\";s:8:\"revision\";s:2:\"67\";s:4:\"uuid\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"67\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"40\";s:18:\"target_revision_id\";s:3:\"577\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"40\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"577\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"93872b1e-0586-4e38-b8a5-5edca3c418e7\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729066868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:19:\"<p>Listing Page</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"50\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"50\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Stay tuned!</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:19:\"<h1>What\'s New</h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:2:\"40\";s:4:\"uuid\";s:36:\"93872b1e-0586-4e38-b8a5-5edca3c418e7\";s:8:\"revision\";s:3:\"577\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"577\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"578\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:751;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_block\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"39\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"578\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_block\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729065292\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"19\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:21:\"field_ept_block_block\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:8:\"settings\";a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}s:9:\"plugin_id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:14:\"_referringItem\";r:751;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_block\";s:2:\"id\";s:2:\"39\";s:4:\"uuid\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";s:8:\"revision\";s:3:\"578\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"578\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"579\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:959;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_views\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"38\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"579\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_views\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729064495\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:20:\"field_ept_views_view\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:9:\"target_id\";s:10:\"what_s_new\";s:10:\"display_id\";s:7:\"block_1\";s:4:\"data\";s:95:\"a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}\";}}}s:14:\"_referringItem\";r:959;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_views\";s:2:\"id\";s:2:\"38\";s:4:\"uuid\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";s:8:\"revision\";s:3:\"579\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"579\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"700c3a89e2d56c630aa0c4da628e607f\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1729067292;}',1729672092),('tempstore.private.layout_paragraphs','1:74519085d57da755fe74cf7de51ef2ce',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"37\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728936706\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728936706\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"270\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"271\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"275\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"278\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"279\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"280\";}i:6;a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"284\";}i:7;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"285\";}i:8;a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"296\";}i:9;a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"299\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"37\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"37\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:10:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"270\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:377;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"270\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:377;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"270\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"270\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"271\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:780;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"271\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:780;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"271\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"271\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"275\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:958;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"275\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"272\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"273\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"274\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:958;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"275\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"275\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"278\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1147;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"278\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"276\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"277\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1147;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"278\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"278\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"279\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1338;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"279\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1338;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"279\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"279\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"280\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1540;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"280\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1540;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"280\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"280\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"284\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1781;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:13:\"ept_slideshow\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"30\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"284\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:13:\"ept_slideshow\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728936575\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}}}}s:19:\"field_ept_slideshow\";a:1:{s:9:\"x-default\";a:3:{i:0;a:5:{s:7:\"subform\";a:4:{s:24:\"field_ept_slideshow_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:25:\"field_ept_slideshow_slide\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"20\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:24:\"field_ept_slideshow_text\";a:1:{i:0;a:2:{s:5:\"value\";s:93:\"<p>Margin, padding, border for each component. You can also set type of border and color.</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_slideshow_title\";a:1:{i:0;a:2:{s:5:\"value\";s:23:\"<p>DOM Box settings</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"27\";s:18:\"target_revision_id\";s:3:\"281\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"27\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"281\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:18:\"ept_slideshow_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"99c07029-1a55-4c8b-9253-35a63ab6dfb4\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728936096\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"30\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_slideshow\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:25:\"field_ept_slideshow_slide\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:1975;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"20\";}}}s:24:\"field_ept_slideshow_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:93:\"<p>Margin, padding, border for each component. You can also set type of border and color.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_slideshow_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:23:\"<p>DOM Box settings</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_slideshow_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:2:\"id\";s:2:\"27\";s:4:\"uuid\";s:36:\"99c07029-1a55-4c8b-9253-35a63ab6dfb4\";s:8:\"revision\";s:3:\"281\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"281\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:4:{s:24:\"field_ept_slideshow_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:25:\"field_ept_slideshow_slide\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"21\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:24:\"field_ept_slideshow_text\";a:1:{i:0;a:2:{s:5:\"value\";s:144:\"<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_slideshow_title\";a:1:{i:0;a:2:{s:5:\"value\";s:40:\"<p>Background color, image or video.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"28\";s:18:\"target_revision_id\";s:3:\"282\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"28\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"282\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:18:\"ept_slideshow_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"3c06beb1-0396-43fd-9447-84df05591b3f\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728936240\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"30\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_slideshow\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:25:\"field_ept_slideshow_slide\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2150;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"21\";}}}s:24:\"field_ept_slideshow_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:144:\"<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_slideshow_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:40:\"<p>Background color, image or video.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_slideshow_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:2:\"id\";s:2:\"28\";s:4:\"uuid\";s:36:\"3c06beb1-0396-43fd-9447-84df05591b3f\";s:8:\"revision\";s:3:\"282\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"282\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:4:{s:24:\"field_ept_slideshow_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:25:\"field_ept_slideshow_slide\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"22\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:24:\"field_ept_slideshow_text\";a:1:{i:0;a:2:{s:5:\"value\";s:100:\"<p>You can set up options for javascript plugins from the same configuration form for component.</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_slideshow_title\";a:1:{i:0;a:2:{s:5:\"value\";s:38:\"<p>Settings for javascript plugins</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"29\";s:18:\"target_revision_id\";s:3:\"283\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"29\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"283\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:18:\"ept_slideshow_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"73569f80-2633-4a12-9cfb-720de0540f8c\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728936467\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"30\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_slideshow\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:25:\"field_ept_slideshow_slide\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2325;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"22\";}}}s:24:\"field_ept_slideshow_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:100:\"<p>You can set up options for javascript plugins from the same configuration form for component.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_slideshow_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:38:\"<p>Settings for javascript plugins</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_slideshow_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:2:\"id\";s:2:\"29\";s:4:\"uuid\";s:36:\"73569f80-2633-4a12-9cfb-720de0540f8c\";s:8:\"revision\";s:3:\"283\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"283\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:40:\"<p>Each EPT module has rich settings</p>\";}}}s:14:\"_referringItem\";r:1781;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_slideshow\";s:2:\"id\";s:2:\"30\";s:4:\"uuid\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";s:8:\"revision\";s:3:\"284\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"284\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:7;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:7;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"285\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2540;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"285\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_quote\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728933345\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"18\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2540;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"285\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"285\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:8;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:8;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"296\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2734;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:12:\"ept_carousel\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"23\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"296\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:12:\"ept_carousel\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728934054\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_carousel\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:2:\"13\";s:18:\"target_revision_id\";s:3:\"286\";}i:1;a:2:{s:9:\"target_id\";s:2:\"14\";s:18:\"target_revision_id\";s:3:\"287\";}i:2;a:2:{s:9:\"target_id\";s:2:\"15\";s:18:\"target_revision_id\";s:3:\"288\";}i:3;a:2:{s:9:\"target_id\";s:2:\"16\";s:18:\"target_revision_id\";s:3:\"289\";}i:4;a:2:{s:9:\"target_id\";s:2:\"17\";s:18:\"target_revision_id\";s:3:\"290\";}i:5;a:2:{s:9:\"target_id\";s:2:\"18\";s:18:\"target_revision_id\";s:3:\"291\";}i:6;a:2:{s:9:\"target_id\";s:2:\"19\";s:18:\"target_revision_id\";s:3:\"292\";}i:7;a:2:{s:9:\"target_id\";s:2:\"20\";s:18:\"target_revision_id\";s:3:\"293\";}i:8;a:2:{s:9:\"target_id\";s:2:\"21\";s:18:\"target_revision_id\";s:3:\"294\";}i:9;a:2:{s:9:\"target_id\";s:2:\"22\";s:18:\"target_revision_id\";s:3:\"295\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<p>Find and download your Extra Paragraph Type</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2734;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:12:\"ept_carousel\";s:2:\"id\";s:2:\"23\";s:4:\"uuid\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";s:8:\"revision\";s:3:\"296\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"296\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:9;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:9;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"299\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:3014;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:11:\"ept_counter\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"26\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"299\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:11:\"ept_counter\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728935787\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_counter_items\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"24\";s:18:\"target_revision_id\";s:3:\"297\";}i:1;a:2:{s:9:\"target_id\";s:2:\"25\";s:18:\"target_revision_id\";s:3:\"298\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>Number of modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:3014;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:11:\"ept_counter\";s:2:\"id\";s:2:\"26\";s:4:\"uuid\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";s:8:\"revision\";s:3:\"299\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"299\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"74519085d57da755fe74cf7de51ef2ce\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728936828;}',1729541628);
INSERT INTO `key_value_expire` VALUES ('tempstore.private.layout_paragraphs','1:77ff93ff1a12f8931e85695a3b58628e',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"31\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728889330\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728889330\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:6:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"163\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"164\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"168\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"171\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"172\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"173\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"31\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"31\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:6:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"163\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:365;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"163\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:365;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"163\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"163\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"164\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:768;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"164\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:768;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"164\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"164\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"168\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:946;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"168\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"165\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"166\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"167\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:946;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"168\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"168\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"171\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1135;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"171\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"169\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"170\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1135;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"171\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"171\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"172\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1326;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"172\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1326;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"172\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"172\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"173\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1528;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"173\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1528;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"173\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"173\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"77ff93ff1a12f8931e85695a3b58628e\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728889692;}',1729494492),('tempstore.private.layout_paragraphs','1:78ef979d1c80cfbf332e03adff3ba22d',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728817647\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728817647\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"15\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"16\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"12\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"12\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"15\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:353;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"15\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:353;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"15\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"15\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:354;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"16\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:495;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:756;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"16\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:756;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"16\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"16\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:934;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:23:\"_layoutParagraphsLayout\";r:3;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_tiles\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728819327;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728819245;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:0;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728819245;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728819327;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:0:{}}s:14:\"_referringItem\";r:934;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:8:\"revision\";N;s:2:\"id\";N;s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"78ef979d1c80cfbf332e03adff3ba22d\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728819415;}',1729424215),('tempstore.private.layout_paragraphs','1:897a6be95f3c452dd92d7c96349d6e89',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:1:\"8\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728808800\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728808800\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:1:\"8\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:1:\"8\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:1:\"8\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:2:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:1:\"8\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:350;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:1:\"8\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:350;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:1:\"8\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:1:\"8\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:753;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"_referringItem\";r:753;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:8:\"ept_text\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728809668;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:3:{s:6:\"bundle\";s:8:\"ept_text\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"897a6be95f3c452dd92d7c96349d6e89\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728809719;}',1729414519),('tempstore.private.layout_paragraphs','1:8a5388b4d4a222cd3b40144aadb823df',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"24\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728884894\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728884894\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:5:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"92\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"93\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"97\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"100\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"101\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"24\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"24\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:5:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"92\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:362;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"92\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:362;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"92\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"92\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"93\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:765;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"93\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:765;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"93\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"93\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"97\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:943;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"97\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"94\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"95\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"96\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:943;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"97\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"97\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"100\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1132;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"100\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:2:\"98\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:2:\"99\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1132;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"100\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"100\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"101\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1323;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"10\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"101\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_image_gallery\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728884868\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:4:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"4\";s:6:\"weight\";s:1:\"0\";}i:1;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"5\";s:6:\"weight\";s:1:\"1\";}i:2;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"6\";s:6:\"weight\";s:1:\"2\";}i:3;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"7\";s:6:\"weight\";s:1:\"3\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1323;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"101\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"101\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"8a5388b4d4a222cd3b40144aadb823df\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728885200;}',1729490000),('tempstore.private.layout_paragraphs','1:9517a18d0b7bbbe8df709c418d760784',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"23\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728884118\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728884118\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:4:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"83\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"84\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"88\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:2:\"91\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"23\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"23\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:5:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"83\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:359;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"83\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:359;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"83\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"83\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:360;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"84\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:501;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:762;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"84\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:762;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"84\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"84\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:360;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"88\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:501;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:940;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"88\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"85\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"86\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"87\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:940;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"88\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"88\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:360;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:2:\"91\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:501;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1129;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"91\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:2:\"89\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:2:\"90\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1129;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:2:\"91\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"91\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1320;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:23:\"_layoutParagraphsLayout\";r:3;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_image_gallery\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728884868;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:3:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"4\";s:6:\"weight\";s:1:\"0\";}i:1;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"5\";s:6:\"weight\";s:1:\"1\";}i:2;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"6\";s:6:\"weight\";s:1:\"2\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1320;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:3:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"9517a18d0b7bbbe8df709c418d760784\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728884894;}',1729489694),('tempstore.private.layout_paragraphs','1:95fe2708534b0147e0e23d777fe2879a',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"17\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728820014\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728820014\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"41\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"42\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"46\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"17\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"17\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"41\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"41\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"41\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"41\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"42\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:759;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"42\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:759;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"42\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"42\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"46\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:937;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"46\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_tiles\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"43\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"3\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"43\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"3\";s:4:\"uuid\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";s:8:\"revision\";s:2:\"43\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"43\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:0;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"44\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"4\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"44\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"4\";s:4:\"uuid\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";s:8:\"revision\";s:2:\"44\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"44\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"45\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"5\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"45\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"5\";s:4:\"uuid\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";s:8:\"revision\";s:2:\"45\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"45\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:14:\"_referringItem\";r:937;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"46\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"46\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"95fe2708534b0147e0e23d777fe2879a\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728882972;}',1729487772),('tempstore.private.layout_paragraphs','1:9e0bae932a14bba9680411f621e10943',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"66\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1729066954\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729064448\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729066954\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:2:\"40\";s:18:\"target_revision_id\";s:3:\"574\";}i:1;a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"575\";}i:2;a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"576\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:2:\"19\";s:8:\"revision\";s:2:\"66\";s:4:\"uuid\";s:36:\"7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:10:\"What\'s New\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"66\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"40\";s:18:\"target_revision_id\";s:3:\"574\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:24:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"40\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"574\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:8:\"ept_hero\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"93872b1e-0586-4e38-b8a5-5edca3c418e7\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729066868\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"19\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:19:\"<p>Listing Page</p>\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"50\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"50\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:18:\"<p>Stay tuned!</p>\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:19:\"<h1>What\'s New</h1>\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;s:27:\"field_ept_hero_column_image\";a:1:{s:9:\"x-default\";a:0:{}}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:2:\"40\";s:4:\"uuid\";s:36:\"93872b1e-0586-4e38-b8a5-5edca3c418e7\";s:8:\"revision\";s:3:\"574\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"574\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"39\";s:18:\"target_revision_id\";s:3:\"575\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:781;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_block\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"39\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"575\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_block\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729065292\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:21:\"field_ept_block_block\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:9:\"plugin_id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:8:\"settings\";a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:14:\"_referringItem\";r:781;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_block\";s:2:\"id\";s:2:\"39\";s:4:\"uuid\";s:36:\"6e8df8b3-0097-4c28-a044-a1ffc40d37ea\";s:8:\"revision\";s:3:\"575\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"575\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"38\";s:18:\"target_revision_id\";s:3:\"576\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:963;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_views\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"38\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"576\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_views\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1729064495\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:2:\"19\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}}}}s:20:\"field_ept_views_view\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:9:\"target_id\";s:10:\"what_s_new\";s:10:\"display_id\";s:7:\"block_1\";s:4:\"data\";s:95:\"a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}\";}}}s:14:\"_referringItem\";r:963;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_views\";s:2:\"id\";s:2:\"38\";s:4:\"uuid\";s:36:\"27496e1b-7e55-4ef1-a324-6a0afdd5dce4\";s:8:\"revision\";s:3:\"576\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"576\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"9e0bae932a14bba9680411f621e10943\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1729067014;}',1729671814),('tempstore.private.layout_paragraphs','1:a0758887d72c0cf735f8962379b4fee5',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"43\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1729022518\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729022518\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:12:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"459\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"460\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"464\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"467\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"468\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"469\";}i:6;a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"473\";}i:7;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"474\";}i:8;a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"485\";}i:9;a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"488\";}i:10;a:2:{s:9:\"target_id\";s:2:\"33\";s:18:\"target_revision_id\";s:3:\"491\";}i:11;a:2:{s:9:\"target_id\";s:2:\"36\";s:18:\"target_revision_id\";s:3:\"494\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"43\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"43\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:12:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"459\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:383;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"459\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:383;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"459\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"459\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"460\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:786;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"460\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:786;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"460\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"460\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"464\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:964;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"464\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"461\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"462\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"463\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:964;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"464\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"464\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"467\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1153;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"467\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"465\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"466\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1153;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"467\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"467\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"468\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1344;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"468\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1344;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"468\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"468\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"469\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1546;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"469\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1546;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"469\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"469\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"473\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1787;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:13:\"ept_slideshow\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"30\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"473\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:13:\"ept_slideshow\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728936575\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}}}}s:19:\"field_ept_slideshow\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:2:\"27\";s:18:\"target_revision_id\";s:3:\"470\";}i:1;a:2:{s:9:\"target_id\";s:2:\"28\";s:18:\"target_revision_id\";s:3:\"471\";}i:2;a:2:{s:9:\"target_id\";s:2:\"29\";s:18:\"target_revision_id\";s:3:\"472\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:40:\"<p>Each EPT module has rich settings</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1787;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_slideshow\";s:2:\"id\";s:2:\"30\";s:4:\"uuid\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";s:8:\"revision\";s:3:\"473\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"473\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:7;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:7;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"474\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2004;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"474\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_quote\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728933345\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"18\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2004;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"474\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"474\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:8;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:8;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"485\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2198;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:12:\"ept_carousel\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"23\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"485\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:12:\"ept_carousel\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728934054\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_carousel\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:2:\"13\";s:18:\"target_revision_id\";s:3:\"475\";}i:1;a:2:{s:9:\"target_id\";s:2:\"14\";s:18:\"target_revision_id\";s:3:\"476\";}i:2;a:2:{s:9:\"target_id\";s:2:\"15\";s:18:\"target_revision_id\";s:3:\"477\";}i:3;a:2:{s:9:\"target_id\";s:2:\"16\";s:18:\"target_revision_id\";s:3:\"478\";}i:4;a:2:{s:9:\"target_id\";s:2:\"17\";s:18:\"target_revision_id\";s:3:\"479\";}i:5;a:2:{s:9:\"target_id\";s:2:\"18\";s:18:\"target_revision_id\";s:3:\"480\";}i:6;a:2:{s:9:\"target_id\";s:2:\"19\";s:18:\"target_revision_id\";s:3:\"481\";}i:7;a:2:{s:9:\"target_id\";s:2:\"20\";s:18:\"target_revision_id\";s:3:\"482\";}i:8;a:2:{s:9:\"target_id\";s:2:\"21\";s:18:\"target_revision_id\";s:3:\"483\";}i:9;a:2:{s:9:\"target_id\";s:2:\"22\";s:18:\"target_revision_id\";s:3:\"484\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<p>Find and download your Extra Paragraph Type</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2198;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:12:\"ept_carousel\";s:2:\"id\";s:2:\"23\";s:4:\"uuid\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";s:8:\"revision\";s:3:\"485\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"485\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:9;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:9;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"488\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2478;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:11:\"ept_counter\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"26\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"488\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:11:\"ept_counter\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728935787\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_counter_items\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"24\";s:18:\"target_revision_id\";s:3:\"486\";}i:1;a:2:{s:9:\"target_id\";s:2:\"25\";s:18:\"target_revision_id\";s:3:\"487\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>Number of modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2478;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:11:\"ept_counter\";s:2:\"id\";s:2:\"26\";s:4:\"uuid\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";s:8:\"revision\";s:3:\"488\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"488\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:10;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:10;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"33\";s:18:\"target_revision_id\";s:3:\"491\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2677;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_tabs\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"33\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"491\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_tabs\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"bc10cacf-328a-491e-9ba0-4d72f49bdd4c\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728937075\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}}}}s:14:\"field_ept_tabs\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"31\";s:18:\"target_revision_id\";s:3:\"489\";}i:1;a:2:{s:9:\"target_id\";s:2:\"32\";s:18:\"target_revision_id\";s:3:\"490\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:77:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2677;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_tabs\";s:2:\"id\";s:2:\"33\";s:4:\"uuid\";s:36:\"bc10cacf-328a-491e-9ba0-4d72f49bdd4c\";s:8:\"revision\";s:3:\"491\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"491\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:11;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:11;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"36\";s:18:\"target_revision_id\";s:3:\"494\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2868;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:13:\"ept_accordion\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"36\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"494\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:13:\"ept_accordion\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"c1d65509-37e9-4ef2-9c23-fbd78fe17204\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729022156\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:19:\"field_ept_accordion\";a:1:{s:9:\"x-default\";a:2:{i:0;a:5:{s:7:\"subform\";a:2:{s:24:\"field_ept_accordion_text\";a:1:{i:0;a:2:{s:5:\"value\";s:579:\"<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_accordion_title\";a:1:{i:0;a:2:{s:5:\"value\";s:48:\"<p>Cool! Can I create my own EPT/EBT module?</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"34\";s:18:\"target_revision_id\";s:3:\"492\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"34\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"492\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:21:\"ept_accordion_section\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"37923327-88d4-4fe3-84e9-3d4b9eef2c3e\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729022156\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"36\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_accordion\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:24:\"field_ept_accordion_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:579:\"<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_accordion_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:48:\"<p>Cool! Can I create my own EPT/EBT module?</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:21:\"ept_accordion_section\";s:2:\"id\";s:2:\"34\";s:4:\"uuid\";s:36:\"37923327-88d4-4fe3-84e9-3d4b9eef2c3e\";s:8:\"revision\";s:3:\"492\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"492\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:2:{s:24:\"field_ept_accordion_text\";a:1:{i:0;a:2:{s:5:\"value\";s:483:\"<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\" target=\"_blank\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\" target=\"_blank\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\" target=\"_blank\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\" target=\"_blank\">DrupalBook</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_accordion_title\";a:1:{i:0;a:2:{s:5:\"value\";s:44:\"<p>Send feedback or idea for EPT modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"35\";s:18:\"target_revision_id\";s:3:\"493\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"35\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"493\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:21:\"ept_accordion_section\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"05578525-caa1-4526-aa56-56d6d3e9b6fc\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729022156\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"36\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_accordion\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:24:\"field_ept_accordion_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:483:\"<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\" target=\"_blank\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\" target=\"_blank\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\" target=\"_blank\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\" target=\"_blank\">DrupalBook</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_accordion_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:44:\"<p>Send feedback or idea for EPT modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:21:\"ept_accordion_section\";s:2:\"id\";s:2:\"35\";s:4:\"uuid\";s:36:\"05578525-caa1-4526-aa56-56d6d3e9b6fc\";s:8:\"revision\";s:3:\"493\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"493\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:12:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"40\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"plus_minus_left\";s:11:\"collapsible\";i:1;s:6:\"closed\";i:1;s:6:\"opened\";i:0;s:16:\"closed_in_tablet\";i:0;s:16:\"closed_in_mobile\";i:0;s:6:\"active\";s:0:\"\";s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:10:\"<p>FAQ</p>\";}}}s:14:\"_referringItem\";r:2868;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_accordion\";s:2:\"id\";s:2:\"36\";s:4:\"uuid\";s:36:\"c1d65509-37e9-4ef2-9c23-fbd78fe17204\";s:8:\"revision\";s:3:\"494\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"494\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"a0758887d72c0cf735f8962379b4fee5\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1729022935;}',1729627735),('tempstore.private.layout_paragraphs','1:a8a77fe264c5775c4e2591b84ba09c6d',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"17\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728820014\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728820014\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"41\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"42\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"46\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"17\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"17\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"41\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"41\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"41\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"41\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:0;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"42\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:754;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"42\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:754;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"42\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"42\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:0;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"46\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:927;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"46\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"43\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"44\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"45\";}}}s:14:\"_referringItem\";r:927;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"46\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"46\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:0;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"a8a77fe264c5775c4e2591b84ba09c6d\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728849867;}',1729454667),('tempstore.private.layout_paragraphs','1:acc568327b0691c84042810bf8f6c98e',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"22\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728883938\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728883938\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:4:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"74\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"75\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"79\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:2:\"82\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"22\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"22\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:4:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"74\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:359;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"74\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:359;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"74\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"74\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:360;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"75\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:501;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:762;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"75\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:762;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"75\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"75\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:360;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"79\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:501;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:940;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"79\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"76\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"77\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"78\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:940;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"79\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"79\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:360;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:2:\"82\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:501;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1129;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"9\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"82\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_stats\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728883680\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:5:{s:7:\"subform\";a:4:{s:26:\"field_ept_stats_item_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:25:\"field_ept_stats_item_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:27:\"field_ept_stats_item_number\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_stats_item_text\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:2:\"80\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"7\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"80\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_stats_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"26311542-79cb-4dbd-afae-5eaaa37c8c3e\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728883680\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"9\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_stats\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:27:\"field_ept_stats_item_number\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_stats_item_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:26:\"field_ept_stats_item_image\";a:1:{s:9:\"x-default\";a:0:{}}s:25:\"field_ept_stats_item_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_stats_item\";s:2:\"id\";s:1:\"7\";s:4:\"uuid\";s:36:\"26311542-79cb-4dbd-afae-5eaaa37c8c3e\";s:8:\"revision\";s:2:\"80\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"80\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:4:{s:26:\"field_ept_stats_item_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:25:\"field_ept_stats_item_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:27:\"field_ept_stats_item_number\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_stats_item_text\";a:1:{i:0;a:2:{s:5:\"value\";s:90:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:2:\"81\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"8\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"81\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_stats_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"13a0b97c-311e-4742-821b-d4d27041731f\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728883680\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"9\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_stats\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:27:\"field_ept_stats_item_number\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_stats_item_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:90:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:26:\"field_ept_stats_item_image\";a:1:{s:9:\"x-default\";a:0:{}}s:25:\"field_ept_stats_item_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_stats_item\";s:2:\"id\";s:1:\"8\";s:4:\"uuid\";s:36:\"13a0b97c-311e-4742-821b-d4d27041731f\";s:8:\"revision\";s:2:\"81\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"81\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";}}}s:14:\"_referringItem\";r:1129;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:2:\"82\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"82\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"acc568327b0691c84042810bf8f6c98e\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728884118;}',1729488918),('tempstore.private.layout_paragraphs','1:b6ae8ab5139a5e0388dbe4182607cf4b',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728809815\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728809815\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"11\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"12\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"10\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"10\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:2:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"11\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:353;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:24:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"11\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:8:\"ept_hero\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242667\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:5:\"title\";s:17:\"EPT Documentation\";s:10:\"attributes\";a:0:{}s:7:\"options\";a:0:{}s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:5:\"title\";s:8:\"Download\";s:10:\"attributes\";a:0:{}s:7:\"options\";a:0:{}s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";}}}s:14:\"_referringItem\";r:353;s:23:\"_layoutParagraphsLayout\";r:3;s:27:\"field_ept_hero_column_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"11\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"11\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:354;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"12\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:495;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:782;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:782;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"12\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"12\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"b6ae8ab5139a5e0388dbe4182607cf4b\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728809849;}',1729414649),('tempstore.private.layout_paragraphs','1:b75f7d638a6f7041beb6d8e7e85cf1e4',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"21\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728883773\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728883773\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:4:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"65\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"66\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"70\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:2:\"73\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"21\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"21\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:4:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"65\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:359;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"65\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:359;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"65\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"65\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:360;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"66\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:501;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:762;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"66\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:762;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"66\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"66\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:360;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"70\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:501;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:940;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"70\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"67\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"68\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"69\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:940;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"70\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"70\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:360;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:2:\"73\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:501;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1129;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"9\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"73\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_stats\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728883680\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:5:{s:7:\"subform\";a:4:{s:26:\"field_ept_stats_item_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:25:\"field_ept_stats_item_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:27:\"field_ept_stats_item_number\";a:1:{i:0;a:2:{s:5:\"value\";s:551:\"<p><span style=\"background-color:rgb(255,255,255);color:rgb(34,34,34);\"><span style=\"-webkit-text-stroke-width:0px;display:inline !important;float:none;font-family:NotoSans, system-ui, sans-serif;font-size:16px;font-style:normal;font-variant-caps:normal;font-variant-ligatures:normal;font-weight:400;letter-spacing:normal;orphans:2;text-align:right;text-decoration-color:initial;text-decoration-style:initial;text-decoration-thickness:initial;text-indent:0px;text-transform:none;white-space:normal;widows:2;word-spacing:0px;\">721,320</span></span></p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_stats_item_text\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Websites use Drupal</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:2:\"71\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"7\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"71\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_stats_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"26311542-79cb-4dbd-afae-5eaaa37c8c3e\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728883680\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"9\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_stats\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:27:\"field_ept_stats_item_number\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:551:\"<p><span style=\"background-color:rgb(255,255,255);color:rgb(34,34,34);\"><span style=\"-webkit-text-stroke-width:0px;display:inline !important;float:none;font-family:NotoSans, system-ui, sans-serif;font-size:16px;font-style:normal;font-variant-caps:normal;font-variant-ligatures:normal;font-weight:400;letter-spacing:normal;orphans:2;text-align:right;text-decoration-color:initial;text-decoration-style:initial;text-decoration-thickness:initial;text-indent:0px;text-transform:none;white-space:normal;widows:2;word-spacing:0px;\">721,320</span></span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_stats_item_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Websites use Drupal</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:26:\"field_ept_stats_item_image\";a:1:{s:9:\"x-default\";a:0:{}}s:25:\"field_ept_stats_item_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_stats_item\";s:2:\"id\";s:1:\"7\";s:4:\"uuid\";s:36:\"26311542-79cb-4dbd-afae-5eaaa37c8c3e\";s:8:\"revision\";s:2:\"71\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"71\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:4:{s:26:\"field_ept_stats_item_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:25:\"field_ept_stats_item_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:27:\"field_ept_stats_item_number\";a:1:{i:0;a:2:{s:5:\"value\";s:14:\"<p>238,556</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_stats_item_text\";a:1:{i:0;a:2:{s:5:\"value\";s:45:\"<p>Usage statistics for Paragraphs module</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:2:\"72\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"8\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"72\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_stats_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"13a0b97c-311e-4742-821b-d4d27041731f\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728883680\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"9\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_stats\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:27:\"field_ept_stats_item_number\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:14:\"<p>238,556</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_stats_item_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:45:\"<p>Usage statistics for Paragraphs module</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:26:\"field_ept_stats_item_image\";a:1:{s:9:\"x-default\";a:0:{}}s:25:\"field_ept_stats_item_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_stats_item\";s:2:\"id\";s:1:\"8\";s:4:\"uuid\";s:36:\"13a0b97c-311e-4742-821b-d4d27041731f\";s:8:\"revision\";s:2:\"72\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"72\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:368:\"<p>Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</p>\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:34:\"<p>What Are Drupal Paragraphs?</p>\";}}}s:14:\"_referringItem\";r:1129;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:2:\"73\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"73\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"b75f7d638a6f7041beb6d8e7e85cf1e4\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728883938;}',1729488738),('tempstore.private.layout_paragraphs','1:b94707ffa3e006bdb55d73b4f20b65d9',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"29\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728888389\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728888389\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:5:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"142\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"143\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"147\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"150\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"151\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"29\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"29\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:6:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"142\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:362;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"142\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:362;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"142\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"142\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"143\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:765;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"143\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:765;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"143\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"143\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"147\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:943;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"147\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"144\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"145\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"146\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:943;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"147\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"147\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"150\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1132;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"150\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"148\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"149\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1132;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"150\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"150\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"151\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1323;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"151\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1323;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"151\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"151\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1525;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:23:\"_layoutParagraphsLayout\";r:3;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:7:\"ept_cta\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728888715;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"16\";s:6:\"weight\";i:0;}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:10:\"attributes\";a:0:{}s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:10:\"attributes\";a:0:{}s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:417:\"<p>EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p>EPT modules uses GLightbox for Image/Video in popups</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1525;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:3:{s:6:\"bundle\";s:7:\"ept_cta\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"b94707ffa3e006bdb55d73b4f20b65d9\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728889242;}',1729494042),('tempstore.private.layout_paragraphs','1:c126137da175595d7d0507389c2a4f78',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"36\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728935838\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728935838\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:9:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"244\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"245\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"249\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"252\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"253\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"254\";}i:6;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"255\";}i:7;a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"266\";}i:8;a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"269\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"36\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"36\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:10:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"244\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:374;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"244\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:374;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"244\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"244\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:375;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"245\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:516;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:777;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"245\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:777;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"245\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"245\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:375;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"249\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:516;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:955;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"249\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"246\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"247\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"248\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:955;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"249\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"249\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:375;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"252\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:516;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1144;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"252\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"250\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"251\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1144;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"252\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"252\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:375;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"253\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:516;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1335;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"253\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1335;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"253\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"253\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:375;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"254\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:516;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1537;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"254\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1537;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"254\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"254\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:375;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:516;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1778;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:13:\"ept_slideshow\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:23:\"_layoutParagraphsLayout\";r:3;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:13:\"ept_slideshow\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728936575;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:0;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}}}}s:19:\"field_ept_slideshow\";a:1:{s:9:\"x-default\";a:3:{i:0;a:5:{s:7:\"subform\";a:4:{s:24:\"field_ept_slideshow_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:25:\"field_ept_slideshow_slide\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"20\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:24:\"field_ept_slideshow_text\";a:1:{i:0;a:2:{s:5:\"value\";s:93:\"<p>Margin, padding, border for each component. You can also set type of border and color.</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_slideshow_title\";a:1:{i:0;a:2:{s:5:\"value\";s:23:\"<p>DOM Box settings</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:18:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"99c07029-1a55-4c8b-9253-35a63ab6dfb4\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:18:\"ept_slideshow_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728936096;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_slideshow\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_slideshow_link\";a:1:{s:9:\"x-default\";a:0:{}}s:25:\"field_ept_slideshow_slide\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:1963;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"20\";}}}s:24:\"field_ept_slideshow_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:93:\"<p>Margin, padding, border for each component. You can also set type of border and color.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_slideshow_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:23:\"<p>DOM Box settings</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"99c07029-1a55-4c8b-9253-35a63ab6dfb4\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:4:{s:24:\"field_ept_slideshow_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:25:\"field_ept_slideshow_slide\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"21\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:24:\"field_ept_slideshow_text\";a:1:{i:0;a:2:{s:5:\"value\";s:144:\"<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_slideshow_title\";a:1:{i:0;a:2:{s:5:\"value\";s:40:\"<p>Background color, image or video.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:18:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"3c06beb1-0396-43fd-9447-84df05591b3f\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:18:\"ept_slideshow_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728936240;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_slideshow\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_slideshow_link\";a:1:{s:9:\"x-default\";a:0:{}}s:25:\"field_ept_slideshow_slide\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2118;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"21\";}}}s:24:\"field_ept_slideshow_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:144:\"<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_slideshow_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:40:\"<p>Background color, image or video.</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"3c06beb1-0396-43fd-9447-84df05591b3f\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:4:{s:24:\"field_ept_slideshow_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:25:\"field_ept_slideshow_slide\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"22\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:24:\"field_ept_slideshow_text\";a:1:{i:0;a:2:{s:5:\"value\";s:100:\"<p>You can set up options for javascript plugins from the same configuration form for component.</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_slideshow_title\";a:1:{i:0;a:2:{s:5:\"value\";s:38:\"<p>Settings for javascript plugins</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:18:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"73569f80-2633-4a12-9cfb-720de0540f8c\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:18:\"ept_slideshow_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728936467;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_slideshow\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_slideshow_link\";a:1:{s:9:\"x-default\";a:0:{}}s:25:\"field_ept_slideshow_slide\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2273;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"22\";}}}s:24:\"field_ept_slideshow_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:100:\"<p>You can set up options for javascript plugins from the same configuration form for component.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_slideshow_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:38:\"<p>Settings for javascript plugins</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"73569f80-2633-4a12-9cfb-720de0540f8c\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:40:\"<p>Each EPT module has rich settings</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1778;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:3:{s:6:\"bundle\";s:13:\"ept_slideshow\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:7;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:375;s:7:\"\0*\0name\";i:7;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"255\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:516;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2460;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"255\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_quote\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728933345\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"18\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2460;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"255\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"255\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:8;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:375;s:7:\"\0*\0name\";i:8;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"266\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:516;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2654;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:12:\"ept_carousel\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"23\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"266\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:12:\"ept_carousel\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728934054\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_carousel\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:2:\"13\";s:18:\"target_revision_id\";s:3:\"256\";}i:1;a:2:{s:9:\"target_id\";s:2:\"14\";s:18:\"target_revision_id\";s:3:\"257\";}i:2;a:2:{s:9:\"target_id\";s:2:\"15\";s:18:\"target_revision_id\";s:3:\"258\";}i:3;a:2:{s:9:\"target_id\";s:2:\"16\";s:18:\"target_revision_id\";s:3:\"259\";}i:4;a:2:{s:9:\"target_id\";s:2:\"17\";s:18:\"target_revision_id\";s:3:\"260\";}i:5;a:2:{s:9:\"target_id\";s:2:\"18\";s:18:\"target_revision_id\";s:3:\"261\";}i:6;a:2:{s:9:\"target_id\";s:2:\"19\";s:18:\"target_revision_id\";s:3:\"262\";}i:7;a:2:{s:9:\"target_id\";s:2:\"20\";s:18:\"target_revision_id\";s:3:\"263\";}i:8;a:2:{s:9:\"target_id\";s:2:\"21\";s:18:\"target_revision_id\";s:3:\"264\";}i:9;a:2:{s:9:\"target_id\";s:2:\"22\";s:18:\"target_revision_id\";s:3:\"265\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<p>Find and download your Extra Paragraph Type</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2654;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:12:\"ept_carousel\";s:2:\"id\";s:2:\"23\";s:4:\"uuid\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";s:8:\"revision\";s:3:\"266\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"266\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:9;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:9;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"269\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2934;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:11:\"ept_counter\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"26\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"269\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:11:\"ept_counter\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728935787\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:23:\"field_ept_counter_items\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"24\";s:18:\"target_revision_id\";s:3:\"267\";}i:1;a:2:{s:9:\"target_id\";s:2:\"25\";s:18:\"target_revision_id\";s:3:\"268\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>Number of modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2934;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:11:\"ept_counter\";s:2:\"id\";s:2:\"26\";s:4:\"uuid\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";s:8:\"revision\";s:3:\"269\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"269\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"c126137da175595d7d0507389c2a4f78\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728936706;}',1729541506),('tempstore.private.layout_paragraphs','1:ce8fe7ab6636a4a9d3e564c958a60a60',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"44\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1729022935\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729022935\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:12:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"495\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"496\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"500\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"503\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"504\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"505\";}i:6;a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"509\";}i:7;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"510\";}i:8;a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"521\";}i:9;a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"524\";}i:10;a:2:{s:9:\"target_id\";s:2:\"33\";s:18:\"target_revision_id\";s:3:\"527\";}i:11;a:2:{s:9:\"target_id\";s:2:\"36\";s:18:\"target_revision_id\";s:3:\"530\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"44\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"44\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:12:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"495\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:383;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"495\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:383;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"495\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"495\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"496\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:786;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"496\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:786;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"496\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"496\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"500\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:964;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"500\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"497\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"498\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"499\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:964;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"500\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"500\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"503\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1153;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"503\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"501\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"502\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1153;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"503\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"503\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"504\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1344;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"504\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1344;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"504\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"504\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"505\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1546;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"505\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1546;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"505\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"505\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"509\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1787;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:13:\"ept_slideshow\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"30\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"509\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:13:\"ept_slideshow\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728936575\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}}}}s:19:\"field_ept_slideshow\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:2:\"27\";s:18:\"target_revision_id\";s:3:\"506\";}i:1;a:2:{s:9:\"target_id\";s:2:\"28\";s:18:\"target_revision_id\";s:3:\"507\";}i:2;a:2:{s:9:\"target_id\";s:2:\"29\";s:18:\"target_revision_id\";s:3:\"508\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:40:\"<p>Each EPT module has rich settings</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1787;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_slideshow\";s:2:\"id\";s:2:\"30\";s:4:\"uuid\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";s:8:\"revision\";s:3:\"509\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"509\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:7;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:7;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"510\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2004;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"510\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_quote\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728933345\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"18\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2004;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"510\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"510\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:8;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:8;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"521\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2198;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:12:\"ept_carousel\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"23\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"521\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:12:\"ept_carousel\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728934054\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_carousel\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:2:\"13\";s:18:\"target_revision_id\";s:3:\"511\";}i:1;a:2:{s:9:\"target_id\";s:2:\"14\";s:18:\"target_revision_id\";s:3:\"512\";}i:2;a:2:{s:9:\"target_id\";s:2:\"15\";s:18:\"target_revision_id\";s:3:\"513\";}i:3;a:2:{s:9:\"target_id\";s:2:\"16\";s:18:\"target_revision_id\";s:3:\"514\";}i:4;a:2:{s:9:\"target_id\";s:2:\"17\";s:18:\"target_revision_id\";s:3:\"515\";}i:5;a:2:{s:9:\"target_id\";s:2:\"18\";s:18:\"target_revision_id\";s:3:\"516\";}i:6;a:2:{s:9:\"target_id\";s:2:\"19\";s:18:\"target_revision_id\";s:3:\"517\";}i:7;a:2:{s:9:\"target_id\";s:2:\"20\";s:18:\"target_revision_id\";s:3:\"518\";}i:8;a:2:{s:9:\"target_id\";s:2:\"21\";s:18:\"target_revision_id\";s:3:\"519\";}i:9;a:2:{s:9:\"target_id\";s:2:\"22\";s:18:\"target_revision_id\";s:3:\"520\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<p>Find and download your Extra Paragraph Type</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2198;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:12:\"ept_carousel\";s:2:\"id\";s:2:\"23\";s:4:\"uuid\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";s:8:\"revision\";s:3:\"521\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"521\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:9;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:9;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"524\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2478;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:11:\"ept_counter\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"26\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"524\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:11:\"ept_counter\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728935787\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_counter_items\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"24\";s:18:\"target_revision_id\";s:3:\"522\";}i:1;a:2:{s:9:\"target_id\";s:2:\"25\";s:18:\"target_revision_id\";s:3:\"523\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>Number of modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2478;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:11:\"ept_counter\";s:2:\"id\";s:2:\"26\";s:4:\"uuid\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";s:8:\"revision\";s:3:\"524\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"524\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:10;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:10;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"33\";s:18:\"target_revision_id\";s:3:\"527\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2677;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_tabs\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"33\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"527\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_tabs\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"bc10cacf-328a-491e-9ba0-4d72f49bdd4c\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728937075\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}}}}s:14:\"field_ept_tabs\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"31\";s:18:\"target_revision_id\";s:3:\"525\";}i:1;a:2:{s:9:\"target_id\";s:2:\"32\";s:18:\"target_revision_id\";s:3:\"526\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:77:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2677;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_tabs\";s:2:\"id\";s:2:\"33\";s:4:\"uuid\";s:36:\"bc10cacf-328a-491e-9ba0-4d72f49bdd4c\";s:8:\"revision\";s:3:\"527\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"527\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:11;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:384;s:7:\"\0*\0name\";i:11;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"36\";s:18:\"target_revision_id\";s:3:\"530\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:525;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2868;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:13:\"ept_accordion\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"36\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"530\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:13:\"ept_accordion\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"c1d65509-37e9-4ef2-9c23-fbd78fe17204\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729022156\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:19:\"field_ept_accordion\";a:1:{s:9:\"x-default\";a:3:{i:0;a:5:{s:7:\"subform\";a:2:{s:24:\"field_ept_accordion_text\";a:1:{i:0;a:2:{s:5:\"value\";s:471:\"<p>You can install EPT modules as usual Drupal module. Download them with composer, for example:</p><pre><code class=\"language-plaintext\">composer require drupal/ept_tabs</code></pre><p>And then install EPT module as usual.</p><p><a href=\"https://www.drupal.org/docs/develop/using-composer/manage-dependencies#adding-modules\">Download contributed modules using Composer</a></p><p>That\'s it!&nbsp;</p><p>All dependencies will be downloaded with composer automatically.</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_accordion_title\";a:1:{i:0;a:2:{s:5:\"value\";s:58:\"<p>How to install Extra Paragraph Types (EPT) modules?</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:16:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"c2fdfa00-3d9e-4e59-89a0-05f5ebf0ed9a\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:21:\"ept_accordion_section\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1729024475;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"36\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_accordion\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_accordion_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:471:\"<p>You can install EPT modules as usual Drupal module. Download them with composer, for example:</p><pre><code class=\"language-plaintext\">composer require drupal/ept_tabs</code></pre><p>And then install EPT module as usual.</p><p><a href=\"https://www.drupal.org/docs/develop/using-composer/manage-dependencies#adding-modules\">Download contributed modules using Composer</a></p><p>That\'s it!&nbsp;</p><p>All dependencies will be downloaded with composer automatically.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_accordion_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:58:\"<p>How to install Extra Paragraph Types (EPT) modules?</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:21:\"ept_accordion_section\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"c2fdfa00-3d9e-4e59-89a0-05f5ebf0ed9a\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:2:{s:24:\"field_ept_accordion_text\";a:1:{i:0;a:2:{s:5:\"value\";s:579:\"<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_accordion_title\";a:1:{i:0;a:2:{s:5:\"value\";s:48:\"<p>Cool! Can I create my own EPT/EBT module?</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"34\";s:18:\"target_revision_id\";s:3:\"528\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"34\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"528\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:21:\"ept_accordion_section\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"37923327-88d4-4fe3-84e9-3d4b9eef2c3e\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729022156\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"36\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_accordion\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_accordion_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:579:\"<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_accordion_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:48:\"<p>Cool! Can I create my own EPT/EBT module?</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:21:\"ept_accordion_section\";s:2:\"id\";s:2:\"34\";s:4:\"uuid\";s:36:\"37923327-88d4-4fe3-84e9-3d4b9eef2c3e\";s:8:\"revision\";s:3:\"528\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"528\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:2:{s:24:\"field_ept_accordion_text\";a:1:{i:0;a:2:{s:5:\"value\";s:483:\"<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\" target=\"_blank\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\" target=\"_blank\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\" target=\"_blank\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\" target=\"_blank\">DrupalBook</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_accordion_title\";a:1:{i:0;a:2:{s:5:\"value\";s:44:\"<p>Send feedback or idea for EPT modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"35\";s:18:\"target_revision_id\";s:3:\"529\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:17:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"35\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"529\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:21:\"ept_accordion_section\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"05578525-caa1-4526-aa56-56d6d3e9b6fc\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1729022156\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"36\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_accordion\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:24:\"field_ept_accordion_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:483:\"<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\" target=\"_blank\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\" target=\"_blank\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\" target=\"_blank\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\" target=\"_blank\">DrupalBook</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_accordion_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:44:\"<p>Send feedback or idea for EPT modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:21:\"ept_accordion_section\";s:2:\"id\";s:2:\"35\";s:4:\"uuid\";s:36:\"05578525-caa1-4526-aa56-56d6d3e9b6fc\";s:8:\"revision\";s:3:\"529\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"529\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:12:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"40\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"plus_minus_left\";s:11:\"collapsible\";i:1;s:6:\"closed\";i:1;s:6:\"opened\";i:0;s:16:\"closed_in_tablet\";i:0;s:16:\"closed_in_mobile\";i:0;s:6:\"active\";s:0:\"\";s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:10:\"<p>FAQ</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2868;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_accordion\";s:2:\"id\";s:2:\"36\";s:4:\"uuid\";s:36:\"c1d65509-37e9-4ef2-9c23-fbd78fe17204\";s:8:\"revision\";s:3:\"530\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"530\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"ce8fe7ab6636a4a9d3e564c958a60a60\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1729024760;}',1729629560),('tempstore.private.layout_paragraphs','1:d184c81623d6461e7f459db77391f669',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"18\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728882972\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728882972\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"47\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"48\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"52\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"18\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"18\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"47\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"47\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"47\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"47\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"48\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:759;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"48\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:759;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"48\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"48\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"52\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:937;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"52\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_tiles\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"49\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"3\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"49\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:91:\"<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:26:\"<p>Install EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"3\";s:4:\"uuid\";s:36:\"34bcf35b-46b1-40fe-945d-8fb70d8699b6\";s:8:\"revision\";s:2:\"49\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"49\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:0;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"50\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"4\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"50\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819245\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:71:\"<p>Enable and configure paragraph types based on your project needs</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:32:\"<p>Configure Paragraph Types</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"4\";s:4:\"uuid\";s:36:\"ca1814e1-24d2-4312-87ce-300646c90af5\";s:8:\"revision\";s:2:\"50\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"50\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:5:{s:24:\"field_ept_clickable_tile\";a:1:{s:5:\"value\";i:1;}s:21:\"field_ept_tiles_image\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:20:\"field_ept_tiles_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:10:\"attributes\";a:0:{}}}s:20:\"field_ept_tiles_text\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}s:21:\"field_ept_tiles_title\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"51\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"5\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"51\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:14:\"ept_tiles_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728819327\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"6\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:15:\"field_ept_tiles\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_clickable_tile\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}}s:20:\"field_ept_tiles_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:4:{s:10:\"attributes\";a:0:{}s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:20:\"field_ept_tiles_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:107:\"<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:21:\"<p>Start Creating</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_tiles_image\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:14:\"ept_tiles_item\";s:2:\"id\";s:1:\"5\";s:4:\"uuid\";s:36:\"41b512ea-5da1-4d79-8932-848dd65fbede\";s:8:\"revision\";s:2:\"51\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"51\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";}}}s:14:\"_referringItem\";r:937;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"52\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"52\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"d184c81623d6461e7f459db77391f669\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728883069;}',1729487869);
INSERT INTO `key_value_expire` VALUES ('tempstore.private.layout_paragraphs','1:da57b3312bdb1390762fbcf384bb9db6',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"31\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728889330\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728889330\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:6:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"163\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"164\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"168\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"171\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"172\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"173\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"31\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"31\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:7:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"163\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:365;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"163\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:365;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"163\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"163\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"164\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:768;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"164\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:768;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"164\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"164\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"168\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:946;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"168\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"165\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"166\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"167\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:946;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"168\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"168\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"171\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1135;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"171\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"169\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"170\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1135;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"171\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"171\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"172\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1326;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"172\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1326;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"172\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"172\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:366;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"173\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:507;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1528;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"173\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1528;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"173\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"173\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1769;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:23:\"_layoutParagraphsLayout\";r:3;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:9:\"ept_quote\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728933345;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"18\";s:6:\"weight\";i:0;}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1769;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:3:{s:6:\"bundle\";s:9:\"ept_quote\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"da57b3312bdb1390762fbcf384bb9db6\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728933423;}',1729538223),('tempstore.private.layout_paragraphs','1:e046f2c3f415ff99131c05536a92d8d3',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"25\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728885200\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728885200\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:5:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"102\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"103\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"107\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"110\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"111\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"25\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"25\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:5:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"102\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:362;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"102\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:362;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"102\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"102\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"103\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:765;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"103\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:765;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"103\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"103\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"107\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:943;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"107\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"104\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"105\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"106\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:943;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"107\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"107\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"110\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1132;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"110\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"108\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"109\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1132;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"110\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"110\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:363;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"111\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:504;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1323;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"10\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"111\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:17:\"ept_image_gallery\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728884868\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:4:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"4\";s:6:\"weight\";s:1:\"0\";}i:1;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"5\";s:6:\"weight\";s:1:\"1\";}i:2;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"6\";s:6:\"weight\";s:1:\"2\";}i:3;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:1:\"7\";s:6:\"weight\";s:1:\"3\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1323;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"111\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"111\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"e046f2c3f415ff99131c05536a92d8d3\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728885506;}',1729490306),('tempstore.private.layout_paragraphs','1:e3bd212968162db5f06efc8c4e34cb1f',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"17\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728820014\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728820014\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"41\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"42\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"46\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"17\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"17\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:3:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:2:\"41\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:356;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"41\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:356;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:2:\"41\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"41\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:2:\"42\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:759;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"42\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:759;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:2:\"42\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"42\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:357;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:2:\"46\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:498;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:937;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:2:\"46\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:2:\"43\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:2:\"44\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:2:\"45\";}}}s:14:\"_referringItem\";r:937;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:2:\"46\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"46\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"e3bd212968162db5f06efc8c4e34cb1f\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728821689;}',1729426489),('tempstore.private.layout_paragraphs','1:ee3524c072413f8c3ea62598b1483ae9',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"40\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728937164\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728937164\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:11:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"360\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"361\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"365\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"368\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"369\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"370\";}i:6;a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"374\";}i:7;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"375\";}i:8;a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"386\";}i:9;a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"389\";}i:10;a:2:{s:9:\"target_id\";s:2:\"33\";s:18:\"target_revision_id\";s:3:\"392\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"40\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"40\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:11:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"360\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:380;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"360\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:380;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"360\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"360\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"361\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:783;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"361\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:783;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"361\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"361\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"365\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:961;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"365\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"362\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"363\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"364\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:961;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"365\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"365\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"368\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1150;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"368\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"366\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"367\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1150;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"368\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"368\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"369\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1341;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"369\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1341;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"369\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"369\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"370\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1543;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"370\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1543;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"370\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"370\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"374\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1784;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:13:\"ept_slideshow\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"30\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"374\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:13:\"ept_slideshow\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728936575\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}}}}s:19:\"field_ept_slideshow\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:2:\"27\";s:18:\"target_revision_id\";s:3:\"371\";}i:1;a:2:{s:9:\"target_id\";s:2:\"28\";s:18:\"target_revision_id\";s:3:\"372\";}i:2;a:2:{s:9:\"target_id\";s:2:\"29\";s:18:\"target_revision_id\";s:3:\"373\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:40:\"<p>Each EPT module has rich settings</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1784;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_slideshow\";s:2:\"id\";s:2:\"30\";s:4:\"uuid\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";s:8:\"revision\";s:3:\"374\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"374\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:7;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:7;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"375\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2001;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"375\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_quote\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728933345\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"18\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2001;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"375\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"375\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:8;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:8;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"386\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2195;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:12:\"ept_carousel\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"23\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"386\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:12:\"ept_carousel\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728934054\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_carousel\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:2:\"13\";s:18:\"target_revision_id\";s:3:\"376\";}i:1;a:2:{s:9:\"target_id\";s:2:\"14\";s:18:\"target_revision_id\";s:3:\"377\";}i:2;a:2:{s:9:\"target_id\";s:2:\"15\";s:18:\"target_revision_id\";s:3:\"378\";}i:3;a:2:{s:9:\"target_id\";s:2:\"16\";s:18:\"target_revision_id\";s:3:\"379\";}i:4;a:2:{s:9:\"target_id\";s:2:\"17\";s:18:\"target_revision_id\";s:3:\"380\";}i:5;a:2:{s:9:\"target_id\";s:2:\"18\";s:18:\"target_revision_id\";s:3:\"381\";}i:6;a:2:{s:9:\"target_id\";s:2:\"19\";s:18:\"target_revision_id\";s:3:\"382\";}i:7;a:2:{s:9:\"target_id\";s:2:\"20\";s:18:\"target_revision_id\";s:3:\"383\";}i:8;a:2:{s:9:\"target_id\";s:2:\"21\";s:18:\"target_revision_id\";s:3:\"384\";}i:9;a:2:{s:9:\"target_id\";s:2:\"22\";s:18:\"target_revision_id\";s:3:\"385\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<p>Find and download your Extra Paragraph Type</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2195;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:12:\"ept_carousel\";s:2:\"id\";s:2:\"23\";s:4:\"uuid\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";s:8:\"revision\";s:3:\"386\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"386\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:9;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:9;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"389\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2475;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:11:\"ept_counter\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"26\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"389\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:11:\"ept_counter\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728935787\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_counter_items\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"24\";s:18:\"target_revision_id\";s:3:\"387\";}i:1;a:2:{s:9:\"target_id\";s:2:\"25\";s:18:\"target_revision_id\";s:3:\"388\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>Number of modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2475;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:11:\"ept_counter\";s:2:\"id\";s:2:\"26\";s:4:\"uuid\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";s:8:\"revision\";s:3:\"389\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"389\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:10;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:10;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"33\";s:18:\"target_revision_id\";s:3:\"392\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2674;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_tabs\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"33\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"392\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:8:\"ept_tabs\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"bc10cacf-328a-491e-9ba0-4d72f49bdd4c\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728937075\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}}}}s:14:\"field_ept_tabs\";a:1:{s:9:\"x-default\";a:2:{i:0;a:5:{s:7:\"subform\";a:6:{s:19:\"field_ept_tab_block\";a:1:{i:0;a:1:{s:9:\"plugin_id\";s:0:\"\";}}s:21:\"field_ept_tab_content\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"text\";}}s:18:\"field_ept_tab_page\";a:1:{i:0;a:1:{s:9:\"target_id\";N;}}s:18:\"field_ept_tab_text\";a:1:{i:0;a:2:{s:5:\"value\";s:2647:\"<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}s:19:\"field_ept_tab_title\";a:1:{i:0;a:2:{s:5:\"value\";s:11:\"EPT modules\";s:6:\"format\";s:9:\"full_html\";}}s:19:\"field_ept_tab_views\";a:1:{i:0;a:2:{s:9:\"target_id\";N;s:10:\"display_id\";s:0:\"\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"31\";s:18:\"target_revision_id\";s:3:\"390\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"31\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"390\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:13:\"ept_tabs_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"03e1362a-b7df-4469-b71d-5195bdeb4904\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728937075\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"33\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:14:\"field_ept_tabs\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:21:\"field_ept_tab_content\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"text\";}}}s:18:\"field_ept_tab_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:2647:\"<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}}s:19:\"field_ept_tab_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:11:\"EPT modules\";s:6:\"format\";s:9:\"full_html\";}}}s:19:\"field_ept_tab_block\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_tab_page\";a:1:{s:9:\"x-default\";a:0:{}}s:19:\"field_ept_tab_views\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_tabs_item\";s:2:\"id\";s:2:\"31\";s:4:\"uuid\";s:36:\"03e1362a-b7df-4469-b71d-5195bdeb4904\";s:8:\"revision\";s:3:\"390\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"390\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:6:{s:19:\"field_ept_tab_block\";a:1:{i:0;a:1:{s:9:\"plugin_id\";s:0:\"\";}}s:21:\"field_ept_tab_content\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"text\";}}s:18:\"field_ept_tab_page\";a:1:{i:0;a:1:{s:9:\"target_id\";N;}}s:18:\"field_ept_tab_text\";a:1:{i:0;a:2:{s:5:\"value\";s:2635:\"<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}s:19:\"field_ept_tab_title\";a:1:{i:0;a:2:{s:5:\"value\";s:11:\"EBT Modules\";s:6:\"format\";s:9:\"full_html\";}}s:19:\"field_ept_tab_views\";a:1:{i:0;a:2:{s:9:\"target_id\";N;s:10:\"display_id\";s:0:\"\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"32\";s:18:\"target_revision_id\";s:3:\"391\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"32\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"391\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:13:\"ept_tabs_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"3747fc91-691d-4dac-a4df-e51cf0a0d5a1\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728937075\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"33\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:14:\"field_ept_tabs\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:21:\"field_ept_tab_content\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"text\";}}}s:18:\"field_ept_tab_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:2635:\"<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}}s:19:\"field_ept_tab_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:11:\"EBT Modules\";s:6:\"format\";s:9:\"full_html\";}}}s:19:\"field_ept_tab_block\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_tab_page\";a:1:{s:9:\"x-default\";a:0:{}}s:19:\"field_ept_tab_views\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_tabs_item\";s:2:\"id\";s:2:\"32\";s:4:\"uuid\";s:36:\"3747fc91-691d-4dac-a4df-e51cf0a0d5a1\";s:8:\"revision\";s:3:\"391\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"391\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:80:\"<p>List of all Extra Paragraph Types (EPT) and Extra Block Types (EBT)&nbsp;</p>\";}}}s:14:\"_referringItem\";r:2674;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_tabs\";s:2:\"id\";s:2:\"33\";s:4:\"uuid\";s:36:\"bc10cacf-328a-491e-9ba0-4d72f49bdd4c\";s:8:\"revision\";s:3:\"392\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"392\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"ee3524c072413f8c3ea62598b1483ae9\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728937228;}',1729542028),('tempstore.private.layout_paragraphs','1:f608dabda30cca8f970060c5f94a7683',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"35\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728934262\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728934262\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:8:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"221\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"222\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"226\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"229\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"230\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"231\";}i:6;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"232\";}i:7;a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"243\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"35\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"35\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:8:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"221\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:371;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"221\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:371;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"221\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"221\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"222\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:774;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"222\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:774;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"222\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"222\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"226\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:952;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"226\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"223\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"224\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"225\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:952;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"226\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"226\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"229\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1141;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"229\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"227\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"228\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1141;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"229\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"229\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"230\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1332;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"230\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1332;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"230\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"230\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"231\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1534;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"231\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1534;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"231\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"231\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"232\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1775;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"232\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_quote\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728933345\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"18\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1775;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"232\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"232\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:7;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:7;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"243\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1969;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:12:\"ept_carousel\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"23\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"243\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:12:\"ept_carousel\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728934054\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_carousel\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:2:\"13\";s:18:\"target_revision_id\";s:3:\"233\";}i:1;a:2:{s:9:\"target_id\";s:2:\"14\";s:18:\"target_revision_id\";s:3:\"234\";}i:2;a:2:{s:9:\"target_id\";s:2:\"15\";s:18:\"target_revision_id\";s:3:\"235\";}i:3;a:2:{s:9:\"target_id\";s:2:\"16\";s:18:\"target_revision_id\";s:3:\"236\";}i:4;a:2:{s:9:\"target_id\";s:2:\"17\";s:18:\"target_revision_id\";s:3:\"237\";}i:5;a:2:{s:9:\"target_id\";s:2:\"18\";s:18:\"target_revision_id\";s:3:\"238\";}i:6;a:2:{s:9:\"target_id\";s:2:\"19\";s:18:\"target_revision_id\";s:3:\"239\";}i:7;a:2:{s:9:\"target_id\";s:2:\"20\";s:18:\"target_revision_id\";s:3:\"240\";}i:8;a:2:{s:9:\"target_id\";s:2:\"21\";s:18:\"target_revision_id\";s:3:\"241\";}i:9;a:2:{s:9:\"target_id\";s:2:\"22\";s:18:\"target_revision_id\";s:3:\"242\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<p>Find and download your Extra Paragraph Type</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1969;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:12:\"ept_carousel\";s:2:\"id\";s:2:\"23\";s:4:\"uuid\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";s:8:\"revision\";s:3:\"243\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"243\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"f608dabda30cca8f970060c5f94a7683\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728935353;}',1729540153),('tempstore.private.layout_paragraphs','1:f8c7736ff48435ec400d13b6b9152e75',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"38\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728936828\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728936828\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"300\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"301\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"305\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"308\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"309\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"310\";}i:6;a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"314\";}i:7;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"315\";}i:8;a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"326\";}i:9;a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"329\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"38\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"38\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:10:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"300\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:377;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"300\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:377;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"300\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"300\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"301\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:780;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"301\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:780;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"301\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"301\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"305\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:958;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"305\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"302\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"303\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"304\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:958;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"305\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"305\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"308\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1147;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"308\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"306\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"307\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1147;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"308\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"308\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"309\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1338;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"309\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1338;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"309\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"309\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"310\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1540;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"310\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1540;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"310\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"310\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"314\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1781;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:13:\"ept_slideshow\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"30\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"314\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:13:\"ept_slideshow\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728936575\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}}}}s:19:\"field_ept_slideshow\";a:1:{s:9:\"x-default\";a:3:{i:0;a:5:{s:7:\"subform\";a:4:{s:24:\"field_ept_slideshow_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:25:\"field_ept_slideshow_slide\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"20\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:24:\"field_ept_slideshow_text\";a:1:{i:0;a:2:{s:5:\"value\";s:93:\"<p>Margin, padding, border for each component. You can also set type of border and color.</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_slideshow_title\";a:1:{i:0;a:2:{s:5:\"value\";s:23:\"<p>DOM Box settings</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"27\";s:18:\"target_revision_id\";s:3:\"311\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"27\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"311\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:18:\"ept_slideshow_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"99c07029-1a55-4c8b-9253-35a63ab6dfb4\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728936096\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"30\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_slideshow\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:25:\"field_ept_slideshow_slide\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:1975;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"20\";}}}s:24:\"field_ept_slideshow_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:93:\"<p>Margin, padding, border for each component. You can also set type of border and color.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_slideshow_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:23:\"<p>DOM Box settings</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_slideshow_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:2:\"id\";s:2:\"27\";s:4:\"uuid\";s:36:\"99c07029-1a55-4c8b-9253-35a63ab6dfb4\";s:8:\"revision\";s:3:\"311\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"311\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:4:{s:24:\"field_ept_slideshow_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:25:\"field_ept_slideshow_slide\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"21\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:24:\"field_ept_slideshow_text\";a:1:{i:0;a:2:{s:5:\"value\";s:144:\"<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_slideshow_title\";a:1:{i:0;a:2:{s:5:\"value\";s:40:\"<p>Background color, image or video.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"28\";s:18:\"target_revision_id\";s:3:\"312\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"28\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"312\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:18:\"ept_slideshow_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"3c06beb1-0396-43fd-9447-84df05591b3f\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728936240\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"30\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_slideshow\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:25:\"field_ept_slideshow_slide\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2148;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"21\";}}}s:24:\"field_ept_slideshow_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:144:\"<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_slideshow_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:40:\"<p>Background color, image or video.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_slideshow_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:2:\"id\";s:2:\"28\";s:4:\"uuid\";s:36:\"3c06beb1-0396-43fd-9447-84df05591b3f\";s:8:\"revision\";s:3:\"312\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"312\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:2;a:5:{s:7:\"subform\";a:4:{s:24:\"field_ept_slideshow_link\";a:1:{i:0;a:3:{s:3:\"uri\";s:0:\"\";s:5:\"title\";s:0:\"\";s:10:\"attributes\";a:0:{}}}s:25:\"field_ept_slideshow_slide\";a:4:{s:9:\"selection\";a:1:{i:0;a:3:{s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"target_id\";s:2:\"22\";s:6:\"weight\";i:0;}}s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:24:\"field_ept_slideshow_text\";a:1:{i:0;a:2:{s:5:\"value\";s:100:\"<p>You can set up options for javascript plugins from the same configuration form for component.</p>\";s:6:\"format\";s:9:\"full_html\";}}s:25:\"field_ept_slideshow_title\";a:1:{i:0;a:2:{s:5:\"value\";s:38:\"<p>Settings for javascript plugins</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"29\";s:18:\"target_revision_id\";s:3:\"313\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:19:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"29\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"313\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:18:\"ept_slideshow_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"73569f80-2633-4a12-9cfb-720de0540f8c\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728936467\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"30\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:19:\"field_ept_slideshow\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:25:\"field_ept_slideshow_slide\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:13:\"remove_button\";r:2321;s:6:\"weight\";i:0;s:9:\"target_id\";s:2:\"22\";}}}s:24:\"field_ept_slideshow_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:100:\"<p>You can set up options for javascript plugins from the same configuration form for component.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:25:\"field_ept_slideshow_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:38:\"<p>Settings for javascript plugins</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:24:\"field_ept_slideshow_link\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:18:\"ept_slideshow_item\";s:2:\"id\";s:2:\"29\";s:4:\"uuid\";s:36:\"73569f80-2633-4a12-9cfb-720de0540f8c\";s:8:\"revision\";s:3:\"313\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"313\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:40:\"<p>Each EPT module has rich settings</p>\";}}}s:14:\"_referringItem\";r:1781;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_slideshow\";s:2:\"id\";s:2:\"30\";s:4:\"uuid\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";s:8:\"revision\";s:3:\"314\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"314\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:7;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:7;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"315\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2534;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"315\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_quote\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728933345\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"18\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2534;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"315\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"315\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:8;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:8;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"326\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2728;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:12:\"ept_carousel\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"23\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"326\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:12:\"ept_carousel\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728934054\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_carousel\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:2:\"13\";s:18:\"target_revision_id\";s:3:\"316\";}i:1;a:2:{s:9:\"target_id\";s:2:\"14\";s:18:\"target_revision_id\";s:3:\"317\";}i:2;a:2:{s:9:\"target_id\";s:2:\"15\";s:18:\"target_revision_id\";s:3:\"318\";}i:3;a:2:{s:9:\"target_id\";s:2:\"16\";s:18:\"target_revision_id\";s:3:\"319\";}i:4;a:2:{s:9:\"target_id\";s:2:\"17\";s:18:\"target_revision_id\";s:3:\"320\";}i:5;a:2:{s:9:\"target_id\";s:2:\"18\";s:18:\"target_revision_id\";s:3:\"321\";}i:6;a:2:{s:9:\"target_id\";s:2:\"19\";s:18:\"target_revision_id\";s:3:\"322\";}i:7;a:2:{s:9:\"target_id\";s:2:\"20\";s:18:\"target_revision_id\";s:3:\"323\";}i:8;a:2:{s:9:\"target_id\";s:2:\"21\";s:18:\"target_revision_id\";s:3:\"324\";}i:9;a:2:{s:9:\"target_id\";s:2:\"22\";s:18:\"target_revision_id\";s:3:\"325\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<p>Find and download your Extra Paragraph Type</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2728;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:12:\"ept_carousel\";s:2:\"id\";s:2:\"23\";s:4:\"uuid\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";s:8:\"revision\";s:3:\"326\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"326\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:9;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:378;s:7:\"\0*\0name\";i:9;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"329\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:519;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:3008;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:11:\"ept_counter\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"26\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"329\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:11:\"ept_counter\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728935787\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_counter_items\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"24\";s:18:\"target_revision_id\";s:3:\"327\";}i:1;a:2:{s:9:\"target_id\";s:2:\"25\";s:18:\"target_revision_id\";s:3:\"328\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>Number of modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:3008;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:11:\"ept_counter\";s:2:\"id\";s:2:\"26\";s:4:\"uuid\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";s:8:\"revision\";s:3:\"329\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"329\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"f8c7736ff48435ec400d13b6b9152e75\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728936888;}',1729541688),('tempstore.private.layout_paragraphs','1:fc150d012570dc21285942b382732f14',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"41\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728937228\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728937228\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:11:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"393\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"394\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"398\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"401\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"402\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"403\";}i:6;a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"407\";}i:7;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"408\";}i:8;a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"419\";}i:9;a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"422\";}i:10;a:2:{s:9:\"target_id\";s:2:\"33\";s:18:\"target_revision_id\";s:3:\"425\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"41\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"41\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:11:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"393\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:380;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"393\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:380;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"393\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"393\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"394\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:783;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"394\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:783;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"394\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"394\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"398\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:961;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"398\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"395\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"396\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"397\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:961;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"398\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"398\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"401\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1150;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"401\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"399\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"400\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1150;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"401\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"401\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"402\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1341;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"402\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1341;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"402\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"402\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"403\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1543;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"403\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1543;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"403\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"403\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"30\";s:18:\"target_revision_id\";s:3:\"407\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1784;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:13:\"ept_slideshow\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"30\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"407\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:13:\"ept_slideshow\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728936575\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}}}}s:19:\"field_ept_slideshow\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:2:\"27\";s:18:\"target_revision_id\";s:3:\"404\";}i:1;a:2:{s:9:\"target_id\";s:2:\"28\";s:18:\"target_revision_id\";s:3:\"405\";}i:2;a:2:{s:9:\"target_id\";s:2:\"29\";s:18:\"target_revision_id\";s:3:\"406\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:40:\"<p>Each EPT module has rich settings</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1784;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_slideshow\";s:2:\"id\";s:2:\"30\";s:4:\"uuid\";s:36:\"ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b\";s:8:\"revision\";s:3:\"407\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"407\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:7;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:7;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"408\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2001;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"408\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_quote\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728933345\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"18\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2001;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"408\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"408\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:8;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:8;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"419\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2195;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:12:\"ept_carousel\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"23\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"419\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:12:\"ept_carousel\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728934054\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_carousel\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:2:\"13\";s:18:\"target_revision_id\";s:3:\"409\";}i:1;a:2:{s:9:\"target_id\";s:2:\"14\";s:18:\"target_revision_id\";s:3:\"410\";}i:2;a:2:{s:9:\"target_id\";s:2:\"15\";s:18:\"target_revision_id\";s:3:\"411\";}i:3;a:2:{s:9:\"target_id\";s:2:\"16\";s:18:\"target_revision_id\";s:3:\"412\";}i:4;a:2:{s:9:\"target_id\";s:2:\"17\";s:18:\"target_revision_id\";s:3:\"413\";}i:5;a:2:{s:9:\"target_id\";s:2:\"18\";s:18:\"target_revision_id\";s:3:\"414\";}i:6;a:2:{s:9:\"target_id\";s:2:\"19\";s:18:\"target_revision_id\";s:3:\"415\";}i:7;a:2:{s:9:\"target_id\";s:2:\"20\";s:18:\"target_revision_id\";s:3:\"416\";}i:8;a:2:{s:9:\"target_id\";s:2:\"21\";s:18:\"target_revision_id\";s:3:\"417\";}i:9;a:2:{s:9:\"target_id\";s:2:\"22\";s:18:\"target_revision_id\";s:3:\"418\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<p>Find and download your Extra Paragraph Type</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2195;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:12:\"ept_carousel\";s:2:\"id\";s:2:\"23\";s:4:\"uuid\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";s:8:\"revision\";s:3:\"419\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"419\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:9;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:9;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"26\";s:18:\"target_revision_id\";s:3:\"422\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2475;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:11:\"ept_counter\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"26\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"422\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:11:\"ept_counter\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728935787\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_counter_items\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:2:\"24\";s:18:\"target_revision_id\";s:3:\"420\";}i:1;a:2:{s:9:\"target_id\";s:2:\"25\";s:18:\"target_revision_id\";s:3:\"421\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>Number of modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2475;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:11:\"ept_counter\";s:2:\"id\";s:2:\"26\";s:4:\"uuid\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";s:8:\"revision\";s:3:\"422\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"422\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:10;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:381;s:7:\"\0*\0name\";i:10;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"33\";s:18:\"target_revision_id\";s:3:\"425\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:522;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2674;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_tabs\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"33\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"425\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:8:\"ept_tabs\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"bc10cacf-328a-491e-9ba0-4d72f49bdd4c\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728937075\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}}}}s:14:\"field_ept_tabs\";a:1:{s:9:\"x-default\";a:2:{i:0;a:5:{s:7:\"subform\";a:6:{s:19:\"field_ept_tab_block\";a:1:{i:0;a:1:{s:9:\"plugin_id\";s:0:\"\";}}s:21:\"field_ept_tab_content\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"text\";}}s:18:\"field_ept_tab_page\";a:1:{i:0;a:1:{s:9:\"target_id\";N;}}s:18:\"field_ept_tab_text\";a:1:{i:0;a:2:{s:5:\"value\";s:2647:\"<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}s:19:\"field_ept_tab_title\";a:1:{i:0;a:2:{s:5:\"value\";s:11:\"EPT modules\";s:6:\"format\";s:9:\"full_html\";}}s:19:\"field_ept_tab_views\";a:1:{i:0;a:2:{s:9:\"target_id\";N;s:10:\"display_id\";s:0:\"\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"31\";s:18:\"target_revision_id\";s:3:\"423\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"31\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"423\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:13:\"ept_tabs_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"03e1362a-b7df-4469-b71d-5195bdeb4904\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728937075\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"33\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:14:\"field_ept_tabs\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:21:\"field_ept_tab_content\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"text\";}}}s:18:\"field_ept_tab_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:2647:\"<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}}s:19:\"field_ept_tab_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:11:\"EPT modules\";s:6:\"format\";s:9:\"full_html\";}}}s:19:\"field_ept_tab_block\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_tab_page\";a:1:{s:9:\"x-default\";a:0:{}}s:19:\"field_ept_tab_views\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_tabs_item\";s:2:\"id\";s:2:\"31\";s:4:\"uuid\";s:36:\"03e1362a-b7df-4469-b71d-5195bdeb4904\";s:8:\"revision\";s:3:\"423\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"423\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:6:{s:19:\"field_ept_tab_block\";a:1:{i:0;a:1:{s:9:\"plugin_id\";s:0:\"\";}}s:21:\"field_ept_tab_content\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"text\";}}s:18:\"field_ept_tab_page\";a:1:{i:0;a:1:{s:9:\"target_id\";N;}}s:18:\"field_ept_tab_text\";a:1:{i:0;a:2:{s:5:\"value\";s:2635:\"<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}s:19:\"field_ept_tab_title\";a:1:{i:0;a:2:{s:5:\"value\";s:11:\"EBT Modules\";s:6:\"format\";s:9:\"full_html\";}}s:19:\"field_ept_tab_views\";a:1:{i:0;a:2:{s:9:\"target_id\";N;s:10:\"display_id\";s:0:\"\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";s:2:\"32\";s:18:\"target_revision_id\";s:3:\"424\";s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"32\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"424\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:13:\"ept_tabs_item\";}}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"3747fc91-691d-4dac-a4df-e51cf0a0d5a1\";}}}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728937075\";}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"33\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:14:\"field_ept_tabs\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:21:\"field_ept_tab_content\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"text\";}}}s:18:\"field_ept_tab_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:2635:\"<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>\";s:6:\"format\";s:9:\"full_html\";}}}s:19:\"field_ept_tab_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:11:\"EBT Modules\";s:6:\"format\";s:9:\"full_html\";}}}s:19:\"field_ept_tab_block\";a:1:{s:9:\"x-default\";a:0:{}}s:18:\"field_ept_tab_page\";a:1:{s:9:\"x-default\";a:0:{}}s:19:\"field_ept_tab_views\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:13:\"ept_tabs_item\";s:2:\"id\";s:2:\"32\";s:4:\"uuid\";s:36:\"3747fc91-691d-4dac-a4df-e51cf0a0d5a1\";s:8:\"revision\";s:3:\"424\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"424\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:6:\"format\";s:9:\"full_html\";s:5:\"value\";s:77:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>\";}}}s:14:\"_referringItem\";r:2674;s:23:\"_layoutParagraphsLayout\";r:3;s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_tabs\";s:2:\"id\";s:2:\"33\";s:4:\"uuid\";s:36:\"bc10cacf-328a-491e-9ba0-4d72f49bdd4c\";s:8:\"revision\";s:3:\"425\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"425\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"fc150d012570dc21285942b382732f14\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1729020152;}',1729624952),('tempstore.private.layout_paragraphs','1:fc23b600033971d748ab994ae8437a24',_binary 'O:8:\"stdClass\":3:{s:5:\"owner\";s:1:\"1\";s:4:\"data\";O:47:\"Drupal\\layout_paragraphs\\LayoutParagraphsLayout\":7:{s:27:\"\0*\0paragraphsReferenceField\";O:71:\"Drupal\\entity_reference_revisions\\EntityReferenceRevisionsFieldItemList\":8:{s:13:\"\0*\0definition\";O:31:\"Drupal\\field\\Entity\\FieldConfig\":33:{s:15:\"\0*\0entityTypeId\";s:12:\"field_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"node.page.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"64183760-d4b4-4088-905f-cc5481b32e41\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"config\";a:25:{i:0;s:35:\"field.storage.node.field_components\";i:1;s:14:\"node.type.page\";i:2;s:40:\"paragraphs.paragraphs_type.ept_accordion\";i:3;s:43:\"paragraphs.paragraphs_type.ept_basic_button\";i:4;s:36:\"paragraphs.paragraphs_type.ept_block\";i:5;s:47:\"paragraphs.paragraphs_type.ept_bootstrap_button\";i:6;s:39:\"paragraphs.paragraphs_type.ept_carousel\";i:7;s:38:\"paragraphs.paragraphs_type.ept_columns\";i:8;s:40:\"paragraphs.paragraphs_type.ept_countdown\";i:9;s:38:\"paragraphs.paragraphs_type.ept_counter\";i:10;s:34:\"paragraphs.paragraphs_type.ept_cta\";i:11;s:35:\"paragraphs.paragraphs_type.ept_hero\";i:12;s:36:\"paragraphs.paragraphs_type.ept_image\";i:13;s:44:\"paragraphs.paragraphs_type.ept_image_gallery\";i:14;s:41:\"paragraphs.paragraphs_type.ept_micromodal\";i:15;s:36:\"paragraphs.paragraphs_type.ept_quote\";i:16;s:43:\"paragraphs.paragraphs_type.ept_slick_slider\";i:17;s:40:\"paragraphs.paragraphs_type.ept_slideshow\";i:18;s:36:\"paragraphs.paragraphs_type.ept_stats\";i:19;s:35:\"paragraphs.paragraphs_type.ept_tabs\";i:20;s:35:\"paragraphs.paragraphs_type.ept_text\";i:21;s:36:\"paragraphs.paragraphs_type.ept_tiles\";i:22;s:36:\"paragraphs.paragraphs_type.ept_video\";i:23;s:54:\"paragraphs.paragraphs_type.ept_video_and_image_gallery\";i:24;s:36:\"paragraphs.paragraphs_type.ept_views\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"node.page.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:13:\"\0*\0field_type\";s:26:\"entity_reference_revisions\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:9:\"\0*\0bundle\";s:4:\"page\";s:8:\"\0*\0label\";s:10:\"Components\";s:14:\"\0*\0description\";s:0:\"\";s:11:\"\0*\0settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}}s:11:\"\0*\0required\";b:0;s:15:\"\0*\0translatable\";b:0;s:16:\"\0*\0default_value\";a:0:{}s:25:\"\0*\0default_value_callback\";s:0:\"\";s:15:\"\0*\0fieldStorage\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:21:\"node.field_components\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7baebb7a-a11d-4ca3-803c-81356e567dc2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:26:\"entity_reference_revisions\";i:1;s:4:\"node\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:21:\"node.field_components\";s:13:\"\0*\0field_name\";s:16:\"field_components\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"\0*\0constraints\";a:0:{}s:22:\"\0*\0propertyConstraints\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:7:\"\0*\0name\";s:16:\"field_components\";s:9:\"\0*\0parent\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:4:\"node\";s:6:\"Bundle\";a:1:{i:0;s:4:\"page\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:23:\"Drupal\\node\\Entity\\Node\":30:{s:15:\"\0*\0entityTypeId\";s:4:\"node\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:3:\"nid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"vid\";a:1:{s:9:\"x-default\";s:2:\"35\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:4:\"page\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:12:\"revision_uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"revision_timestamp\";a:1:{s:9:\"x-default\";s:10:\"1728934262\";}s:12:\"revision_log\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";N;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"title\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728242588\";}}}s:7:\"changed\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:10:\"1728934262\";}}}s:7:\"promote\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:6:\"sticky\";a:1:{s:9:\"x-default\";s:1:\"0\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"field_components\";a:1:{s:9:\"x-default\";a:8:{i:0;a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"221\";}i:1;a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"222\";}i:2;a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"226\";}i:3;a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"229\";}i:4;a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"230\";}i:5;a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"231\";}i:6;a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"232\";}i:7;a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"243\";}}}s:4:\"body\";a:1:{s:9:\"x-default\";a:1:{i:0;a:0:{}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:4:\"page\";s:2:\"id\";s:1:\"1\";s:8:\"revision\";s:2:\"35\";s:4:\"uuid\";s:36:\"b86c7571-14d1-44a5-bd24-0d90f5afff32\";}s:25:\"\0*\0translatableEntityKeys\";a:8:{s:5:\"label\";a:1:{s:9:\"x-default\";s:31:\"Getting Started EPT Page Buider\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:3:\"uid\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:5:\"owner\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:2:\"35\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:10:\"in_preview\";N;}}s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:7:\"\0*\0list\";a:9:{i:0;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:0;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"1\";s:18:\"target_revision_id\";s:3:\"221\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:371;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_hero\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"221\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_hero\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728242667\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:19:\"field_ept_hero_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:31:\"https://drupalbook.org/ept/demo\";s:5:\"title\";s:17:\"EPT Documentation\";s:7:\"options\";a:0:{}}}}s:26:\"field_ept_hero_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"title\";s:8:\"Download\";s:7:\"options\";a:0:{}}}}s:27:\"field_ept_hero_title_prefix\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:59:\"<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:136:\"<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:121:\"<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:371;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_hero\";s:2:\"id\";s:1:\"1\";s:4:\"uuid\";s:36:\"088e8f36-aa92-4779-a6f3-20855a3bee73\";s:8:\"revision\";s:3:\"221\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"221\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:1;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:1;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"2\";s:18:\"target_revision_id\";s:3:\"222\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:774;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:8:\"ept_text\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"2\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"222\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:8:\"ept_text\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728809668\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:387:\"<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<h2 class=\"text-align-center\">Why Choose EPT?</h2>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:774;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:8:\"ept_text\";s:2:\"id\";s:1:\"2\";s:4:\"uuid\";s:36:\"be1571de-b029-444e-be82-de9318b229ad\";s:8:\"revision\";s:3:\"222\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"222\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:2;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:2;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"6\";s:18:\"target_revision_id\";s:3:\"226\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:952;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_tiles\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"6\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"226\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_tiles\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728819327\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}}}}s:15:\"field_ept_tiles\";a:1:{s:9:\"x-default\";a:3:{i:0;a:2:{s:9:\"target_id\";s:1:\"3\";s:18:\"target_revision_id\";s:3:\"223\";}i:1;a:2:{s:9:\"target_id\";s:1:\"4\";s:18:\"target_revision_id\";s:3:\"224\";}i:2;a:2:{s:9:\"target_id\";s:1:\"5\";s:18:\"target_revision_id\";s:3:\"225\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:117:\"<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:952;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_tiles\";s:2:\"id\";s:1:\"6\";s:4:\"uuid\";s:36:\"f427a33f-64f8-4506-99c7-a8605b1df563\";s:8:\"revision\";s:3:\"226\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"226\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:3;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:3;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:1:\"9\";s:18:\"target_revision_id\";s:3:\"229\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1141;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_stats\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:21:{s:2:\"id\";a:1:{s:9:\"x-default\";s:1:\"9\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"229\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_stats\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728883680\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}}}}s:15:\"field_ept_stats\";a:1:{s:9:\"x-default\";a:2:{i:0;a:2:{s:9:\"target_id\";s:1:\"7\";s:18:\"target_revision_id\";s:3:\"227\";}i:1;a:2:{s:9:\"target_id\";s:1:\"8\";s:18:\"target_revision_id\";s:3:\"228\";}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:413:\"<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:79:\"<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1141;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_stats\";s:2:\"id\";s:1:\"9\";s:4:\"uuid\";s:36:\"926f3603-0a5c-4fc3-9d32-eddfeb355833\";s:8:\"revision\";s:3:\"229\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"229\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:4;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:4;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"10\";s:18:\"target_revision_id\";s:3:\"230\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1332;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:17:\"ept_image_gallery\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"10\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"230\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:17:\"ept_image_gallery\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728884868\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:23:\"field_ept_image_gallery\";a:1:{s:9:\"x-default\";a:11:{i:0;a:1:{s:9:\"target_id\";s:1:\"4\";}i:1;a:1:{s:9:\"target_id\";s:1:\"5\";}i:2;a:1:{s:9:\"target_id\";s:1:\"6\";}i:3;a:1:{s:9:\"target_id\";s:1:\"7\";}i:4;a:1:{s:9:\"target_id\";s:1:\"9\";}i:5;a:1:{s:9:\"target_id\";s:2:\"10\";}i:6;a:1:{s:9:\"target_id\";s:2:\"11\";}i:7;a:1:{s:9:\"target_id\";s:2:\"12\";}i:8;a:1:{s:9:\"target_id\";s:2:\"13\";}i:9;a:1:{s:9:\"target_id\";s:2:\"14\";}i:10;a:1:{s:9:\"target_id\";s:2:\"15\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:62:\"<p>You can download a bunch of EPT modules from Drupal.org</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1332;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:17:\"ept_image_gallery\";s:2:\"id\";s:2:\"10\";s:4:\"uuid\";s:36:\"c2140955-0941-4cea-a839-676831aacf2d\";s:8:\"revision\";s:3:\"230\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"230\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:5;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:5;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"11\";s:18:\"target_revision_id\";s:3:\"231\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1534;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:7:\"ept_cta\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:23:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"11\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"231\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:7:\"ept_cta\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728888715\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:26:\"field_ept_cta_column_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"16\";}}}s:18:\"field_ept_cta_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"title\";s:16:\"GLightbox module\";s:7:\"options\";a:0:{}}}}s:25:\"field_ept_cta_second_link\";a:1:{s:9:\"x-default\";a:1:{i:0;a:3:{s:3:\"uri\";s:42:\"https://biati-digital.github.io/glightbox/\";s:5:\"title\";s:14:\"GLightbox site\";s:7:\"options\";a:0:{}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:462:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:104:\"<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1534;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:7:\"ept_cta\";s:2:\"id\";s:2:\"11\";s:4:\"uuid\";s:36:\"df2b4021-56a6-496c-a770-df39af537eee\";s:8:\"revision\";s:3:\"231\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"231\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:6;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:6;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"12\";s:18:\"target_revision_id\";s:3:\"232\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1775;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:9:\"ept_quote\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:22:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"12\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"232\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:9:\"ept_quote\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728933345\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}s:22:\"field_ept_quote_author\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>Hockey Club</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:21:\"field_ept_quote_image\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:2:\"18\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:82:\"<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:37:\"<p>You can start from one module.</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1775;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:9:\"ept_quote\";s:2:\"id\";s:2:\"12\";s:4:\"uuid\";s:36:\"7926a1d4-73de-4662-af2c-f956f44efc2a\";s:8:\"revision\";s:3:\"232\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";N;}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"232\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:7;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";r:372;s:7:\"\0*\0name\";i:7;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";s:2:\"23\";s:18:\"target_revision_id\";s:3:\"243\";}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";r:513;s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:1969;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:12:\"ept_carousel\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:2:\"id\";a:1:{s:9:\"x-default\";s:2:\"23\";}s:11:\"revision_id\";a:1:{s:9:\"x-default\";s:3:\"243\";}s:4:\"type\";a:1:{s:9:\"x-default\";s:12:\"ept_carousel\";}s:4:\"uuid\";a:1:{s:9:\"x-default\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";}s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:17:\"isDefaultRevision\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:6:\"status\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:7:\"created\";a:1:{s:9:\"x-default\";s:10:\"1728934054\";}s:9:\"parent_id\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:11:\"parent_type\";a:1:{s:9:\"x-default\";s:4:\"node\";}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";s:16:\"field_components\";}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:73:\"a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:18:\"field_ept_carousel\";a:1:{s:9:\"x-default\";a:10:{i:0;a:2:{s:9:\"target_id\";s:2:\"13\";s:18:\"target_revision_id\";s:3:\"233\";}i:1;a:2:{s:9:\"target_id\";s:2:\"14\";s:18:\"target_revision_id\";s:3:\"234\";}i:2;a:2:{s:9:\"target_id\";s:2:\"15\";s:18:\"target_revision_id\";s:3:\"235\";}i:3;a:2:{s:9:\"target_id\";s:2:\"16\";s:18:\"target_revision_id\";s:3:\"236\";}i:4;a:2:{s:9:\"target_id\";s:2:\"17\";s:18:\"target_revision_id\";s:3:\"237\";}i:5;a:2:{s:9:\"target_id\";s:2:\"18\";s:18:\"target_revision_id\";s:3:\"238\";}i:6;a:2:{s:9:\"target_id\";s:2:\"19\";s:18:\"target_revision_id\";s:3:\"239\";}i:7;a:2:{s:9:\"target_id\";s:2:\"20\";s:18:\"target_revision_id\";s:3:\"240\";}i:8;a:2:{s:9:\"target_id\";s:2:\"21\";s:18:\"target_revision_id\";s:3:\"241\";}i:9;a:2:{s:9:\"target_id\";s:2:\"22\";s:18:\"target_revision_id\";s:3:\"242\";}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}}}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:50:\"<p>Find and download your Extra Paragraph Type</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:1969;s:23:\"_layoutParagraphsLayout\";r:3;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:1;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:0;s:20:\"\0*\0isDefaultRevision\";s:1:\"1\";s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:12:\"ept_carousel\";s:2:\"id\";s:2:\"23\";s:4:\"uuid\";s:36:\"9d2e5c79-3f95-4416-adba-4ad4ae7683d3\";s:8:\"revision\";s:3:\"243\";}s:25:\"\0*\0translatableEntityKeys\";a:4:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}s:9:\"published\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";s:1:\"1\";}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";s:1:\"1\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";s:3:\"243\";s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}i:8;O:85:\"Drupal\\entity_reference_revisions\\Plugin\\Field\\FieldType\\EntityReferenceRevisionsItem\":8:{s:13:\"\0*\0definition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:37:\"field_item:entity_reference_revisions\";s:8:\"settings\";a:3:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:23:{s:13:\"ept_accordion\";s:13:\"ept_accordion\";s:16:\"ept_basic_button\";s:16:\"ept_basic_button\";s:9:\"ept_block\";s:9:\"ept_block\";s:20:\"ept_bootstrap_button\";s:20:\"ept_bootstrap_button\";s:12:\"ept_carousel\";s:12:\"ept_carousel\";s:11:\"ept_columns\";s:11:\"ept_columns\";s:13:\"ept_countdown\";s:13:\"ept_countdown\";s:11:\"ept_counter\";s:11:\"ept_counter\";s:7:\"ept_cta\";s:7:\"ept_cta\";s:8:\"ept_hero\";s:8:\"ept_hero\";s:9:\"ept_image\";s:9:\"ept_image\";s:17:\"ept_image_gallery\";s:17:\"ept_image_gallery\";s:14:\"ept_micromodal\";s:14:\"ept_micromodal\";s:9:\"ept_quote\";s:9:\"ept_quote\";s:16:\"ept_slick_slider\";s:16:\"ept_slick_slider\";s:13:\"ept_slideshow\";s:13:\"ept_slideshow\";s:9:\"ept_stats\";s:9:\"ept_stats\";s:8:\"ept_tabs\";s:8:\"ept_tabs\";s:8:\"ept_text\";s:8:\"ept_text\";s:9:\"ept_tiles\";s:9:\"ept_tiles\";s:9:\"ept_video\";s:9:\"ept_video\";s:27:\"ept_video_and_image_gallery\";s:27:\"ept_video_and_image_gallery\";s:9:\"ept_views\";s:9:\"ept_views\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:32:{s:13:\"ept_accordion\";a:2:{s:6:\"weight\";i:33;s:7:\"enabled\";b:1;}s:21:\"ept_accordion_section\";a:2:{s:6:\"weight\";i:34;s:7:\"enabled\";b:0;}s:16:\"ept_basic_button\";a:2:{s:6:\"weight\";i:35;s:7:\"enabled\";b:1;}s:9:\"ept_block\";a:2:{s:6:\"weight\";i:36;s:7:\"enabled\";b:1;}s:20:\"ept_bootstrap_button\";a:2:{s:6:\"weight\";i:37;s:7:\"enabled\";b:1;}s:12:\"ept_carousel\";a:2:{s:6:\"weight\";i:38;s:7:\"enabled\";b:1;}s:17:\"ept_carousel_item\";a:2:{s:6:\"weight\";i:39;s:7:\"enabled\";b:0;}s:11:\"ept_columns\";a:2:{s:6:\"weight\";i:40;s:7:\"enabled\";b:1;}s:13:\"ept_countdown\";a:2:{s:6:\"weight\";i:41;s:7:\"enabled\";b:1;}s:11:\"ept_counter\";a:2:{s:6:\"weight\";i:42;s:7:\"enabled\";b:1;}s:16:\"ept_counter_item\";a:2:{s:6:\"weight\";i:43;s:7:\"enabled\";b:0;}s:7:\"ept_cta\";a:2:{s:6:\"weight\";i:44;s:7:\"enabled\";b:1;}s:8:\"ept_hero\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}s:9:\"ept_image\";a:2:{s:6:\"weight\";i:46;s:7:\"enabled\";b:1;}s:17:\"ept_image_gallery\";a:2:{s:6:\"weight\";i:47;s:7:\"enabled\";b:1;}s:14:\"ept_micromodal\";a:2:{s:6:\"weight\";i:48;s:7:\"enabled\";b:1;}s:9:\"ept_quote\";a:2:{s:6:\"weight\";i:49;s:7:\"enabled\";b:1;}s:16:\"ept_slick_slider\";a:2:{s:6:\"weight\";i:50;s:7:\"enabled\";b:1;}s:21:\"ept_slick_slider_item\";a:2:{s:6:\"weight\";i:51;s:7:\"enabled\";b:0;}s:13:\"ept_slideshow\";a:2:{s:6:\"weight\";i:52;s:7:\"enabled\";b:1;}s:18:\"ept_slideshow_item\";a:2:{s:6:\"weight\";i:53;s:7:\"enabled\";b:0;}s:9:\"ept_stats\";a:2:{s:6:\"weight\";i:54;s:7:\"enabled\";b:1;}s:14:\"ept_stats_item\";a:2:{s:6:\"weight\";i:55;s:7:\"enabled\";b:0;}s:8:\"ept_tabs\";a:2:{s:6:\"weight\";i:56;s:7:\"enabled\";b:1;}s:13:\"ept_tabs_item\";a:2:{s:6:\"weight\";i:57;s:7:\"enabled\";b:0;}s:8:\"ept_text\";a:2:{s:6:\"weight\";i:58;s:7:\"enabled\";b:1;}s:9:\"ept_tiles\";a:2:{s:6:\"weight\";i:59;s:7:\"enabled\";b:1;}s:14:\"ept_tiles_item\";a:2:{s:6:\"weight\";i:60;s:7:\"enabled\";b:0;}s:9:\"ept_video\";a:2:{s:6:\"weight\";i:61;s:7:\"enabled\";b:1;}s:27:\"ept_video_and_image_gallery\";a:2:{s:6:\"weight\";i:62;s:7:\"enabled\";b:1;}s:32:\"ept_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:63;s:7:\"enabled\";b:0;}s:9:\"ept_views\";a:2:{s:6:\"weight\";i:64;s:7:\"enabled\";b:1;}}}s:11:\"target_type\";s:9:\"paragraph\";}}s:18:\"\0*\0fieldDefinition\";r:5;}s:7:\"\0*\0name\";i:8;s:9:\"\0*\0parent\";r:4;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0values\";a:2:{s:9:\"target_id\";N;s:18:\"target_revision_id\";N;}s:13:\"\0*\0properties\";a:1:{s:6:\"entity\";O:74:\"Drupal\\entity_reference_revisions\\Plugin\\DataType\\EntityReferenceRevisions\":7:{s:13:\"\0*\0definition\";O:45:\"Drupal\\Core\\TypedData\\DataReferenceDefinition\":2:{s:13:\"\0*\0definition\";a:5:{s:4:\"type\";s:25:\"entity_revision_reference\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The referenced entity revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"computed\";b:1;s:9:\"read-only\";b:0;}s:19:\"\0*\0targetDefinition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:12:{s:5:\"class\";s:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\";s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:10:\"EntityType\";s:9:\"paragraph\";}s:8:\"internal\";b:0;s:8:\"provider\";s:4:\"core\";s:2:\"id\";s:6:\"entity\";s:7:\"deriver\";s:56:\"Drupal\\Core\\Entity\\Plugin\\DataType\\Deriver\\EntityDeriver\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"All kind of entities, e.g. nodes, comments or users.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"definition_class\";s:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\";s:10:\"list_class\";s:46:\"Drupal\\Core\\TypedData\\Plugin\\DataType\\ItemList\";s:21:\"list_definition_class\";s:40:\"Drupal\\Core\\TypedData\\ListDataDefinition\";s:35:\"unwrap_for_canonical_representation\";b:1;}}}s:7:\"\0*\0name\";s:6:\"entity\";s:9:\"\0*\0parent\";r:2249;s:14:\"\0*\0_serviceIds\";a:1:{s:16:\"typedDataManager\";s:18:\"typed_data_manager\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:9:\"\0*\0target\";O:48:\"Drupal\\Core\\Entity\\Plugin\\DataType\\EntityAdapter\":8:{s:13:\"\0*\0definition\";O:49:\"Drupal\\Core\\Entity\\TypedData\\EntityDataDefinition\":1:{s:13:\"\0*\0definition\";a:1:{s:11:\"constraints\";a:2:{s:10:\"EntityType\";s:9:\"paragraph\";s:6:\"Bundle\";a:1:{i:0;s:11:\"ept_counter\";}}}}s:7:\"\0*\0name\";N;s:9:\"\0*\0parent\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:19:\"\0*\0typedDataManager\";N;s:9:\"\0*\0entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:20:{s:23:\"_layoutParagraphsLayout\";r:3;s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:11:\"ept_counter\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728935787;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:1:\"1\";}}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:4:\"node\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:16:\"field_components\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:23:\"field_ept_counter_items\";a:1:{s:9:\"x-default\";a:2:{i:0;a:5:{s:7:\"subform\";a:4:{s:29:\"field_ept_counter_description\";a:1:{i:0;a:2:{s:5:\"value\";s:0:\"\";s:6:\"format\";s:9:\"full_html\";}}s:22:\"field_ept_counter_icon\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:24:\"field_ept_counter_number\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"25\";}}s:23:\"field_ept_counter_title\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:18:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"b7e52e90-6342-4ad9-9dc2-55f13a47c86b\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:16:\"ept_counter_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728935787;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:23:\"field_ept_counter_items\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"field_ept_counter_description\";a:1:{s:9:\"x-default\";a:0:{}}s:22:\"field_ept_counter_icon\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_counter_number\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"25\";}}}s:23:\"field_ept_counter_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>EPT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:16:\"ept_counter_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"b7e52e90-6342-4ad9-9dc2-55f13a47c86b\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}i:1;a:5:{s:7:\"subform\";a:4:{s:29:\"field_ept_counter_description\";a:1:{i:0;a:2:{s:5:\"value\";s:0:\"\";s:6:\"format\";s:9:\"full_html\";}}s:22:\"field_ept_counter_icon\";a:3:{s:11:\"open_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:23:\"media_library_selection\";s:0:\"\";s:27:\"media_library_update_widget\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Update widget\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:24:\"field_ept_counter_number\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"25\";}}s:23:\"field_ept_counter_title\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>EBT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:3:\"top\";a:1:{s:7:\"actions\";a:2:{s:7:\"actions\";a:1:{s:15:\"collapse_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Collapse\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:16:\"dropdown_actions\";a:2:{s:16:\"duplicate_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Duplicate\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"remove_button\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Remove\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}s:9:\"target_id\";N;s:18:\"target_revision_id\";N;s:6:\"entity\";O:34:\"Drupal\\paragraphs\\Entity\\Paragraph\":33:{s:15:\"\0*\0entityTypeId\";s:9:\"paragraph\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:9:\"\0*\0values\";a:18:{s:8:\"langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"en\";}}}s:11:\"revision_id\";a:1:{s:9:\"x-default\";a:0:{}}s:2:\"id\";a:1:{s:9:\"x-default\";a:0:{}}s:4:\"uuid\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:36:\"ce5d0752-e11c-4fcb-9b52-46d8c45b4a74\";}}}s:4:\"type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:9:\"target_id\";s:16:\"ept_counter_item\";}}}s:6:\"status\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:7:\"created\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";i:1728935787;}}}s:9:\"parent_id\";a:1:{s:9:\"x-default\";a:0:{}}s:11:\"parent_type\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:9:\"paragraph\";}}}s:17:\"parent_field_name\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:23:\"field_ept_counter_items\";}}}s:17:\"behavior_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}}s:16:\"default_langcode\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}}s:16:\"revision_default\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"revision_translation_affected\";a:1:{s:9:\"x-default\";a:0:{}}s:29:\"field_ept_counter_description\";a:1:{s:9:\"x-default\";a:0:{}}s:22:\"field_ept_counter_icon\";a:1:{s:9:\"x-default\";a:0:{}}s:24:\"field_ept_counter_number\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:5:\"value\";s:2:\"25\";}}}s:23:\"field_ept_counter_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:18:\"<p>EBT Modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:16:\"ept_counter_item\";s:8:\"revision\";N;s:4:\"uuid\";s:36:\"ce5d0752-e11c-4fcb-9b52-46d8c45b4a74\";s:2:\"id\";N;}s:25:\"\0*\0translatableEntityKeys\";a:0:{}s:12:\"\0*\0validated\";b:1;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";N;s:15:\"\0*\0summaryCount\";i:0;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}s:18:\"field_ept_settings\";a:1:{s:9:\"x-default\";a:1:{i:0;a:1:{s:12:\"ept_settings\";a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}}}}s:14:\"field_ept_text\";a:1:{s:9:\"x-default\";a:0:{}}s:15:\"field_ept_title\";a:1:{s:9:\"x-default\";a:1:{i:0;a:2:{s:5:\"value\";s:24:\"<p>Number of modules</p>\";s:6:\"format\";s:9:\"full_html\";}}}s:14:\"_referringItem\";r:2249;}s:9:\"\0*\0fields\";a:0:{}s:19:\"\0*\0fieldDefinitions\";N;s:12:\"\0*\0languages\";N;s:14:\"\0*\0langcodeKey\";s:8:\"langcode\";s:21:\"\0*\0defaultLangcodeKey\";s:16:\"default_langcode\";s:17:\"\0*\0activeLangcode\";s:9:\"x-default\";s:28:\"\0*\0enforceDefaultTranslation\";N;s:18:\"\0*\0defaultLangcode\";s:2:\"en\";s:15:\"\0*\0translations\";a:1:{s:9:\"x-default\";a:1:{s:6:\"status\";i:2;}}s:24:\"\0*\0translationInitialize\";b:0;s:14:\"\0*\0newRevision\";b:1;s:20:\"\0*\0isDefaultRevision\";b:1;s:13:\"\0*\0entityKeys\";a:4:{s:6:\"bundle\";s:11:\"ept_counter\";s:8:\"revision\";N;s:2:\"id\";N;s:4:\"uuid\";s:36:\"face81f9-5400-406b-a64c-0c7717518193\";}s:25:\"\0*\0translatableEntityKeys\";a:1:{s:8:\"langcode\";a:1:{s:9:\"x-default\";s:2:\"en\";}}s:12:\"\0*\0validated\";b:0;s:21:\"\0*\0validationRequired\";b:0;s:19:\"\0*\0loadedRevisionId\";N;s:33:\"\0*\0revisionTranslationAffectedKey\";s:29:\"revision_translation_affected\";s:37:\"\0*\0enforceRevisionTranslationAffected\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:31:\"\0*\0unserializedBehaviorSettings\";a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}s:15:\"\0*\0summaryCount\";N;s:12:\"\0*\0needsSave\";b:1;s:20:\"\0*\0stringTranslation\";N;}}}}}}s:11:\"\0*\0langcode\";s:2:\"en\";}s:21:\"\0*\0thirdPartySettings\";a:0:{}s:11:\"\0*\0settings\";a:6:{s:9:\"view_mode\";s:7:\"default\";s:17:\"preview_view_mode\";s:7:\"default\";s:17:\"form_display_mode\";s:7:\"default\";s:13:\"nesting_depth\";i:4;s:15:\"require_layouts\";i:0;s:13:\"empty_message\";s:0:\"\";}s:5:\"\0*\0id\";s:32:\"fc23b600033971d748ab994ae8437a24\";s:9:\"\0*\0entity\";N;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}}s:7:\"updated\";i:1728935838;}',1729540638),('update_available_releases','admin_toolbar',_binary 'a:10:{s:5:\"title\";s:13:\"Admin Toolbar\";s:10:\"short_name\";s:13:\"admin_toolbar\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"3.4.,3.5.\";s:18:\"composer_namespace\";s:20:\"drupal/admin_toolbar\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/admin_toolbar\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:54:{s:5:\"3.5.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.5.0\";s:7:\"version\";s:5:\"3.5.0\";s:3:\"tag\";s:5:\"3.5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.5.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.5.0.tar.gz\";s:4:\"date\";s:10:\"1722639094\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";}s:5:\"3.4.2\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.4.2\";s:7:\"version\";s:5:\"3.4.2\";s:3:\"tag\";s:5:\"3.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.4.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.4.2.tar.gz\";s:4:\"date\";s:10:\"1696006154\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.4.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.4.1\";s:7:\"version\";s:5:\"3.4.1\";s:3:\"tag\";s:5:\"3.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.4.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.4.1.tar.gz\";s:4:\"date\";s:10:\"1684944156\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.4.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.4.0\";s:7:\"version\";s:5:\"3.4.0\";s:3:\"tag\";s:5:\"3.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.4.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.4.0.tar.gz\";s:4:\"date\";s:10:\"1683730335\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.3.2\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.3.2\";s:7:\"version\";s:5:\"3.3.2\";s:3:\"tag\";s:5:\"3.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.3.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.3.2.tar.gz\";s:4:\"date\";s:10:\"1683055364\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.3.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.3.1\";s:7:\"version\";s:5:\"3.3.1\";s:3:\"tag\";s:5:\"3.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.3.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.3.1.tar.gz\";s:4:\"date\";s:10:\"1682689245\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.3.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.3.0\";s:7:\"version\";s:5:\"3.3.0\";s:3:\"tag\";s:5:\"3.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.3.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.3.0.tar.gz\";s:4:\"date\";s:10:\"1669567837\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"3.2.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.2.1\";s:7:\"version\";s:5:\"3.2.1\";s:3:\"tag\";s:5:\"3.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.2.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.2.1.tar.gz\";s:4:\"date\";s:10:\"1665044276\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.2.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.2.0\";s:7:\"version\";s:5:\"3.2.0\";s:3:\"tag\";s:5:\"3.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.2.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.2.0.tar.gz\";s:4:\"date\";s:10:\"1664981657\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.1.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.1.1\";s:7:\"version\";s:5:\"3.1.1\";s:3:\"tag\";s:5:\"3.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.1.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.1.1.tar.gz\";s:4:\"date\";s:10:\"1658801841\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:19:\"^8.8.0 || ^9 || ^10\";}s:5:\"3.1.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.1.0\";s:7:\"version\";s:5:\"3.1.0\";s:3:\"tag\";s:5:\"3.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.1.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.1.0.tar.gz\";s:4:\"date\";s:10:\"1643097060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:19:\"^8.8.0 || ^9 || ^10\";}s:5:\"3.0.3\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.0.3\";s:7:\"version\";s:5:\"3.0.3\";s:3:\"tag\";s:5:\"3.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.0.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.0.3.tar.gz\";s:4:\"date\";s:10:\"1632322068\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.0.2\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.0.2\";s:7:\"version\";s:5:\"3.0.2\";s:3:\"tag\";s:5:\"3.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.0.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.0.2.tar.gz\";s:4:\"date\";s:10:\"1629882675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.0.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.0.1\";s:7:\"version\";s:5:\"3.0.1\";s:3:\"tag\";s:5:\"3.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.0.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.0.1.tar.gz\";s:4:\"date\";s:10:\"1622644077\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.0.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.0.0\";s:7:\"version\";s:5:\"3.0.0\";s:3:\"tag\";s:5:\"3.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.0.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.0.0.tar.gz\";s:4:\"date\";s:10:\"1611311186\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.5\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.5\";s:7:\"version\";s:7:\"8.x-2.5\";s:3:\"tag\";s:7:\"8.x-2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.5.tar.gz\";s:4:\"date\";s:10:\"1629883381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1601998853\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1592535597\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1585017179\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1584986458\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.7.7 || ^9.0\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1572370984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-2.0-beta2\";a:11:{s:4:\"name\";s:27:\"admin_toolbar 8.x-2.0-beta2\";s:7:\"version\";s:13:\"8.x-2.0-beta2\";s:3:\"tag\";s:13:\"8.x-2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.0-beta2\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1567506785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-2.0-beta1\";a:11:{s:4:\"name\";s:27:\"admin_toolbar 8.x-2.0-beta1\";s:7:\"version\";s:13:\"8.x-2.0-beta1\";s:3:\"tag\";s:13:\"8.x-2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.0-beta1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1562269081\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.27\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.27\";s:7:\"version\";s:8:\"8.x-1.27\";s:3:\"tag\";s:8:\"8.x-1.27\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.27\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.27.tar.gz\";s:4:\"date\";s:10:\"1558552081\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.26\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.26\";s:7:\"version\";s:8:\"8.x-1.26\";s:3:\"tag\";s:8:\"8.x-1.26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.26\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.26.tar.gz\";s:4:\"date\";s:10:\"1549218480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.25\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.25\";s:7:\"version\";s:8:\"8.x-1.25\";s:3:\"tag\";s:8:\"8.x-1.25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.25\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.25.tar.gz\";s:4:\"date\";s:10:\"1542915180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.24\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.24\";s:7:\"version\";s:8:\"8.x-1.24\";s:3:\"tag\";s:8:\"8.x-1.24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.24\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.24.tar.gz\";s:4:\"date\";s:10:\"1527522480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.23\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.23\";s:7:\"version\";s:8:\"8.x-1.23\";s:3:\"tag\";s:8:\"8.x-1.23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.23\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.23.tar.gz\";s:4:\"date\";s:10:\"1517936581\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.22\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.22\";s:7:\"version\";s:8:\"8.x-1.22\";s:3:\"tag\";s:8:\"8.x-1.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.22\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.22.tar.gz\";s:4:\"date\";s:10:\"1514888585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.21\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.21\";s:7:\"version\";s:8:\"8.x-1.21\";s:3:\"tag\";s:8:\"8.x-1.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.21\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.21.tar.gz\";s:4:\"date\";s:10:\"1511190785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.20\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.20\";s:7:\"version\";s:8:\"8.x-1.20\";s:3:\"tag\";s:8:\"8.x-1.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.20\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.20.tar.gz\";s:4:\"date\";s:10:\"1505199844\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.19\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.19\";s:7:\"version\";s:8:\"8.x-1.19\";s:3:\"tag\";s:8:\"8.x-1.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.19\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.19.tar.gz\";s:4:\"date\";s:10:\"1491487683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.18\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.18\";s:7:\"version\";s:8:\"8.x-1.18\";s:3:\"tag\";s:8:\"8.x-1.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.18\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.18.tar.gz\";s:4:\"date\";s:10:\"1480614184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.17\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.17\";s:7:\"version\";s:8:\"8.x-1.17\";s:3:\"tag\";s:8:\"8.x-1.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.17\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.17.tar.gz\";s:4:\"date\";s:10:\"1472585039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.16\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.16\";s:7:\"version\";s:8:\"8.x-1.16\";s:3:\"tag\";s:8:\"8.x-1.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.16\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.16.tar.gz\";s:4:\"date\";s:10:\"1469715839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.15\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.15\";s:7:\"version\";s:8:\"8.x-1.15\";s:3:\"tag\";s:8:\"8.x-1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.15\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.15.tar.gz\";s:4:\"date\";s:10:\"1464016832\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.14\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1454942939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.13\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1454405939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.12\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1454402339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.11\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1449833341\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.10\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1445350439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.9\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1438248239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.8\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1437400139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.7\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1434972483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.6\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1433331481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1433329681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1432141381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1432129285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1432129285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1432048381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1431018181\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"3.x-dev\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 3.x-dev\";s:7:\"version\";s:7:\"3.x-dev\";s:3:\"tag\";s:3:\"3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/3.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1725568092\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:25:\"admin_toolbar 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1649739022\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:25:\"admin_toolbar 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1567701780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}}s:10:\"last_fetch\";i:1729018489;}',1729104889),('update_available_releases','block_field',_binary 'a:10:{s:5:\"title\";s:11:\"Block field\";s:10:\"short_name\";s:11:\"block_field\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:18:\"drupal/block_field\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/block_field\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:14:{s:11:\"8.x-1.0-rc5\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1723550576\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1667511464\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1658858536\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1621950813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1588279781\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:14:\"8.x-1.0-alpha8\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha8\";s:7:\"version\";s:14:\"8.x-1.0-alpha8\";s:3:\"tag\";s:14:\"8.x-1.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha8\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1536732480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha7\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha7\";s:7:\"version\";s:14:\"8.x-1.0-alpha7\";s:3:\"tag\";s:14:\"8.x-1.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha7\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1533866285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha6\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha6\";s:7:\"version\";s:14:\"8.x-1.0-alpha6\";s:3:\"tag\";s:14:\"8.x-1.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha6\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1525303380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1511317688\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1487611082\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1464034139\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1464016832\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1463668739\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721425360\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018489;}',1729104889),('update_available_releases','ckeditor5_plugin_pack',_binary 'a:10:{s:5:\"title\";s:22:\"CKEditor 5 Plugin Pack\";s:10:\"short_name\";s:21:\"ckeditor5_plugin_pack\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.2.\";s:18:\"composer_namespace\";s:28:\"drupal/ckeditor5_plugin_pack\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:52:\"https://www.drupal.org/project/ckeditor5_plugin_pack\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:6:{s:5:\"1.2.2\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.2\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1727947517\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1723548212\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1722415813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.1.0\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.1.0\";s:7:\"version\";s:5:\"1.1.0\";s:3:\"tag\";s:5:\"1.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.1.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.1.0.tar.gz\";s:4:\"date\";s:10:\"1718271916\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.0.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1714466054\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.0.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1713945391\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018489;}',1729104889),('update_available_releases','ckeditor5_premium_features',_binary 'a:10:{s:5:\"title\";s:27:\"CKEditor 5 Premium Features\";s:10:\"short_name\";s:26:\"ckeditor5_premium_features\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.3.\";s:18:\"composer_namespace\";s:33:\"drupal/ckeditor5_premium_features\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:57:\"https://www.drupal.org/project/ckeditor5_premium_features\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:21:{s:5:\"1.3.2\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.2\";s:7:\"version\";s:5:\"1.3.2\";s:3:\"tag\";s:5:\"1.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.2\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.2.tar.gz\";s:4:\"date\";s:10:\"1727958023\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1723546977\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1722416832\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.9\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.9\";s:7:\"version\";s:5:\"1.2.9\";s:3:\"tag\";s:5:\"1.2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.9\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.9.tar.gz\";s:4:\"date\";s:10:\"1718272066\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.8\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.8\";s:7:\"version\";s:5:\"1.2.8\";s:3:\"tag\";s:5:\"1.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.8\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.8.tar.gz\";s:4:\"date\";s:10:\"1713960338\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.7\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.7\";s:7:\"version\";s:5:\"1.2.7\";s:3:\"tag\";s:5:\"1.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.7\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.7.tar.gz\";s:4:\"date\";s:10:\"1713946256\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}s:5:\"1.2.6\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.6\";s:7:\"version\";s:5:\"1.2.6\";s:3:\"tag\";s:5:\"1.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.6\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.6.tar.gz\";s:4:\"date\";s:10:\"1709550478\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.5\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.5\";s:7:\"version\";s:5:\"1.2.5\";s:3:\"tag\";s:5:\"1.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.5\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.5.tar.gz\";s:4:\"date\";s:10:\"1706087373\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.4\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.4\";s:7:\"version\";s:5:\"1.2.4\";s:3:\"tag\";s:5:\"1.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.4\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.4.tar.gz\";s:4:\"date\";s:10:\"1702994815\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.3\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.3\";s:7:\"version\";s:5:\"1.2.3\";s:3:\"tag\";s:5:\"1.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.3\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.3.tar.gz\";s:4:\"date\";s:10:\"1699963145\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.2\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1693384282\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1688647071\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1687776512\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.1.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.1.1\";s:7:\"version\";s:5:\"1.1.1\";s:3:\"tag\";s:5:\"1.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.1.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.1.1.tar.gz\";s:4:\"date\";s:10:\"1684309128\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.1.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.1.0\";s:7:\"version\";s:5:\"1.1.0\";s:3:\"tag\";s:5:\"1.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.1.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.1.0.tar.gz\";s:4:\"date\";s:10:\"1683814836\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1681894913\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1677662363\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:9:\"1.0.0-rc2\";a:11:{s:4:\"name\";s:36:\"ckeditor5_premium_features 1.0.0-rc2\";s:7:\"version\";s:9:\"1.0.0-rc2\";s:3:\"tag\";s:9:\"1.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-rc2\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1671113465\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:9:\"1.0.0-rc1\";a:11:{s:4:\"name\";s:36:\"ckeditor5_premium_features 1.0.0-rc1\";s:7:\"version\";s:9:\"1.0.0-rc1\";s:3:\"tag\";s:9:\"1.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-rc1\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1667227760\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:11:\"1.0.0-beta2\";a:11:{s:4:\"name\";s:38:\"ckeditor5_premium_features 1.0.0-beta2\";s:7:\"version\";s:11:\"1.0.0-beta2\";s:3:\"tag\";s:11:\"1.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-beta2\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1663854316\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:11:\"1.0.0-beta1\";a:11:{s:4:\"name\";s:38:\"ckeditor5_premium_features 1.0.0-beta1\";s:7:\"version\";s:11:\"1.0.0-beta1\";s:3:\"tag\";s:11:\"1.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-beta1\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1663684376\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018489;}',1729104889),('update_available_releases','drupal',_binary 'a:10:{s:5:\"title\";s:11:\"Drupal core\";s:10:\"short_name\";s:6:\"drupal\";s:4:\"type\";s:12:\"project_core\";s:18:\"supported_branches\";s:23:\"10.2.,10.3.,10.4.,11.0.\";s:18:\"composer_namespace\";s:11:\"drupal/core\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:37:\"https://www.drupal.org/project/drupal\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:420:{s:6:\"11.0.5\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.5\";s:7:\"version\";s:6:\"11.0.5\";s:3:\"tag\";s:6:\"11.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.5.tar.gz\";s:4:\"date\";s:10:\"1727946737\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.4\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.4\";s:7:\"version\";s:6:\"11.0.4\";s:3:\"tag\";s:6:\"11.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.4.tar.gz\";s:4:\"date\";s:10:\"1726136390\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.3\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.3\";s:7:\"version\";s:6:\"11.0.3\";s:3:\"tag\";s:6:\"11.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.3.tar.gz\";s:4:\"date\";s:10:\"1726074557\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.2\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.2\";s:7:\"version\";s:6:\"11.0.2\";s:3:\"tag\";s:6:\"11.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.2.tar.gz\";s:4:\"date\";s:10:\"1725526703\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.1\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.1\";s:7:\"version\";s:6:\"11.0.1\";s:3:\"tag\";s:6:\"11.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.1.tar.gz\";s:4:\"date\";s:10:\"1723108396\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"11.0.0\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.0\";s:7:\"version\";s:6:\"11.0.0\";s:3:\"tag\";s:6:\"11.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.0.tar.gz\";s:4:\"date\";s:10:\"1722578454\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"11.0.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 11.0.0-rc1\";s:7:\"version\";s:10:\"11.0.0-rc1\";s:3:\"tag\";s:10:\"11.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/11.0.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-11.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1720736512\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"11.0.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 11.0.0-beta1\";s:7:\"version\";s:12:\"11.0.0-beta1\";s:3:\"tag\";s:12:\"11.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/11.0.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-11.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1715953266\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"11.0.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 11.0.0-alpha1\";s:7:\"version\";s:13:\"11.0.0-alpha1\";s:3:\"tag\";s:13:\"11.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/11.0.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-11.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1714797816\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"10.3.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.6\";s:7:\"version\";s:6:\"10.3.6\";s:3:\"tag\";s:6:\"10.3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.6.tar.gz\";s:4:\"date\";s:10:\"1727948888\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.5\";s:7:\"version\";s:6:\"10.3.5\";s:3:\"tag\";s:6:\"10.3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.5.tar.gz\";s:4:\"date\";s:10:\"1726134993\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.4\";s:7:\"version\";s:6:\"10.3.4\";s:3:\"tag\";s:6:\"10.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.4.tar.gz\";s:4:\"date\";s:10:\"1726072510\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.3\";s:7:\"version\";s:6:\"10.3.3\";s:3:\"tag\";s:6:\"10.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.3.tar.gz\";s:4:\"date\";s:10:\"1725528161\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.2\";s:7:\"version\";s:6:\"10.3.2\";s:3:\"tag\";s:6:\"10.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.2.tar.gz\";s:4:\"date\";s:10:\"1723109810\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.1\";s:7:\"version\";s:6:\"10.3.1\";s:3:\"tag\";s:6:\"10.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.1.tar.gz\";s:4:\"date\";s:10:\"1720094095\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.0\";s:7:\"version\";s:6:\"10.3.0\";s:3:\"tag\";s:6:\"10.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.0.tar.gz\";s:4:\"date\";s:10:\"1718911125\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.3.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.3.0-rc1\";s:7:\"version\";s:10:\"10.3.0-rc1\";s:3:\"tag\";s:10:\"10.3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.3.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1717621189\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.3.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.3.0-beta1\";s:7:\"version\";s:12:\"10.3.0-beta1\";s:3:\"tag\";s:12:\"10.3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.3.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1715953149\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"10.2.9\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.9\";s:7:\"version\";s:6:\"10.2.9\";s:3:\"tag\";s:6:\"10.2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.9.tar.gz\";s:4:\"date\";s:10:\"1728387439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.8\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.8\";s:7:\"version\";s:6:\"10.2.8\";s:3:\"tag\";s:6:\"10.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.8.tar.gz\";s:4:\"date\";s:10:\"1726073816\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.7\";s:7:\"version\";s:6:\"10.2.7\";s:3:\"tag\";s:6:\"10.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.7.tar.gz\";s:4:\"date\";s:10:\"1717660024\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.6\";s:7:\"version\";s:6:\"10.2.6\";s:3:\"tag\";s:6:\"10.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.6.tar.gz\";s:4:\"date\";s:10:\"1714597701\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.5\";s:7:\"version\";s:6:\"10.2.5\";s:3:\"tag\";s:6:\"10.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.5.tar.gz\";s:4:\"date\";s:10:\"1712130945\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.4\";s:7:\"version\";s:6:\"10.2.4\";s:3:\"tag\";s:6:\"10.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.4.tar.gz\";s:4:\"date\";s:10:\"1709715366\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.3\";s:7:\"version\";s:6:\"10.2.3\";s:3:\"tag\";s:6:\"10.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.3.tar.gz\";s:4:\"date\";s:10:\"1707347611\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.2\";s:7:\"version\";s:6:\"10.2.2\";s:3:\"tag\";s:6:\"10.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.2.tar.gz\";s:4:\"date\";s:10:\"1705511786\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.1\";s:7:\"version\";s:6:\"10.2.1\";s:3:\"tag\";s:6:\"10.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.1.tar.gz\";s:4:\"date\";s:10:\"1704448164\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.0\";s:7:\"version\";s:6:\"10.2.0\";s:3:\"tag\";s:6:\"10.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.0.tar.gz\";s:4:\"date\";s:10:\"1702681674\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.2.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.2.0-rc1\";s:7:\"version\";s:10:\"10.2.0-rc1\";s:3:\"tag\";s:10:\"10.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.2.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1701450971\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.2.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.2.0-beta1\";s:7:\"version\";s:12:\"10.2.0-beta1\";s:3:\"tag\";s:12:\"10.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.2.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1700578716\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"10.2.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 10.2.0-alpha1\";s:7:\"version\";s:13:\"10.2.0-alpha1\";s:3:\"tag\";s:13:\"10.2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.2.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1699048959\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"10.1.8\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.8\";s:7:\"version\";s:6:\"10.1.8\";s:3:\"tag\";s:6:\"10.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.8.tar.gz\";s:4:\"date\";s:10:\"1705512711\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.7\";s:7:\"version\";s:6:\"10.1.7\";s:3:\"tag\";s:6:\"10.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.7.tar.gz\";s:4:\"date\";s:10:\"1701857745\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.6\";s:7:\"version\";s:6:\"10.1.6\";s:3:\"tag\";s:6:\"10.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.6.tar.gz\";s:4:\"date\";s:10:\"1698841286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.5\";s:7:\"version\";s:6:\"10.1.5\";s:3:\"tag\";s:6:\"10.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.5.tar.gz\";s:4:\"date\";s:10:\"1696456362\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.4\";s:7:\"version\";s:6:\"10.1.4\";s:3:\"tag\";s:6:\"10.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.4.tar.gz\";s:4:\"date\";s:10:\"1695227262\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.3\";s:7:\"version\";s:6:\"10.1.3\";s:3:\"tag\";s:6:\"10.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.3.tar.gz\";s:4:\"date\";s:10:\"1694101052\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.2\";s:7:\"version\";s:6:\"10.1.2\";s:3:\"tag\";s:6:\"10.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.2.tar.gz\";s:4:\"date\";s:10:\"1690972078\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.1\";s:7:\"version\";s:6:\"10.1.1\";s:3:\"tag\";s:6:\"10.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.1.tar.gz\";s:4:\"date\";s:10:\"1688632960\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.0\";s:7:\"version\";s:6:\"10.1.0\";s:3:\"tag\";s:6:\"10.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.0.tar.gz\";s:4:\"date\";s:10:\"1687424272\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.1.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.1.0-rc1\";s:7:\"version\";s:10:\"10.1.0-rc1\";s:3:\"tag\";s:10:\"10.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.1.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1686244833\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.1.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.1.0-beta1\";s:7:\"version\";s:12:\"10.1.0-beta1\";s:3:\"tag\";s:12:\"10.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.1.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1684130534\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"10.1.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 10.1.0-alpha1\";s:7:\"version\";s:13:\"10.1.0-alpha1\";s:3:\"tag\";s:13:\"10.1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.1.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1682694475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:7:\"10.0.11\";a:10:{s:4:\"name\";s:14:\"drupal 10.0.11\";s:7:\"version\";s:7:\"10.0.11\";s:3:\"tag\";s:7:\"10.0.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.0.11\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.0.11.tar.gz\";s:4:\"date\";s:10:\"1695228927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"10.0.10\";a:10:{s:4:\"name\";s:14:\"drupal 10.0.10\";s:7:\"version\";s:7:\"10.0.10\";s:3:\"tag\";s:7:\"10.0.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.0.10\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.0.10.tar.gz\";s:4:\"date\";s:10:\"1688549719\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.9\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.9\";s:7:\"version\";s:6:\"10.0.9\";s:3:\"tag\";s:6:\"10.0.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.9.tar.gz\";s:4:\"date\";s:10:\"1683108606\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.8\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.8\";s:7:\"version\";s:6:\"10.0.8\";s:3:\"tag\";s:6:\"10.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.8.tar.gz\";s:4:\"date\";s:10:\"1681921539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.7\";s:7:\"version\";s:6:\"10.0.7\";s:3:\"tag\";s:6:\"10.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.7.tar.gz\";s:4:\"date\";s:10:\"1679678060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.6\";s:7:\"version\";s:6:\"10.0.6\";s:3:\"tag\";s:6:\"10.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.6.tar.gz\";s:4:\"date\";s:10:\"1679664982\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.5\";s:7:\"version\";s:6:\"10.0.5\";s:3:\"tag\";s:6:\"10.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.5.tar.gz\";s:4:\"date\";s:10:\"1678901067\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.4\";s:7:\"version\";s:6:\"10.0.4\";s:3:\"tag\";s:6:\"10.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.4.tar.gz\";s:4:\"date\";s:10:\"1677681486\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.3\";s:7:\"version\";s:6:\"10.0.3\";s:3:\"tag\";s:6:\"10.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.3.tar.gz\";s:4:\"date\";s:10:\"1675276709\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.2\";s:7:\"version\";s:6:\"10.0.2\";s:3:\"tag\";s:6:\"10.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.2.tar.gz\";s:4:\"date\";s:10:\"1674065542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.1\";s:7:\"version\";s:6:\"10.0.1\";s:3:\"tag\";s:6:\"10.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.1.tar.gz\";s:4:\"date\";s:10:\"1672847780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.0\";s:7:\"version\";s:6:\"10.0.0\";s:3:\"tag\";s:6:\"10.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.0.tar.gz\";s:4:\"date\";s:10:\"1671125939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.0.0-rc3\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.0-rc3\";s:7:\"version\";s:10:\"10.0.0-rc3\";s:3:\"tag\";s:10:\"10.0.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.0-rc3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1670591784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:10:\"10.0.0-rc2\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.0-rc2\";s:7:\"version\";s:10:\"10.0.0-rc2\";s:3:\"tag\";s:10:\"10.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.0-rc2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1670320927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:10:\"10.0.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.0-rc1\";s:7:\"version\";s:10:\"10.0.0-rc1\";s:3:\"tag\";s:10:\"10.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1668612993\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.0.0-beta2\";a:10:{s:4:\"name\";s:19:\"drupal 10.0.0-beta2\";s:7:\"version\";s:12:\"10.0.0-beta2\";s:3:\"tag\";s:12:\"10.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.0.0-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1664462663\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"10.0.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.0.0-beta1\";s:7:\"version\";s:12:\"10.0.0-beta1\";s:3:\"tag\";s:12:\"10.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.0.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1663358020\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha7\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha7\";s:7:\"version\";s:13:\"10.0.0-alpha7\";s:3:\"tag\";s:13:\"10.0.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha7\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1659633851\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha6\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha6\";s:7:\"version\";s:13:\"10.0.0-alpha6\";s:3:\"tag\";s:13:\"10.0.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha6\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1657218740\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha5\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha5\";s:7:\"version\";s:13:\"10.0.0-alpha5\";s:3:\"tag\";s:13:\"10.0.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha5\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1654722993\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha4\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha4\";s:7:\"version\";s:13:\"10.0.0-alpha4\";s:3:\"tag\";s:13:\"10.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1651875601\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha3\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha3\";s:7:\"version\";s:13:\"10.0.0-alpha3\";s:3:\"tag\";s:13:\"10.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1649887793\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha2\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha2\";s:7:\"version\";s:13:\"10.0.0-alpha2\";s:3:\"tag\";s:13:\"10.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1645204305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha1\";s:7:\"version\";s:13:\"10.0.0-alpha1\";s:3:\"tag\";s:13:\"10.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1643404041\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.5.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.5.11\";s:7:\"version\";s:6:\"9.5.11\";s:3:\"tag\";s:6:\"9.5.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.5.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.5.11.tar.gz\";s:4:\"date\";s:10:\"1695228016\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.5.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.5.10\";s:7:\"version\";s:6:\"9.5.10\";s:3:\"tag\";s:6:\"9.5.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.5.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.5.10.tar.gz\";s:4:\"date\";s:10:\"1688550984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.9\";s:7:\"version\";s:5:\"9.5.9\";s:3:\"tag\";s:5:\"9.5.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.9.tar.gz\";s:4:\"date\";s:10:\"1683121532\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.8\";s:7:\"version\";s:5:\"9.5.8\";s:3:\"tag\";s:5:\"9.5.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.8.tar.gz\";s:4:\"date\";s:10:\"1681922649\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.7\";s:7:\"version\";s:5:\"9.5.7\";s:3:\"tag\";s:5:\"9.5.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.7.tar.gz\";s:4:\"date\";s:10:\"1679677448\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.6\";s:7:\"version\";s:5:\"9.5.6\";s:3:\"tag\";s:5:\"9.5.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.6.tar.gz\";s:4:\"date\";s:10:\"1679664389\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.5\";s:7:\"version\";s:5:\"9.5.5\";s:3:\"tag\";s:5:\"9.5.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.5.tar.gz\";s:4:\"date\";s:10:\"1678902101\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.4\";s:7:\"version\";s:5:\"9.5.4\";s:3:\"tag\";s:5:\"9.5.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.4.tar.gz\";s:4:\"date\";s:10:\"1677680813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.3\";s:7:\"version\";s:5:\"9.5.3\";s:3:\"tag\";s:5:\"9.5.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.3.tar.gz\";s:4:\"date\";s:10:\"1675281829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.2\";s:7:\"version\";s:5:\"9.5.2\";s:3:\"tag\";s:5:\"9.5.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.2.tar.gz\";s:4:\"date\";s:10:\"1674066112\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.1\";s:7:\"version\";s:5:\"9.5.1\";s:3:\"tag\";s:5:\"9.5.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.1.tar.gz\";s:4:\"date\";s:10:\"1672849046\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.0\";s:7:\"version\";s:5:\"9.5.0\";s:3:\"tag\";s:5:\"9.5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.0.tar.gz\";s:4:\"date\";s:10:\"1671115839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.5.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 9.5.0-rc2\";s:7:\"version\";s:9:\"9.5.0-rc2\";s:3:\"tag\";s:9:\"9.5.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.5.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1670593040\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.5.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.5.0-rc1\";s:7:\"version\";s:9:\"9.5.0-rc1\";s:3:\"tag\";s:9:\"9.5.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.5.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1668611189\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.5.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.5.0-beta2\";s:7:\"version\";s:11:\"9.5.0-beta2\";s:3:\"tag\";s:11:\"9.5.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.5.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1664463958\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.5.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.5.0-beta1\";s:7:\"version\";s:11:\"9.5.0-beta1\";s:3:\"tag\";s:11:\"9.5.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.5.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1663358587\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"9.4.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.15\";s:7:\"version\";s:6:\"9.4.15\";s:3:\"tag\";s:6:\"9.4.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.15.tar.gz\";s:4:\"date\";s:10:\"1683122076\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.14\";s:7:\"version\";s:6:\"9.4.14\";s:3:\"tag\";s:6:\"9.4.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.14.tar.gz\";s:4:\"date\";s:10:\"1681922120\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.13\";s:7:\"version\";s:6:\"9.4.13\";s:3:\"tag\";s:6:\"9.4.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.13.tar.gz\";s:4:\"date\";s:10:\"1679665413\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.12\";s:7:\"version\";s:6:\"9.4.12\";s:3:\"tag\";s:6:\"9.4.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.12.tar.gz\";s:4:\"date\";s:10:\"1678901516\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.11\";s:7:\"version\";s:6:\"9.4.11\";s:3:\"tag\";s:6:\"9.4.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.11.tar.gz\";s:4:\"date\";s:10:\"1675282255\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.10\";s:7:\"version\";s:6:\"9.4.10\";s:3:\"tag\";s:6:\"9.4.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.10.tar.gz\";s:4:\"date\";s:10:\"1674066615\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.9\";s:7:\"version\";s:5:\"9.4.9\";s:3:\"tag\";s:5:\"9.4.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.9.tar.gz\";s:4:\"date\";s:10:\"1670421053\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.8\";s:7:\"version\";s:5:\"9.4.8\";s:3:\"tag\";s:5:\"9.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.8.tar.gz\";s:4:\"date\";s:10:\"1665072393\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.7\";s:7:\"version\";s:5:\"9.4.7\";s:3:\"tag\";s:5:\"9.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.7.tar.gz\";s:4:\"date\";s:10:\"1664383239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.6\";s:7:\"version\";s:5:\"9.4.6\";s:3:\"tag\";s:5:\"9.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.6.tar.gz\";s:4:\"date\";s:10:\"1663681319\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.5\";s:7:\"version\";s:5:\"9.4.5\";s:3:\"tag\";s:5:\"9.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.5.tar.gz\";s:4:\"date\";s:10:\"1659545453\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.4\";s:7:\"version\";s:5:\"9.4.4\";s:3:\"tag\";s:5:\"9.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.4.tar.gz\";s:4:\"date\";s:10:\"1659037490\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.3\";s:7:\"version\";s:5:\"9.4.3\";s:3:\"tag\";s:5:\"9.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.3.tar.gz\";s:4:\"date\";s:10:\"1658333415\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.2\";s:7:\"version\";s:5:\"9.4.2\";s:3:\"tag\";s:5:\"9.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.2.tar.gz\";s:4:\"date\";s:10:\"1657157309\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.1\";s:7:\"version\";s:5:\"9.4.1\";s:3:\"tag\";s:5:\"9.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.1.tar.gz\";s:4:\"date\";s:10:\"1655845511\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.0\";s:7:\"version\";s:5:\"9.4.0\";s:3:\"tag\";s:5:\"9.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.0.tar.gz\";s:4:\"date\";s:10:\"1655311138\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.4.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 9.4.0-rc2\";s:7:\"version\";s:9:\"9.4.0-rc2\";s:3:\"tag\";s:9:\"9.4.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.4.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1654890055\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.4.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.4.0-rc1\";s:7:\"version\";s:9:\"9.4.0-rc1\";s:3:\"tag\";s:9:\"9.4.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.4.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1654740019\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.4.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.4.0-beta1\";s:7:\"version\";s:11:\"9.4.0-beta1\";s:3:\"tag\";s:11:\"9.4.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.4.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1653938214\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.4.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.4.0-alpha1\";s:7:\"version\";s:12:\"9.4.0-alpha1\";s:3:\"tag\";s:12:\"9.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.4.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1651875606\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.3.22\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.22\";s:7:\"version\";s:6:\"9.3.22\";s:3:\"tag\";s:6:\"9.3.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.22\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.22.tar.gz\";s:4:\"date\";s:10:\"1664382666\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.21\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.21\";s:7:\"version\";s:6:\"9.3.21\";s:3:\"tag\";s:6:\"9.3.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.21\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.21.tar.gz\";s:4:\"date\";s:10:\"1659544886\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.20\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.20\";s:7:\"version\";s:6:\"9.3.20\";s:3:\"tag\";s:6:\"9.3.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.20\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.20.tar.gz\";s:4:\"date\";s:10:\"1659037977\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.19\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.19\";s:7:\"version\";s:6:\"9.3.19\";s:3:\"tag\";s:6:\"9.3.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.19\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.19.tar.gz\";s:4:\"date\";s:10:\"1658333887\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.18\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.18\";s:7:\"version\";s:6:\"9.3.18\";s:3:\"tag\";s:6:\"9.3.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.18.tar.gz\";s:4:\"date\";s:10:\"1657238772\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.17\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.17\";s:7:\"version\";s:6:\"9.3.17\";s:3:\"tag\";s:6:\"9.3.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.17.tar.gz\";s:4:\"date\";s:10:\"1655846622\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.16\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.16\";s:7:\"version\";s:6:\"9.3.16\";s:3:\"tag\";s:6:\"9.3.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.16.tar.gz\";s:4:\"date\";s:10:\"1654888736\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.15\";s:7:\"version\";s:6:\"9.3.15\";s:3:\"tag\";s:6:\"9.3.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.15.tar.gz\";s:4:\"date\";s:10:\"1654098765\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.14\";s:7:\"version\";s:6:\"9.3.14\";s:3:\"tag\";s:6:\"9.3.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.14.tar.gz\";s:4:\"date\";s:10:\"1653506291\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.13\";s:7:\"version\";s:6:\"9.3.13\";s:3:\"tag\";s:6:\"9.3.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.13.tar.gz\";s:4:\"date\";s:10:\"1652261874\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.12\";s:7:\"version\";s:6:\"9.3.12\";s:3:\"tag\";s:6:\"9.3.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.12.tar.gz\";s:4:\"date\";s:10:\"1650467536\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.11\";s:7:\"version\";s:6:\"9.3.11\";s:3:\"tag\";s:6:\"9.3.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.11.tar.gz\";s:4:\"date\";s:10:\"1649897391\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.10\";s:7:\"version\";s:6:\"9.3.10\";s:3:\"tag\";s:6:\"9.3.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.10.tar.gz\";s:4:\"date\";s:10:\"1649890098\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.9\";s:7:\"version\";s:5:\"9.3.9\";s:3:\"tag\";s:5:\"9.3.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.9.tar.gz\";s:4:\"date\";s:10:\"1647899360\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.8\";s:7:\"version\";s:5:\"9.3.8\";s:3:\"tag\";s:5:\"9.3.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.8.tar.gz\";s:4:\"date\";s:10:\"1647446914\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.7\";s:7:\"version\";s:5:\"9.3.7\";s:3:\"tag\";s:5:\"9.3.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.7.tar.gz\";s:4:\"date\";s:10:\"1646300599\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.6\";s:7:\"version\";s:5:\"9.3.6\";s:3:\"tag\";s:5:\"9.3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.6.tar.gz\";s:4:\"date\";s:10:\"1645029460\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.5\";s:7:\"version\";s:5:\"9.3.5\";s:3:\"tag\";s:5:\"9.3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.5.tar.gz\";s:4:\"date\";s:10:\"1644011676\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.4\";s:7:\"version\";s:5:\"9.3.4\";s:3:\"tag\";s:5:\"9.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.4.tar.gz\";s:4:\"date\";s:10:\"1643832805\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.3\";s:7:\"version\";s:5:\"9.3.3\";s:3:\"tag\";s:5:\"9.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.3.tar.gz\";s:4:\"date\";s:10:\"1642607769\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.2\";s:7:\"version\";s:5:\"9.3.2\";s:3:\"tag\";s:5:\"9.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.2.tar.gz\";s:4:\"date\";s:10:\"1641351799\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.1\";s:7:\"version\";s:5:\"9.3.1\";s:3:\"tag\";s:5:\"9.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.1.tar.gz\";s:4:\"date\";s:10:\"1641342679\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.0\";s:7:\"version\";s:5:\"9.3.0\";s:3:\"tag\";s:5:\"9.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.0.tar.gz\";s:4:\"date\";s:10:\"1639051276\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.3.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.3.0-rc1\";s:7:\"version\";s:9:\"9.3.0-rc1\";s:3:\"tag\";s:9:\"9.3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.3.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1637959424\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.3.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 9.3.0-beta3\";s:7:\"version\";s:11:\"9.3.0-beta3\";s:3:\"tag\";s:11:\"9.3.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.3.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1637764182\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.3.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.3.0-beta2\";s:7:\"version\";s:11:\"9.3.0-beta2\";s:3:\"tag\";s:11:\"9.3.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.3.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1637196496\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.3.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.3.0-beta1\";s:7:\"version\";s:11:\"9.3.0-beta1\";s:3:\"tag\";s:11:\"9.3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.3.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1636746050\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.3.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.3.0-alpha1\";s:7:\"version\";s:12:\"9.3.0-alpha1\";s:3:\"tag\";s:12:\"9.3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.3.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1635510285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.2.21\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.21\";s:7:\"version\";s:6:\"9.2.21\";s:3:\"tag\";s:6:\"9.2.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.21\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.21.tar.gz\";s:4:\"date\";s:10:\"1654889475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.20\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.20\";s:7:\"version\";s:6:\"9.2.20\";s:3:\"tag\";s:6:\"9.2.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.20\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.20.tar.gz\";s:4:\"date\";s:10:\"1653507225\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.19\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.19\";s:7:\"version\";s:6:\"9.2.19\";s:3:\"tag\";s:6:\"9.2.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.19\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.19.tar.gz\";s:4:\"date\";s:10:\"1652306637\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.18\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.18\";s:7:\"version\";s:6:\"9.2.18\";s:3:\"tag\";s:6:\"9.2.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.18.tar.gz\";s:4:\"date\";s:10:\"1650466972\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.17\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.17\";s:7:\"version\";s:6:\"9.2.17\";s:3:\"tag\";s:6:\"9.2.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.17.tar.gz\";s:4:\"date\";s:10:\"1649898006\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.16\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.16\";s:7:\"version\";s:6:\"9.2.16\";s:3:\"tag\";s:6:\"9.2.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.16.tar.gz\";s:4:\"date\";s:10:\"1647898826\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.15\";s:7:\"version\";s:6:\"9.2.15\";s:3:\"tag\";s:6:\"9.2.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.15.tar.gz\";s:4:\"date\";s:10:\"1647447411\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.14\";s:7:\"version\";s:6:\"9.2.14\";s:3:\"tag\";s:6:\"9.2.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.14.tar.gz\";s:4:\"date\";s:10:\"1647027629\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.13\";s:7:\"version\";s:6:\"9.2.13\";s:3:\"tag\";s:6:\"9.2.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.13.tar.gz\";s:4:\"date\";s:10:\"1645029955\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.12\";s:7:\"version\";s:6:\"9.2.12\";s:3:\"tag\";s:6:\"9.2.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.12.tar.gz\";s:4:\"date\";s:10:\"1644012448\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.11\";s:7:\"version\";s:6:\"9.2.11\";s:3:\"tag\";s:6:\"9.2.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.11.tar.gz\";s:4:\"date\";s:10:\"1642608353\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.10\";s:7:\"version\";s:6:\"9.2.10\";s:3:\"tag\";s:6:\"9.2.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.10.tar.gz\";s:4:\"date\";s:10:\"1637765544\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.9\";s:7:\"version\";s:5:\"9.2.9\";s:3:\"tag\";s:5:\"9.2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.9.tar.gz\";s:4:\"date\";s:10:\"1637184936\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.8\";s:7:\"version\";s:5:\"9.2.8\";s:3:\"tag\";s:5:\"9.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.8.tar.gz\";s:4:\"date\";s:10:\"1635961216\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.7\";s:7:\"version\";s:5:\"9.2.7\";s:3:\"tag\";s:5:\"9.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.7.tar.gz\";s:4:\"date\";s:10:\"1633544267\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.6\";s:7:\"version\";s:5:\"9.2.6\";s:3:\"tag\";s:5:\"9.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.6.tar.gz\";s:4:\"date\";s:10:\"1631721555\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.5\";s:7:\"version\";s:5:\"9.2.5\";s:3:\"tag\";s:5:\"9.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.5.tar.gz\";s:4:\"date\";s:10:\"1630534729\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.4\";s:7:\"version\";s:5:\"9.2.4\";s:3:\"tag\";s:5:\"9.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.4.tar.gz\";s:4:\"date\";s:10:\"1628791178\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.3\";s:7:\"version\";s:5:\"9.2.3\";s:3:\"tag\";s:5:\"9.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.3.tar.gz\";s:4:\"date\";s:10:\"1627997922\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.2\";s:7:\"version\";s:5:\"9.2.2\";s:3:\"tag\";s:5:\"9.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.2.tar.gz\";s:4:\"date\";s:10:\"1626882385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.1\";s:7:\"version\";s:5:\"9.2.1\";s:3:\"tag\";s:5:\"9.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.1.tar.gz\";s:4:\"date\";s:10:\"1625664286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.0\";s:7:\"version\";s:5:\"9.2.0\";s:3:\"tag\";s:5:\"9.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.0.tar.gz\";s:4:\"date\";s:10:\"1623847798\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.2.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.2.0-rc1\";s:7:\"version\";s:9:\"9.2.0-rc1\";s:3:\"tag\";s:9:\"9.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.2.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1623080867\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.2.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 9.2.0-beta3\";s:7:\"version\";s:11:\"9.2.0-beta3\";s:3:\"tag\";s:11:\"9.2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.2.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1622207568\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.2.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.2.0-beta2\";s:7:\"version\";s:11:\"9.2.0-beta2\";s:3:\"tag\";s:11:\"9.2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.2.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1622068611\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.2.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.2.0-beta1\";s:7:\"version\";s:11:\"9.2.0-beta1\";s:3:\"tag\";s:11:\"9.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.2.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1621506248\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.2.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.2.0-alpha1\";s:7:\"version\";s:12:\"9.2.0-alpha1\";s:3:\"tag\";s:12:\"9.2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.2.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1620291652\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.1.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.15\";s:7:\"version\";s:6:\"9.1.15\";s:3:\"tag\";s:6:\"9.1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.15.tar.gz\";s:4:\"date\";s:10:\"1637766681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.14\";s:7:\"version\";s:6:\"9.1.14\";s:3:\"tag\";s:6:\"9.1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.14.tar.gz\";s:4:\"date\";s:10:\"1637185450\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.13\";s:7:\"version\";s:6:\"9.1.13\";s:3:\"tag\";s:6:\"9.1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.13.tar.gz\";s:4:\"date\";s:10:\"1631722011\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.12\";s:7:\"version\";s:6:\"9.1.12\";s:3:\"tag\";s:6:\"9.1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.12.tar.gz\";s:4:\"date\";s:10:\"1628791786\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.11\";s:7:\"version\";s:6:\"9.1.11\";s:3:\"tag\";s:6:\"9.1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.11.tar.gz\";s:4:\"date\";s:10:\"1626882849\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.10\";s:7:\"version\";s:6:\"9.1.10\";s:3:\"tag\";s:6:\"9.1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.10.tar.gz\";s:4:\"date\";s:10:\"1622828120\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.9\";s:7:\"version\";s:5:\"9.1.9\";s:3:\"tag\";s:5:\"9.1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.9.tar.gz\";s:4:\"date\";s:10:\"1622056478\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.8\";s:7:\"version\";s:5:\"9.1.8\";s:3:\"tag\";s:5:\"9.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.8.tar.gz\";s:4:\"date\";s:10:\"1620214182\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.7\";s:7:\"version\";s:5:\"9.1.7\";s:3:\"tag\";s:5:\"9.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.7.tar.gz\";s:4:\"date\";s:10:\"1619022156\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.6\";s:7:\"version\";s:5:\"9.1.6\";s:3:\"tag\";s:5:\"9.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.6.tar.gz\";s:4:\"date\";s:10:\"1617795446\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.5\";s:7:\"version\";s:5:\"9.1.5\";s:3:\"tag\";s:5:\"9.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.5.tar.gz\";s:4:\"date\";s:10:\"1614869503\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.4\";s:7:\"version\";s:5:\"9.1.4\";s:3:\"tag\";s:5:\"9.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.4.tar.gz\";s:4:\"date\";s:10:\"1612380948\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.3\";s:7:\"version\";s:5:\"9.1.3\";s:3:\"tag\";s:5:\"9.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.3.tar.gz\";s:4:\"date\";s:10:\"1611161215\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.2\";s:7:\"version\";s:5:\"9.1.2\";s:3:\"tag\";s:5:\"9.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.2.tar.gz\";s:4:\"date\";s:10:\"1609984407\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.1\";s:7:\"version\";s:5:\"9.1.1\";s:3:\"tag\";s:5:\"9.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.1.tar.gz\";s:4:\"date\";s:10:\"1609979034\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.0\";s:7:\"version\";s:5:\"9.1.0\";s:3:\"tag\";s:5:\"9.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.0.tar.gz\";s:4:\"date\";s:10:\"1606933254\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.1.0-rc3\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.0-rc3\";s:7:\"version\";s:9:\"9.1.0-rc3\";s:3:\"tag\";s:9:\"9.1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.0-rc3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1606357271\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.1.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.0-rc2\";s:7:\"version\";s:9:\"9.1.0-rc2\";s:3:\"tag\";s:9:\"9.1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1606332982\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.1.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.0-rc1\";s:7:\"version\";s:9:\"9.1.0-rc1\";s:3:\"tag\";s:9:\"9.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1605722782\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.1.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.1.0-beta1\";s:7:\"version\";s:11:\"9.1.0-beta1\";s:3:\"tag\";s:11:\"9.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.1.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1604672644\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.1.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.1.0-alpha1\";s:7:\"version\";s:12:\"9.1.0-alpha1\";s:3:\"tag\";s:12:\"9.1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.1.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1603466665\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.0.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.14\";s:7:\"version\";s:6:\"9.0.14\";s:3:\"tag\";s:6:\"9.0.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.14.tar.gz\";s:4:\"date\";s:10:\"1622055778\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.13\";s:7:\"version\";s:6:\"9.0.13\";s:3:\"tag\";s:6:\"9.0.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.13.tar.gz\";s:4:\"date\";s:10:\"1620218506\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.12\";s:7:\"version\";s:6:\"9.0.12\";s:3:\"tag\";s:6:\"9.0.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.12.tar.gz\";s:4:\"date\";s:10:\"1619020951\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.11\";s:7:\"version\";s:6:\"9.0.11\";s:3:\"tag\";s:6:\"9.0.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.11.tar.gz\";s:4:\"date\";s:10:\"1611161749\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.10\";s:7:\"version\";s:6:\"9.0.10\";s:3:\"tag\";s:6:\"9.0.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.10.tar.gz\";s:4:\"date\";s:10:\"1607029536\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.9\";s:7:\"version\";s:5:\"9.0.9\";s:3:\"tag\";s:5:\"9.0.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.9.tar.gz\";s:4:\"date\";s:10:\"1606359757\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.8\";s:7:\"version\";s:5:\"9.0.8\";s:3:\"tag\";s:5:\"9.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.8.tar.gz\";s:4:\"date\";s:10:\"1605720638\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.7\";s:7:\"version\";s:5:\"9.0.7\";s:3:\"tag\";s:5:\"9.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.7.tar.gz\";s:4:\"date\";s:10:\"1602100055\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.6\";s:7:\"version\";s:5:\"9.0.6\";s:3:\"tag\";s:5:\"9.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.6.tar.gz\";s:4:\"date\";s:10:\"1600275813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.5\";s:7:\"version\";s:5:\"9.0.5\";s:3:\"tag\";s:5:\"9.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.5.tar.gz\";s:4:\"date\";s:10:\"1599167739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.4\";s:7:\"version\";s:5:\"9.0.4\";s:3:\"tag\";s:5:\"9.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.4.tar.gz\";s:4:\"date\";s:10:\"1599046734\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.3\";s:7:\"version\";s:5:\"9.0.3\";s:3:\"tag\";s:5:\"9.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.3.tar.gz\";s:4:\"date\";s:10:\"1596664575\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.2\";s:7:\"version\";s:5:\"9.0.2\";s:3:\"tag\";s:5:\"9.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.2.tar.gz\";s:4:\"date\";s:10:\"1594237418\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.1\";s:7:\"version\";s:5:\"9.0.1\";s:3:\"tag\";s:5:\"9.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.1.tar.gz\";s:4:\"date\";s:10:\"1592417721\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.0\";s:7:\"version\";s:5:\"9.0.0\";s:3:\"tag\";s:5:\"9.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.0.tar.gz\";s:4:\"date\";s:10:\"1591221685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.0.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.0.0-rc1\";s:7:\"version\";s:9:\"9.0.0-rc1\";s:3:\"tag\";s:9:\"9.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.0.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1590187579\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.0.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 9.0.0-beta3\";s:7:\"version\";s:11:\"9.0.0-beta3\";s:3:\"tag\";s:11:\"9.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.0.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1589587936\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.0.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.0.0-beta2\";s:7:\"version\";s:11:\"9.0.0-beta2\";s:3:\"tag\";s:11:\"9.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.0.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1585597395\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.0.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.0.0-beta1\";s:7:\"version\";s:11:\"9.0.0-beta1\";s:3:\"tag\";s:11:\"9.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.0.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1584734060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.0.0-alpha2\";a:10:{s:4:\"name\";s:19:\"drupal 9.0.0-alpha2\";s:7:\"version\";s:12:\"9.0.0-alpha2\";s:3:\"tag\";s:12:\"9.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.0.0-alpha2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1583349043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:12:\"9.0.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.0.0-alpha1\";s:7:\"version\";s:12:\"9.0.0-alpha1\";s:3:\"tag\";s:12:\"9.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.0.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1581447927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.9.20\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.20\";s:7:\"version\";s:6:\"8.9.20\";s:3:\"tag\";s:6:\"8.9.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.20\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.20.tar.gz\";s:4:\"date\";s:10:\"1637185966\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.19\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.19\";s:7:\"version\";s:6:\"8.9.19\";s:3:\"tag\";s:6:\"8.9.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.19\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.19.tar.gz\";s:4:\"date\";s:10:\"1631722431\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.18\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.18\";s:7:\"version\";s:6:\"8.9.18\";s:3:\"tag\";s:6:\"8.9.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.18.tar.gz\";s:4:\"date\";s:10:\"1628792296\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.17\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.17\";s:7:\"version\";s:6:\"8.9.17\";s:3:\"tag\";s:6:\"8.9.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.17.tar.gz\";s:4:\"date\";s:10:\"1626883324\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.16\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.16\";s:7:\"version\";s:6:\"8.9.16\";s:3:\"tag\";s:6:\"8.9.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.16.tar.gz\";s:4:\"date\";s:10:\"1622058087\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.15\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.15\";s:7:\"version\";s:6:\"8.9.15\";s:3:\"tag\";s:6:\"8.9.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.15.tar.gz\";s:4:\"date\";s:10:\"1620216983\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.14\";s:7:\"version\";s:6:\"8.9.14\";s:3:\"tag\";s:6:\"8.9.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.14.tar.gz\";s:4:\"date\";s:10:\"1619021518\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.13\";s:7:\"version\";s:6:\"8.9.13\";s:3:\"tag\";s:6:\"8.9.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.13.tar.gz\";s:4:\"date\";s:10:\"1611162272\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.12\";s:7:\"version\";s:6:\"8.9.12\";s:3:\"tag\";s:6:\"8.9.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.12.tar.gz\";s:4:\"date\";s:10:\"1609977009\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.11\";s:7:\"version\";s:6:\"8.9.11\";s:3:\"tag\";s:6:\"8.9.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.11.tar.gz\";s:4:\"date\";s:10:\"1607030087\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.10\";s:7:\"version\";s:6:\"8.9.10\";s:3:\"tag\";s:6:\"8.9.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.10.tar.gz\";s:4:\"date\";s:10:\"1606360301\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.9\";s:7:\"version\";s:5:\"8.9.9\";s:3:\"tag\";s:5:\"8.9.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.9.tar.gz\";s:4:\"date\";s:10:\"1605721120\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.8\";s:7:\"version\";s:5:\"8.9.8\";s:3:\"tag\";s:5:\"8.9.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.8.tar.gz\";s:4:\"date\";s:10:\"1604595269\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.7\";s:7:\"version\";s:5:\"8.9.7\";s:3:\"tag\";s:5:\"8.9.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.7.tar.gz\";s:4:\"date\";s:10:\"1602100507\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.6\";s:7:\"version\";s:5:\"8.9.6\";s:3:\"tag\";s:5:\"8.9.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.6.tar.gz\";s:4:\"date\";s:10:\"1600276267\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.5\";s:7:\"version\";s:5:\"8.9.5\";s:3:\"tag\";s:5:\"8.9.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.5.tar.gz\";s:4:\"date\";s:10:\"1599168205\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.4\";s:7:\"version\";s:5:\"8.9.4\";s:3:\"tag\";s:5:\"8.9.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.4.tar.gz\";s:4:\"date\";s:10:\"1599047691\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.3\";s:7:\"version\";s:5:\"8.9.3\";s:3:\"tag\";s:5:\"8.9.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.3.tar.gz\";s:4:\"date\";s:10:\"1596665051\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.2\";s:7:\"version\";s:5:\"8.9.2\";s:3:\"tag\";s:5:\"8.9.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.2.tar.gz\";s:4:\"date\";s:10:\"1594237961\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.1\";s:7:\"version\";s:5:\"8.9.1\";s:3:\"tag\";s:5:\"8.9.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.1.tar.gz\";s:4:\"date\";s:10:\"1592418237\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.0\";s:7:\"version\";s:5:\"8.9.0\";s:3:\"tag\";s:5:\"8.9.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.0.tar.gz\";s:4:\"date\";s:10:\"1591204117\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.9.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.9.0-rc1\";s:7:\"version\";s:9:\"8.9.0-rc1\";s:3:\"tag\";s:9:\"8.9.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.9.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1590189096\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.9.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 8.9.0-beta3\";s:7:\"version\";s:11:\"8.9.0-beta3\";s:3:\"tag\";s:11:\"8.9.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.9.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1589746375\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.9.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.9.0-beta2\";s:7:\"version\";s:11:\"8.9.0-beta2\";s:3:\"tag\";s:11:\"8.9.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.9.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1585863226\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.9.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.9.0-beta1\";s:7:\"version\";s:11:\"8.9.0-beta1\";s:3:\"tag\";s:11:\"8.9.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.9.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1585263710\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"8.8.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.8.12\";s:7:\"version\";s:6:\"8.8.12\";s:3:\"tag\";s:6:\"8.8.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.8.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.8.12.tar.gz\";s:4:\"date\";s:10:\"1606360866\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.8.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.8.11\";s:7:\"version\";s:6:\"8.8.11\";s:3:\"tag\";s:6:\"8.8.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.8.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.8.11.tar.gz\";s:4:\"date\";s:10:\"1605721628\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.8.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.8.10\";s:7:\"version\";s:6:\"8.8.10\";s:3:\"tag\";s:6:\"8.8.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.8.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.8.10.tar.gz\";s:4:\"date\";s:10:\"1600276704\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.9\";s:7:\"version\";s:5:\"8.8.9\";s:3:\"tag\";s:5:\"8.8.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.9.tar.gz\";s:4:\"date\";s:10:\"1599168716\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.8\";s:7:\"version\";s:5:\"8.8.8\";s:3:\"tag\";s:5:\"8.8.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.8.tar.gz\";s:4:\"date\";s:10:\"1592418750\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.7\";s:7:\"version\";s:5:\"8.8.7\";s:3:\"tag\";s:5:\"8.8.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.7.tar.gz\";s:4:\"date\";s:10:\"1591203837\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.6\";s:7:\"version\";s:5:\"8.8.6\";s:3:\"tag\";s:5:\"8.8.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.6.tar.gz\";s:4:\"date\";s:10:\"1589989060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.5\";s:7:\"version\";s:5:\"8.8.5\";s:3:\"tag\";s:5:\"8.8.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.5.tar.gz\";s:4:\"date\";s:10:\"1585861530\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.4\";s:7:\"version\";s:5:\"8.8.4\";s:3:\"tag\";s:5:\"8.8.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.4.tar.gz\";s:4:\"date\";s:10:\"1584560524\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.3\";s:7:\"version\";s:5:\"8.8.3\";s:3:\"tag\";s:5:\"8.8.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.3.tar.gz\";s:4:\"date\";s:10:\"1583347094\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.2\";s:7:\"version\";s:5:\"8.8.2\";s:3:\"tag\";s:5:\"8.8.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.2.tar.gz\";s:4:\"date\";s:10:\"1580598849\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.1\";s:7:\"version\";s:5:\"8.8.1\";s:3:\"tag\";s:5:\"8.8.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.1.tar.gz\";s:4:\"date\";s:10:\"1576695785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.0\";s:7:\"version\";s:5:\"8.8.0\";s:3:\"tag\";s:5:\"8.8.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.0.tar.gz\";s:4:\"date\";s:10:\"1575450481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.8.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.8.0-rc1\";s:7:\"version\";s:9:\"8.8.0-rc1\";s:3:\"tag\";s:9:\"8.8.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.8.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.8.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1574462580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.8.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.8.0-beta1\";s:7:\"version\";s:11:\"8.8.0-beta1\";s:3:\"tag\";s:11:\"8.8.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.8.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.8.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1573256280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.8.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.8.0-alpha1\";s:7:\"version\";s:12:\"8.8.0-alpha1\";s:3:\"tag\";s:12:\"8.8.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.8.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.8.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1571355784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.7.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.14\";s:7:\"version\";s:6:\"8.7.14\";s:3:\"tag\";s:6:\"8.7.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.14.tar.gz\";s:4:\"date\";s:10:\"1589988665\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.13\";s:7:\"version\";s:6:\"8.7.13\";s:3:\"tag\";s:6:\"8.7.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.13.tar.gz\";s:4:\"date\";s:10:\"1585861883\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.12\";s:7:\"version\";s:6:\"8.7.12\";s:3:\"tag\";s:6:\"8.7.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.12.tar.gz\";s:4:\"date\";s:10:\"1584552250\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.11\";s:7:\"version\";s:6:\"8.7.11\";s:3:\"tag\";s:6:\"8.7.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.11.tar.gz\";s:4:\"date\";s:10:\"1576695785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.10\";s:7:\"version\";s:6:\"8.7.10\";s:3:\"tag\";s:6:\"8.7.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.10.tar.gz\";s:4:\"date\";s:10:\"1573687985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.9\";s:7:\"version\";s:5:\"8.7.9\";s:3:\"tag\";s:5:\"8.7.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.9.tar.gz\";s:4:\"date\";s:10:\"1573063387\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.8\";s:7:\"version\";s:5:\"8.7.8\";s:3:\"tag\";s:5:\"8.7.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.8.tar.gz\";s:4:\"date\";s:10:\"1570044484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.7\";s:7:\"version\";s:5:\"8.7.7\";s:3:\"tag\";s:5:\"8.7.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.7.tar.gz\";s:4:\"date\";s:10:\"1567593185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.6\";s:7:\"version\";s:5:\"8.7.6\";s:3:\"tag\";s:5:\"8.7.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.6.tar.gz\";s:4:\"date\";s:10:\"1565206385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.5\";s:7:\"version\";s:5:\"8.7.5\";s:3:\"tag\";s:5:\"8.7.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.5.tar.gz\";s:4:\"date\";s:10:\"1563380885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.4\";s:7:\"version\";s:5:\"8.7.4\";s:3:\"tag\";s:5:\"8.7.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.4.tar.gz\";s:4:\"date\";s:10:\"1562225587\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.3\";s:7:\"version\";s:5:\"8.7.3\";s:3:\"tag\";s:5:\"8.7.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.3.tar.gz\";s:4:\"date\";s:10:\"1559762581\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.2\";s:7:\"version\";s:5:\"8.7.2\";s:3:\"tag\";s:5:\"8.7.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.2.tar.gz\";s:4:\"date\";s:10:\"1558597086\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.1\";s:7:\"version\";s:5:\"8.7.1\";s:3:\"tag\";s:5:\"8.7.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.1.tar.gz\";s:4:\"date\";s:10:\"1557335588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.0\";s:7:\"version\";s:5:\"8.7.0\";s:3:\"tag\";s:5:\"8.7.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.0.tar.gz\";s:4:\"date\";s:10:\"1556737085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.7.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.7.0-rc1\";s:7:\"version\";s:9:\"8.7.0-rc1\";s:3:\"tag\";s:9:\"8.7.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.7.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1555603385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.7.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.7.0-beta2\";s:7:\"version\";s:11:\"8.7.0-beta2\";s:3:\"tag\";s:11:\"8.7.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.7.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1554684784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.7.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.7.0-beta1\";s:7:\"version\";s:11:\"8.7.0-beta1\";s:3:\"tag\";s:11:\"8.7.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.7.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1553881681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.7.0-alpha2\";a:10:{s:4:\"name\";s:19:\"drupal 8.7.0-alpha2\";s:7:\"version\";s:12:\"8.7.0-alpha2\";s:3:\"tag\";s:12:\"8.7.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.7.0-alpha2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1553106180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:12:\"8.7.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.7.0-alpha1\";s:7:\"version\";s:12:\"8.7.0-alpha1\";s:3:\"tag\";s:12:\"8.7.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.7.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1552602484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.6.18\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.18\";s:7:\"version\";s:6:\"8.6.18\";s:3:\"tag\";s:6:\"8.6.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.18.tar.gz\";s:4:\"date\";s:10:\"1573687985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.17\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.17\";s:7:\"version\";s:6:\"8.6.17\";s:3:\"tag\";s:6:\"8.6.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.17.tar.gz\";s:4:\"date\";s:10:\"1560756785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.16\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.16\";s:7:\"version\";s:6:\"8.6.16\";s:3:\"tag\";s:6:\"8.6.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.16.tar.gz\";s:4:\"date\";s:10:\"1557335588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.15\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.15\";s:7:\"version\";s:6:\"8.6.15\";s:3:\"tag\";s:6:\"8.6.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.15.tar.gz\";s:4:\"date\";s:10:\"1555533181\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.14\";s:7:\"version\";s:6:\"8.6.14\";s:3:\"tag\";s:6:\"8.6.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.14.tar.gz\";s:4:\"date\";s:10:\"1554688384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.13\";s:7:\"version\";s:6:\"8.6.13\";s:3:\"tag\";s:6:\"8.6.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.13.tar.gz\";s:4:\"date\";s:10:\"1553099584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.12\";s:7:\"version\";s:6:\"8.6.12\";s:3:\"tag\";s:6:\"8.6.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.12.tar.gz\";s:4:\"date\";s:10:\"1552601584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.11\";s:7:\"version\";s:6:\"8.6.11\";s:3:\"tag\";s:6:\"8.6.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.11.tar.gz\";s:4:\"date\";s:10:\"1552511584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.10\";s:7:\"version\";s:6:\"8.6.10\";s:3:\"tag\";s:6:\"8.6.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.10.tar.gz\";s:4:\"date\";s:10:\"1550691784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.9\";s:7:\"version\";s:5:\"8.6.9\";s:3:\"tag\";s:5:\"8.6.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.9.tar.gz\";s:4:\"date\";s:10:\"1549628580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.8\";s:7:\"version\";s:5:\"8.6.8\";s:3:\"tag\";s:5:\"8.6.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.8.tar.gz\";s:4:\"date\";s:10:\"1549466580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.7\";s:7:\"version\";s:5:\"8.6.7\";s:3:\"tag\";s:5:\"8.6.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.7.tar.gz\";s:4:\"date\";s:10:\"1547682180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.6\";s:7:\"version\";s:5:\"8.6.6\";s:3:\"tag\";s:5:\"8.6.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.6.tar.gz\";s:4:\"date\";s:10:\"1547663557\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.5\";s:7:\"version\";s:5:\"8.6.5\";s:3:\"tag\";s:5:\"8.6.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.5.tar.gz\";s:4:\"date\";s:10:\"1546467485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.4\";s:7:\"version\";s:5:\"8.6.4\";s:3:\"tag\";s:5:\"8.6.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.4.tar.gz\";s:4:\"date\";s:10:\"1544011681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.3\";s:7:\"version\";s:5:\"8.6.3\";s:3:\"tag\";s:5:\"8.6.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.3.tar.gz\";s:4:\"date\";s:10:\"1541602684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.2\";s:7:\"version\";s:5:\"8.6.2\";s:3:\"tag\";s:5:\"8.6.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.2.tar.gz\";s:4:\"date\";s:10:\"1539816180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.1\";s:7:\"version\";s:5:\"8.6.1\";s:3:\"tag\";s:5:\"8.6.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.1.tar.gz\";s:4:\"date\";s:10:\"1536585780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.0\";s:7:\"version\";s:5:\"8.6.0\";s:3:\"tag\";s:5:\"8.6.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.0.tar.gz\";s:4:\"date\";s:10:\"1536186480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.6.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.6.0-rc1\";s:7:\"version\";s:9:\"8.6.0-rc1\";s:3:\"tag\";s:9:\"8.6.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.6.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1534532580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.6.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.6.0-beta2\";s:7:\"version\";s:11:\"8.6.0-beta2\";s:3:\"tag\";s:11:\"8.6.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.6.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1533298080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.6.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.6.0-beta1\";s:7:\"version\";s:11:\"8.6.0-beta1\";s:3:\"tag\";s:11:\"8.6.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.6.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1533270485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.6.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.6.0-alpha1\";s:7:\"version\";s:12:\"8.6.0-alpha1\";s:3:\"tag\";s:12:\"8.6.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.6.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1532033881\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.5.15\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.15\";s:7:\"version\";s:6:\"8.5.15\";s:3:\"tag\";s:6:\"8.5.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.15.tar.gz\";s:4:\"date\";s:10:\"1555533181\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.14\";s:7:\"version\";s:6:\"8.5.14\";s:3:\"tag\";s:6:\"8.5.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.14.tar.gz\";s:4:\"date\";s:10:\"1553099584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.13\";s:7:\"version\";s:6:\"8.5.13\";s:3:\"tag\";s:6:\"8.5.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.13.tar.gz\";s:4:\"date\";s:10:\"1552601584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.12\";s:7:\"version\";s:6:\"8.5.12\";s:3:\"tag\";s:6:\"8.5.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.12.tar.gz\";s:4:\"date\";s:10:\"1552511584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.11\";s:7:\"version\";s:6:\"8.5.11\";s:3:\"tag\";s:6:\"8.5.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.11.tar.gz\";s:4:\"date\";s:10:\"1550691784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.10\";s:7:\"version\";s:6:\"8.5.10\";s:3:\"tag\";s:6:\"8.5.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.10.tar.gz\";s:4:\"date\";s:10:\"1547682180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.9\";s:7:\"version\";s:5:\"8.5.9\";s:3:\"tag\";s:5:\"8.5.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.9.tar.gz\";s:4:\"date\";s:10:\"1547663557\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.8\";s:7:\"version\";s:5:\"8.5.8\";s:3:\"tag\";s:5:\"8.5.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.8.tar.gz\";s:4:\"date\";s:10:\"1539816180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.7\";s:7:\"version\";s:5:\"8.5.7\";s:3:\"tag\";s:5:\"8.5.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.7.tar.gz\";s:4:\"date\";s:10:\"1536187080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.6\";s:7:\"version\";s:5:\"8.5.6\";s:3:\"tag\";s:5:\"8.5.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.6.tar.gz\";s:4:\"date\";s:10:\"1533156780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.5\";s:7:\"version\";s:5:\"8.5.5\";s:3:\"tag\";s:5:\"8.5.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.5.tar.gz\";s:4:\"date\";s:10:\"1530738820\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.4\";s:7:\"version\";s:5:\"8.5.4\";s:3:\"tag\";s:5:\"8.5.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.4.tar.gz\";s:4:\"date\";s:10:\"1528319584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.3\";s:7:\"version\";s:5:\"8.5.3\";s:3:\"tag\";s:5:\"8.5.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.3.tar.gz\";s:4:\"date\";s:10:\"1524672780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.2\";s:7:\"version\";s:5:\"8.5.2\";s:3:\"tag\";s:5:\"8.5.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.2.tar.gz\";s:4:\"date\";s:10:\"1524073147\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.1\";s:7:\"version\";s:5:\"8.5.1\";s:3:\"tag\";s:5:\"8.5.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.1.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.0\";s:7:\"version\";s:5:\"8.5.0\";s:3:\"tag\";s:5:\"8.5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.0.tar.gz\";s:4:\"date\";s:10:\"1520457780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.5.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.5.0-rc1\";s:7:\"version\";s:9:\"8.5.0-rc1\";s:3:\"tag\";s:9:\"8.5.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.5.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.5.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1519234680\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";i:2;s:9:\"Bug fixes\";i:3;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.5.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.5.0-beta1\";s:7:\"version\";s:11:\"8.5.0-beta1\";s:3:\"tag\";s:11:\"8.5.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.5.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.5.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1518211380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.5.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.5.0-alpha1\";s:7:\"version\";s:12:\"8.5.0-alpha1\";s:3:\"tag\";s:12:\"8.5.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.5.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.5.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1516320484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:5:\"8.4.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.8\";s:7:\"version\";s:5:\"8.4.8\";s:3:\"tag\";s:5:\"8.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.8.tar.gz\";s:4:\"date\";s:10:\"1524672780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.7\";s:7:\"version\";s:5:\"8.4.7\";s:3:\"tag\";s:5:\"8.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.7.tar.gz\";s:4:\"date\";s:10:\"1524073147\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.6\";s:7:\"version\";s:5:\"8.4.6\";s:3:\"tag\";s:5:\"8.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.6.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.5\";s:7:\"version\";s:5:\"8.4.5\";s:3:\"tag\";s:5:\"8.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.5.tar.gz\";s:4:\"date\";s:10:\"1519234680\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.4\";s:7:\"version\";s:5:\"8.4.4\";s:3:\"tag\";s:5:\"8.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.4.tar.gz\";s:4:\"date\";s:10:\"1515021185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.3\";s:7:\"version\";s:5:\"8.4.3\";s:3:\"tag\";s:5:\"8.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.3.tar.gz\";s:4:\"date\";s:10:\"1512600784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.2\";s:7:\"version\";s:5:\"8.4.2\";s:3:\"tag\";s:5:\"8.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.2.tar.gz\";s:4:\"date\";s:10:\"1509719885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.1\";s:7:\"version\";s:5:\"8.4.1\";s:3:\"tag\";s:5:\"8.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.1.tar.gz\";s:4:\"date\";s:10:\"1509562384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.0\";s:7:\"version\";s:5:\"8.4.0\";s:3:\"tag\";s:5:\"8.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.0.tar.gz\";s:4:\"date\";s:10:\"1507146244\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.4.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.4.0-rc2\";s:7:\"version\";s:9:\"8.4.0-rc2\";s:3:\"tag\";s:9:\"8.4.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.4.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1505911444\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.4.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.4.0-rc1\";s:7:\"version\";s:9:\"8.4.0-rc1\";s:3:\"tag\";s:9:\"8.4.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.4.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1504733043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.4.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.4.0-beta1\";s:7:\"version\";s:11:\"8.4.0-beta1\";s:3:\"tag\";s:11:\"8.4.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.4.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1502992144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.4.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.4.0-alpha1\";s:7:\"version\";s:12:\"8.4.0-alpha1\";s:3:\"tag\";s:12:\"8.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.4.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1501790944\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:5:\"8.3.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.9\";s:7:\"version\";s:5:\"8.3.9\";s:3:\"tag\";s:5:\"8.3.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.9.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.8\";s:7:\"version\";s:5:\"8.3.8\";s:3:\"tag\";s:5:\"8.3.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.8.tar.gz\";s:4:\"date\";s:10:\"1520881985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";i:2;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.7\";s:7:\"version\";s:5:\"8.3.7\";s:3:\"tag\";s:5:\"8.3.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.7.tar.gz\";s:4:\"date\";s:10:\"1502903903\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.6\";s:7:\"version\";s:5:\"8.3.6\";s:3:\"tag\";s:5:\"8.3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.6.tar.gz\";s:4:\"date\";s:10:\"1501688043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.5\";s:7:\"version\";s:5:\"8.3.5\";s:3:\"tag\";s:5:\"8.3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.5.tar.gz\";s:4:\"date\";s:10:\"1499274843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.4\";s:7:\"version\";s:5:\"8.3.4\";s:3:\"tag\";s:5:\"8.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.4.tar.gz\";s:4:\"date\";s:10:\"1498069442\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.3\";s:7:\"version\";s:5:\"8.3.3\";s:3:\"tag\";s:5:\"8.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.3.tar.gz\";s:4:\"date\";s:10:\"1496858041\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.2\";s:7:\"version\";s:5:\"8.3.2\";s:3:\"tag\";s:5:\"8.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.2.tar.gz\";s:4:\"date\";s:10:\"1493834585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.1\";s:7:\"version\";s:5:\"8.3.1\";s:3:\"tag\";s:5:\"8.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.1.tar.gz\";s:4:\"date\";s:10:\"1492622946\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.0\";s:7:\"version\";s:5:\"8.3.0\";s:3:\"tag\";s:5:\"8.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.0.tar.gz\";s:4:\"date\";s:10:\"1491439084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.3.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.3.0-rc2\";s:7:\"version\";s:9:\"8.3.0-rc2\";s:3:\"tag\";s:9:\"8.3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.3.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1489613583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.3.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.3.0-rc1\";s:7:\"version\";s:9:\"8.3.0-rc1\";s:3:\"tag\";s:9:\"8.3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.3.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1488383284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.3.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.3.0-beta1\";s:7:\"version\";s:11:\"8.3.0-beta1\";s:3:\"tag\";s:11:\"8.3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.3.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1487175783\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.3.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.3.0-alpha1\";s:7:\"version\";s:12:\"8.3.0-alpha1\";s:3:\"tag\";s:12:\"8.3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.3.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1485968583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:5:\"8.2.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.8\";s:7:\"version\";s:5:\"8.2.8\";s:3:\"tag\";s:5:\"8.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.8.tar.gz\";s:4:\"date\";s:10:\"1492622852\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.7\";s:7:\"version\";s:5:\"8.2.7\";s:3:\"tag\";s:5:\"8.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.7.tar.gz\";s:4:\"date\";s:10:\"1489609638\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.6\";s:7:\"version\";s:5:\"8.2.6\";s:3:\"tag\";s:5:\"8.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.6.tar.gz\";s:4:\"date\";s:10:\"1485975485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.5\";s:7:\"version\";s:5:\"8.2.5\";s:3:\"tag\";s:5:\"8.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.5.tar.gz\";s:4:\"date\";s:10:\"1483529942\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.4\";s:7:\"version\";s:5:\"8.2.4\";s:3:\"tag\";s:5:\"8.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.4.tar.gz\";s:4:\"date\";s:10:\"1481136784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.3\";s:7:\"version\";s:5:\"8.2.3\";s:3:\"tag\";s:5:\"8.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.3.tar.gz\";s:4:\"date\";s:10:\"1479322439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.2\";s:7:\"version\";s:5:\"8.2.2\";s:3:\"tag\";s:5:\"8.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.2.tar.gz\";s:4:\"date\";s:10:\"1478106542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.1\";s:7:\"version\";s:5:\"8.2.1\";s:3:\"tag\";s:5:\"8.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.1.tar.gz\";s:4:\"date\";s:10:\"1476181439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.0\";s:7:\"version\";s:5:\"8.2.0\";s:3:\"tag\";s:5:\"8.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.0.tar.gz\";s:4:\"date\";s:10:\"1475660639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.2.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.2.0-rc2\";s:7:\"version\";s:9:\"8.2.0-rc2\";s:3:\"tag\";s:9:\"8.2.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.2.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1474484358\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.2.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.2.0-rc1\";s:7:\"version\";s:9:\"8.2.0-rc1\";s:3:\"tag\";s:9:\"8.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.2.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1473285089\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.2.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 8.2.0-beta3\";s:7:\"version\";s:11:\"8.2.0-beta3\";s:3:\"tag\";s:11:\"8.2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.2.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1472222475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.2.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.2.0-beta2\";s:7:\"version\";s:11:\"8.2.0-beta2\";s:3:\"tag\";s:11:\"8.2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.2.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1471710839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.2.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.2.0-beta1\";s:7:\"version\";s:11:\"8.2.0-beta1\";s:3:\"tag\";s:11:\"8.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.2.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1470230639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"8.1.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.1.10\";s:7:\"version\";s:6:\"8.1.10\";s:3:\"tag\";s:6:\"8.1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.1.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.1.10.tar.gz\";s:4:\"date\";s:10:\"1474478939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.9\";s:7:\"version\";s:5:\"8.1.9\";s:3:\"tag\";s:5:\"8.1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.9.tar.gz\";s:4:\"date\";s:10:\"1473276313\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.8\";s:7:\"version\";s:5:\"8.1.8\";s:3:\"tag\";s:5:\"8.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.8.tar.gz\";s:4:\"date\";s:10:\"1470233647\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.7\";s:7:\"version\";s:5:\"8.1.7\";s:3:\"tag\";s:5:\"8.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.7.tar.gz\";s:4:\"date\";s:10:\"1468855358\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.6\";s:7:\"version\";s:5:\"8.1.6\";s:3:\"tag\";s:5:\"8.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.6.tar.gz\";s:4:\"date\";s:10:\"1468242539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.5\";s:7:\"version\";s:5:\"8.1.5\";s:3:\"tag\";s:5:\"8.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.5.tar.gz\";s:4:\"date\";s:10:\"1467884639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.4\";s:7:\"version\";s:5:\"8.1.4\";s:3:\"tag\";s:5:\"8.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.4.tar.gz\";s:4:\"date\";s:10:\"1467810839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.3\";s:7:\"version\";s:5:\"8.1.3\";s:3:\"tag\";s:5:\"8.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.3.tar.gz\";s:4:\"date\";s:10:\"1466021480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.2\";s:7:\"version\";s:5:\"8.1.2\";s:3:\"tag\";s:5:\"8.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.2.tar.gz\";s:4:\"date\";s:10:\"1464824339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.1\";s:7:\"version\";s:5:\"8.1.1\";s:3:\"tag\";s:5:\"8.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.1.tar.gz\";s:4:\"date\";s:10:\"1462361039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.0\";s:7:\"version\";s:5:\"8.1.0\";s:3:\"tag\";s:5:\"8.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.0.tar.gz\";s:4:\"date\";s:10:\"1461118190\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.1.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.1.0-rc1\";s:7:\"version\";s:9:\"8.1.0-rc1\";s:3:\"tag\";s:9:\"8.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.1.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1459976639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.1.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.1.0-beta2\";s:7:\"version\";s:11:\"8.1.0-beta2\";s:3:\"tag\";s:11:\"8.1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.1.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1458699840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.1.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.1.0-beta1\";s:7:\"version\";s:11:\"8.1.0-beta1\";s:3:\"tag\";s:11:\"8.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.1.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1456975758\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:5:\"8.0.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.6\";s:7:\"version\";s:5:\"8.0.6\";s:3:\"tag\";s:5:\"8.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.6.tar.gz\";s:4:\"date\";s:10:\"1459900439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.5\";s:7:\"version\";s:5:\"8.0.5\";s:3:\"tag\";s:5:\"8.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.5.tar.gz\";s:4:\"date\";s:10:\"1456914839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.4\";s:7:\"version\";s:5:\"8.0.4\";s:3:\"tag\";s:5:\"8.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.4.tar.gz\";s:4:\"date\";s:10:\"1456341749\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.3\";s:7:\"version\";s:5:\"8.0.3\";s:3:\"tag\";s:5:\"8.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.3.tar.gz\";s:4:\"date\";s:10:\"1454489043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.2\";s:7:\"version\";s:5:\"8.0.2\";s:3:\"tag\";s:5:\"8.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.2.tar.gz\";s:4:\"date\";s:10:\"1452119939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.1\";s:7:\"version\";s:5:\"8.0.1\";s:3:\"tag\";s:5:\"8.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.1.tar.gz\";s:4:\"date\";s:10:\"1449066839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.0\";s:7:\"version\";s:5:\"8.0.0\";s:3:\"tag\";s:5:\"8.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.0.tar.gz\";s:4:\"date\";s:10:\"1447941840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.0.0-rc4\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc4\";s:7:\"version\";s:9:\"8.0.0-rc4\";s:3:\"tag\";s:9:\"8.0.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc4\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1447413840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.0.0-rc3\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc3\";s:7:\"version\";s:9:\"8.0.0-rc3\";s:3:\"tag\";s:9:\"8.0.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1446633239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.0.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc2\";s:7:\"version\";s:9:\"8.0.0-rc2\";s:3:\"tag\";s:9:\"8.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1445468639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.0.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc1\";s:7:\"version\";s:9:\"8.0.0-rc1\";s:3:\"tag\";s:9:\"8.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1444253039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta16\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta16\";s:7:\"version\";s:12:\"8.0.0-beta16\";s:3:\"tag\";s:12:\"8.0.0-beta16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta16\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta16.tar.gz\";s:4:\"date\";s:10:\"1443746640\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta15\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta15\";s:7:\"version\";s:12:\"8.0.0-beta15\";s:3:\"tag\";s:12:\"8.0.0-beta15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta15\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta15.tar.gz\";s:4:\"date\";s:10:\"1441357140\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta14\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta14\";s:7:\"version\";s:12:\"8.0.0-beta14\";s:3:\"tag\";s:12:\"8.0.0-beta14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta14\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta14.tar.gz\";s:4:\"date\";s:10:\"1438593539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta13\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta13\";s:7:\"version\";s:12:\"8.0.0-beta13\";s:3:\"tag\";s:12:\"8.0.0-beta13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta13.tar.gz\";s:4:\"date\";s:10:\"1438194539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta12\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta12\";s:7:\"version\";s:12:\"8.0.0-beta12\";s:3:\"tag\";s:12:\"8.0.0-beta12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta12.tar.gz\";s:4:\"date\";s:10:\"1435601583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta11\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta11\";s:7:\"version\";s:12:\"8.0.0-beta11\";s:3:\"tag\";s:12:\"8.0.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1432758481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta10\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta10\";s:7:\"version\";s:12:\"8.0.0-beta10\";s:3:\"tag\";s:12:\"8.0.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1430314681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta9\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta9\";s:7:\"version\";s:11:\"8.0.0-beta9\";s:3:\"tag\";s:11:\"8.0.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1427299981\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta7\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta7\";s:7:\"version\";s:11:\"8.0.0-beta7\";s:3:\"tag\";s:11:\"8.0.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1424875381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta6\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta6\";s:7:\"version\";s:11:\"8.0.0-beta6\";s:3:\"tag\";s:11:\"8.0.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1422443800\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta4\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta4\";s:7:\"version\";s:11:\"8.0.0-beta4\";s:3:\"tag\";s:11:\"8.0.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1418825280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta3\";s:7:\"version\";s:11:\"8.0.0-beta3\";s:3:\"tag\";s:11:\"8.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1415797380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta2\";s:7:\"version\";s:11:\"8.0.0-beta2\";s:3:\"tag\";s:11:\"8.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1413394161\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta1\";s:7:\"version\";s:11:\"8.0.0-beta1\";s:3:\"tag\";s:11:\"8.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1412147030\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"8.0.0-alpha15\";a:10:{s:4:\"name\";s:20:\"drupal 8.0.0-alpha15\";s:7:\"version\";s:13:\"8.0.0-alpha15\";s:3:\"tag\";s:13:\"8.0.0-alpha15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/8.0.0-alpha15\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-alpha15.tar.gz\";s:4:\"date\";s:10:\"1411139628\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"8.0.0-alpha14\";a:10:{s:4:\"name\";s:20:\"drupal 8.0.0-alpha14\";s:7:\"version\";s:13:\"8.0.0-alpha14\";s:3:\"tag\";s:13:\"8.0.0-alpha14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/8.0.0-alpha14\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-alpha14.tar.gz\";s:4:\"date\";s:10:\"1407344628\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha13\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha13\";s:7:\"version\";s:11:\"8.0-alpha13\";s:3:\"tag\";s:11:\"8.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha13\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1404296627\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha12\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha12\";s:7:\"version\";s:11:\"8.0-alpha12\";s:3:\"tag\";s:11:\"8.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha12\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1401293627\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha11\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha11\";s:7:\"version\";s:11:\"8.0-alpha11\";s:3:\"tag\";s:11:\"8.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha11\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1398249227\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha10\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha10\";s:7:\"version\";s:11:\"8.0-alpha10\";s:3:\"tag\";s:11:\"8.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha10\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1395231556\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha9\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha9\";s:7:\"version\";s:10:\"8.0-alpha9\";s:3:\"tag\";s:10:\"8.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha9\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1392806005\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha8\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha8\";s:7:\"version\";s:10:\"8.0-alpha8\";s:3:\"tag\";s:10:\"8.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha8\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1390393105\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha7\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha7\";s:7:\"version\";s:10:\"8.0-alpha7\";s:3:\"tag\";s:10:\"8.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha7\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1387399705\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha6\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha6\";s:7:\"version\";s:10:\"8.0-alpha6\";s:3:\"tag\";s:10:\"8.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha6\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1385153305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha5\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha5\";s:7:\"version\";s:10:\"8.0-alpha5\";s:3:\"tag\";s:10:\"8.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1384850305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha4\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha4\";s:7:\"version\";s:10:\"8.0-alpha4\";s:3:\"tag\";s:10:\"8.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1382092313\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:12:\"New features\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha3\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha3\";s:7:\"version\";s:10:\"8.0-alpha3\";s:3:\"tag\";s:10:\"8.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1378303307\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:12:\"New features\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha2\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha2\";s:7:\"version\";s:10:\"8.0-alpha2\";s:3:\"tag\";s:10:\"8.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1372069563\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"11.0.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 11.0.x-dev\";s:7:\"version\";s:10:\"11.0.x-dev\";s:3:\"tag\";s:6:\"11.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/11.0.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-11.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1729002164\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:8:\"11.x-dev\";a:10:{s:4:\"name\";s:15:\"drupal 11.x-dev\";s:7:\"version\";s:8:\"11.x-dev\";s:3:\"tag\";s:4:\"11.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/drupal/releases/11.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/drupal-11.x-dev.tar.gz\";s:4:\"date\";s:10:\"1729002546\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:10:\"10.4.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.4.x-dev\";s:7:\"version\";s:10:\"10.4.x-dev\";s:3:\"tag\";s:6:\"10.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.4.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1729001731\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.3.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.3.x-dev\";s:7:\"version\";s:10:\"10.3.x-dev\";s:3:\"tag\";s:6:\"10.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.3.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1729001305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.2.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.2.x-dev\";s:7:\"version\";s:10:\"10.2.x-dev\";s:3:\"tag\";s:6:\"10.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.2.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1728388156\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.1.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.1.x-dev\";s:7:\"version\";s:10:\"10.1.x-dev\";s:3:\"tag\";s:6:\"10.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.1.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1713001795\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.0.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.x-dev\";s:7:\"version\";s:10:\"10.0.x-dev\";s:3:\"tag\";s:6:\"10.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1696930730\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"9.5.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.5.x-dev\";s:7:\"version\";s:9:\"9.5.x-dev\";s:3:\"tag\";s:5:\"9.5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.5.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1701801362\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.4.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.4.x-dev\";s:7:\"version\";s:9:\"9.4.x-dev\";s:3:\"tag\";s:5:\"9.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.4.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1683123227\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.3.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.3.x-dev\";s:7:\"version\";s:9:\"9.3.x-dev\";s:3:\"tag\";s:5:\"9.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.3.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1664385919\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"9.2.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.2.x-dev\";s:7:\"version\";s:9:\"9.2.x-dev\";s:3:\"tag\";s:5:\"9.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.2.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1654891907\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.1.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.x-dev\";s:7:\"version\";s:9:\"9.1.x-dev\";s:3:\"tag\";s:5:\"9.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1637766277\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.0.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.0.x-dev\";s:7:\"version\";s:9:\"9.0.x-dev\";s:3:\"tag\";s:5:\"9.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.0.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1622063424\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.9.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.9.x-dev\";s:7:\"version\";s:9:\"8.9.x-dev\";s:3:\"tag\";s:5:\"8.9.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.9.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.9.x-dev.tar.gz\";s:4:\"date\";s:10:\"1637188625\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.8.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.8.x-dev\";s:7:\"version\";s:9:\"8.8.x-dev\";s:3:\"tag\";s:5:\"8.8.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.8.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.8.x-dev.tar.gz\";s:4:\"date\";s:10:\"1606364994\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.7.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.7.x-dev\";s:7:\"version\";s:9:\"8.7.x-dev\";s:3:\"tag\";s:5:\"8.7.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.7.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.7.x-dev.tar.gz\";s:4:\"date\";s:10:\"1589987612\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.6.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.6.x-dev\";s:7:\"version\";s:9:\"8.6.x-dev\";s:3:\"tag\";s:5:\"8.6.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.6.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.6.x-dev.tar.gz\";s:4:\"date\";s:10:\"1573687985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.5.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.5.x-dev\";s:7:\"version\";s:9:\"8.5.x-dev\";s:3:\"tag\";s:5:\"8.5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.5.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1555533181\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.4.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.4.x-dev\";s:7:\"version\";s:9:\"8.4.x-dev\";s:3:\"tag\";s:5:\"8.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.4.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1533047880\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.3.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.3.x-dev\";s:7:\"version\";s:9:\"8.3.x-dev\";s:3:\"tag\";s:5:\"8.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.3.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.2.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.2.x-dev\";s:7:\"version\";s:9:\"8.2.x-dev\";s:3:\"tag\";s:5:\"8.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.2.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1492624982\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.1.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.1.x-dev\";s:7:\"version\";s:9:\"8.1.x-dev\";s:3:\"tag\";s:5:\"8.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.1.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1474478393\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.0.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.x-dev\";s:7:\"version\";s:9:\"8.0.x-dev\";s:3:\"tag\";s:5:\"8.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1459900439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}}s:10:\"last_fetch\";i:1729018489;}',1729104889),('update_available_releases','entity_reference_revisions',_binary 'a:10:{s:5:\"title\";s:26:\"Entity Reference Revisions\";s:10:\"short_name\";s:26:\"entity_reference_revisions\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:33:\"drupal/entity_reference_revisions\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:57:\"https://www.drupal.org/project/entity_reference_revisions\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:18:{s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:35:\"entity_reference_revisions 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:75:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.12\";s:13:\"download_link\";s:80:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1722804497\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:35:\"entity_reference_revisions 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:75:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.11\";s:13:\"download_link\";s:80:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1705140721\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:35:\"entity_reference_revisions 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:75:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.10\";s:13:\"download_link\";s:80:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1660664712\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.9\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1614805871\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.8\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1583961846\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.7\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1570284187\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.6\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1539588781\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.5\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1527241084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.4\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1515143885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.3\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1495814284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.2\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1485790085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.1\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1485526384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1469725439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc7\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.0-rc7\";s:7:\"version\";s:11:\"8.x-1.0-rc7\";s:3:\"tag\";s:11:\"8.x-1.0-rc7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0-rc7\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0-rc7.tar.gz\";s:4:\"date\";s:10:\"1464727139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc6\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.0-rc6\";s:7:\"version\";s:11:\"8.x-1.0-rc6\";s:3:\"tag\";s:11:\"8.x-1.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0-rc6\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1460582040\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1447766339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1444419239\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.x-dev\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722630009\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018489;}',1729104889),('update_available_releases','ept_accordion',_binary 'a:10:{s:5:\"title\";s:38:\"Extra Paragraph Types (EPT): Accordion\";s:10:\"short_name\";s:13:\"ept_accordion\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:20:\"drupal/ept_accordion\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/ept_accordion\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:19:\"ept_accordion 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_accordion/releases/1.4.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384043\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:19:\"ept_accordion 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_accordion/releases/1.4.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1718776467\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:19:\"ept_accordion 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_accordion/releases/1.4.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1714489328\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:19:\"ept_accordion 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_accordion/releases/1.4.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792727\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:26:\"ept_accordion 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_accordion/releases/1.4.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732066\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:26:\"ept_accordion 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_accordion/releases/1.4.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020115\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:26:\"ept_accordion 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_accordion/releases/1.4.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1692443900\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:23:\"ept_accordion 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_accordion/releases/1.4.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_accordion-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1714489288\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018489;}',1729104889),('update_available_releases','ept_basic_button',_binary 'a:10:{s:5:\"title\";s:41:\"Extra Paragraph Types (EPT): Basic Button\";s:10:\"short_name\";s:16:\"ept_basic_button\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:23:\"drupal/ept_basic_button\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:47:\"https://www.drupal.org/project/ept_basic_button\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:11:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:22:\"ept_basic_button 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1721384071\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:22:\"ept_basic_button 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1720604132\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:22:\"ept_basic_button 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1720420232\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:22:\"ept_basic_button 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792787\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha7\";a:11:{s:4:\"name\";s:29:\"ept_basic_button 1.4.0-alpha7\";s:7:\"version\";s:12:\"1.4.0-alpha7\";s:3:\"tag\";s:12:\"1.4.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0-alpha7\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1697732075\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha6\";a:11:{s:4:\"name\";s:29:\"ept_basic_button 1.4.0-alpha6\";s:7:\"version\";s:12:\"1.4.0-alpha6\";s:3:\"tag\";s:12:\"1.4.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0-alpha6\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1696934220\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:29:\"ept_basic_button 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0-alpha4\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1696319554\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:29:\"ept_basic_button 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0-alpha3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1695020210\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:29:\"ept_basic_button 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0-alpha2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1692553614\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:29:\"ept_basic_button 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.0-alpha1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1692553208\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:26:\"ept_basic_button 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_basic_button/releases/1.4.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_basic_button-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1720604082\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018489;}',1729104889),('update_available_releases','ept_block',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Block\";s:10:\"short_name\";s:9:\"ept_block\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_block\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_block\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:4:{s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_block 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_block/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_block-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384098\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ept_block 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_block/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_block-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721031434\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ept_block 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_block/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_block-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1705580708\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_block 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_block/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_block-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710712789\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018489;}',1729104889),('update_available_releases','ept_bootstrap_button',_binary 'a:10:{s:5:\"title\";s:45:\"Extra Paragraph Types (EPT): Bootstrap Button\";s:10:\"short_name\";s:20:\"ept_bootstrap_button\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:27:\"drupal/ept_bootstrap_button\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:51:\"https://www.drupal.org/project/ept_bootstrap_button\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:7:{s:5:\"1.4.2\";a:11:{s:4:\"name\";s:26:\"ept_bootstrap_button 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384122\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:26:\"ept_bootstrap_button 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721030798\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:26:\"ept_bootstrap_button 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.0\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792837\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:33:\"ept_bootstrap_button 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.0-alpha4\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697732086\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:33:\"ept_bootstrap_button 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.0-alpha3\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1695020260\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:33:\"ept_bootstrap_button 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.0-alpha2\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1692604880\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:30:\"ept_bootstrap_button 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/ept_bootstrap_button/releases/1.4.x-dev\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/ept_bootstrap_button-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710712585\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_carousel',_binary 'a:10:{s:5:\"title\";s:37:\"Extra Paragraph Types (EPT): Carousel\";s:10:\"short_name\";s:12:\"ept_carousel\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:19:\"drupal/ept_carousel\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:43:\"https://www.drupal.org/project/ept_carousel\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:18:\"ept_carousel 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_carousel/releases/1.4.4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722409993\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:18:\"ept_carousel 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_carousel/releases/1.4.3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384164\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:18:\"ept_carousel 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_carousel/releases/1.4.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1714489408\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:18:\"ept_carousel 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_carousel/releases/1.4.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1707471100\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:18:\"ept_carousel 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_carousel/releases/1.4.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792944\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:25:\"ept_carousel 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/ept_carousel/releases/1.4.0-alpha3\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732150\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:25:\"ept_carousel 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/ept_carousel/releases/1.4.0-alpha2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020351\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:25:\"ept_carousel 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/ept_carousel/releases/1.4.0-alpha1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1692689650\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:22:\"ept_carousel 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_carousel/releases/1.4.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_carousel-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710712745\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_columns',_binary 'a:10:{s:5:\"title\";s:48:\"Extra Paragraph Types (EPT): Columns / Container\";s:10:\"short_name\";s:11:\"ept_columns\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:18:\"drupal/ept_columns\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/ept_columns\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.4.6\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.6\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1721384279\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1721217525\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1714489646\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1714471360\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1714469260\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1713721134\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:17:\"ept_columns 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_columns/releases/1.4.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1711960728\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:21:\"ept_columns 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_columns/releases/1.4.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_columns-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721215251\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_core',_binary 'a:10:{s:5:\"title\";s:33:\"Extra Paragraph Types (EPT): Core\";s:10:\"short_name\";s:8:\"ept_core\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:15:\"drupal/ept_core\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ept_core\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:25:{s:6:\"1.4.17\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.17\";s:7:\"version\";s:6:\"1.4.17\";s:3:\"tag\";s:6:\"1.4.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.17\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.17.tar.gz\";s:4:\"date\";s:10:\"1728849210\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.4.16\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.16\";s:7:\"version\";s:6:\"1.4.16\";s:3:\"tag\";s:6:\"1.4.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.16\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.16.tar.gz\";s:4:\"date\";s:10:\"1728847500\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.4.15\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.15\";s:7:\"version\";s:6:\"1.4.15\";s:3:\"tag\";s:6:\"1.4.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.15\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.15.tar.gz\";s:4:\"date\";s:10:\"1728818487\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:6:\"1.4.14\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.14\";s:7:\"version\";s:6:\"1.4.14\";s:3:\"tag\";s:6:\"1.4.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.14\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.14.tar.gz\";s:4:\"date\";s:10:\"1721383996\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.4.13\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.13\";s:7:\"version\";s:6:\"1.4.13\";s:3:\"tag\";s:6:\"1.4.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.13\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.13.tar.gz\";s:4:\"date\";s:10:\"1721242210\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.4.12\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.12\";s:7:\"version\";s:6:\"1.4.12\";s:3:\"tag\";s:6:\"1.4.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.12\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.12.tar.gz\";s:4:\"date\";s:10:\"1721217306\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.4.11\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.11\";s:7:\"version\";s:6:\"1.4.11\";s:3:\"tag\";s:6:\"1.4.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.11\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.11.tar.gz\";s:4:\"date\";s:10:\"1720512693\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:6:\"1.4.10\";a:11:{s:4:\"name\";s:15:\"ept_core 1.4.10\";s:7:\"version\";s:6:\"1.4.10\";s:3:\"tag\";s:6:\"1.4.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_core/releases/1.4.10\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_core-1.4.10.tar.gz\";s:4:\"date\";s:10:\"1718775833\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.9\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.9\";s:7:\"version\";s:5:\"1.4.9\";s:3:\"tag\";s:5:\"1.4.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.9\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.9.tar.gz\";s:4:\"date\";s:10:\"1715419475\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.8\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.8\";s:7:\"version\";s:5:\"1.4.8\";s:3:\"tag\";s:5:\"1.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.8\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.8.tar.gz\";s:4:\"date\";s:10:\"1715413979\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.7\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.7\";s:7:\"version\";s:5:\"1.4.7\";s:3:\"tag\";s:5:\"1.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.7\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.7.tar.gz\";s:4:\"date\";s:10:\"1714924340\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.6\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.6\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1714489789\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.5\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1713714097\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.4\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1711960476\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1709310495\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1708886906\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1708007013\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:14:\"ept_core 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792691\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha5\";a:11:{s:4:\"name\";s:21:\"ept_core 1.4.0-alpha5\";s:7:\"version\";s:12:\"1.4.0-alpha5\";s:3:\"tag\";s:12:\"1.4.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_core/releases/1.4.0-alpha5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_core-1.4.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1697731614\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:21:\"ept_core 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_core/releases/1.4.0-alpha4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_core-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1696538022\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:21:\"ept_core 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_core/releases/1.4.0-alpha3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_core-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1696506197\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:21:\"ept_core 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_core/releases/1.4.0-alpha2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_core-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1694968748\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:21:\"ept_core 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_core/releases/1.4.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_core-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1693757733\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:14:\"ept_core 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_core/releases/1.0.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_core-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1699792566\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:18:\"ept_core 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_core/releases/1.4.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_core-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1728848866\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','ept_countdown',_binary 'a:10:{s:5:\"title\";s:38:\"Extra Paragraph Types (EPT): Countdown\";s:10:\"short_name\";s:13:\"ept_countdown\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:20:\"drupal/ept_countdown\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/ept_countdown\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:7:{s:5:\"1.4.2\";a:11:{s:4:\"name\";s:19:\"ept_countdown 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_countdown/releases/1.4.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384290\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:19:\"ept_countdown 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_countdown/releases/1.4.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721030874\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:19:\"ept_countdown 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_countdown/releases/1.4.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792985\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:26:\"ept_countdown 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_countdown/releases/1.4.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732156\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:26:\"ept_countdown 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_countdown/releases/1.4.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020395\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:26:\"ept_countdown 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_countdown/releases/1.4.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1692778248\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:23:\"ept_countdown 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_countdown/releases/1.4.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_countdown-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710712522\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_counter',_binary 'a:10:{s:5:\"title\";s:36:\"Extra Paragraph Types (EPT): Counter\";s:10:\"short_name\";s:11:\"ept_counter\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:18:\"drupal/ept_counter\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/ept_counter\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:17:\"ept_counter 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_counter/releases/1.4.4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722410408\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:17:\"ept_counter 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_counter/releases/1.4.3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384316\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:17:\"ept_counter 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_counter/releases/1.4.2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1718562283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:17:\"ept_counter 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_counter/releases/1.4.1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1714489891\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:17:\"ept_counter 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_counter/releases/1.4.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793022\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:24:\"ept_counter 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/ept_counter/releases/1.4.0-alpha3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732420\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:24:\"ept_counter 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/ept_counter/releases/1.4.0-alpha2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020452\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:24:\"ept_counter 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/ept_counter/releases/1.4.0-alpha1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1693207585\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:21:\"ept_counter 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_counter/releases/1.4.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_counter-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1718907619\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890);
INSERT INTO `key_value_expire` VALUES ('update_available_releases','ept_cta',_binary 'a:10:{s:5:\"title\";s:43:\"Extra Paragraph Types (EPT): Call to Action\";s:10:\"short_name\";s:7:\"ept_cta\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:14:\"drupal/ept_cta\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:38:\"https://www.drupal.org/project/ept_cta\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:10:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:13:\"ept_cta 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ept_cta/releases/1.4.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722410462\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:13:\"ept_cta 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ept_cta/releases/1.4.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384167\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:13:\"ept_cta 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ept_cta/releases/1.4.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1720991536\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:13:\"ept_cta 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ept_cta/releases/1.4.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1716387526\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:13:\"ept_cta 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ept_cta/releases/1.4.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699792891\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:20:\"ept_cta 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_cta/releases/1.4.0-alpha4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697732446\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:20:\"ept_cta 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_cta/releases/1.4.0-alpha3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1696319604\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:20:\"ept_cta 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_cta/releases/1.4.0-alpha2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020301\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:20:\"ept_cta 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_cta/releases/1.4.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1693758608\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:17:\"ept_cta 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ept_cta/releases/1.4.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ept_cta-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1720991032\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_hero',_binary 'a:10:{s:5:\"title\";s:33:\"Extra Paragraph Types (EPT): Hero\";s:10:\"short_name\";s:8:\"ept_hero\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:15:\"drupal/ept_hero\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ept_hero\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:5:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:14:\"ept_hero 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_hero/releases/1.4.4\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_hero-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722410507\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:14:\"ept_hero 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_hero/releases/1.4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_hero-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384368\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:14:\"ept_hero 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_hero/releases/1.4.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_hero-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1720603705\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:14:\"ept_hero 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_hero/releases/1.4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_hero-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1720426508\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:14:\"ept_hero 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_hero/releases/1.4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_hero-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1720419415\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_image',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Image\";s:10:\"short_name\";s:9:\"ept_image\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_image\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_image\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:15:\"ept_image 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_image/releases/1.4.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_image-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722410542\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ept_image 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_image/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_image-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384323\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_image 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_image/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_image-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721030984\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ept_image 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_image/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_image-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1708353027\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ept_image 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_image/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_image-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793072\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:22:\"ept_image 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_image/releases/1.4.0-alpha3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_image-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697731932\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:22:\"ept_image 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_image/releases/1.4.0-alpha2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_image-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020495\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:22:\"ept_image 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_image/releases/1.4.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_image-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1693758273\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_image 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_image/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_image-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710712339\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_image_gallery',_binary 'a:10:{s:5:\"title\";s:42:\"Extra Paragraph Types (EPT): Image Gallery\";s:10:\"short_name\";s:17:\"ept_image_gallery\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:24:\"drupal/ept_image_gallery\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:48:\"https://www.drupal.org/project/ept_image_gallery\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:23:\"ept_image_gallery 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722411235\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:23:\"ept_image_gallery 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384350\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:23:\"ept_image_gallery 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1713943658\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:23:\"ept_image_gallery 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1710340960\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:23:\"ept_image_gallery 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793283\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:30:\"ept_image_gallery 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.0-alpha3\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732179\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:30:\"ept_image_gallery 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.0-alpha2\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020535\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:30:\"ept_image_gallery 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.0-alpha1\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694461714\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:27:\"ept_image_gallery 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ept_image_gallery/releases/1.4.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ept_image_gallery-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721383208\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_micromodal',_binary 'a:10:{s:5:\"title\";s:39:\"Extra Paragraph Types (EPT): Micromodal\";s:10:\"short_name\";s:14:\"ept_micromodal\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:21:\"drupal/ept_micromodal\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:45:\"https://www.drupal.org/project/ept_micromodal\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:7:{s:5:\"1.4.2\";a:11:{s:4:\"name\";s:20:\"ept_micromodal 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384358\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:20:\"ept_micromodal 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721028333\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:20:\"ept_micromodal 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793347\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:27:\"ept_micromodal 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.0-alpha3\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732239\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:27:\"ept_micromodal 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.0-alpha2\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020582\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:27:\"ept_micromodal 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.0-alpha1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694460759\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:24:\"ept_micromodal 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/ept_micromodal/releases/1.4.x-dev\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/ept_micromodal-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1720418520\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_quote',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Quote\";s:10:\"short_name\";s:9:\"ept_quote\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_quote\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_quote\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ept_quote 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_quote/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1722411325\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_quote 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_quote/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384506\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ept_quote 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_quote/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721031062\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ept_quote 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_quote/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793452\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:22:\"ept_quote 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_quote/releases/1.4.0-alpha4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697732241\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:22:\"ept_quote 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_quote/releases/1.4.0-alpha2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020634\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:22:\"ept_quote 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_quote/releases/1.4.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694461930\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_quote 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_quote/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_quote-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710712167\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_slick_slider',_binary 'a:10:{s:5:\"title\";s:41:\"Extra Paragraph Types (EPT): Slick Slider\";s:10:\"short_name\";s:16:\"ept_slick_slider\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:23:\"drupal/ept_slick_slider\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:47:\"https://www.drupal.org/project/ept_slick_slider\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:22:\"ept_slick_slider 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1722411497\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:22:\"ept_slick_slider 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384509\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:22:\"ept_slick_slider 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1714490011\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:22:\"ept_slick_slider 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793405\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:29:\"ept_slick_slider 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.0-alpha3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732269\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:29:\"ept_slick_slider 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.0-alpha2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020685\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:29:\"ept_slick_slider 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.0-alpha1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694462501\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:26:\"ept_slick_slider 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_slick_slider/releases/1.4.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_slick_slider-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1714489937\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_slideshow',_binary 'a:10:{s:5:\"title\";s:38:\"Extra Paragraph Types (EPT): Slideshow\";s:10:\"short_name\";s:13:\"ept_slideshow\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:20:\"drupal/ept_slideshow\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/ept_slideshow\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:19:\"ept_slideshow 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722411522\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:19:\"ept_slideshow 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384539\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:19:\"ept_slideshow 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1714490171\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:19:\"ept_slideshow 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793513\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:26:\"ept_slideshow 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.0-alpha4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697732270\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:26:\"ept_slideshow 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1695880151\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:26:\"ept_slideshow 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695020896\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:26:\"ept_slideshow 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694499626\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:23:\"ept_slideshow 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ept_slideshow/releases/1.4.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ept_slideshow-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1714490056\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_stats',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Stats\";s:10:\"short_name\";s:9:\"ept_stats\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_stats\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_stats\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_stats 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_stats/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384552\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ept_stats 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_stats/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1714490449\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ept_stats 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_stats/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793563\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:22:\"ept_stats 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_stats/releases/1.4.0-alpha4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697732311\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:22:\"ept_stats 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_stats/releases/1.4.0-alpha3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1696750413\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:22:\"ept_stats 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_stats/releases/1.4.0-alpha2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695021127\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:22:\"ept_stats 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_stats/releases/1.4.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694500446\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_stats 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_stats/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_stats-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1714490389\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_tabs',_binary 'a:10:{s:5:\"title\";s:33:\"Extra Paragraph Types (EPT): Tabs\";s:10:\"short_name\";s:8:\"ept_tabs\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:15:\"drupal/ept_tabs\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ept_tabs\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:14:\"ept_tabs 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_tabs/releases/1.4.4\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1729019768\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:14:\"ept_tabs 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_tabs/releases/1.4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1722411586\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:14:\"ept_tabs 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_tabs/releases/1.4.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384552\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:14:\"ept_tabs 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_tabs/releases/1.4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721031136\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:14:\"ept_tabs 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_tabs/releases/1.4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793604\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:21:\"ept_tabs 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_tabs/releases/1.4.0-alpha3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732314\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:21:\"ept_tabs 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_tabs/releases/1.4.0-alpha2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695021196\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:21:\"ept_tabs 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_tabs/releases/1.4.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1694519731\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:18:\"ept_tabs 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_tabs/releases/1.4.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_tabs-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1729019702\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729063142;}',1729149542),('update_available_releases','ept_text',_binary 'a:10:{s:5:\"title\";s:33:\"Extra Paragraph Types (EPT): Text\";s:10:\"short_name\";s:8:\"ept_text\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:15:\"drupal/ept_text\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ept_text\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:14:\"ept_text 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_text/releases/1.4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_text-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384579\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:14:\"ept_text 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_text/releases/1.4.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_text-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721031205\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:14:\"ept_text 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_text/releases/1.4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_text-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1704965319\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:14:\"ept_text 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ept_text/releases/1.4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ept_text-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793728\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:21:\"ept_text 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_text/releases/1.4.0-alpha3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_text-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697732346\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:21:\"ept_text 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_text/releases/1.4.0-alpha2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_text-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695021325\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:21:\"ept_text 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ept_text/releases/1.4.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ept_text-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1692442868\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:18:\"ept_text 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ept_text/releases/1.4.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ept_text-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710707781\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_tiles',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Tiles\";s:10:\"short_name\";s:9:\"ept_tiles\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_tiles\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_tiles\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:15:\"ept_tiles 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_tiles/releases/1.4.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1721384596\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ept_tiles 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_tiles/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1714488760\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_tiles 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_tiles/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1706861493\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ept_tiles 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_tiles/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793674\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:22:\"ept_tiles 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_tiles/releases/1.4.0-alpha4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697732347\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:22:\"ept_tiles 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_tiles/releases/1.4.0-alpha3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1696078892\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:22:\"ept_tiles 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_tiles/releases/1.4.0-alpha2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695888461\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:22:\"ept_tiles 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_tiles/releases/1.4.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1695579452\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_tiles 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_tiles/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_tiles-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1725277615\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018490;}',1729104890),('update_available_releases','ept_video',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Video\";s:10:\"short_name\";s:9:\"ept_video\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_video\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_video\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:11:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ept_video 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_video/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_video-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1722411733\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_video 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_video/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_video-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721384620\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ept_video 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_video/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_video-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1714490864\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ept_video 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_video/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699793973\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha7\";a:11:{s:4:\"name\";s:22:\"ept_video 1.4.0-alpha7\";s:7:\"version\";s:12:\"1.4.0-alpha7\";s:3:\"tag\";s:12:\"1.4.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_video/releases/1.4.0-alpha7\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1697732210\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha6\";a:11:{s:4:\"name\";s:22:\"ept_video 1.4.0-alpha6\";s:7:\"version\";s:12:\"1.4.0-alpha6\";s:3:\"tag\";s:12:\"1.4.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_video/releases/1.4.0-alpha6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1696687235\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha5\";a:11:{s:4:\"name\";s:22:\"ept_video 1.4.0-alpha5\";s:7:\"version\";s:12:\"1.4.0-alpha5\";s:3:\"tag\";s:12:\"1.4.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_video/releases/1.4.0-alpha5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1696539789\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:22:\"ept_video 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_video/releases/1.4.0-alpha4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1696537986\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:22:\"ept_video 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_video/releases/1.4.0-alpha2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1696531646\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:22:\"ept_video 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ept_video/releases/1.4.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ept_video-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1695573537\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_video 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_video/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_video-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1714490714\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','ept_video_and_image_gallery',_binary 'a:10:{s:5:\"title\";s:52:\"Extra Paragraph Types (EPT): Video and Image Gallery\";s:10:\"short_name\";s:27:\"ept_video_and_image_gallery\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:34:\"drupal/ept_video_and_image_gallery\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:58:\"https://www.drupal.org/project/ept_video_and_image_gallery\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:12:{s:5:\"1.4.5\";a:11:{s:4:\"name\";s:33:\"ept_video_and_image_gallery 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.5\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1722411776\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:33:\"ept_video_and_image_gallery 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.4\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1721384619\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:33:\"ept_video_and_image_gallery 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.3\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1714490933\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:33:\"ept_video_and_image_gallery 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.2\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1713944254\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:33:\"ept_video_and_image_gallery 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.1\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1713944053\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:33:\"ept_video_and_image_gallery 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.0\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699794213\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha6\";a:11:{s:4:\"name\";s:40:\"ept_video_and_image_gallery 1.4.0-alpha6\";s:7:\"version\";s:12:\"1.4.0-alpha6\";s:3:\"tag\";s:12:\"1.4.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.0-alpha6\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1697732380\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha5\";a:11:{s:4:\"name\";s:40:\"ept_video_and_image_gallery 1.4.0-alpha5\";s:7:\"version\";s:12:\"1.4.0-alpha5\";s:3:\"tag\";s:12:\"1.4.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.0-alpha5\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1696687259\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:40:\"ept_video_and_image_gallery 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.0-alpha4\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1696151181\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:40:\"ept_video_and_image_gallery 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.0-alpha3\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1696149547\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:40:\"ept_video_and_image_gallery 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.0-alpha2\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695713209\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:37:\"ept_video_and_image_gallery 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:77:\"https://www.drupal.org/project/ept_video_and_image_gallery/releases/1.4.x-dev\";s:13:\"download_link\";s:82:\"https://ftp.drupal.org/files/projects/ept_video_and_image_gallery-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1714490789\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','ept_views',_binary 'a:10:{s:5:\"title\";s:34:\"Extra Paragraph Types (EPT): Views\";s:10:\"short_name\";s:9:\"ept_views\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ept_views\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ept_views\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:6:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:15:\"ept_views 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_views/releases/1.4.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_views-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1727007515\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ept_views 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_views/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_views-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721384637\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ept_views 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_views/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_views-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721031270\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ept_views 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_views/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_views-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1705528653\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:15:\"ept_views 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ept_views/releases/1.0.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ept_views-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1705528233\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ept_views 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ept_views/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ept_views-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1727007416\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','field_group',_binary 'a:10:{s:5:\"title\";s:11:\"Field Group\";s:10:\"short_name\";s:11:\"field_group\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:11:\"4.0.,8.x-3.\";s:18:\"composer_namespace\";s:18:\"drupal/field_group\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/field_group\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:19:{s:12:\"4.0.0-alpha1\";a:11:{s:4:\"name\";s:24:\"field_group 4.0.0-alpha1\";s:7:\"version\";s:12:\"4.0.0-alpha1\";s:3:\"tag\";s:12:\"4.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/field_group/releases/4.0.0-alpha1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/field_group-4.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1725952813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";}s:7:\"8.x-3.6\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.6\";s:7:\"version\";s:7:\"8.x-3.6\";s:3:\"tag\";s:7:\"8.x-3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.6.tar.gz\";s:4:\"date\";s:10:\"1722672510\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:7:\"8.x-3.5\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.5\";s:7:\"version\";s:7:\"8.x-3.5\";s:3:\"tag\";s:7:\"8.x-3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.5.tar.gz\";s:4:\"date\";s:10:\"1722630494\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:7:\"8.x-3.4\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.4\";s:7:\"version\";s:7:\"8.x-3.4\";s:3:\"tag\";s:7:\"8.x-3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.4.tar.gz\";s:4:\"date\";s:10:\"1667241979\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:7:\"8.x-3.3\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.3\";s:7:\"version\";s:7:\"8.x-3.3\";s:3:\"tag\";s:7:\"8.x-3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.3.tar.gz\";s:4:\"date\";s:10:\"1663516404\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-3.2\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.2\";s:7:\"version\";s:7:\"8.x-3.2\";s:3:\"tag\";s:7:\"8.x-3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.2.tar.gz\";s:4:\"date\";s:10:\"1628513585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-3.1\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.1\";s:7:\"version\";s:7:\"8.x-3.1\";s:3:\"tag\";s:7:\"8.x-3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.1.tar.gz\";s:4:\"date\";s:10:\"1591772567\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-3.0\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.0\";s:7:\"version\";s:7:\"8.x-3.0\";s:3:\"tag\";s:7:\"8.x-3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0.tar.gz\";s:4:\"date\";s:10:\"1580250787\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-3.0-rc2\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-3.0-rc2\";s:7:\"version\";s:11:\"8.x-3.0-rc2\";s:3:\"tag\";s:11:\"8.x-3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-3.0-rc2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1574200085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-3.0-rc1\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-3.0-rc1\";s:7:\"version\";s:11:\"8.x-3.0-rc1\";s:3:\"tag\";s:11:\"8.x-3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-3.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1558647185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-3.0-beta1\";a:11:{s:4:\"name\";s:25:\"field_group 8.x-3.0-beta1\";s:7:\"version\";s:13:\"8.x-3.0-beta1\";s:3:\"tag\";s:13:\"8.x-3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/field_group/releases/8.x-3.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1510352284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-1.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1510352885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc6\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc6\";s:7:\"version\";s:11:\"8.x-1.0-rc6\";s:3:\"tag\";s:11:\"8.x-1.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc6\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1480365484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc5\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1480288380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1449771240\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1447385940\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"4.x-dev\";a:11:{s:4:\"name\";s:19:\"field_group 4.x-dev\";s:7:\"version\";s:7:\"4.x-dev\";s:3:\"tag\";s:3:\"4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1725952112\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-3.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1725973161\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1570214888\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','file_mdm',_binary 'a:10:{s:5:\"title\";s:21:\"File metadata manager\";s:10:\"short_name\";s:8:\"file_mdm\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"3.0.,3.1.\";s:18:\"composer_namespace\";s:15:\"drupal/file_mdm\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/file_mdm\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:31:{s:5:\"3.1.0\";a:11:{s:4:\"name\";s:14:\"file_mdm 3.1.0\";s:7:\"version\";s:5:\"3.1.0\";s:3:\"tag\";s:5:\"3.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/file_mdm/releases/3.1.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/file_mdm-3.1.0.tar.gz\";s:4:\"date\";s:10:\"1718086268\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:11:\"3.1.0-beta2\";a:11:{s:4:\"name\";s:20:\"file_mdm 3.1.0-beta2\";s:7:\"version\";s:11:\"3.1.0-beta2\";s:3:\"tag\";s:11:\"3.1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/3.1.0-beta2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-3.1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1716133805\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:11:\"3.1.0-beta1\";a:11:{s:4:\"name\";s:20:\"file_mdm 3.1.0-beta1\";s:7:\"version\";s:11:\"3.1.0-beta1\";s:3:\"tag\";s:11:\"3.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/3.1.0-beta1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-3.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1714414299\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.2\";s:5:\"terms\";a:0:{}}s:12:\"3.1.0-alpha1\";a:11:{s:4:\"name\";s:21:\"file_mdm 3.1.0-alpha1\";s:7:\"version\";s:12:\"3.1.0-alpha1\";s:3:\"tag\";s:12:\"3.1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/file_mdm/releases/3.1.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/file_mdm-3.1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1705056866\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.2\";s:5:\"terms\";a:0:{}}s:5:\"3.0.0\";a:11:{s:4:\"name\";s:14:\"file_mdm 3.0.0\";s:7:\"version\";s:5:\"3.0.0\";s:3:\"tag\";s:5:\"3.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/file_mdm/releases/3.0.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/file_mdm-3.0.0.tar.gz\";s:4:\"date\";s:10:\"1691421181\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:9:\"3.0.0-rc1\";a:11:{s:4:\"name\";s:18:\"file_mdm 3.0.0-rc1\";s:7:\"version\";s:9:\"3.0.0-rc1\";s:3:\"tag\";s:9:\"3.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/file_mdm/releases/3.0.0-rc1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/file_mdm-3.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1688577226\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:12:\"3.0.0-alpha2\";a:11:{s:4:\"name\";s:21:\"file_mdm 3.0.0-alpha2\";s:7:\"version\";s:12:\"3.0.0-alpha2\";s:3:\"tag\";s:12:\"3.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/file_mdm/releases/3.0.0-alpha2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/file_mdm-3.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1687256944\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:12:\"3.0.0-alpha1\";a:11:{s:4:\"name\";s:21:\"file_mdm 3.0.0-alpha1\";s:7:\"version\";s:12:\"3.0.0-alpha1\";s:3:\"tag\";s:12:\"3.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/file_mdm/releases/3.0.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/file_mdm-3.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1677421044\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:7:\"8.x-2.6\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.6\";s:7:\"version\";s:7:\"8.x-2.6\";s:3:\"tag\";s:7:\"8.x-2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.6\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.6.tar.gz\";s:4:\"date\";s:10:\"1688489716\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^9.3 | ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.5\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.5\";s:7:\"version\";s:7:\"8.x-2.5\";s:3:\"tag\";s:7:\"8.x-2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.5\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.5.tar.gz\";s:4:\"date\";s:10:\"1663668519\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^9.3 | ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.4\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1645440700\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.2\";}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1644943374\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1639755096\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.2\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1586801064\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1576506188\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.0-rc1\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-2.0-rc1\";s:7:\"version\";s:11:\"8.x-2.0-rc1\";s:3:\"tag\";s:11:\"8.x-2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.0-rc1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1575543485\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-2.0-beta1\";a:11:{s:4:\"name\";s:22:\"file_mdm 8.x-2.0-beta1\";s:7:\"version\";s:13:\"8.x-2.0-beta1\";s:3:\"tag\";s:13:\"8.x-2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.0-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1573293184\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1488273785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:16:\"file_mdm 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1487968683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1486564984\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1486127283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1485945784\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1483048683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:22:\"file_mdm 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1469723039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:22:\"file_mdm 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1467634468\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:22:\"file_mdm 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1466009639\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:17:\"8.x-1.0-unstable1\";a:11:{s:4:\"name\";s:26:\"file_mdm 8.x-1.0-unstable1\";s:7:\"version\";s:17:\"8.x-1.0-unstable1\";s:3:\"tag\";s:17:\"8.x-1.0-unstable1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.0-unstable1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.0-unstable1.tar.gz\";s:4:\"date\";s:10:\"1465294739\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:64:\"Unstable releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:9:\"3.1.x-dev\";a:11:{s:4:\"name\";s:18:\"file_mdm 3.1.x-dev\";s:7:\"version\";s:9:\"3.1.x-dev\";s:3:\"tag\";s:5:\"3.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/file_mdm/releases/3.1.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/file_mdm-3.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1717702605\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:9:\"3.0.x-dev\";a:11:{s:4:\"name\";s:18:\"file_mdm 3.0.x-dev\";s:7:\"version\";s:9:\"3.0.x-dev\";s:3:\"tag\";s:5:\"3.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/file_mdm/releases/3.0.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/file_mdm-3.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1699192268\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-2.x-dev\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1687253170\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^9.3 | ^10\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:20:\"file_mdm 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/file_mdm/releases/8.x-1.x-dev\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/file_mdm-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1576326787\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729063142;}',1729149542),('update_available_releases','gin',_binary 'a:10:{s:5:\"title\";s:15:\"Gin Admin Theme\";s:10:\"short_name\";s:3:\"gin\";s:4:\"type\";s:13:\"project_theme\";s:18:\"supported_branches\";s:11:\"4.0.,8.x-3.\";s:18:\"composer_namespace\";s:10:\"drupal/gin\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:34:\"https://www.drupal.org/project/gin\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:86:{s:12:\"8.x-3.0-rc13\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc13\";s:7:\"version\";s:12:\"8.x-3.0-rc13\";s:3:\"tag\";s:12:\"8.x-3.0-rc13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc13\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc13.tar.gz\";s:4:\"date\";s:10:\"1720416342\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc12\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc12\";s:7:\"version\";s:12:\"8.x-3.0-rc12\";s:3:\"tag\";s:12:\"8.x-3.0-rc12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc12\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc12.tar.gz\";s:4:\"date\";s:10:\"1719568767\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc11\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc11\";s:7:\"version\";s:12:\"8.x-3.0-rc11\";s:3:\"tag\";s:12:\"8.x-3.0-rc11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc11\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc11.tar.gz\";s:4:\"date\";s:10:\"1718351205\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:12:\"8.x-3.0-rc10\";a:11:{s:4:\"name\";s:16:\"gin 8.x-3.0-rc10\";s:7:\"version\";s:12:\"8.x-3.0-rc10\";s:3:\"tag\";s:12:\"8.x-3.0-rc10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc10\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc10.tar.gz\";s:4:\"date\";s:10:\"1712686345\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc9\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc9\";s:7:\"version\";s:11:\"8.x-3.0-rc9\";s:3:\"tag\";s:11:\"8.x-3.0-rc9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc9\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc9.tar.gz\";s:4:\"date\";s:10:\"1706705034\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc8\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc8\";s:7:\"version\";s:11:\"8.x-3.0-rc8\";s:3:\"tag\";s:11:\"8.x-3.0-rc8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc8\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc8.tar.gz\";s:4:\"date\";s:10:\"1702729136\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc7\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc7\";s:7:\"version\";s:11:\"8.x-3.0-rc7\";s:3:\"tag\";s:11:\"8.x-3.0-rc7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc7\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc7.tar.gz\";s:4:\"date\";s:10:\"1697193234\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc6\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc6\";s:7:\"version\";s:11:\"8.x-3.0-rc6\";s:3:\"tag\";s:11:\"8.x-3.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc6\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1693299666\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc5\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc5\";s:7:\"version\";s:11:\"8.x-3.0-rc5\";s:3:\"tag\";s:11:\"8.x-3.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc5\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1689504430\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc4\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc4\";s:7:\"version\";s:11:\"8.x-3.0-rc4\";s:3:\"tag\";s:11:\"8.x-3.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1688474317\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc3\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc3\";s:7:\"version\";s:11:\"8.x-3.0-rc3\";s:3:\"tag\";s:11:\"8.x-3.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1682979025\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc2\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc2\";s:7:\"version\";s:11:\"8.x-3.0-rc2\";s:3:\"tag\";s:11:\"8.x-3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1678627668\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-3.0-rc1\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.0-rc1\";s:7:\"version\";s:11:\"8.x-3.0-rc1\";s:3:\"tag\";s:11:\"8.x-3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.0-rc1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1669666691\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta5\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta5\";s:7:\"version\";s:13:\"8.x-3.0-beta5\";s:3:\"tag\";s:13:\"8.x-3.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1656068146\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta4\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta4\";s:7:\"version\";s:13:\"8.x-3.0-beta4\";s:3:\"tag\";s:13:\"8.x-3.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1656062400\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta3\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta3\";s:7:\"version\";s:13:\"8.x-3.0-beta3\";s:3:\"tag\";s:13:\"8.x-3.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1653469869\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta2\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta2\";s:7:\"version\";s:13:\"8.x-3.0-beta2\";s:3:\"tag\";s:13:\"8.x-3.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1649709347\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:13:\"8.x-3.0-beta1\";a:11:{s:4:\"name\";s:17:\"gin 8.x-3.0-beta1\";s:7:\"version\";s:13:\"8.x-3.0-beta1\";s:3:\"tag\";s:13:\"8.x-3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/gin/releases/8.x-3.0-beta1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1646929485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.9 || ^9 || ^10\";}s:15:\"8.x-3.0-alpha37\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha37\";s:7:\"version\";s:15:\"8.x-3.0-alpha37\";s:3:\"tag\";s:15:\"8.x-3.0-alpha37\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha37\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha37.tar.gz\";s:4:\"date\";s:10:\"1632767973\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:15:\"8.x-3.0-alpha36\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha36\";s:7:\"version\";s:15:\"8.x-3.0-alpha36\";s:3:\"tag\";s:15:\"8.x-3.0-alpha36\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha36\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha36.tar.gz\";s:4:\"date\";s:10:\"1625232222\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha35\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha35\";s:7:\"version\";s:15:\"8.x-3.0-alpha35\";s:3:\"tag\";s:15:\"8.x-3.0-alpha35\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha35\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha35.tar.gz\";s:4:\"date\";s:10:\"1622412154\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha34\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha34\";s:7:\"version\";s:15:\"8.x-3.0-alpha34\";s:3:\"tag\";s:15:\"8.x-3.0-alpha34\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha34\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha34.tar.gz\";s:4:\"date\";s:10:\"1620394439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha33\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha33\";s:7:\"version\";s:15:\"8.x-3.0-alpha33\";s:3:\"tag\";s:15:\"8.x-3.0-alpha33\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha33\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha33.tar.gz\";s:4:\"date\";s:10:\"1611172829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha32\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha32\";s:7:\"version\";s:15:\"8.x-3.0-alpha32\";s:3:\"tag\";s:15:\"8.x-3.0-alpha32\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha32\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha32.tar.gz\";s:4:\"date\";s:10:\"1607370374\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha31\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha31\";s:7:\"version\";s:15:\"8.x-3.0-alpha31\";s:3:\"tag\";s:15:\"8.x-3.0-alpha31\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha31\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha31.tar.gz\";s:4:\"date\";s:10:\"1606944288\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha30\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha30\";s:7:\"version\";s:15:\"8.x-3.0-alpha30\";s:3:\"tag\";s:15:\"8.x-3.0-alpha30\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha30\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha30.tar.gz\";s:4:\"date\";s:10:\"1605395013\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha29\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha29\";s:7:\"version\";s:15:\"8.x-3.0-alpha29\";s:3:\"tag\";s:15:\"8.x-3.0-alpha29\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha29\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha29.tar.gz\";s:4:\"date\";s:10:\"1605375202\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha28\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha28\";s:7:\"version\";s:15:\"8.x-3.0-alpha28\";s:3:\"tag\";s:15:\"8.x-3.0-alpha28\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha28\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha28.tar.gz\";s:4:\"date\";s:10:\"1604868112\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha27\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha27\";s:7:\"version\";s:15:\"8.x-3.0-alpha27\";s:3:\"tag\";s:15:\"8.x-3.0-alpha27\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha27\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha27.tar.gz\";s:4:\"date\";s:10:\"1601291419\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha26\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha26\";s:7:\"version\";s:15:\"8.x-3.0-alpha26\";s:3:\"tag\";s:15:\"8.x-3.0-alpha26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha26\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha26.tar.gz\";s:4:\"date\";s:10:\"1598863786\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha25\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha25\";s:7:\"version\";s:15:\"8.x-3.0-alpha25\";s:3:\"tag\";s:15:\"8.x-3.0-alpha25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha25\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha25.tar.gz\";s:4:\"date\";s:10:\"1597406186\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha24\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha24\";s:7:\"version\";s:15:\"8.x-3.0-alpha24\";s:3:\"tag\";s:15:\"8.x-3.0-alpha24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha24\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha24.tar.gz\";s:4:\"date\";s:10:\"1595854343\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha23\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha23\";s:7:\"version\";s:15:\"8.x-3.0-alpha23\";s:3:\"tag\";s:15:\"8.x-3.0-alpha23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha23\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha23.tar.gz\";s:4:\"date\";s:10:\"1594643695\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha22\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha22\";s:7:\"version\";s:15:\"8.x-3.0-alpha22\";s:3:\"tag\";s:15:\"8.x-3.0-alpha22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha22\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha22.tar.gz\";s:4:\"date\";s:10:\"1593766525\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha21\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha21\";s:7:\"version\";s:15:\"8.x-3.0-alpha21\";s:3:\"tag\";s:15:\"8.x-3.0-alpha21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha21\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha21.tar.gz\";s:4:\"date\";s:10:\"1593461879\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha20\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha20\";s:7:\"version\";s:15:\"8.x-3.0-alpha20\";s:3:\"tag\";s:15:\"8.x-3.0-alpha20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha20\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha20.tar.gz\";s:4:\"date\";s:10:\"1592855613\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha19\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha19\";s:7:\"version\";s:15:\"8.x-3.0-alpha19\";s:3:\"tag\";s:15:\"8.x-3.0-alpha19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha19\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha19.tar.gz\";s:4:\"date\";s:10:\"1592580886\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha18\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha18\";s:7:\"version\";s:15:\"8.x-3.0-alpha18\";s:3:\"tag\";s:15:\"8.x-3.0-alpha18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha18\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha18.tar.gz\";s:4:\"date\";s:10:\"1592169349\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha17\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha17\";s:7:\"version\";s:15:\"8.x-3.0-alpha17\";s:3:\"tag\";s:15:\"8.x-3.0-alpha17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha17\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha17.tar.gz\";s:4:\"date\";s:10:\"1591349946\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:15:\"8.x-3.0-alpha16\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha16\";s:7:\"version\";s:15:\"8.x-3.0-alpha16\";s:3:\"tag\";s:15:\"8.x-3.0-alpha16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha16\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha16.tar.gz\";s:4:\"date\";s:10:\"1591188802\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha15\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha15\";s:7:\"version\";s:15:\"8.x-3.0-alpha15\";s:3:\"tag\";s:15:\"8.x-3.0-alpha15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha15\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha15.tar.gz\";s:4:\"date\";s:10:\"1591026800\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha14\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha14\";s:7:\"version\";s:15:\"8.x-3.0-alpha14\";s:3:\"tag\";s:15:\"8.x-3.0-alpha14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha14\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha14.tar.gz\";s:4:\"date\";s:10:\"1590401622\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha13\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha13\";s:7:\"version\";s:15:\"8.x-3.0-alpha13\";s:3:\"tag\";s:15:\"8.x-3.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1590058790\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha12\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha12\";s:7:\"version\";s:15:\"8.x-3.0-alpha12\";s:3:\"tag\";s:15:\"8.x-3.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1588701093\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha11\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha11\";s:7:\"version\";s:15:\"8.x-3.0-alpha11\";s:3:\"tag\";s:15:\"8.x-3.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1588112180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-3.0-alpha10\";a:11:{s:4:\"name\";s:19:\"gin 8.x-3.0-alpha10\";s:7:\"version\";s:15:\"8.x-3.0-alpha10\";s:3:\"tag\";s:15:\"8.x-3.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1588110279\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha9\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha9\";s:7:\"version\";s:14:\"8.x-3.0-alpha9\";s:3:\"tag\";s:14:\"8.x-3.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1587598687\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha8\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha8\";s:7:\"version\";s:14:\"8.x-3.0-alpha8\";s:3:\"tag\";s:14:\"8.x-3.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1587403171\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha7\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha7\";s:7:\"version\";s:14:\"8.x-3.0-alpha7\";s:3:\"tag\";s:14:\"8.x-3.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1586889051\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha6\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha6\";s:7:\"version\";s:14:\"8.x-3.0-alpha6\";s:3:\"tag\";s:14:\"8.x-3.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1585911008\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha5\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha5\";s:7:\"version\";s:14:\"8.x-3.0-alpha5\";s:3:\"tag\";s:14:\"8.x-3.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1585758919\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha4\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha4\";s:7:\"version\";s:14:\"8.x-3.0-alpha4\";s:3:\"tag\";s:14:\"8.x-3.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1585218206\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha3\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha3\";s:7:\"version\";s:14:\"8.x-3.0-alpha3\";s:3:\"tag\";s:14:\"8.x-3.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1585056344\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha2\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha2\";s:7:\"version\";s:14:\"8.x-3.0-alpha2\";s:3:\"tag\";s:14:\"8.x-3.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1584823830\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-3.0-alpha1\";a:11:{s:4:\"name\";s:18:\"gin 8.x-3.0-alpha1\";s:7:\"version\";s:14:\"8.x-3.0-alpha1\";s:3:\"tag\";s:14:\"8.x-3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-3.0-alpha1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1584713675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-2.0-alpha13\";a:11:{s:4:\"name\";s:19:\"gin 8.x-2.0-alpha13\";s:7:\"version\";s:15:\"8.x-2.0-alpha13\";s:3:\"tag\";s:15:\"8.x-2.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1582141618\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-2.0-alpha12\";a:11:{s:4:\"name\";s:19:\"gin 8.x-2.0-alpha12\";s:7:\"version\";s:15:\"8.x-2.0-alpha12\";s:3:\"tag\";s:15:\"8.x-2.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1581799850\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:15:\"8.x-2.0-alpha11\";a:11:{s:4:\"name\";s:19:\"gin 8.x-2.0-alpha11\";s:7:\"version\";s:15:\"8.x-2.0-alpha11\";s:3:\"tag\";s:15:\"8.x-2.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1581784971\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:15:\"8.x-2.0-alpha10\";a:11:{s:4:\"name\";s:19:\"gin 8.x-2.0-alpha10\";s:7:\"version\";s:15:\"8.x-2.0-alpha10\";s:3:\"tag\";s:15:\"8.x-2.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1581670919\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha9\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha9\";s:7:\"version\";s:14:\"8.x-2.0-alpha9\";s:3:\"tag\";s:14:\"8.x-2.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1580894379\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha8\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha8\";s:7:\"version\";s:14:\"8.x-2.0-alpha8\";s:3:\"tag\";s:14:\"8.x-2.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1580892462\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha7\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha7\";s:7:\"version\";s:14:\"8.x-2.0-alpha7\";s:3:\"tag\";s:14:\"8.x-2.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1580374257\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha6\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha6\";s:7:\"version\";s:14:\"8.x-2.0-alpha6\";s:3:\"tag\";s:14:\"8.x-2.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1580139185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha5\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha5\";s:7:\"version\";s:14:\"8.x-2.0-alpha5\";s:3:\"tag\";s:14:\"8.x-2.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1579908781\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha4\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha4\";s:7:\"version\";s:14:\"8.x-2.0-alpha4\";s:3:\"tag\";s:14:\"8.x-2.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1578573789\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-2.0-alpha3\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha3\";s:7:\"version\";s:14:\"8.x-2.0-alpha3\";s:3:\"tag\";s:14:\"8.x-2.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1576589285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-2.0-alpha2\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha2\";s:7:\"version\";s:14:\"8.x-2.0-alpha2\";s:3:\"tag\";s:14:\"8.x-2.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1575496380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-2.0-alpha1\";a:11:{s:4:\"name\";s:18:\"gin 8.x-2.0-alpha1\";s:7:\"version\";s:14:\"8.x-2.0-alpha1\";s:3:\"tag\";s:14:\"8.x-2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-2.0-alpha1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1575493680\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";s:5:\"terms\";a:0:{}}s:15:\"8.x-1.0-alpha14\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha14\";s:7:\"version\";s:15:\"8.x-1.0-alpha14\";s:3:\"tag\";s:15:\"8.x-1.0-alpha14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha14\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha14.tar.gz\";s:4:\"date\";s:10:\"1582141601\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:15:\"8.x-1.0-alpha13\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha13\";s:7:\"version\";s:15:\"8.x-1.0-alpha13\";s:3:\"tag\";s:15:\"8.x-1.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1581799836\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:15:\"8.x-1.0-alpha12\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha12\";s:7:\"version\";s:15:\"8.x-1.0-alpha12\";s:3:\"tag\";s:15:\"8.x-1.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1581784989\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";s:5:\"terms\";a:0:{}}s:15:\"8.x-1.0-alpha11\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha11\";s:7:\"version\";s:15:\"8.x-1.0-alpha11\";s:3:\"tag\";s:15:\"8.x-1.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1581670945\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:15:\"8.x-1.0-alpha10\";a:11:{s:4:\"name\";s:19:\"gin 8.x-1.0-alpha10\";s:7:\"version\";s:15:\"8.x-1.0-alpha10\";s:3:\"tag\";s:15:\"8.x-1.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1580894364\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha9\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha9\";s:7:\"version\";s:14:\"8.x-1.0-alpha9\";s:3:\"tag\";s:14:\"8.x-1.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1580892445\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha8\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha8\";s:7:\"version\";s:14:\"8.x-1.0-alpha8\";s:3:\"tag\";s:14:\"8.x-1.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1580139185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha7\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha7\";s:7:\"version\";s:14:\"8.x-1.0-alpha7\";s:3:\"tag\";s:14:\"8.x-1.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1578905887\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha6\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha6\";s:7:\"version\";s:14:\"8.x-1.0-alpha6\";s:3:\"tag\";s:14:\"8.x-1.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1578573789\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1576589285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1572892684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1572358984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1572007384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:18:\"gin 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/gin/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/gin-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1570199287\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:9:\"4.0.x-dev\";a:11:{s:4:\"name\";s:13:\"gin 4.0.x-dev\";s:7:\"version\";s:9:\"4.0.x-dev\";s:3:\"tag\";s:5:\"4.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/gin/releases/4.0.x-dev\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/gin-4.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1728815254\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:15:\"gin 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-3.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1728815068\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:15:\"gin 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-2.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1582387423\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:15:\"gin 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/gin/releases/8.x-1.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/gin-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1582387472\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"<8.8\";}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','gin_toolbar',_binary 'a:10:{s:5:\"title\";s:11:\"Gin Toolbar\";s:10:\"short_name\";s:11:\"gin_toolbar\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:18:\"drupal/gin_toolbar\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/gin_toolbar\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:33:{s:11:\"8.x-1.0-rc6\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc6\";s:7:\"version\";s:11:\"8.x-1.0-rc6\";s:3:\"tag\";s:11:\"8.x-1.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc6\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1718368950\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:11:\"8.x-1.0-rc5\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1702727588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1697192878\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1688477489\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1688474912\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1669666835\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:14:\"8.x-1.0-beta22\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta22\";s:7:\"version\";s:14:\"8.x-1.0-beta22\";s:3:\"tag\";s:14:\"8.x-1.0-beta22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta22\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta22.tar.gz\";s:4:\"date\";s:10:\"1649709351\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:14:\"8.x-1.0-beta21\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta21\";s:7:\"version\";s:14:\"8.x-1.0-beta21\";s:3:\"tag\";s:14:\"8.x-1.0-beta21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta21\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta21.tar.gz\";s:4:\"date\";s:10:\"1646929714\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:14:\"8.x-1.0-beta20\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta20\";s:7:\"version\";s:14:\"8.x-1.0-beta20\";s:3:\"tag\";s:14:\"8.x-1.0-beta20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta20\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta20.tar.gz\";s:4:\"date\";s:10:\"1635149590\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:14:\"8.x-1.0-beta19\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta19\";s:7:\"version\";s:14:\"8.x-1.0-beta19\";s:3:\"tag\";s:14:\"8.x-1.0-beta19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta19\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta19.tar.gz\";s:4:\"date\";s:10:\"1626682027\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta18\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta18\";s:7:\"version\";s:14:\"8.x-1.0-beta18\";s:3:\"tag\";s:14:\"8.x-1.0-beta18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta18\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta18.tar.gz\";s:4:\"date\";s:10:\"1625232247\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta17\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta17\";s:7:\"version\";s:14:\"8.x-1.0-beta17\";s:3:\"tag\";s:14:\"8.x-1.0-beta17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta17\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta17.tar.gz\";s:4:\"date\";s:10:\"1622635843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta16\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta16\";s:7:\"version\";s:14:\"8.x-1.0-beta16\";s:3:\"tag\";s:14:\"8.x-1.0-beta16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta16\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta16.tar.gz\";s:4:\"date\";s:10:\"1622620508\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta15\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta15\";s:7:\"version\";s:14:\"8.x-1.0-beta15\";s:3:\"tag\";s:14:\"8.x-1.0-beta15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta15\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta15.tar.gz\";s:4:\"date\";s:10:\"1620393971\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta14\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta14\";s:7:\"version\";s:14:\"8.x-1.0-beta14\";s:3:\"tag\";s:14:\"8.x-1.0-beta14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta14\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta14.tar.gz\";s:4:\"date\";s:10:\"1607370428\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta13\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta13\";s:7:\"version\";s:14:\"8.x-1.0-beta13\";s:3:\"tag\";s:14:\"8.x-1.0-beta13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta13\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta13.tar.gz\";s:4:\"date\";s:10:\"1604868424\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta12\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta12\";s:7:\"version\";s:14:\"8.x-1.0-beta12\";s:3:\"tag\";s:14:\"8.x-1.0-beta12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta12\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta12.tar.gz\";s:4:\"date\";s:10:\"1597406475\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-beta11\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta11\";s:7:\"version\";s:14:\"8.x-1.0-beta11\";s:3:\"tag\";s:14:\"8.x-1.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta11\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1594643490\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-beta10\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-beta10\";s:7:\"version\";s:14:\"8.x-1.0-beta10\";s:3:\"tag\";s:14:\"8.x-1.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta10\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1593766660\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta9\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta9\";s:7:\"version\";s:13:\"8.x-1.0-beta9\";s:3:\"tag\";s:13:\"8.x-1.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta9\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1593462042\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta8\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta8\";s:7:\"version\";s:13:\"8.x-1.0-beta8\";s:3:\"tag\";s:13:\"8.x-1.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta8\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1592855833\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta7\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta7\";s:7:\"version\";s:13:\"8.x-1.0-beta7\";s:3:\"tag\";s:13:\"8.x-1.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta7\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1591349902\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta6\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta6\";s:7:\"version\";s:13:\"8.x-1.0-beta6\";s:3:\"tag\";s:13:\"8.x-1.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta6\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1590401639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta5\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta5\";s:7:\"version\";s:13:\"8.x-1.0-beta5\";s:3:\"tag\";s:13:\"8.x-1.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta5\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1588460020\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta4\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta4\";s:7:\"version\";s:13:\"8.x-1.0-beta4\";s:3:\"tag\";s:13:\"8.x-1.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta4\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1588342225\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1587403136\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1584829276\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:25:\"gin_toolbar 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1584713311\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1581785004\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1580139185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1579960985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:26:\"gin_toolbar 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1579958885\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"gin_toolbar 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/gin_toolbar/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/gin_toolbar-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722894078\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','glightbox',_binary 'a:10:{s:5:\"title\";s:9:\"GLightbox\";s:10:\"short_name\";s:9:\"glightbox\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.0.\";s:18:\"composer_namespace\";s:16:\"drupal/glightbox\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:12:{s:5:\"1.0.9\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.9\";s:7:\"version\";s:5:\"1.0.9\";s:3:\"tag\";s:5:\"1.0.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.9\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.9.tar.gz\";s:4:\"date\";s:10:\"1727939818\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.8\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.8\";s:7:\"version\";s:5:\"1.0.8\";s:3:\"tag\";s:5:\"1.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.8\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.8.tar.gz\";s:4:\"date\";s:10:\"1726929656\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.7\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.7\";s:7:\"version\";s:5:\"1.0.7\";s:3:\"tag\";s:5:\"1.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.7\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.7.tar.gz\";s:4:\"date\";s:10:\"1713942568\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.6\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.6\";s:7:\"version\";s:5:\"1.0.6\";s:3:\"tag\";s:5:\"1.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.6\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.6.tar.gz\";s:4:\"date\";s:10:\"1712003661\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.5\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.5\";s:7:\"version\";s:5:\"1.0.5\";s:3:\"tag\";s:5:\"1.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.5\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.5.tar.gz\";s:4:\"date\";s:10:\"1712002850\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.4\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.4\";s:7:\"version\";s:5:\"1.0.4\";s:3:\"tag\";s:5:\"1.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.4.tar.gz\";s:4:\"date\";s:10:\"1704707152\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.2\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.2\";s:7:\"version\";s:5:\"1.0.2\";s:3:\"tag\";s:5:\"1.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.2.tar.gz\";s:4:\"date\";s:10:\"1697006475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1690874897\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1670673111\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:11:\"1.0.0-beta1\";a:11:{s:4:\"name\";s:21:\"glightbox 1.0.0-beta1\";s:7:\"version\";s:11:\"1.0.0-beta1\";s:3:\"tag\";s:11:\"1.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/glightbox/releases/1.0.0-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/glightbox-1.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1669550449\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.0.0-alpha1\";a:11:{s:4:\"name\";s:22:\"glightbox 1.0.0-alpha1\";s:7:\"version\";s:12:\"1.0.0-alpha1\";s:3:\"tag\";s:12:\"1.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/glightbox/releases/1.0.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/glightbox-1.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1669124562\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:9:\"1.0.x-dev\";a:11:{s:4:\"name\";s:19:\"glightbox 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/glightbox/releases/1.0.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/glightbox-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1727936126\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','glightbox_media_video',_binary 'a:10:{s:5:\"title\";s:21:\"GLightbox Media Video\";s:10:\"short_name\";s:21:\"glightbox_media_video\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.0.\";s:18:\"composer_namespace\";s:28:\"drupal/glightbox_media_video\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:52:\"https://www.drupal.org/project/glightbox_media_video\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:5:{s:5:\"1.0.1\";a:11:{s:4:\"name\";s:27:\"glightbox_media_video 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1713942578\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:27:\"glightbox_media_video 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1705421893\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.0.0-alpha3\";a:11:{s:4:\"name\";s:34:\"glightbox_media_video 1.0.0-alpha3\";s:7:\"version\";s:12:\"1.0.0-alpha3\";s:3:\"tag\";s:12:\"1.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.0-alpha3\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697395686\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.0.0-alpha2\";a:11:{s:4:\"name\";s:34:\"glightbox_media_video 1.0.0-alpha2\";s:7:\"version\";s:12:\"1.0.0-alpha2\";s:3:\"tag\";s:12:\"1.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.0-alpha2\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1694768486\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.0.x-dev\";a:11:{s:4:\"name\";s:31:\"glightbox_media_video 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:71:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.x-dev\";s:13:\"download_link\";s:76:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1713265199\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','image_effects',_binary 'a:10:{s:5:\"title\";s:13:\"Image Effects\";s:10:\"short_name\";s:13:\"image_effects\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:11:\"4.0.,8.x-3.\";s:18:\"composer_namespace\";s:20:\"drupal/image_effects\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/image_effects\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:34:{s:9:\"4.0.0-rc1\";a:11:{s:4:\"name\";s:23:\"image_effects 4.0.0-rc1\";s:7:\"version\";s:9:\"4.0.0-rc1\";s:3:\"tag\";s:9:\"4.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/image_effects/releases/4.0.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/image_effects-4.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1726321525\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:11:\"4.0.0-beta2\";a:11:{s:4:\"name\";s:25:\"image_effects 4.0.0-beta2\";s:7:\"version\";s:11:\"4.0.0-beta2\";s:3:\"tag\";s:11:\"4.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/4.0.0-beta2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-4.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1725133607\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";}s:11:\"4.0.0-beta1\";a:11:{s:4:\"name\";s:25:\"image_effects 4.0.0-beta1\";s:7:\"version\";s:11:\"4.0.0-beta1\";s:3:\"tag\";s:11:\"4.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/4.0.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-4.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1723547538\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:12:\"4.0.0-alpha2\";a:11:{s:4:\"name\";s:26:\"image_effects 4.0.0-alpha2\";s:7:\"version\";s:12:\"4.0.0-alpha2\";s:3:\"tag\";s:12:\"4.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/image_effects/releases/4.0.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/image_effects-4.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1719673323\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:12:\"4.0.0-alpha1\";a:11:{s:4:\"name\";s:26:\"image_effects 4.0.0-alpha1\";s:7:\"version\";s:12:\"4.0.0-alpha1\";s:3:\"tag\";s:12:\"4.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/image_effects/releases/4.0.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/image_effects-4.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1719174775\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:7:\"8.x-3.6\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.6\";s:7:\"version\";s:7:\"8.x-3.6\";s:3:\"tag\";s:7:\"8.x-3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.6\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.6.tar.gz\";s:4:\"date\";s:10:\"1705681111\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:7:\"8.x-3.5\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.5\";s:7:\"version\";s:7:\"8.x-3.5\";s:3:\"tag\";s:7:\"8.x-3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.5.tar.gz\";s:4:\"date\";s:10:\"1703018384\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:7:\"8.x-3.4\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.4\";s:7:\"version\";s:7:\"8.x-3.4\";s:3:\"tag\";s:7:\"8.x-3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.4.tar.gz\";s:4:\"date\";s:10:\"1664106631\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-3.3\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.3\";s:7:\"version\";s:7:\"8.x-3.3\";s:3:\"tag\";s:7:\"8.x-3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.3.tar.gz\";s:4:\"date\";s:10:\"1656755133\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.2\";}s:7:\"8.x-3.2\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.2\";s:7:\"version\";s:7:\"8.x-3.2\";s:3:\"tag\";s:7:\"8.x-3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.2.tar.gz\";s:4:\"date\";s:10:\"1639923532\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.2\";}s:7:\"8.x-3.1\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.1\";s:7:\"version\";s:7:\"8.x-3.1\";s:3:\"tag\";s:7:\"8.x-3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.1.tar.gz\";s:4:\"date\";s:10:\"1607189720\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.9 || ^9\";}s:7:\"8.x-3.0\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-3.0\";s:7:\"version\";s:7:\"8.x-3.0\";s:3:\"tag\";s:7:\"8.x-3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-3.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.0.tar.gz\";s:4:\"date\";s:10:\"1581702907\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.0-rc2\";a:11:{s:4:\"name\";s:25:\"image_effects 8.x-3.0-rc2\";s:7:\"version\";s:11:\"8.x-3.0-rc2\";s:3:\"tag\";s:11:\"8.x-3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/8.x-3.0-rc2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1579511590\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.0-rc1\";a:11:{s:4:\"name\";s:25:\"image_effects 8.x-3.0-rc1\";s:7:\"version\";s:11:\"8.x-3.0-rc1\";s:3:\"tag\";s:11:\"8.x-3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/8.x-3.0-rc1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1579013889\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:14:\"8.x-3.0-alpha1\";a:11:{s:4:\"name\";s:28:\"image_effects 8.x-3.0-alpha1\";s:7:\"version\";s:14:\"8.x-3.0-alpha1\";s:3:\"tag\";s:14:\"8.x-3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/image_effects/releases/8.x-3.0-alpha1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1573398784\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-2.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1547928180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-2.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1543319281\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-2.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1524304984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-2.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1507016344\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:13:\"8.x-2.0-beta1\";a:11:{s:4:\"name\";s:27:\"image_effects 8.x-2.0-beta1\";s:7:\"version\";s:13:\"8.x-2.0-beta1\";s:3:\"tag\";s:13:\"8.x-2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/image_effects/releases/8.x-2.0-beta1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/image_effects-8.x-2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1503414544\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-1.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1547998080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-1.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1543322281\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-1.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1524304384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:21:\"image_effects 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1492431842\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:27:\"image_effects 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1489994284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:28:\"image_effects 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1487259483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:28:\"image_effects 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1485631383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:28:\"image_effects 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1479725943\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:28:\"image_effects 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1459699439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:28:\"image_effects 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/image_effects/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1454614739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:9:\"4.0.x-dev\";a:11:{s:4:\"name\";s:23:\"image_effects 4.0.x-dev\";s:7:\"version\";s:9:\"4.0.x-dev\";s:3:\"tag\";s:5:\"4.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/image_effects/releases/4.0.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/image_effects-4.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1726315345\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^10.3 | ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:25:\"image_effects 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/8.x-3.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1718480779\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.2\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:25:\"image_effects 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/8.x-2.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1580899404\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:25:\"image_effects 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/image_effects/releases/8.x-1.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/image_effects-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1554798486\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729063142;}',1729149542),('update_available_releases','jquery_ui',_binary 'a:10:{s:5:\"title\";s:9:\"jQuery UI\";s:10:\"short_name\";s:9:\"jquery_ui\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:16:\"drupal/jquery_ui\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/jquery_ui\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.7\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1717002098\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.6\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1668521197\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1668437968\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1582149957\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1582044456\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1571251084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1571242084\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1568823185\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:21:\"jquery_ui 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1716994751\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','jquery_ui_accordion',_binary 'a:10:{s:5:\"title\";s:19:\"jQuery UI Accordion\";s:10:\"short_name\";s:19:\"jquery_ui_accordion\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"2.0.,2.1.\";s:18:\"composer_namespace\";s:26:\"drupal/jquery_ui_accordion\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:50:\"https://www.drupal.org/project/jquery_ui_accordion\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:6:{s:5:\"2.1.0\";a:11:{s:4:\"name\";s:25:\"jquery_ui_accordion 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/jquery_ui_accordion/releases/2.1.0\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1717015495\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:25:\"jquery_ui_accordion 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/jquery_ui_accordion/releases/2.0.0\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1670871459\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:27:\"jquery_ui_accordion 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/jquery_ui_accordion/releases/8.x-1.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1584106477\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:27:\"jquery_ui_accordion 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/jquery_ui_accordion/releases/8.x-1.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1568740983\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:27:\"jquery_ui_accordion 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/jquery_ui_accordion/releases/2.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1717012942\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:31:\"jquery_ui_accordion 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:71:\"https://www.drupal.org/project/jquery_ui_accordion/releases/8.x-1.x-dev\";s:13:\"download_link\";s:76:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1584102992\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','jquery_ui_tabs',_binary 'a:10:{s:5:\"title\";s:14:\"jQuery UI Tabs\";s:10:\"short_name\";s:14:\"jquery_ui_tabs\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"2.1.\";s:18:\"composer_namespace\";s:21:\"drupal/jquery_ui_tabs\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:45:\"https://www.drupal.org/project/jquery_ui_tabs\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:5:{s:5:\"2.1.0\";a:11:{s:4:\"name\";s:20:\"jquery_ui_tabs 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/jquery_ui_tabs/releases/2.1.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1719935962\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:20:\"jquery_ui_tabs 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/jquery_ui_tabs/releases/2.0.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1670948528\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:22:\"jquery_ui_tabs 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jquery_ui_tabs/releases/8.x-1.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1590102797\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:22:\"jquery_ui_tabs 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jquery_ui_tabs/releases/8.x-1.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1568819887\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:26:\"jquery_ui_tabs 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jquery_ui_tabs/releases/8.x-1.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1590102633\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','layout_paragraphs',_binary 'a:10:{s:5:\"title\";s:17:\"Layout Paragraphs\";s:10:\"short_name\";s:17:\"layout_paragraphs\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"2.0.,2.1.\";s:18:\"composer_namespace\";s:24:\"drupal/layout_paragraphs\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:48:\"https://www.drupal.org/project/layout_paragraphs\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:32:{s:5:\"2.1.0\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.1.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1724879054\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"2.0.8\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.8\";s:7:\"version\";s:5:\"2.0.8\";s:3:\"tag\";s:5:\"2.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.8\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.8.tar.gz\";s:4:\"date\";s:10:\"1722385148\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:5:\"2.0.7\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.7\";s:7:\"version\";s:5:\"2.0.7\";s:3:\"tag\";s:5:\"2.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.7\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.7.tar.gz\";s:4:\"date\";s:10:\"1722017736\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.6\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.6\";s:7:\"version\";s:5:\"2.0.6\";s:3:\"tag\";s:5:\"2.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.6\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.6.tar.gz\";s:4:\"date\";s:10:\"1720734897\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.5\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.5\";s:7:\"version\";s:5:\"2.0.5\";s:3:\"tag\";s:5:\"2.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.5.tar.gz\";s:4:\"date\";s:10:\"1717779453\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.4\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.4\";s:7:\"version\";s:5:\"2.0.4\";s:3:\"tag\";s:5:\"2.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.4.tar.gz\";s:4:\"date\";s:10:\"1702252843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.3\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.3\";s:7:\"version\";s:5:\"2.0.3\";s:3:\"tag\";s:5:\"2.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.3.tar.gz\";s:4:\"date\";s:10:\"1683938207\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.2\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.2\";s:7:\"version\";s:5:\"2.0.2\";s:3:\"tag\";s:5:\"2.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.2.tar.gz\";s:4:\"date\";s:10:\"1671393656\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.1 || ^10\";}s:5:\"2.0.1\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.1\";s:7:\"version\";s:5:\"2.0.1\";s:3:\"tag\";s:5:\"2.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.1.tar.gz\";s:4:\"date\";s:10:\"1661260491\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1660593911\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta9\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta9\";s:7:\"version\";s:11:\"2.0.0-beta9\";s:3:\"tag\";s:11:\"2.0.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta9\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1649970500\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta8\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta8\";s:7:\"version\";s:11:\"2.0.0-beta8\";s:3:\"tag\";s:11:\"2.0.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta8\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1647014784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta7\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta7\";s:7:\"version\";s:11:\"2.0.0-beta7\";s:3:\"tag\";s:11:\"2.0.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta7\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1646947506\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta6\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta6\";s:7:\"version\";s:11:\"2.0.0-beta6\";s:3:\"tag\";s:11:\"2.0.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta6\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1641858451\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta5\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta5\";s:7:\"version\";s:11:\"2.0.0-beta5\";s:3:\"tag\";s:11:\"2.0.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta5\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1636558301\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta4\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta4\";s:7:\"version\";s:11:\"2.0.0-beta4\";s:3:\"tag\";s:11:\"2.0.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta4\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1636489464\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta3\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta3\";s:7:\"version\";s:11:\"2.0.0-beta3\";s:3:\"tag\";s:11:\"2.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1636388762\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta2\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta2\";s:7:\"version\";s:11:\"2.0.0-beta2\";s:3:\"tag\";s:11:\"2.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1635776878\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"2.0.0-beta1\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 2.0.0-beta1\";s:7:\"version\";s:11:\"2.0.0-beta1\";s:3:\"tag\";s:11:\"2.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-beta1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1631717394\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha4\";a:11:{s:4:\"name\";s:30:\"layout_paragraphs 2.0.0-alpha4\";s:7:\"version\";s:12:\"2.0.0-alpha4\";s:3:\"tag\";s:12:\"2.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-alpha4\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1626282275\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha3\";a:11:{s:4:\"name\";s:30:\"layout_paragraphs 2.0.0-alpha3\";s:7:\"version\";s:12:\"2.0.0-alpha3\";s:3:\"tag\";s:12:\"2.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-alpha3\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1626108808\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha2\";a:11:{s:4:\"name\";s:30:\"layout_paragraphs 2.0.0-alpha2\";s:7:\"version\";s:12:\"2.0.0-alpha2\";s:3:\"tag\";s:12:\"2.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-alpha2\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1624480490\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha1\";a:11:{s:4:\"name\";s:30:\"layout_paragraphs 2.0.0-alpha1\";s:7:\"version\";s:12:\"2.0.0-alpha1\";s:3:\"tag\";s:12:\"2.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.0-alpha1\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1621283252\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:23:\"layout_paragraphs 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1621524309\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta5\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 1.0.0-beta5\";s:7:\"version\";s:11:\"1.0.0-beta5\";s:3:\"tag\";s:11:\"1.0.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.0-beta5\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1614782452\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta4\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 1.0.0-beta4\";s:7:\"version\";s:11:\"1.0.0-beta4\";s:3:\"tag\";s:11:\"1.0.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.0-beta4\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1607441986\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta3\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 1.0.0-beta3\";s:7:\"version\";s:11:\"1.0.0-beta3\";s:3:\"tag\";s:11:\"1.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.0-beta3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1594929046\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta2\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 1.0.0-beta2\";s:7:\"version\";s:11:\"1.0.0-beta2\";s:3:\"tag\";s:11:\"1.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.0-beta2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1594316314\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta1\";a:11:{s:4:\"name\";s:29:\"layout_paragraphs 1.0.0-beta1\";s:7:\"version\";s:11:\"1.0.0-beta1\";s:3:\"tag\";s:11:\"1.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.0-beta1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1593994369\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:9:\"2.1.x-dev\";a:11:{s:4:\"name\";s:27:\"layout_paragraphs 2.1.x-dev\";s:7:\"version\";s:9:\"2.1.x-dev\";s:3:\"tag\";s:5:\"2.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/layout_paragraphs/releases/2.1.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1726430907\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"2.0.x-dev\";a:11:{s:4:\"name\";s:27:\"layout_paragraphs 2.0.x-dev\";s:7:\"version\";s:9:\"2.0.x-dev\";s:3:\"tag\";s:5:\"2.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/layout_paragraphs/releases/2.0.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/layout_paragraphs-2.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1724777448\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.0.x-dev\";a:11:{s:4:\"name\";s:27:\"layout_paragraphs 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/layout_paragraphs/releases/1.0.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/layout_paragraphs-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1635096355\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','link_attributes',_binary 'a:10:{s:5:\"title\";s:22:\"Link Attributes widget\";s:10:\"short_name\";s:15:\"link_attributes\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"2.1.\";s:18:\"composer_namespace\";s:22:\"drupal/link_attributes\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:46:\"https://www.drupal.org/project/link_attributes\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:25:{s:5:\"2.1.1\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.1.1\";s:7:\"version\";s:5:\"2.1.1\";s:3:\"tag\";s:5:\"2.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.1.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.1.1.tar.gz\";s:4:\"date\";s:10:\"1721366572\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:5:\"2.1.0\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.1.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1690356668\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"2.0.2\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.0.2\";s:7:\"version\";s:5:\"2.0.2\";s:3:\"tag\";s:5:\"2.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.0.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.0.2.tar.gz\";s:4:\"date\";s:10:\"1689299675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"2.0.1\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.0.1\";s:7:\"version\";s:5:\"2.0.1\";s:3:\"tag\";s:5:\"2.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.0.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.0.1.tar.gz\";s:4:\"date\";s:10:\"1689118258\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:21:\"link_attributes 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/link_attributes/releases/2.0.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/link_attributes-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1687393829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.14\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1687393687\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.13\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1677018560\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.12\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1668801560\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";s:5:\"terms\";a:0:{}}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.11\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1598323550\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:24:\"link_attributes 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.10\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1580259496\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.9\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1564012686\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.8\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1560473286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.7\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1559689681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.6\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1554334381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1537173781\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1537148883\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1526769180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1514787185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1500846243\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:23:\"link_attributes 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1481849583\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:30:\"link_attributes 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1479245341\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:30:\"link_attributes 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1467697426\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:30:\"link_attributes 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1467697426\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:23:\"link_attributes 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/link_attributes/releases/2.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/link_attributes-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721366461\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:27:\"link_attributes 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/link_attributes/releases/8.x-1.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/link_attributes-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1685694375\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','media_library_edit',_binary 'a:10:{s:5:\"title\";s:18:\"Media Library Edit\";s:10:\"short_name\";s:18:\"media_library_edit\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"3.0.\";s:18:\"composer_namespace\";s:25:\"drupal/media_library_edit\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:49:\"https://www.drupal.org/project/media_library_edit\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:15:{s:5:\"3.0.4\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.4\";s:7:\"version\";s:5:\"3.0.4\";s:3:\"tag\";s:5:\"3.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.4.tar.gz\";s:4:\"date\";s:10:\"1724357846\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"3.0.3\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.3\";s:7:\"version\";s:5:\"3.0.3\";s:3:\"tag\";s:5:\"3.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.3.tar.gz\";s:4:\"date\";s:10:\"1706394959\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.0.2\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.2\";s:7:\"version\";s:5:\"3.0.2\";s:3:\"tag\";s:5:\"3.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.2.tar.gz\";s:4:\"date\";s:10:\"1671913381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.0.1\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.1\";s:7:\"version\";s:5:\"3.0.1\";s:3:\"tag\";s:5:\"3.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.1.tar.gz\";s:4:\"date\";s:10:\"1667499767\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"3.0.0\";a:11:{s:4:\"name\";s:24:\"media_library_edit 3.0.0\";s:7:\"version\";s:5:\"3.0.0\";s:3:\"tag\";s:5:\"3.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/media_library_edit/releases/3.0.0\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.0.tar.gz\";s:4:\"date\";s:10:\"1667489719\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1653483531\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1638192802\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1634818379\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.0\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1607795681\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:26:\"media_library_edit 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/media_library_edit/releases/8.x-1.0\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1607795644\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:33:\"media_library_edit 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/media_library_edit/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1591618255\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:33:\"media_library_edit 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/media_library_edit/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1573913585\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:9:\"3.0.x-dev\";a:11:{s:4:\"name\";s:28:\"media_library_edit 3.0.x-dev\";s:7:\"version\";s:9:\"3.0.x-dev\";s:3:\"tag\";s:5:\"3.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/media_library_edit/releases/3.0.x-dev\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/media_library_edit-3.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1724357732\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:30:\"media_library_edit 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/media_library_edit/releases/8.x-2.x-dev\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1667477923\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:30:\"media_library_edit 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/media_library_edit/releases/8.x-1.x-dev\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/media_library_edit-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1593086545\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729063142;}',1729149542),('update_available_releases','media_library_form_element',_binary 'a:10:{s:5:\"title\";s:30:\"Media Library Form API Element\";s:10:\"short_name\";s:26:\"media_library_form_element\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"2.0.,2.1.\";s:18:\"composer_namespace\";s:33:\"drupal/media_library_form_element\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:57:\"https://www.drupal.org/project/media_library_form_element\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:28:{s:5:\"2.1.1\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.1.1\";s:7:\"version\";s:5:\"2.1.1\";s:3:\"tag\";s:5:\"2.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.1.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.1.1.tar.gz\";s:4:\"date\";s:10:\"1724676084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";}s:5:\"2.1.0\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.1.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1719852877\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.3\";}s:5:\"2.0.6\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.6\";s:7:\"version\";s:5:\"2.0.6\";s:3:\"tag\";s:5:\"2.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.6\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.6.tar.gz\";s:4:\"date\";s:10:\"1674048931\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.5\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.5\";s:7:\"version\";s:5:\"2.0.5\";s:3:\"tag\";s:5:\"2.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.5\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.5.tar.gz\";s:4:\"date\";s:10:\"1673542646\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.4\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.4\";s:7:\"version\";s:5:\"2.0.4\";s:3:\"tag\";s:5:\"2.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.4\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.4.tar.gz\";s:4:\"date\";s:10:\"1659257104\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"2.0.3\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.3\";s:7:\"version\";s:5:\"2.0.3\";s:3:\"tag\";s:5:\"2.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.3\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.3.tar.gz\";s:4:\"date\";s:10:\"1608021997\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"2.0.1\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.1\";s:7:\"version\";s:5:\"2.0.1\";s:3:\"tag\";s:5:\"2.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.1.tar.gz\";s:4:\"date\";s:10:\"1607696048\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1592564249\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha1\";a:11:{s:4:\"name\";s:39:\"media_library_form_element 2.0.0-alpha1\";s:7:\"version\";s:12:\"2.0.0-alpha1\";s:3:\"tag\";s:12:\"2.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:79:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.0-alpha1\";s:13:\"download_link\";s:84:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1592563784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:34:\"media_library_form_element 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.3\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1608023001\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:34:\"media_library_form_element 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.2\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1607703376\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:34:\"media_library_form_element 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.1\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1607699562\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta5\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta5\";s:7:\"version\";s:13:\"8.x-1.0-beta5\";s:3:\"tag\";s:13:\"8.x-1.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta5\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1592562569\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta4\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta4\";s:7:\"version\";s:13:\"8.x-1.0-beta4\";s:3:\"tag\";s:13:\"8.x-1.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta4\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1592560499\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1592039969\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1589988383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1588247675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha9\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha9\";s:7:\"version\";s:14:\"8.x-1.0-alpha9\";s:3:\"tag\";s:14:\"8.x-1.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha9\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1588244814\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha8\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha8\";s:7:\"version\";s:14:\"8.x-1.0-alpha8\";s:3:\"tag\";s:14:\"8.x-1.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha8\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1587107544\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha7\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha7\";s:7:\"version\";s:14:\"8.x-1.0-alpha7\";s:3:\"tag\";s:14:\"8.x-1.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha7\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1580121481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha6\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha6\";s:7:\"version\";s:14:\"8.x-1.0-alpha6\";s:3:\"tag\";s:14:\"8.x-1.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha6\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1578740587\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1578645188\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1576831688\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1576246080\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1575558480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1571816584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:34:\"media_library_form_element 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/media_library_form_element/releases/2.x-dev\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1724180723\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.3 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:38:\"media_library_form_element 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.x-dev\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1608021762\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','paragraphs',_binary 'a:10:{s:5:\"title\";s:10:\"Paragraphs\";s:10:\"short_name\";s:10:\"paragraphs\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:17:\"drupal/paragraphs\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:41:\"https://www.drupal.org/project/paragraphs\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:24:{s:8:\"8.x-1.18\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.18\";s:7:\"version\";s:8:\"8.x-1.18\";s:3:\"tag\";s:8:\"8.x-1.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.18\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.18.tar.gz\";s:4:\"date\";s:10:\"1723029144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^10.2 || ^11\";}s:8:\"8.x-1.17\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.17\";s:7:\"version\";s:8:\"8.x-1.17\";s:3:\"tag\";s:8:\"8.x-1.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.17\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.17.tar.gz\";s:4:\"date\";s:10:\"1705234146\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.16\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.16\";s:7:\"version\";s:8:\"8.x-1.16\";s:3:\"tag\";s:8:\"8.x-1.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.16\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.16.tar.gz\";s:4:\"date\";s:10:\"1694007797\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.15\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.15\";s:7:\"version\";s:8:\"8.x-1.15\";s:3:\"tag\";s:8:\"8.x-1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.15\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.15.tar.gz\";s:4:\"date\";s:10:\"1661440897\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.14\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1650520869\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.2\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1646121716\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1590061335\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1581850829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1572617586\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1565881389\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1553618281\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1553087589\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1550669584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1541001780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1540628880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1527502684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1505802544\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1487331784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1469725739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc5\";a:11:{s:4:\"name\";s:22:\"paragraphs 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1464728039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:22:\"paragraphs 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1447766339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:25:\"paragraphs 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1421889780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:25:\"paragraphs 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1421790180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:22:\"paragraphs 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1723028810\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.2 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','tb_megamenu',_binary 'a:10:{s:5:\"title\";s:20:\"The Better Mega Menu\";s:10:\"short_name\";s:11:\"tb_megamenu\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:11:\"3.0.,8.x-1.\";s:18:\"composer_namespace\";s:18:\"drupal/tb_megamenu\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/tb_megamenu\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:29:{s:12:\"3.0.0-alpha4\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 3.0.0-alpha4\";s:7:\"version\";s:12:\"3.0.0-alpha4\";s:3:\"tag\";s:12:\"3.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/3.0.0-alpha4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-3.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1713052614\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";}s:12:\"3.0.0-alpha3\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 3.0.0-alpha3\";s:7:\"version\";s:12:\"3.0.0-alpha3\";s:3:\"tag\";s:12:\"3.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/3.0.0-alpha3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-3.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1711742804\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:12:\"3.0.0-alpha2\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 3.0.0-alpha2\";s:7:\"version\";s:12:\"3.0.0-alpha2\";s:3:\"tag\";s:12:\"3.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/3.0.0-alpha2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-3.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1686707445\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"^10\";}s:12:\"3.0.0-alpha1\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 3.0.0-alpha1\";s:7:\"version\";s:12:\"3.0.0-alpha1\";s:3:\"tag\";s:12:\"3.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/3.0.0-alpha1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-3.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1686670925\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"^10\";}s:12:\"2.0.0-alpha7\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha7\";s:7:\"version\";s:12:\"2.0.0-alpha7\";s:3:\"tag\";s:12:\"2.0.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha7\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1686707356\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha6\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha6\";s:7:\"version\";s:12:\"2.0.0-alpha6\";s:3:\"tag\";s:12:\"2.0.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha6\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1686671319\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha5\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha5\";s:7:\"version\";s:12:\"2.0.0-alpha5\";s:3:\"tag\";s:12:\"2.0.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha5\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1686670725\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:12:\"2.0.0-alpha4\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha4\";s:7:\"version\";s:12:\"2.0.0-alpha4\";s:3:\"tag\";s:12:\"2.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1686090563\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";}s:12:\"2.0.0-alpha3\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha3\";s:7:\"version\";s:12:\"2.0.0-alpha3\";s:3:\"tag\";s:12:\"2.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1648217068\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha2\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha2\";s:7:\"version\";s:12:\"2.0.0-alpha2\";s:3:\"tag\";s:12:\"2.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1637335448\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha1\";a:11:{s:4:\"name\";s:24:\"tb_megamenu 2.0.0-alpha1\";s:7:\"version\";s:12:\"2.0.0-alpha1\";s:3:\"tag\";s:12:\"2.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/tb_megamenu/releases/2.0.0-alpha1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1637263588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.9\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1712869460\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.8\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1711743071\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.7\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1648215867\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1636411554\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1632512202\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1632256810\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1628694822\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1625679425\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1625676068\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1624642896\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:23:\"tb_megamenu 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1613058353\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:23:\"tb_megamenu 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1611863067\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:23:\"tb_megamenu 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1611795247\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:25:\"tb_megamenu 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1601668581\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:25:\"tb_megamenu 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1599847241\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"3.x-dev\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 3.x-dev\";s:7:\"version\";s:7:\"3.x-dev\";s:3:\"tag\";s:3:\"3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/3.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1716413185\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:19:\"tb_megamenu 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/tb_megamenu/releases/2.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/tb_megamenu-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1692374714\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"tb_megamenu 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/tb_megamenu/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/tb_megamenu-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1711725397\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:22:\"^8 || ^9 || ^10 || ^11\";}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','twig_tweak',_binary 'a:10:{s:5:\"title\";s:10:\"Twig Tweak\";s:10:\"short_name\";s:10:\"twig_tweak\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"3.3.,3.4.\";s:18:\"composer_namespace\";s:17:\"drupal/twig_tweak\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:41:\"https://www.drupal.org/project/twig_tweak\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:43:{s:5:\"3.4.0\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.4.0\";s:7:\"version\";s:5:\"3.4.0\";s:3:\"tag\";s:5:\"3.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.4.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.4.0.tar.gz\";s:4:\"date\";s:10:\"1721562308\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:5:\"3.3.0\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.3.0\";s:7:\"version\";s:5:\"3.3.0\";s:3:\"tag\";s:5:\"3.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.3.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.3.0.tar.gz\";s:4:\"date\";s:10:\"1708670116\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"3.2.1\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.2.1\";s:7:\"version\";s:5:\"3.2.1\";s:3:\"tag\";s:5:\"3.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.2.1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.2.1.tar.gz\";s:4:\"date\";s:10:\"1677404306\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"3.2.0\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.2.0\";s:7:\"version\";s:5:\"3.2.0\";s:3:\"tag\";s:5:\"3.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.2.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.2.0.tar.gz\";s:4:\"date\";s:10:\"1664084754\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:5:\"3.1.3\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.1.3\";s:7:\"version\";s:5:\"3.1.3\";s:3:\"tag\";s:5:\"3.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.1.3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.1.3.tar.gz\";s:4:\"date\";s:10:\"1635338145\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:5:\"3.1.2\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.1.2\";s:7:\"version\";s:5:\"3.1.2\";s:3:\"tag\";s:5:\"3.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.1.2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.1.2.tar.gz\";s:4:\"date\";s:10:\"1625377167\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:5:\"3.1.1\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.1.1\";s:7:\"version\";s:5:\"3.1.1\";s:3:\"tag\";s:5:\"3.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.1.1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.1.1.tar.gz\";s:4:\"date\";s:10:\"1619981432\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:5:\"3.1.0\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.1.0\";s:7:\"version\";s:5:\"3.1.0\";s:3:\"tag\";s:5:\"3.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.1.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.1.0.tar.gz\";s:4:\"date\";s:10:\"1619885672\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:5:\"3.0.0\";a:11:{s:4:\"name\";s:16:\"twig_tweak 3.0.0\";s:7:\"version\";s:5:\"3.0.0\";s:3:\"tag\";s:5:\"3.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/twig_tweak/releases/3.0.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/twig_tweak-3.0.0.tar.gz\";s:4:\"date\";s:10:\"1608096096\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:9:\"3.0.0-rc2\";a:11:{s:4:\"name\";s:20:\"twig_tweak 3.0.0-rc2\";s:7:\"version\";s:9:\"3.0.0-rc2\";s:3:\"tag\";s:9:\"3.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/twig_tweak/releases/3.0.0-rc2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/twig_tweak-3.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1599738229\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^9\";}s:9:\"3.0.0-rc1\";a:11:{s:4:\"name\";s:20:\"twig_tweak 3.0.0-rc1\";s:7:\"version\";s:9:\"3.0.0-rc1\";s:3:\"tag\";s:9:\"3.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/twig_tweak/releases/3.0.0-rc1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/twig_tweak-3.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1596039349\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^9\";}s:11:\"3.0.0-beta3\";a:11:{s:4:\"name\";s:22:\"twig_tweak 3.0.0-beta3\";s:7:\"version\";s:11:\"3.0.0-beta3\";s:3:\"tag\";s:11:\"3.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/3.0.0-beta3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-3.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1593957712\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^9\";}s:11:\"3.0.0-beta2\";a:11:{s:4:\"name\";s:22:\"twig_tweak 3.0.0-beta2\";s:7:\"version\";s:11:\"3.0.0-beta2\";s:3:\"tag\";s:11:\"3.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/3.0.0-beta2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-3.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1588828286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^9\";}s:11:\"3.0.0-beta1\";a:11:{s:4:\"name\";s:22:\"twig_tweak 3.0.0-beta1\";s:7:\"version\";s:11:\"3.0.0-beta1\";s:3:\"tag\";s:11:\"3.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/3.0.0-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-3.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1585244745\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^9\";s:5:\"terms\";a:0:{}}s:8:\"8.x-2.10\";a:11:{s:4:\"name\";s:19:\"twig_tweak 8.x-2.10\";s:7:\"version\";s:8:\"8.x-2.10\";s:3:\"tag\";s:8:\"8.x-2.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.10.tar.gz\";s:4:\"date\";s:10:\"1663947949\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.9\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.9\";s:7:\"version\";s:7:\"8.x-2.9\";s:3:\"tag\";s:7:\"8.x-2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.9.tar.gz\";s:4:\"date\";s:10:\"1608093728\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.8\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.8\";s:7:\"version\";s:7:\"8.x-2.8\";s:3:\"tag\";s:7:\"8.x-2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.8.tar.gz\";s:4:\"date\";s:10:\"1602156806\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.7\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.7\";s:7:\"version\";s:7:\"8.x-2.7\";s:3:\"tag\";s:7:\"8.x-2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.7.tar.gz\";s:4:\"date\";s:10:\"1601530189\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.6\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.6\";s:7:\"version\";s:7:\"8.x-2.6\";s:3:\"tag\";s:7:\"8.x-2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.6.tar.gz\";s:4:\"date\";s:10:\"1589992479\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.5\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.5\";s:7:\"version\";s:7:\"8.x-2.5\";s:3:\"tag\";s:7:\"8.x-2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.5.tar.gz\";s:4:\"date\";s:10:\"1583908076\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1563096785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1555516385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1555515190\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1531889025\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1523707084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc4\";a:11:{s:4:\"name\";s:22:\"twig_tweak 8.x-2.0-rc4\";s:7:\"version\";s:11:\"8.x-2.0-rc4\";s:3:\"tag\";s:11:\"8.x-2.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.0-rc4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1522232884\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc3\";a:11:{s:4:\"name\";s:22:\"twig_tweak 8.x-2.0-rc3\";s:7:\"version\";s:11:\"8.x-2.0-rc3\";s:3:\"tag\";s:11:\"8.x-2.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.0-rc3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1520442180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc2\";a:11:{s:4:\"name\";s:22:\"twig_tweak 8.x-2.0-rc2\";s:7:\"version\";s:11:\"8.x-2.0-rc2\";s:3:\"tag\";s:11:\"8.x-2.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.0-rc2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1512379985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc1\";a:11:{s:4:\"name\";s:22:\"twig_tweak 8.x-2.0-rc1\";s:7:\"version\";s:11:\"8.x-2.0-rc1\";s:3:\"tag\";s:11:\"8.x-2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.0-rc1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1505466243\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:19:\"twig_tweak 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1582883089\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1505464444\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1495984083\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1493543043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1489930083\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1484994183\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1478691840\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1472818139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1464796439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1459421432\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:18:\"twig_tweak 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1457772839\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"3.x-dev\";a:11:{s:4:\"name\";s:18:\"twig_tweak 3.x-dev\";s:7:\"version\";s:7:\"3.x-dev\";s:3:\"tag\";s:3:\"3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/twig_tweak/releases/3.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/twig_tweak-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721561383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:22:\"twig_tweak 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/8.x-2.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1664082283\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:22:\"twig_tweak 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/twig_tweak/releases/8.x-1.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/twig_tweak-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1582880828\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891),('update_available_releases','viewsreference',_binary 'a:10:{s:5:\"title\";s:21:\"Views Reference Field\";s:10:\"short_name\";s:14:\"viewsreference\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-2.\";s:18:\"composer_namespace\";s:21:\"drupal/viewsreference\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:45:\"https://www.drupal.org/project/viewsreference\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:41:{s:14:\"8.x-2.0-beta10\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-beta10\";s:7:\"version\";s:14:\"8.x-2.0-beta10\";s:3:\"tag\";s:14:\"8.x-2.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta10\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1725510905\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:13:\"8.x-2.0-beta9\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta9\";s:7:\"version\";s:13:\"8.x-2.0-beta9\";s:3:\"tag\";s:13:\"8.x-2.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta9\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1722575139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:13:\"8.x-2.0-beta8\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta8\";s:7:\"version\";s:13:\"8.x-2.0-beta8\";s:3:\"tag\";s:13:\"8.x-2.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta8\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1717030540\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:13:\"8.x-2.0-beta7\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta7\";s:7:\"version\";s:13:\"8.x-2.0-beta7\";s:3:\"tag\";s:13:\"8.x-2.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta7\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1698849225\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:13:\"8.x-2.0-beta6\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta6\";s:7:\"version\";s:13:\"8.x-2.0-beta6\";s:3:\"tag\";s:13:\"8.x-2.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta6\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1691400463\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:13:\"8.x-2.0-beta5\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta5\";s:7:\"version\";s:13:\"8.x-2.0-beta5\";s:3:\"tag\";s:13:\"8.x-2.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta5\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1691399238\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:13:\"8.x-2.0-beta4\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta4\";s:7:\"version\";s:13:\"8.x-2.0-beta4\";s:3:\"tag\";s:13:\"8.x-2.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta4\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1664821610\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:13:\"8.x-2.0-beta3\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta3\";s:7:\"version\";s:13:\"8.x-2.0-beta3\";s:3:\"tag\";s:13:\"8.x-2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta3\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1658840434\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-2.0-beta2\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta2\";s:7:\"version\";s:13:\"8.x-2.0-beta2\";s:3:\"tag\";s:13:\"8.x-2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta2\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1597235052\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-2.0-beta1\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta1\";s:7:\"version\";s:13:\"8.x-2.0-beta1\";s:3:\"tag\";s:13:\"8.x-2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1595873106\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-2.0-alpha7\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha7\";s:7:\"version\";s:14:\"8.x-2.0-alpha7\";s:3:\"tag\";s:14:\"8.x-2.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha7\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1588510059\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-2.0-alpha6\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha6\";s:7:\"version\";s:14:\"8.x-2.0-alpha6\";s:3:\"tag\";s:14:\"8.x-2.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha6\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1576373887\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha5\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha5\";s:7:\"version\";s:14:\"8.x-2.0-alpha5\";s:3:\"tag\";s:14:\"8.x-2.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha5\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1574807584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha4\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha4\";s:7:\"version\";s:14:\"8.x-2.0-alpha4\";s:3:\"tag\";s:14:\"8.x-2.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha4\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1515706384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha3\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha3\";s:7:\"version\";s:14:\"8.x-2.0-alpha3\";s:3:\"tag\";s:14:\"8.x-2.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1510927385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha2\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha2\";s:7:\"version\";s:14:\"8.x-2.0-alpha2\";s:3:\"tag\";s:14:\"8.x-2.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1508957945\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha1\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha1\";s:7:\"version\";s:14:\"8.x-2.0-alpha1\";s:3:\"tag\";s:14:\"8.x-2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1508408044\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.8\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1652694596\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.7\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1610571201\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1601529306\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1601512918\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1544740080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1544678580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1515538984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1515464888\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1502947144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1500699843\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1500437042\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1500319442\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1500074043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1497764942\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha8\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha8\";s:7:\"version\";s:14:\"8.x-1.0-alpha8\";s:3:\"tag\";s:14:\"8.x-1.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha8\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1482381184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha7\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha7\";s:7:\"version\";s:14:\"8.x-1.0-alpha7\";s:3:\"tag\";s:14:\"8.x-1.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha7\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1480293783\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha6\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha6\";s:7:\"version\";s:14:\"8.x-1.0-alpha6\";s:3:\"tag\";s:14:\"8.x-1.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha6\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1480270680\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1478134740\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1477682339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1473627239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1473283439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1473023939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1728447853\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^10 || ^11\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1691455445\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1729018491;}',1729104891);
/*!40000 ALTER TABLE `key_value_expire` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media`
--

DROP TABLE IF EXISTS `media`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media` (
  `mid` int unsigned NOT NULL AUTO_INCREMENT,
  `vid` int unsigned DEFAULT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`mid`),
  UNIQUE KEY `media_field__uuid__value` (`uuid`),
  UNIQUE KEY `media__vid` (`vid`),
  KEY `media_field__bundle__target_id` (`bundle`)
) ENGINE=InnoDB AUTO_INCREMENT=23 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for media entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media`
--

LOCK TABLES `media` WRITE;
/*!40000 ALTER TABLE `media` DISABLE KEYS */;
INSERT INTO `media` VALUES (1,1,'remote_video','09297b09-7e0f-4d3a-864c-a0cf5ab5350d','en'),(2,2,'image','0ad232e1-6107-4310-92c9-244c2bf555aa','en'),(3,3,'image','ecab1c87-0a5c-4eed-a4f8-8f75e26e209e','en'),(4,12,'image','e2688481-96fe-4e19-b8e0-5457b039e0c0','en'),(5,9,'image','c9674f24-0ae0-4b53-9471-b5b149c3e88b','en'),(6,10,'image','bcf6c7ff-7630-4757-8b1f-b63e327e82ef','en'),(7,11,'image','676d1c54-c3e2-425e-adde-d8205fde923e','en'),(8,13,'image','ccaa30f4-5032-4a50-be23-4cc574744493','en'),(9,14,'image','e087dd7a-cc44-4f25-bc04-76a7099eb5d6','en'),(10,15,'image','d521e7ca-5721-42ac-bf99-3393a2fa4ac8','en'),(11,16,'image','7aa39db3-5814-472b-b6ab-1b501a760f6e','en'),(12,17,'image','41e00732-a437-49d8-b8e2-078a9d1b0a32','en'),(13,18,'image','438b954b-bb63-469c-979c-5a5a14b53cfb','en'),(14,19,'image','28e6f9a8-1a9c-4020-8559-358e13575d33','en'),(15,20,'image','b5ffa8a9-e530-4537-86c3-8c5891fffb13','en'),(16,21,'image','6f51e936-b5c5-442c-b595-1c62afe53218','en'),(17,22,'image','097c4f46-932a-4f71-a580-7e0914bb0b25','en'),(18,23,'image','9ef37388-d32b-44ae-8954-3ae90ba6d589','en'),(19,25,'image','ee25d426-f054-4126-af7f-0b51834d0c81','en'),(20,26,'image','fe1311cb-0d4a-4ae3-9bfc-f9d5072d5110','en'),(21,27,'image','a94fd233-d617-4213-aadc-4d2c1cd994e2','en'),(22,28,'image','fa386fe6-9acc-488d-99ec-455f693c45eb','en');
/*!40000 ALTER TABLE `media` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media__field_media_audio_file`
--

DROP TABLE IF EXISTS `media__field_media_audio_file`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media__field_media_audio_file` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_audio_file_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_audio_file_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_audio_file_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_audio_file_target_id` (`field_media_audio_file_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_audio_file.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media__field_media_audio_file`
--

LOCK TABLES `media__field_media_audio_file` WRITE;
/*!40000 ALTER TABLE `media__field_media_audio_file` DISABLE KEYS */;
/*!40000 ALTER TABLE `media__field_media_audio_file` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media__field_media_document`
--

DROP TABLE IF EXISTS `media__field_media_document`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media__field_media_document` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_document_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_document_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_document_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_document_target_id` (`field_media_document_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_document.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media__field_media_document`
--

LOCK TABLES `media__field_media_document` WRITE;
/*!40000 ALTER TABLE `media__field_media_document` DISABLE KEYS */;
/*!40000 ALTER TABLE `media__field_media_document` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media__field_media_image`
--

DROP TABLE IF EXISTS `media__field_media_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media__field_media_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_media_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_media_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_media_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_image_target_id` (`field_media_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media__field_media_image`
--

LOCK TABLES `media__field_media_image` WRITE;
/*!40000 ALTER TABLE `media__field_media_image` DISABLE KEYS */;
INSERT INTO `media__field_media_image` VALUES ('image',0,2,2,'en',0,3,'bubbles 1','',1024,1024),('image',0,3,3,'en',0,4,'Bubbles 1','',826,831),('image',0,4,12,'en',0,5,'Extra Paragraph Types (EPT): Image Gallery','',632,405),('image',0,5,9,'en',0,6,'Extra Paragraph Types (EPT): Accordion','',440,415),('image',0,6,10,'en',0,7,'Extra Paragraph Types (EPT): Call to Action','',661,300),('image',0,7,11,'en',0,8,'Extra Paragraph Types (EPT): Tabs','',503,206),('image',0,8,13,'en',0,9,'bubbles 2','',1024,1024),('image',0,9,14,'en',0,10,'Extra Paragraph Types (EPT): Slick Slider','',1270,500),('image',0,10,15,'en',0,11,'Extra Paragraph Types (EPT): Carousel','',887,348),('image',0,11,16,'en',0,12,'Extra Paragraph Types (EPT): Slideshow','',947,652),('image',0,12,17,'en',0,13,'Extra Paragraph Types (EPT): Quote','',639,299),('image',0,13,18,'en',0,14,'Extra Paragraph Types (EPT): Tiles','',1186,615),('image',0,14,19,'en',0,15,'Extra Paragraph Types (EPT): Text','',1108,269),('image',0,15,20,'en',0,16,'Extra Block Types (EBT): Counter','',800,360),('image',0,16,21,'en',0,17,'GLightbox','',569,267),('image',0,17,22,'en',0,18,'Dark drop','',1280,777),('image',0,18,23,'en',0,19,'Footbal club','',1494,739),('image',0,19,25,'en',0,21,'bubbles 3','',1024,1024),('image',0,20,26,'en',0,22,'DOM Box','',1913,1049),('image',0,21,27,'en',0,23,'Background color, image or video','',1092,821),('image',0,22,28,'en',0,24,'Javascript plugins','',842,802);
/*!40000 ALTER TABLE `media__field_media_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media__field_media_oembed_video`
--

DROP TABLE IF EXISTS `media__field_media_oembed_video`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media__field_media_oembed_video` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_oembed_video_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_oembed_video.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media__field_media_oembed_video`
--

LOCK TABLES `media__field_media_oembed_video` WRITE;
/*!40000 ALTER TABLE `media__field_media_oembed_video` DISABLE KEYS */;
INSERT INTO `media__field_media_oembed_video` VALUES ('remote_video',0,1,1,'en',0,'https://youtu.be/zbdI7ugf6B8');
/*!40000 ALTER TABLE `media__field_media_oembed_video` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media__field_media_video_file`
--

DROP TABLE IF EXISTS `media__field_media_video_file`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media__field_media_video_file` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_video_file_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_video_file_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_video_file_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_video_file_target_id` (`field_media_video_file_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_video_file.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media__field_media_video_file`
--

LOCK TABLES `media__field_media_video_file` WRITE;
/*!40000 ALTER TABLE `media__field_media_video_file` DISABLE KEYS */;
/*!40000 ALTER TABLE `media__field_media_video_file` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_field_data`
--

DROP TABLE IF EXISTS `media_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_field_data` (
  `mid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `name` varchar(255) DEFAULT NULL,
  `thumbnail__target_id` int unsigned DEFAULT NULL COMMENT 'The ID of the file entity.',
  `thumbnail__alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `thumbnail__title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `thumbnail__width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `thumbnail__height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  `created` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`mid`,`langcode`),
  KEY `media__id__default_langcode__langcode` (`mid`,`default_langcode`,`langcode`),
  KEY `media__vid` (`vid`),
  KEY `media_field__bundle__target_id` (`bundle`),
  KEY `media_field__uid__target_id` (`uid`),
  KEY `media_field__thumbnail__target_id` (`thumbnail__target_id`),
  KEY `media__status_bundle` (`status`,`bundle`,`mid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for media entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_field_data`
--

LOCK TABLES `media_field_data` WRITE;
/*!40000 ALTER TABLE `media_field_data` DISABLE KEYS */;
INSERT INTO `media_field_data` VALUES (1,1,'remote_video','en',1,1,'What\'s DrupalCon All About?',2,'',NULL,480,360,1728242872,1728242872,1,1),(2,2,'image','en',1,1,'333b8c43-dbee-469a-8766-c302f74bb595.jpg',3,'bubbles 1',NULL,1024,1024,1728819558,1728819558,1,1),(3,3,'image','en',1,1,'bg-image1.webp',4,'Bubbles 1',NULL,826,831,1728883281,1728883281,1,1),(4,12,'image','en',1,1,'fluid_grid_1.webp',5,'Fluid grid image gallery',NULL,632,405,1728884475,1728885349,1,1),(5,9,'image','en',1,1,'faq example.webp',6,'FAQ example',NULL,440,415,1728884651,1728885288,1,1),(6,10,'image','en',1,1,'2 columns CTA.webp',7,'2 Columns CTA',NULL,661,300,1728884846,1728885310,1,1),(7,11,'image','en',1,1,'EBT Tabs.webp',8,'EBT Tabs',NULL,503,206,1728885156,1728885331,1,1),(8,13,'image','en',1,1,'8af0c440-2152-4678-86c7-95ee5c055211.jpg',9,'bubbles 2',NULL,1024,1024,1728885422,1728885422,1,1),(9,14,'image','en',1,1,'ept-slick-slider.webp',10,'Extra Paragraph Types (EPT): Slick Slider',NULL,1270,500,1728885872,1728885872,1,1),(10,15,'image','en',1,1,'ebt carousel.webp',11,'Extra Paragraph Types (EPT): Carousel',NULL,887,348,1728887601,1728887601,1,1),(11,16,'image','en',1,1,'Home-Drupal-9_0.webp',12,'Extra Paragraph Types (EPT): Slideshow',NULL,947,652,1728887677,1728887677,1,1),(12,17,'image','en',1,1,'with_square_img_0.webp',13,'Extra Paragraph Types (EPT): Quote',NULL,639,299,1728887791,1728887791,1,1),(13,18,'image','en',1,1,'ept tiles.webp',14,'Extra Paragraph Types (EPT): Tiles',NULL,1186,615,1728887900,1728887900,1,1),(14,19,'image','en',1,1,'EPT text.webp',15,'Extra Paragraph Types (EPT): Text',NULL,1108,269,1728888003,1728888003,1,1),(15,20,'image','en',1,1,'ept counter.webp',16,'Extra Block Types (EBT): Counter',NULL,800,360,1728888321,1728888321,1,1),(16,21,'image','en',1,1,'glightbox.webp',17,'GLightbox',NULL,569,267,1728888670,1728888670,1,1),(17,22,'image','en',1,1,'dark drop.webp',18,'Dark drop',NULL,1280,777,1728889183,1728889183,1,1),(18,23,'image','en',1,1,'ept case.webp',19,'Footbal club',NULL,1494,739,1728933322,1728933322,1,1),(19,25,'image','en',1,1,'4950565d-af48-45ef-be68-c27550a02da9.webp',21,'bubbles 3',NULL,1024,1024,1728934033,1728935148,1,1),(20,26,'image','en',1,1,'DOM Box.webp',22,'DOM Box',NULL,1913,1049,1728936151,1728936151,1,1),(21,27,'image','en',1,1,'background image or video.webp',23,'Background color, image or video',NULL,1092,821,1728936355,1728936355,1,1),(22,28,'image','en',1,1,'javascript plugins.webp',24,'Javascript plugins',NULL,842,802,1728936556,1728936556,1,1);
/*!40000 ALTER TABLE `media_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_field_revision`
--

DROP TABLE IF EXISTS `media_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_field_revision` (
  `mid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `name` varchar(255) DEFAULT NULL,
  `thumbnail__target_id` int unsigned DEFAULT NULL COMMENT 'The ID of the file entity.',
  `thumbnail__alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `thumbnail__title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `thumbnail__width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `thumbnail__height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  `created` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`,`langcode`),
  KEY `media__id__default_langcode__langcode` (`mid`,`default_langcode`,`langcode`),
  KEY `media_field__uid__target_id` (`uid`),
  KEY `media_field__thumbnail__target_id` (`thumbnail__target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for media entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_field_revision`
--

LOCK TABLES `media_field_revision` WRITE;
/*!40000 ALTER TABLE `media_field_revision` DISABLE KEYS */;
INSERT INTO `media_field_revision` VALUES (1,1,'en',1,1,'What\'s DrupalCon All About?',2,'',NULL,480,360,1728242872,1728242872,1,1),(2,2,'en',1,1,'333b8c43-dbee-469a-8766-c302f74bb595.jpg',3,'bubbles 1',NULL,1024,1024,1728819558,1728819558,1,1),(3,3,'en',1,1,'bg-image1.webp',4,'Bubbles 1',NULL,826,831,1728883281,1728883281,1,1),(4,4,'en',1,1,'fluid_grid_1.webp',5,'Fluid grid image gallery',NULL,632,405,1728884475,1728884475,1,1),(5,5,'en',1,1,'faq example.webp',6,'FAQ example',NULL,440,415,1728884651,1728884651,1,1),(6,6,'en',1,1,'2 columns CTA.webp',7,'2 Columns CTA',NULL,661,300,1728884846,1728884846,1,1),(7,7,'en',1,1,'EBT Tabs.webp',8,'EBT Tabs',NULL,503,206,1728885156,1728885156,1,1),(4,8,'en',1,1,'fluid_grid_1.webp',5,'Fluid grid image gallery',NULL,632,405,1728884475,1728885249,1,1),(5,9,'en',1,1,'faq example.webp',6,'FAQ example',NULL,440,415,1728884651,1728885288,1,1),(6,10,'en',1,1,'2 columns CTA.webp',7,'2 Columns CTA',NULL,661,300,1728884846,1728885310,1,1),(7,11,'en',1,1,'EBT Tabs.webp',8,'EBT Tabs',NULL,503,206,1728885156,1728885331,1,1),(4,12,'en',1,1,'fluid_grid_1.webp',5,'Fluid grid image gallery',NULL,632,405,1728884475,1728885349,1,1),(8,13,'en',1,1,'8af0c440-2152-4678-86c7-95ee5c055211.jpg',9,'bubbles 2',NULL,1024,1024,1728885422,1728885422,1,1),(9,14,'en',1,1,'ept-slick-slider.webp',10,'Extra Paragraph Types (EPT): Slick Slider',NULL,1270,500,1728885872,1728885872,1,1),(10,15,'en',1,1,'ebt carousel.webp',11,'Extra Paragraph Types (EPT): Carousel',NULL,887,348,1728887601,1728887601,1,1),(11,16,'en',1,1,'Home-Drupal-9_0.webp',12,'Extra Paragraph Types (EPT): Slideshow',NULL,947,652,1728887677,1728887677,1,1),(12,17,'en',1,1,'with_square_img_0.webp',13,'Extra Paragraph Types (EPT): Quote',NULL,639,299,1728887791,1728887791,1,1),(13,18,'en',1,1,'ept tiles.webp',14,'Extra Paragraph Types (EPT): Tiles',NULL,1186,615,1728887900,1728887900,1,1),(14,19,'en',1,1,'EPT text.webp',15,'Extra Paragraph Types (EPT): Text',NULL,1108,269,1728888003,1728888003,1,1),(15,20,'en',1,1,'ept counter.webp',16,'Extra Block Types (EBT): Counter',NULL,800,360,1728888321,1728888321,1,1),(16,21,'en',1,1,'glightbox.webp',17,'GLightbox',NULL,569,267,1728888670,1728888670,1,1),(17,22,'en',1,1,'dark drop.webp',18,'Dark drop',NULL,1280,777,1728889183,1728889183,1,1),(18,23,'en',1,1,'ept case.webp',19,'Footbal club',NULL,1494,739,1728933322,1728933322,1,1),(19,24,'en',1,1,'4950565d-af48-45ef-be68-c27550a02da9.jpg',20,'bubbles 3',NULL,1024,1024,1728934033,1728934033,1,1),(19,25,'en',1,1,'4950565d-af48-45ef-be68-c27550a02da9.webp',21,'bubbles 3',NULL,1024,1024,1728934033,1728935148,1,1),(20,26,'en',1,1,'DOM Box.webp',22,'DOM Box',NULL,1913,1049,1728936151,1728936151,1,1),(21,27,'en',1,1,'background image or video.webp',23,'Background color, image or video',NULL,1092,821,1728936355,1728936355,1,1),(22,28,'en',1,1,'javascript plugins.webp',24,'Javascript plugins',NULL,842,802,1728936556,1728936556,1,1);
/*!40000 ALTER TABLE `media_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_revision`
--

DROP TABLE IF EXISTS `media_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_revision` (
  `mid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log_message` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`),
  KEY `media__mid` (`mid`),
  KEY `media_field__revision_user__target_id` (`revision_user`)
) ENGINE=InnoDB AUTO_INCREMENT=29 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for media entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_revision`
--

LOCK TABLES `media_revision` WRITE;
/*!40000 ALTER TABLE `media_revision` DISABLE KEYS */;
INSERT INTO `media_revision` VALUES (1,1,'en',NULL,1728242872,NULL,1),(2,2,'en',NULL,1728819558,NULL,1),(3,3,'en',NULL,1728883281,NULL,1),(4,4,'en',NULL,1728884475,NULL,1),(5,5,'en',NULL,1728884651,NULL,1),(6,6,'en',NULL,1728884846,NULL,1),(7,7,'en',NULL,1728885156,NULL,1),(4,8,'en',1,1728885249,NULL,1),(5,9,'en',1,1728885288,NULL,1),(6,10,'en',1,1728885310,NULL,1),(7,11,'en',1,1728885331,NULL,1),(4,12,'en',1,1728885349,NULL,1),(8,13,'en',NULL,1728885422,NULL,1),(9,14,'en',NULL,1728885872,NULL,1),(10,15,'en',NULL,1728887601,NULL,1),(11,16,'en',NULL,1728887677,NULL,1),(12,17,'en',NULL,1728887791,NULL,1),(13,18,'en',NULL,1728887900,NULL,1),(14,19,'en',NULL,1728888003,NULL,1),(15,20,'en',NULL,1728888321,NULL,1),(16,21,'en',NULL,1728888670,NULL,1),(17,22,'en',NULL,1728889183,NULL,1),(18,23,'en',NULL,1728933322,NULL,1),(19,24,'en',NULL,1728934033,NULL,1),(19,25,'en',1,1728935148,NULL,1),(20,26,'en',NULL,1728936151,NULL,1),(21,27,'en',NULL,1728936355,NULL,1),(22,28,'en',NULL,1728936556,NULL,1);
/*!40000 ALTER TABLE `media_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_revision__field_media_audio_file`
--

DROP TABLE IF EXISTS `media_revision__field_media_audio_file`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_revision__field_media_audio_file` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_audio_file_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_audio_file_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_audio_file_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_audio_file_target_id` (`field_media_audio_file_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media_audio…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_revision__field_media_audio_file`
--

LOCK TABLES `media_revision__field_media_audio_file` WRITE;
/*!40000 ALTER TABLE `media_revision__field_media_audio_file` DISABLE KEYS */;
/*!40000 ALTER TABLE `media_revision__field_media_audio_file` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_revision__field_media_document`
--

DROP TABLE IF EXISTS `media_revision__field_media_document`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_revision__field_media_document` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_document_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_document_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_document_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_document_target_id` (`field_media_document_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_revision__field_media_document`
--

LOCK TABLES `media_revision__field_media_document` WRITE;
/*!40000 ALTER TABLE `media_revision__field_media_document` DISABLE KEYS */;
/*!40000 ALTER TABLE `media_revision__field_media_document` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_revision__field_media_image`
--

DROP TABLE IF EXISTS `media_revision__field_media_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_revision__field_media_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_media_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_media_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_media_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_image_target_id` (`field_media_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_revision__field_media_image`
--

LOCK TABLES `media_revision__field_media_image` WRITE;
/*!40000 ALTER TABLE `media_revision__field_media_image` DISABLE KEYS */;
INSERT INTO `media_revision__field_media_image` VALUES ('image',0,2,2,'en',0,3,'bubbles 1','',1024,1024),('image',0,3,3,'en',0,4,'Bubbles 1','',826,831),('image',0,4,4,'en',0,5,'Fluid grid image gallery','',632,405),('image',0,4,8,'en',0,5,'EPT Image Gallery','',632,405),('image',0,4,12,'en',0,5,'Extra Paragraph Types (EPT): Image Gallery','',632,405),('image',0,5,5,'en',0,6,'FAQ example','',440,415),('image',0,5,9,'en',0,6,'Extra Paragraph Types (EPT): Accordion','',440,415),('image',0,6,6,'en',0,7,'2 Columns CTA','',661,300),('image',0,6,10,'en',0,7,'Extra Paragraph Types (EPT): Call to Action','',661,300),('image',0,7,7,'en',0,8,'EBT Tabs','',503,206),('image',0,7,11,'en',0,8,'Extra Paragraph Types (EPT): Tabs','',503,206),('image',0,8,13,'en',0,9,'bubbles 2','',1024,1024),('image',0,9,14,'en',0,10,'Extra Paragraph Types (EPT): Slick Slider','',1270,500),('image',0,10,15,'en',0,11,'Extra Paragraph Types (EPT): Carousel','',887,348),('image',0,11,16,'en',0,12,'Extra Paragraph Types (EPT): Slideshow','',947,652),('image',0,12,17,'en',0,13,'Extra Paragraph Types (EPT): Quote','',639,299),('image',0,13,18,'en',0,14,'Extra Paragraph Types (EPT): Tiles','',1186,615),('image',0,14,19,'en',0,15,'Extra Paragraph Types (EPT): Text','',1108,269),('image',0,15,20,'en',0,16,'Extra Block Types (EBT): Counter','',800,360),('image',0,16,21,'en',0,17,'GLightbox','',569,267),('image',0,17,22,'en',0,18,'Dark drop','',1280,777),('image',0,18,23,'en',0,19,'Footbal club','',1494,739),('image',0,19,24,'en',0,20,'bubbles 3','',1024,1024),('image',0,19,25,'en',0,21,'bubbles 3','',1024,1024),('image',0,20,26,'en',0,22,'DOM Box','',1913,1049),('image',0,21,27,'en',0,23,'Background color, image or video','',1092,821),('image',0,22,28,'en',0,24,'Javascript plugins','',842,802);
/*!40000 ALTER TABLE `media_revision__field_media_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_revision__field_media_oembed_video`
--

DROP TABLE IF EXISTS `media_revision__field_media_oembed_video`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_revision__field_media_oembed_video` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_oembed_video_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media_oembed…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_revision__field_media_oembed_video`
--

LOCK TABLES `media_revision__field_media_oembed_video` WRITE;
/*!40000 ALTER TABLE `media_revision__field_media_oembed_video` DISABLE KEYS */;
INSERT INTO `media_revision__field_media_oembed_video` VALUES ('remote_video',0,1,1,'en',0,'https://youtu.be/zbdI7ugf6B8');
/*!40000 ALTER TABLE `media_revision__field_media_oembed_video` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `media_revision__field_media_video_file`
--

DROP TABLE IF EXISTS `media_revision__field_media_video_file`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `media_revision__field_media_video_file` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_video_file_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_video_file_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_video_file_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_video_file_target_id` (`field_media_video_file_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media_video…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `media_revision__field_media_video_file`
--

LOCK TABLES `media_revision__field_media_video_file` WRITE;
/*!40000 ALTER TABLE `media_revision__field_media_video_file` DISABLE KEYS */;
/*!40000 ALTER TABLE `media_revision__field_media_video_file` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_link_content`
--

DROP TABLE IF EXISTS `menu_link_content`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_link_content` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `menu_link_content_field__uuid__value` (`uuid`),
  UNIQUE KEY `menu_link_content__revision_id` (`revision_id`)
) ENGINE=InnoDB AUTO_INCREMENT=15 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for menu_link_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_link_content`
--

LOCK TABLES `menu_link_content` WRITE;
/*!40000 ALTER TABLE `menu_link_content` DISABLE KEYS */;
INSERT INTO `menu_link_content` VALUES (1,1,'menu_link_content','d5043c53-9961-4a60-bb2a-a37bbaaa3961','en'),(3,3,'menu_link_content','9618e6db-485e-4fa0-84d3-b56e8936ef0d','en'),(4,4,'menu_link_content','9a831874-a895-4cc7-ac58-2de2055f7c4b','en'),(5,5,'menu_link_content','60ff628e-4af5-44f0-af2a-8bd88c057b15','en'),(6,6,'menu_link_content','0cdaaebf-f931-4b2e-a1ed-fed2026812e5','en'),(7,7,'menu_link_content','c099779d-431c-4fb8-831c-02e395b960b7','en'),(8,8,'menu_link_content','5ddd00be-7fb0-4648-8176-b3cdf1a8fbff','en'),(9,9,'menu_link_content','86cc3040-af4c-4f8b-901a-c9c517ae0ab6','en'),(10,10,'menu_link_content','f7dcb4f3-cc8d-40eb-944e-073aea38aad3','en'),(11,11,'menu_link_content','b7aae8ff-5c43-4ae2-a08a-7fec98be2568','en'),(12,12,'menu_link_content','99f46f29-6f08-4218-8291-d84b7e07ab0d','en'),(13,13,'menu_link_content','fa9e2736-9b20-41fa-9e2c-c19aad723aab','en'),(14,14,'menu_link_content','10f330e8-9bde-4bb7-a57c-c1f39e9a02fd','en');
/*!40000 ALTER TABLE `menu_link_content` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_link_content_data`
--

DROP TABLE IF EXISTS `menu_link_content_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_link_content_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `enabled` tinyint NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `description` varchar(255) DEFAULT NULL,
  `menu_name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `external` tinyint DEFAULT NULL,
  `rediscover` tinyint DEFAULT NULL,
  `weight` int DEFAULT NULL,
  `expanded` tinyint DEFAULT NULL,
  `parent` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `menu_link_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `menu_link_content__revision_id` (`revision_id`),
  KEY `menu_link_content_field__link__uri` (`link__uri`(30)),
  KEY `menu_link_content__enabled_bundle` (`enabled`,`bundle`,`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for menu_link_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_link_content_data`
--

LOCK TABLES `menu_link_content_data` WRITE;
/*!40000 ALTER TABLE `menu_link_content_data` DISABLE KEYS */;
INSERT INTO `menu_link_content_data` VALUES (1,1,'menu_link_content','en',0,'EPT modules',NULL,'main','https://www.drupal.org/project/ept_core','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-47,1,NULL,1729064670,1,1),(3,3,'menu_link_content','en',1,'LinkedIn',NULL,'footer','https://www.linkedin.com/in/ivan-abramenko/','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-49,0,NULL,1729021239,1,1),(4,4,'menu_link_content','en',1,'DrupalBook',NULL,'footer','https://drupalbook.org/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-46,0,NULL,1729021177,1,1),(5,5,'menu_link_content','en',1,'Drupal.org',NULL,'footer','https://www.drupal.org/user/1079574/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-48,0,NULL,1729021243,1,1),(6,6,'menu_link_content','en',1,'LinkedIn',NULL,'account','https://www.linkedin.com/in/ivan-abramenko/','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,0,0,NULL,1729020965,1,1),(7,7,'menu_link_content','en',1,'Drupal.org',NULL,'account','https://www.drupal.org/user/1079574/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,0,0,NULL,1729021101,1,1),(8,8,'menu_link_content','en',1,'Slack',NULL,'account','https://drupal.slack.com/archives/C07A942U72P','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,0,0,NULL,1729021132,1,1),(9,9,'menu_link_content','en',1,'Slack',NULL,'footer','https://drupal.slack.com/archives/C07A942U72P','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-47,0,NULL,1729021177,1,1),(10,10,'menu_link_content','en',1,'DrupalBook',NULL,'account','https://drupalbook.org/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,0,0,NULL,1729021302,1,1),(11,11,'menu_link_content','en',0,'EBT Modules',NULL,'main','https://www.drupal.org/project/ebt_core','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:5:\"_self\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-46,0,NULL,1729064670,1,1),(12,12,'menu_link_content','en',1,'Documentation',NULL,'main','https://drupalbook.org/ept/demo','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-45,0,NULL,1729064670,1,1),(13,13,'menu_link_content','en',1,'Listing Page',NULL,'main','entity:node/19','',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,0,-48,0,NULL,1729064670,1,1),(14,14,'menu_link_content','en',1,'Landing Page',NULL,'main','internal:/','',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1,-49,0,NULL,1729064670,1,1);
/*!40000 ALTER TABLE `menu_link_content_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_link_content_field_revision`
--

DROP TABLE IF EXISTS `menu_link_content_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_link_content_field_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `enabled` tinyint NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `description` varchar(255) DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `external` tinyint DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `menu_link_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `menu_link_content_field__link__uri` (`link__uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for menu_link_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_link_content_field_revision`
--

LOCK TABLES `menu_link_content_field_revision` WRITE;
/*!40000 ALTER TABLE `menu_link_content_field_revision` DISABLE KEYS */;
INSERT INTO `menu_link_content_field_revision` VALUES (1,1,'en',0,'EPT modules',NULL,'https://www.drupal.org/project/ept_core','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729064670,1,1),(3,3,'en',1,'LinkedIn',NULL,'https://www.linkedin.com/in/ivan-abramenko/','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021239,1,1),(4,4,'en',1,'DrupalBook',NULL,'https://drupalbook.org/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021177,1,1),(5,5,'en',1,'Drupal.org',NULL,'https://www.drupal.org/user/1079574/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021243,1,1),(6,6,'en',1,'LinkedIn',NULL,'https://www.linkedin.com/in/ivan-abramenko/','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729020965,1,1),(7,7,'en',1,'Drupal.org',NULL,'https://www.drupal.org/user/1079574/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021101,1,1),(8,8,'en',1,'Slack',NULL,'https://drupal.slack.com/archives/C07A942U72P','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021132,1,1),(9,9,'en',1,'Slack',NULL,'https://drupal.slack.com/archives/C07A942U72P','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021177,1,1),(10,10,'en',1,'DrupalBook',NULL,'https://drupalbook.org/contact','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729021302,1,1),(11,11,'en',0,'EBT Modules',NULL,'https://www.drupal.org/project/ebt_core','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:5:\"_self\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729064670,1,1),(12,12,'en',1,'Documentation',NULL,'https://drupalbook.org/ept/demo','',_binary 'a:1:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729064670,1,1),(13,13,'en',1,'Listing Page',NULL,'entity:node/19','',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729064670,1,1),(14,14,'en',1,'Landing Page',NULL,'internal:/','',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}',0,1729064670,1,1);
/*!40000 ALTER TABLE `menu_link_content_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_link_content_revision`
--

DROP TABLE IF EXISTS `menu_link_content_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_link_content_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log_message` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `menu_link_content__id` (`id`),
  KEY `menu_link_content__ef029a1897` (`revision_user`)
) ENGINE=InnoDB AUTO_INCREMENT=15 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for menu_link_content entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_link_content_revision`
--

LOCK TABLES `menu_link_content_revision` WRITE;
/*!40000 ALTER TABLE `menu_link_content_revision` DISABLE KEYS */;
INSERT INTO `menu_link_content_revision` VALUES (1,1,'en',NULL,1728554708,NULL,1),(3,3,'en',NULL,1729020303,NULL,1),(4,4,'en',NULL,1729020367,NULL,1),(5,5,'en',NULL,1729020511,NULL,1),(6,6,'en',NULL,1729020965,NULL,1),(7,7,'en',NULL,1729021084,NULL,1),(8,8,'en',NULL,1729021132,NULL,1),(9,9,'en',NULL,1729021168,NULL,1),(10,10,'en',NULL,1729021302,NULL,1),(11,11,'en',NULL,1729021388,NULL,1),(12,12,'en',NULL,1729023766,NULL,1),(13,13,'en',NULL,1729064625,NULL,1),(14,14,'en',NULL,1729064649,NULL,1);
/*!40000 ALTER TABLE `menu_link_content_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `menu_tree`
--

DROP TABLE IF EXISTS `menu_tree`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `menu_tree` (
  `menu_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The menu name. All links with the same menu name (such as ''tools'') are part of the same menu.',
  `mlid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'The menu link ID (mlid) is the integer primary key.',
  `id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'Unique machine name: the plugin ID.',
  `parent` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The plugin ID for the parent of this link.',
  `route_name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The machine name of a defined Symfony Route this menu link represents.',
  `route_param_key` varchar(255) DEFAULT NULL COMMENT 'An encoded string of route parameters for loading by route.',
  `route_parameters` longblob COMMENT 'Serialized array of route parameters of this menu link.',
  `url` varchar(255) NOT NULL DEFAULT '' COMMENT 'The external path this link points to (when not using a route).',
  `title` longblob COMMENT 'The serialized title for the link. May be a TranslatableMarkup.',
  `description` longblob COMMENT 'The serialized description of this link - used for admin pages and title attribute. May be a TranslatableMarkup.',
  `class` text COMMENT 'The class for this link plugin.',
  `options` longblob COMMENT 'A serialized array of URL options, such as a query string or HTML attributes.',
  `provider` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT 'system' COMMENT 'The name of the module that generated this link.',
  `enabled` smallint NOT NULL DEFAULT '1' COMMENT 'A flag for whether the link should be rendered in menus. (0 = a disabled menu link that may be shown on admin screens, 1 = a normal, visible link)',
  `discovered` smallint NOT NULL DEFAULT '0' COMMENT 'A flag for whether the link was discovered, so can be purged on rebuild',
  `expanded` smallint NOT NULL DEFAULT '0' COMMENT 'Flag for whether this link should be rendered as expanded in menus - expanded links always have their child links displayed, instead of only when the link is in the active trail (1 = expanded, 0 = not expanded)',
  `weight` int NOT NULL DEFAULT '0' COMMENT 'Link weight among links in the same menu at the same depth.',
  `metadata` longblob COMMENT 'A serialized array of data that may be used by the plugin instance.',
  `has_children` smallint NOT NULL DEFAULT '0' COMMENT 'Flag indicating whether any enabled links have this link as a parent (1 = enabled children exist, 0 = no enabled children).',
  `depth` smallint NOT NULL DEFAULT '0' COMMENT 'The depth relative to the top level. A link with empty parent will have depth == 1.',
  `p1` int unsigned NOT NULL DEFAULT '0' COMMENT 'The first mlid in the materialized path. If N = depth, then pN must equal the mlid. If depth > 1 then p(N-1) must equal the parent link mlid. All pX where X > depth must equal zero. The columns p1 .. p9 are also called the parents.',
  `p2` int unsigned NOT NULL DEFAULT '0' COMMENT 'The second mlid in the materialized path. See p1.',
  `p3` int unsigned NOT NULL DEFAULT '0' COMMENT 'The third mlid in the materialized path. See p1.',
  `p4` int unsigned NOT NULL DEFAULT '0' COMMENT 'The fourth mlid in the materialized path. See p1.',
  `p5` int unsigned NOT NULL DEFAULT '0' COMMENT 'The fifth mlid in the materialized path. See p1.',
  `p6` int unsigned NOT NULL DEFAULT '0' COMMENT 'The sixth mlid in the materialized path. See p1.',
  `p7` int unsigned NOT NULL DEFAULT '0' COMMENT 'The seventh mlid in the materialized path. See p1.',
  `p8` int unsigned NOT NULL DEFAULT '0' COMMENT 'The eighth mlid in the materialized path. See p1.',
  `p9` int unsigned NOT NULL DEFAULT '0' COMMENT 'The ninth mlid in the materialized path. See p1.',
  `form_class` varchar(255) DEFAULT NULL COMMENT 'meh',
  PRIMARY KEY (`mlid`),
  UNIQUE KEY `id` (`id`),
  KEY `menu_parents` (`menu_name`,`p1`,`p2`,`p3`,`p4`,`p5`,`p6`,`p7`,`p8`,`p9`),
  KEY `menu_parent_expand_child` (`menu_name`,`expanded`,`has_children`,`parent`(16)),
  KEY `route_values` (`route_name`(32),`route_param_key`(16))
) ENGINE=InnoDB AUTO_INCREMENT=366 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Contains the menu tree hierarchy.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `menu_tree`
--

LOCK TABLES `menu_tree` WRITE;
/*!40000 ALTER TABLE `menu_tree` DISABLE KEYS */;
INSERT INTO `menu_tree` VALUES ('footer',1,'contact.site_page','','contact.site_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Contact\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','contact',0,1,0,-50,_binary 'a:0:{}',0,1,1,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('tools',2,'filter.tips_all','','filter.tips_all','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Compose tips\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','filter',0,1,0,0,_binary 'a:0:{}',0,1,2,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('tools',3,'node.add_page','','node.add_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Add content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','node',1,1,0,0,_binary 'a:0:{}',0,1,3,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('tools',4,'search.view','','search.view','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Search\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','search',0,1,0,0,_binary 'a:0:{}',0,1,4,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',6,'system.admin','','system.admin','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Administration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,9,_binary 'a:0:{}',1,1,6,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',7,'announcements_feed.announcement','system.admin','announcements_feed.announcement','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Announcements\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:49:\"Displays announcements from the Drupal community.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','announcements_feed',1,1,0,10,_binary 'a:0:{}',0,2,6,7,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',8,'help.main','system.admin','help.main','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Help\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Reference for usage, configuration, and modules.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','help',1,1,0,9,_binary 'a:0:{}',0,2,6,8,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',9,'system.admin_content','system.admin','system.admin_content','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Find and manage content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',1,2,6,9,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',10,'comment.admin','system.admin_content','comment.admin','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Comments\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"List and edit site comments and the comment approval queue.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','comment',1,1,0,0,_binary 'a:0:{}',0,3,6,9,10,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',11,'system.admin_structure','system.admin','system.admin_structure','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Structure\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"Administer blocks, content types, menus, etc.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-8,_binary 'a:0:{}',1,2,6,11,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',12,'block.admin_display','system.admin_structure','block.admin_display','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Block layout\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:79:\"Configure what block content appears in your site\'s sidebars and other regions.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','block',1,1,0,0,_binary 'a:0:{}',0,3,6,11,12,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',13,'entity.block_content_type.collection','system.admin_structure','entity.block_content_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Block types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:78:\"Create and manage fields, forms, and display settings for your content blocks.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','block_content',1,1,0,0,_binary 'a:0:{}',1,3,6,11,13,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',14,'entity.comment_type.collection','system.admin_structure','entity.comment_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Comment types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:46:\"Manage form and displays settings of comments.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','comment',1,1,0,0,_binary 'a:0:{}',1,3,6,11,14,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',15,'entity.contact_form.collection','system.admin_structure','entity.contact_form.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Contact forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"Create and manage contact forms.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','contact',1,1,0,0,_binary 'a:0:{}',1,3,6,11,15,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',16,'field_ui.display_mode','system.admin_structure','field_ui.display_mode','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Display modes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:65:\"Configure what displays are available for your content and forms.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','field_ui',1,1,0,0,_binary 'a:0:{}',1,3,6,11,16,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',17,'entity.entity_view_mode.collection','field_ui.display_mode','entity.entity_view_mode.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"View modes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Manage custom view modes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','field_ui',1,1,0,0,_binary 'a:0:{}',1,4,6,11,16,17,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',18,'entity.entity_form_mode.collection','field_ui.display_mode','entity.entity_form_mode.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Form modes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Manage custom form modes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','field_ui',1,1,0,0,_binary 'a:0:{}',1,4,6,11,16,18,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',19,'entity.menu.collection','system.admin_structure','entity.menu.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Menus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Manage menus and menu links.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','menu_ui',1,1,0,0,_binary 'a:0:{}',1,3,6,11,19,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',20,'entity.node_type.collection','system.admin_structure','entity.node_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Content types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:71:\"Create and manage fields, forms, and display settings for your content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','node',1,1,0,0,_binary 'a:0:{}',1,3,6,11,20,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',21,'entity.taxonomy_vocabulary.collection','system.admin_structure','entity.taxonomy_vocabulary.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Taxonomy\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:67:\"Manage tagging, categorization, and classification of your content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','taxonomy',1,1,0,0,_binary 'a:0:{}',1,3,6,11,21,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',22,'entity.view.collection','system.admin_structure','entity.view.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Views\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"Manage customized lists of content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','views_ui',1,1,0,0,_binary 'a:0:{}',1,3,6,11,22,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',23,'system.themes_page','system.admin','system.themes_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Appearance\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Select and configure themes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-6,_binary 'a:0:{}',1,2,6,23,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',24,'system.modules_list','system.admin','system.modules_list','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Extend\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:53:\"Add and install modules to extend site functionality.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-2,_binary 'a:0:{}',1,2,6,24,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',25,'system.admin_config','system.admin','system.admin_config','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Administer settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,0,_binary 'a:0:{}',1,2,6,25,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',26,'system.admin_config_media','system.admin_config','system.admin_config_media','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',1,3,6,25,26,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',27,'entity.image_style.collection','system.admin_config_media','entity.image_style.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Image styles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:78:\"Configure styles that can be used for resizing or adjusting images on display.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','image',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,27,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',28,'system.file_system_settings','system.admin_config_media','system.file_system_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"File system\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:67:\"Configure the location of uploaded files and how they are accessed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,28,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',29,'system.image_toolkit_settings','system.admin_config_media','system.image_toolkit_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Image toolkit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:74:\"Choose which image toolkit to use if you have installed optional toolkits.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,20,_binary 'a:0:{}',0,4,6,25,26,29,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',30,'system.admin_config_services','system.admin_config','system.admin_config_services','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Web services\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,0,_binary 'a:0:{}',1,3,6,25,30,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',31,'system.rss_feeds_settings','system.admin_config_services','system.rss_feeds_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"RSS publishing\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:115:\"Configure the site description, the number of items per feed, and whether feeds should be titles/teasers/full-text.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,0,_binary 'a:0:{}',0,4,6,25,30,31,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',32,'system.linkset_settings','system.admin_config_services','system.linkset_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Menu Linkset Settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Enable or disable the menu linkset endpoint\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,10,_binary 'a:0:{}',0,4,6,25,30,32,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',33,'system.admin_config_development','system.admin_config','system.admin_config_development','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Development\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Configure and use development tools.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',1,3,6,25,33,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',34,'config.sync','system.admin_config_development','config.sync','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Configuration synchronization\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"Import and export your configuration.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','config',1,1,0,0,_binary 'a:0:{}',1,4,6,25,33,34,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',35,'system.site_maintenance_mode','system.admin_config_development','system.site_maintenance_mode','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Maintenance mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:62:\"Take the site offline for updates and other maintenance tasks.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',0,4,6,25,33,35,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',36,'system.performance_settings','system.admin_config_development','system.performance_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Performance\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"Configure caching and bandwidth optimization.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-20,_binary 'a:0:{}',0,4,6,25,33,36,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',37,'system.development_settings','system.admin_config_development','system.development_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Development settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Configure theme development settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-19,_binary 'a:0:{}',0,4,6,25,33,37,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',38,'system.logging_settings','system.admin_config_development','system.logging_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Logging and errors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:61:\"Configure the display of error messages and database logging.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-15,_binary 'a:0:{}',0,4,6,25,33,38,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',39,'system.admin_config_regional','system.admin_config','system.admin_config_regional','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Region and language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"Configure regional settings, localization, and translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-5,_binary 'a:0:{}',1,3,6,25,39,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',40,'system.regional_settings','system.admin_config_regional','system.regional_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Regional settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Configure the locale and timezone settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-20,_binary 'a:0:{}',0,4,6,25,39,40,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',41,'entity.date_format.collection','system.admin_config_regional','entity.date_format.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Date and time formats\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"Configure how dates and times are displayed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-9,_binary 'a:0:{}',0,4,6,25,39,41,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',42,'system.admin_config_search','system.admin_config','system.admin_config_search','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Search and metadata\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:64:\"Configure site search, metadata, and search engine optimization.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-10,_binary 'a:0:{}',1,3,6,25,42,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',43,'entity.path_alias.collection','system.admin_config_search','entity.path_alias.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"URL aliases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Add custom URLs to existing paths.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','path',1,1,0,-5,_binary 'a:0:{}',0,4,6,25,42,43,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',44,'entity.search_page.collection','system.admin_config_search','entity.search_page.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Search pages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:51:\"Configure search pages and search indexing options.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','search',1,1,0,-10,_binary 'a:0:{}',0,4,6,25,42,44,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',45,'system.admin_config_system','system.admin_config','system.admin_config_system','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"System\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:49:\"Configure basic site settings, actions, and cron.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-20,_binary 'a:0:{}',1,3,6,25,45,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',46,'system.site_information_settings','system.admin_config_system','system.site_information_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Basic site settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:77:\"Change site name, email address, slogan, default front page, and error pages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-20,_binary 'a:0:{}',0,4,6,25,45,46,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',47,'system.cron_settings','system.admin_config_system','system.cron_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Cron\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"Manage automatic site maintenance tasks.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,20,_binary 'a:0:{}',0,4,6,25,45,47,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',48,'system.admin_config_ui','system.admin_config','system.admin_config_ui','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"User interface\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"Configure the administrative user interface.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-15,_binary 'a:0:{}',1,3,6,25,48,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',49,'entity.shortcut_set.collection','system.admin_config_ui','entity.shortcut_set.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Shortcuts\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Add and modify shortcut sets.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','shortcut',1,1,0,0,_binary 'a:0:{}',0,4,6,25,48,49,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',50,'system.admin_config_workflow','system.admin_config','system.admin_config_workflow','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Workflow\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Manage the content workflow.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,5,_binary 'a:0:{}',0,3,6,25,50,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',51,'system.admin_config_content','system.admin_config','system.admin_config_content','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Content authoring\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Configure content formatting and authoring.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-15,_binary 'a:0:{}',1,3,6,25,51,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',52,'filter.admin_overview','system.admin_config_content','filter.admin_overview','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Text formats and editors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:78:\"Select and configure text editors, and how content is filtered when displayed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','filter',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,52,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',53,'user.admin_index','system.admin_config','user.admin_index','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"People\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Configure user accounts.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','user',1,1,0,-20,_binary 'a:0:{}',1,3,6,25,53,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',54,'entity.user.admin_form','user.admin_index','entity.user.admin_form','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Account settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:105:\"Configure default user account settings, including fields, registration requirements, and email messages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','user',1,1,0,-10,_binary 'a:0:{}',1,4,6,25,53,54,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',55,'system.admin_reports','system.admin','system.admin_reports','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Reports\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"View reports, updates, and errors.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,5,_binary 'a:0:{}',1,2,6,55,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',56,'dblog.overview','system.admin_reports','dblog.overview','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Recent log messages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"View events that have recently been logged.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','dblog',1,1,0,-1,_binary 'a:0:{}',0,3,6,55,56,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',57,'dblog.page_not_found','system.admin_reports','dblog.page_not_found','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"Top \'page not found\' errors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"View \'page not found\' errors (404s).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','dblog',1,1,0,0,_binary 'a:0:{}',0,3,6,55,57,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',58,'dblog.access_denied','system.admin_reports','dblog.access_denied','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Top \'access denied\' errors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"View \'access denied\' errors (403s).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','dblog',1,1,0,0,_binary 'a:0:{}',0,3,6,55,58,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',59,'entity.field_storage_config.collection','system.admin_reports','entity.field_storage_config.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Field list\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Overview of fields on all entity types.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','field_ui',1,1,0,0,_binary 'a:0:{}',1,3,6,55,59,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',60,'system.status','system.admin_reports','system.status','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Status report\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Get a status report about your site\'s operation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','system',1,1,0,-60,_binary 'a:0:{}',0,3,6,55,60,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',61,'views_ui.reports_plugins','system.admin_reports','views_ui.reports_plugins','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Views plugins\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"Overview of plugins used in all views.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','views_ui',1,1,0,0,_binary 'a:0:{}',0,3,6,55,61,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',62,'dblog.search','system.admin_reports','dblog.search','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Top search phrases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"View most popular search phrases.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','',1,1,0,0,_binary 'a:0:{}',0,3,6,55,62,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',63,'entity.user.collection','system.admin','entity.user.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"People\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"Manage user accounts, roles, and permissions.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','user',1,1,0,4,_binary 'a:0:{}',1,2,6,63,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('account',64,'user.page','','user.page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"My account\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','user',0,1,0,-10,_binary 'a:0:{}',0,1,64,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('account',65,'user.logout','','','',_binary 'a:0:{}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\user\\Plugin\\Menu\\LoginLogoutMenuLink',_binary 'a:0:{}','user',0,1,0,10,_binary 'a:0:{}',0,1,65,0,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',66,'update.status','system.admin_reports','update.status','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Available updates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:82:\"Get a status report about available updates for your installed modules and themes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','update',1,1,0,-50,_binary 'a:0:{}',0,3,6,55,66,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',67,'entity.media_type.collection','system.admin_structure','entity.media_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Media types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage media types.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','media',1,1,0,0,_binary 'a:0:{}',1,3,6,11,67,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',68,'media.settings','system.admin_config_media','media.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Media settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Manage media settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','media',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,68,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',69,'admin_toolbar_tools.extra_links:node.add','system.admin_content','node.add_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Add content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,3,6,9,69,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',70,'admin_toolbar_tools.extra_links:node.add.article','admin_toolbar_tools.extra_links:node.add','node.add','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:9:\"node_type\";s:9:\"entity_id\";s:7:\"article\";}',0,4,6,9,69,70,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',71,'admin_toolbar_tools.extra_links:node.add.page','admin_toolbar_tools.extra_links:node.add','node.add','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:9:\"node_type\";s:9:\"entity_id\";s:4:\"page\";}',0,4,6,9,69,71,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',72,'admin_toolbar_tools.extra_links:block_content_page','system.admin_content','entity.block_content.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,3,6,9,72,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',73,'admin_toolbar_tools.extra_links:add_block','admin_toolbar_tools.extra_links:block_content_page','block_content.add_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Add content block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,4,6,9,72,73,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',74,'admin_toolbar_tools.extra_links:block_content.add.basic','admin_toolbar_tools.extra_links:add_block','block_content.add_form','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:5:\"basic\";}',0,5,6,9,72,73,74,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',75,'admin_toolbar_tools.extra_links:media_page','system.admin_content','entity.media.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,3,6,9,75,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',76,'admin_toolbar_tools.extra_links:media_library','admin_toolbar_tools.extra_links:media_page','view.media_library.page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Media library\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,9,75,76,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',77,'admin_toolbar_tools.extra_links:add_media','admin_toolbar_tools.extra_links:media_page','entity.media.add_page','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,4,6,9,75,77,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',78,'admin_toolbar_tools.extra_links:media.add.audio','admin_toolbar_tools.extra_links:add_media','entity.media.add_form','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"audio\";}',0,5,6,9,75,77,78,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',79,'admin_toolbar_tools.extra_links:media.add.document','admin_toolbar_tools.extra_links:add_media','entity.media.add_form','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:8:\"document\";}',0,5,6,9,75,77,79,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',80,'admin_toolbar_tools.extra_links:media.add.image','admin_toolbar_tools.extra_links:add_media','entity.media.add_form','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"image\";}',0,5,6,9,75,77,80,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',81,'admin_toolbar_tools.extra_links:media.add.remote_video','admin_toolbar_tools.extra_links:add_media','entity.media.add_form','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:12:\"remote_video\";}',0,5,6,9,75,77,81,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',82,'admin_toolbar_tools.extra_links:media.add.video','admin_toolbar_tools.extra_links:add_media','entity.media.add_form','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"video\";}',0,5,6,9,75,77,82,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',83,'admin_toolbar_tools.extra_links:view.files','system.admin_content','view.files.page_1','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Files\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,9,83,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',84,'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic','entity.block_content_type.collection','entity.block_content_type.edit_form','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:5:\"basic\";}',1,4,6,11,13,84,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',85,'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsbasic','admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic','entity.block_content.field_ui_fields','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,13,84,85,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',86,'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultbasic','admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic','entity.entity_form_display.block_content.default','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,13,84,86,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',87,'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.basic','admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic','entity.entity_view_display.block_content.default','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,13,84,87,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',88,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.basic','admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic','entity.block_content_type.entity_permissions_form','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,13,84,88,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',89,'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.basic','admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic','entity.block_content_type.delete_form','block_content_type=basic',_binary 'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,13,84,89,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',90,'admin_toolbar_tools.extra_links:entity.comment_type.edit_form.comment','entity.comment_type.collection','entity.comment_type.edit_form','comment_type=comment',_binary 'a:1:{s:12:\"comment_type\";s:7:\"comment\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"entity_id\";s:7:\"comment\";}',1,4,6,11,14,90,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',91,'admin_toolbar_tools.extra_links:entity.comment.field_ui_fieldscomment','admin_toolbar_tools.extra_links:entity.comment_type.edit_form.comment','entity.comment.field_ui_fields','comment_type=comment',_binary 'a:1:{s:12:\"comment_type\";s:7:\"comment\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,14,90,91,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',92,'admin_toolbar_tools.extra_links:entity.entity_form_display.comment.defaultcomment','admin_toolbar_tools.extra_links:entity.comment_type.edit_form.comment','entity.entity_form_display.comment.default','comment_type=comment',_binary 'a:1:{s:12:\"comment_type\";s:7:\"comment\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,14,90,92,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',93,'admin_toolbar_tools.extra_links:entity.entity_view_display.comment.default.comment','admin_toolbar_tools.extra_links:entity.comment_type.edit_form.comment','entity.entity_view_display.comment.default','comment_type=comment',_binary 'a:1:{s:12:\"comment_type\";s:7:\"comment\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,14,90,93,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',94,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.comment.default.comment','admin_toolbar_tools.extra_links:entity.comment_type.edit_form.comment','entity.comment_type.entity_permissions_form','comment_type=comment',_binary 'a:1:{s:12:\"comment_type\";s:7:\"comment\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,14,90,94,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',95,'admin_toolbar_tools.extra_links:entity.comment_type.delete_form.comment','admin_toolbar_tools.extra_links:entity.comment_type.edit_form.comment','entity.comment_type.delete_form','comment_type=comment',_binary 'a:1:{s:12:\"comment_type\";s:7:\"comment\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,14,90,95,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',96,'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal','entity.contact_form.collection','entity.contact_form.edit_form','contact_form=personal',_binary 'a:1:{s:12:\"contact_form\";s:8:\"personal\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"entity_id\";s:8:\"personal\";}',1,4,6,11,15,96,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',97,'admin_toolbar_tools.extra_links:entity.contact_message.field_ui_fieldspersonal','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal','entity.contact_message.field_ui_fields','contact_form=personal',_binary 'a:1:{s:12:\"contact_form\";s:8:\"personal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,15,96,97,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',98,'admin_toolbar_tools.extra_links:entity.entity_form_display.contact_message.defaultpersonal','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal','entity.entity_form_display.contact_message.default','contact_form=personal',_binary 'a:1:{s:12:\"contact_form\";s:8:\"personal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,15,96,98,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',99,'admin_toolbar_tools.extra_links:entity.entity_view_display.contact_message.default.personal','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal','entity.entity_view_display.contact_message.default','contact_form=personal',_binary 'a:1:{s:12:\"contact_form\";s:8:\"personal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,15,96,99,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',100,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.contact_message.default.personal','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal','entity.contact_form.entity_permissions_form','contact_form=personal',_binary 'a:1:{s:12:\"contact_form\";s:8:\"personal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,15,96,100,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',101,'admin_toolbar_tools.extra_links:entity.contact_form.delete_form.personal','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal','entity.contact_form.delete_form','contact_form=personal',_binary 'a:1:{s:12:\"contact_form\";s:8:\"personal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,15,96,101,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',102,'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback','entity.contact_form.collection','entity.contact_form.edit_form','contact_form=feedback',_binary 'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"entity_id\";s:8:\"feedback\";}',1,4,6,11,15,102,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',103,'admin_toolbar_tools.extra_links:entity.contact_message.field_ui_fieldsfeedback','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback','entity.contact_message.field_ui_fields','contact_form=feedback',_binary 'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,15,102,103,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',104,'admin_toolbar_tools.extra_links:entity.entity_form_display.contact_message.defaultfeedback','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback','entity.entity_form_display.contact_message.default','contact_form=feedback',_binary 'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,15,102,104,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',105,'admin_toolbar_tools.extra_links:entity.entity_view_display.contact_message.default.feedback','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback','entity.entity_view_display.contact_message.default','contact_form=feedback',_binary 'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,15,102,105,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',106,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.contact_message.default.feedback','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback','entity.contact_form.entity_permissions_form','contact_form=feedback',_binary 'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,15,102,106,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',107,'admin_toolbar_tools.extra_links:entity.contact_form.delete_form.feedback','admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback','entity.contact_form.delete_form','contact_form=feedback',_binary 'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,15,102,107,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',108,'admin_toolbar_tools.extra_links:contact.form_add','entity.contact_form.collection','contact.form_add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Add contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-5,_binary 'a:0:{}',0,4,6,11,15,108,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',109,'admin_toolbar_tools.extra_links:field_ui.entity_view_mode_add','entity.entity_view_mode.collection','field_ui.entity_view_mode_add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Add view mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,16,17,109,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',110,'admin_toolbar_tools.extra_links:field_ui.entity_form_mode_add','entity.entity_form_mode.collection','field_ui.entity_form_mode_add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Add form mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,16,18,110,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',111,'admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio','entity.media_type.collection','entity.media_type.edit_form','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"audio\";}',1,4,6,11,67,111,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',112,'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsaudio','admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio','entity.media.field_ui_fields','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,67,111,112,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',113,'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultaudio','admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio','entity.entity_form_display.media.default','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,67,111,113,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',114,'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.audio','admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio','entity.entity_view_display.media.default','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,111,114,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',115,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.audio','admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio','entity.media_type.entity_permissions_form','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,111,115,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',116,'admin_toolbar_tools.extra_links:entity.media_type.delete_form.audio','admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio','entity.media_type.delete_form','media_type=audio',_binary 'a:1:{s:10:\"media_type\";s:5:\"audio\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,67,111,116,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',117,'admin_toolbar_tools.extra_links:entity.media_type.edit_form.document','entity.media_type.collection','entity.media_type.edit_form','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:8:\"document\";}',1,4,6,11,67,117,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',118,'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsdocument','admin_toolbar_tools.extra_links:entity.media_type.edit_form.document','entity.media.field_ui_fields','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,67,117,118,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',119,'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultdocument','admin_toolbar_tools.extra_links:entity.media_type.edit_form.document','entity.entity_form_display.media.default','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,67,117,119,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',120,'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.document','admin_toolbar_tools.extra_links:entity.media_type.edit_form.document','entity.entity_view_display.media.default','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,117,120,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',121,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.document','admin_toolbar_tools.extra_links:entity.media_type.edit_form.document','entity.media_type.entity_permissions_form','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,117,121,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',122,'admin_toolbar_tools.extra_links:entity.media_type.delete_form.document','admin_toolbar_tools.extra_links:entity.media_type.edit_form.document','entity.media_type.delete_form','media_type=document',_binary 'a:1:{s:10:\"media_type\";s:8:\"document\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,67,117,122,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',123,'admin_toolbar_tools.extra_links:entity.media_type.edit_form.image','entity.media_type.collection','entity.media_type.edit_form','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"image\";}',1,4,6,11,67,123,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',124,'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsimage','admin_toolbar_tools.extra_links:entity.media_type.edit_form.image','entity.media.field_ui_fields','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,67,123,124,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',125,'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultimage','admin_toolbar_tools.extra_links:entity.media_type.edit_form.image','entity.entity_form_display.media.default','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,67,123,125,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',126,'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.image','admin_toolbar_tools.extra_links:entity.media_type.edit_form.image','entity.entity_view_display.media.default','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,123,126,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',127,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.image','admin_toolbar_tools.extra_links:entity.media_type.edit_form.image','entity.media_type.entity_permissions_form','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,123,127,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',128,'admin_toolbar_tools.extra_links:entity.media_type.delete_form.image','admin_toolbar_tools.extra_links:entity.media_type.edit_form.image','entity.media_type.delete_form','media_type=image',_binary 'a:1:{s:10:\"media_type\";s:5:\"image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,67,123,128,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',129,'admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video','entity.media_type.collection','entity.media_type.edit_form','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:12:\"remote_video\";}',1,4,6,11,67,129,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',130,'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsremote_video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video','entity.media.field_ui_fields','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,67,129,130,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',131,'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultremote_video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video','entity.entity_form_display.media.default','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,67,129,131,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',132,'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.remote_video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video','entity.entity_view_display.media.default','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,129,132,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',133,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.remote_video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video','entity.media_type.entity_permissions_form','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,129,133,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',134,'admin_toolbar_tools.extra_links:entity.media_type.delete_form.remote_video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video','entity.media_type.delete_form','media_type=remote_video',_binary 'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,67,129,134,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',135,'admin_toolbar_tools.extra_links:entity.media_type.edit_form.video','entity.media_type.collection','entity.media_type.edit_form','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"video\";}',1,4,6,11,67,135,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',136,'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsvideo','admin_toolbar_tools.extra_links:entity.media_type.edit_form.video','entity.media.field_ui_fields','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,67,135,136,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',137,'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultvideo','admin_toolbar_tools.extra_links:entity.media_type.edit_form.video','entity.entity_form_display.media.default','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,67,135,137,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',138,'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.video','entity.entity_view_display.media.default','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,135,138,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',139,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.video','entity.media_type.entity_permissions_form','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,67,135,139,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',140,'admin_toolbar_tools.extra_links:entity.media_type.delete_form.video','admin_toolbar_tools.extra_links:entity.media_type.edit_form.video','entity.media_type.delete_form','media_type=video',_binary 'a:1:{s:10:\"media_type\";s:5:\"video\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,67,135,140,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',141,'admin_toolbar_tools.extra_links:media.type_add','entity.media_type.collection','entity.media_type.add_form','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Add media type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-2,_binary 'a:0:{}',0,4,6,11,67,141,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',142,'admin_toolbar_tools.extra_links:entity.menu.add_form','entity.menu.collection','entity.menu.add_form','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-2,_binary 'a:0:{}',0,4,6,11,19,142,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',143,'admin_toolbar_tools.extra_links:entity.menu.edit_form.admin','entity.menu.collection','entity.menu.edit_form','menu=admin',_binary 'a:1:{s:4:\"menu\";s:5:\"admin\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:5:\"admin\";}',1,4,6,11,19,143,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',144,'admin_toolbar_tools.extra_links:entity.menu.add_link_form.admin','admin_toolbar_tools.extra_links:entity.menu.edit_form.admin','entity.menu.add_link_form','menu=admin',_binary 'a:1:{s:4:\"menu\";s:5:\"admin\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,19,143,144,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',145,'admin_toolbar_tools.extra_links:entity.menu.edit_form.footer','entity.menu.collection','entity.menu.edit_form','menu=footer',_binary 'a:1:{s:4:\"menu\";s:6:\"footer\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:6:\"footer\";}',1,4,6,11,19,145,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',146,'admin_toolbar_tools.extra_links:entity.menu.add_link_form.footer','admin_toolbar_tools.extra_links:entity.menu.edit_form.footer','entity.menu.add_link_form','menu=footer',_binary 'a:1:{s:4:\"menu\";s:6:\"footer\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,19,145,146,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',147,'admin_toolbar_tools.extra_links:entity.menu.edit_form.main','entity.menu.collection','entity.menu.edit_form','menu=main',_binary 'a:1:{s:4:\"menu\";s:4:\"main\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:4:\"main\";}',1,4,6,11,19,147,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',148,'admin_toolbar_tools.extra_links:entity.menu.add_link_form.main','admin_toolbar_tools.extra_links:entity.menu.edit_form.main','entity.menu.add_link_form','menu=main',_binary 'a:1:{s:4:\"menu\";s:4:\"main\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,19,147,148,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',149,'admin_toolbar_tools.extra_links:entity.menu.edit_form.tools','entity.menu.collection','entity.menu.edit_form','menu=tools',_binary 'a:1:{s:4:\"menu\";s:5:\"tools\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:5:\"tools\";}',1,4,6,11,19,149,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',150,'admin_toolbar_tools.extra_links:entity.menu.add_link_form.tools','admin_toolbar_tools.extra_links:entity.menu.edit_form.tools','entity.menu.add_link_form','menu=tools',_binary 'a:1:{s:4:\"menu\";s:5:\"tools\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,19,149,150,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',151,'admin_toolbar_tools.extra_links:entity.menu.edit_form.account','entity.menu.collection','entity.menu.edit_form','menu=account',_binary 'a:1:{s:4:\"menu\";s:7:\"account\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,4,_binary 'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:7:\"account\";}',1,4,6,11,19,151,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',152,'admin_toolbar_tools.extra_links:entity.menu.add_link_form.account','admin_toolbar_tools.extra_links:entity.menu.edit_form.account','entity.menu.add_link_form','menu=account',_binary 'a:1:{s:4:\"menu\";s:7:\"account\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,19,151,152,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',153,'admin_toolbar_tools.extra_links:entity.node_type.edit_form.article','entity.node_type.collection','entity.node_type.edit_form','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:9:\"node_type\";s:9:\"entity_id\";s:7:\"article\";}',1,4,6,11,20,153,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',154,'admin_toolbar_tools.extra_links:entity.node.field_ui_fieldsarticle','admin_toolbar_tools.extra_links:entity.node_type.edit_form.article','entity.node.field_ui_fields','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,20,153,154,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',155,'admin_toolbar_tools.extra_links:entity.entity_form_display.node.defaultarticle','admin_toolbar_tools.extra_links:entity.node_type.edit_form.article','entity.entity_form_display.node.default','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,20,153,155,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',156,'admin_toolbar_tools.extra_links:entity.entity_view_display.node.default.article','admin_toolbar_tools.extra_links:entity.node_type.edit_form.article','entity.entity_view_display.node.default','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,20,153,156,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',157,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.node.default.article','admin_toolbar_tools.extra_links:entity.node_type.edit_form.article','entity.node_type.entity_permissions_form','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,20,153,157,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',158,'admin_toolbar_tools.extra_links:entity.node_type.delete_form.article','admin_toolbar_tools.extra_links:entity.node_type.edit_form.article','entity.node_type.delete_form','node_type=article',_binary 'a:1:{s:9:\"node_type\";s:7:\"article\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,20,153,158,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',159,'admin_toolbar_tools.extra_links:entity.node_type.edit_form.page','entity.node_type.collection','entity.node_type.edit_form','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:9:\"node_type\";s:9:\"entity_id\";s:4:\"page\";}',1,4,6,11,20,159,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',160,'admin_toolbar_tools.extra_links:entity.node.field_ui_fieldspage','admin_toolbar_tools.extra_links:entity.node_type.edit_form.page','entity.node.field_ui_fields','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,20,159,160,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',161,'admin_toolbar_tools.extra_links:entity.entity_form_display.node.defaultpage','admin_toolbar_tools.extra_links:entity.node_type.edit_form.page','entity.entity_form_display.node.default','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,20,159,161,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',162,'admin_toolbar_tools.extra_links:entity.entity_view_display.node.default.page','admin_toolbar_tools.extra_links:entity.node_type.edit_form.page','entity.entity_view_display.node.default','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,20,159,162,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',163,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.node.default.page','admin_toolbar_tools.extra_links:entity.node_type.edit_form.page','entity.node_type.entity_permissions_form','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,20,159,163,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',164,'admin_toolbar_tools.extra_links:entity.node_type.delete_form.page','admin_toolbar_tools.extra_links:entity.node_type.edit_form.page','entity.node_type.delete_form','node_type=page',_binary 'a:1:{s:9:\"node_type\";s:4:\"page\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,20,159,164,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',165,'admin_toolbar_tools.extra_links:node.type_add','entity.node_type.collection','node.type_add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Add content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-2,_binary 'a:0:{}',0,4,6,11,20,165,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',166,'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.taxonomy_vocabulary.collection','entity.taxonomy_vocabulary.overview_form','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"entity_id\";s:4:\"tags\";}',1,4,6,11,21,166,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',167,'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.edit_form.tags','admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.taxonomy_vocabulary.edit_form','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Edit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,11,21,166,167,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',168,'admin_toolbar_tools.extra_links:entity.taxonomy_term.field_ui_fieldstags','admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.taxonomy_term.field_ui_fields','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,21,166,168,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',169,'admin_toolbar_tools.extra_links:entity.entity_form_display.taxonomy_term.defaulttags','admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.entity_form_display.taxonomy_term.default','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,21,166,169,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',170,'admin_toolbar_tools.extra_links:entity.entity_view_display.taxonomy_term.default.tags','admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.entity_view_display.taxonomy_term.default','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,21,166,170,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',171,'admin_toolbar_tools.extra_links:entity.entity_permissions_form.taxonomy_term.default.tags','admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.taxonomy_vocabulary.entity_permissions_form','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,21,166,171,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',172,'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.delete_form.tags','admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags','entity.taxonomy_vocabulary.delete_form','taxonomy_vocabulary=tags',_binary 'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,21,166,172,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',173,'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.add_form','entity.taxonomy_vocabulary.collection','entity.taxonomy_vocabulary.add_form','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Add vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-998,_binary 'a:0:{}',0,4,6,11,21,173,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',174,'admin_toolbar_tools.extra_links:views_ui.add','entity.view.collection','views_ui.add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add view\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-5,_binary 'a:0:{}',0,4,6,11,22,174,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',175,'admin_toolbar_tools.extra_links:views_ui.block_content','entity.view.collection','entity.view.edit_form','view=block_content',_binary 'a:1:{s:4:\"view\";s:13:\"block_content\";}','',_binary 's:14:\"Content blocks\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,175,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',176,'admin_toolbar_tools.extra_links:views_ui.comment','entity.view.collection','entity.view.edit_form','view=comment',_binary 'a:1:{s:4:\"view\";s:7:\"comment\";}','',_binary 's:8:\"Comments\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,176,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',177,'admin_toolbar_tools.extra_links:views_ui.comments_recent','entity.view.collection','entity.view.edit_form','view=comments_recent',_binary 'a:1:{s:4:\"view\";s:15:\"comments_recent\";}','',_binary 's:15:\"Recent comments\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,177,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',178,'admin_toolbar_tools.extra_links:views_ui.content','entity.view.collection','entity.view.edit_form','view=content',_binary 'a:1:{s:4:\"view\";s:7:\"content\";}','',_binary 's:7:\"Content\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,178,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',179,'admin_toolbar_tools.extra_links:views_ui.content_recent','entity.view.collection','entity.view.edit_form','view=content_recent',_binary 'a:1:{s:4:\"view\";s:14:\"content_recent\";}','',_binary 's:14:\"Recent content\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,179,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',180,'admin_toolbar_tools.extra_links:views_ui.files','entity.view.collection','entity.view.edit_form','view=files',_binary 'a:1:{s:4:\"view\";s:5:\"files\";}','',_binary 's:5:\"Files\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,180,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',181,'admin_toolbar_tools.extra_links:views_ui.frontpage','entity.view.collection','entity.view.edit_form','view=frontpage',_binary 'a:1:{s:4:\"view\";s:9:\"frontpage\";}','',_binary 's:9:\"Frontpage\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,181,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',182,'admin_toolbar_tools.extra_links:views_ui.media','entity.view.collection','entity.view.edit_form','view=media',_binary 'a:1:{s:4:\"view\";s:5:\"media\";}','',_binary 's:5:\"Media\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,182,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',183,'admin_toolbar_tools.extra_links:views_ui.media_library','entity.view.collection','entity.view.edit_form','view=media_library',_binary 'a:1:{s:4:\"view\";s:13:\"media_library\";}','',_binary 's:13:\"Media library\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,183,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',184,'admin_toolbar_tools.extra_links:views_ui.taxonomy_term','entity.view.collection','entity.view.edit_form','view=taxonomy_term',_binary 'a:1:{s:4:\"view\";s:13:\"taxonomy_term\";}','',_binary 's:13:\"Taxonomy term\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,184,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',185,'admin_toolbar_tools.extra_links:views_ui.user_admin_people','entity.view.collection','entity.view.edit_form','view=user_admin_people',_binary 'a:1:{s:4:\"view\";s:17:\"user_admin_people\";}','',_binary 's:6:\"People\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,185,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',186,'admin_toolbar_tools.extra_links:views_ui.watchdog','entity.view.collection','entity.view.edit_form','view=watchdog',_binary 'a:1:{s:4:\"view\";s:8:\"watchdog\";}','',_binary 's:8:\"Watchdog\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,186,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',187,'admin_toolbar_tools.extra_links:views_ui.who_s_new','entity.view.collection','entity.view.edit_form','view=who_s_new',_binary 'a:1:{s:4:\"view\";s:9:\"who_s_new\";}','',_binary 's:9:\"Who\'s new\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,187,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',188,'admin_toolbar_tools.extra_links:views_ui.who_s_online','entity.view.collection','entity.view.edit_form','view=who_s_online',_binary 'a:1:{s:4:\"view\";s:12:\"who_s_online\";}','',_binary 's:18:\"Who\'s online block\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,188,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',189,'admin_toolbar_tools.extra_links:update.theme_install','system.themes_page','update.theme_install','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Install new theme\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,23,189,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',190,'admin_toolbar_tools.extra_links:update.theme_update','system.themes_page','update.theme_update','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Update\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,23,190,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',191,'admin_toolbar_tools.extra_links:system.theme_settings','system.themes_page','system.theme_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,3,6,23,191,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',192,'admin_toolbar_tools.extra_links:system.theme_settings_theme.olivero','admin_toolbar_tools.extra_links:system.theme_settings','system.theme_settings_theme','theme=olivero',_binary 'a:1:{s:5:\"theme\";s:7:\"olivero\";}','',_binary 's:7:\"Olivero\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,23,191,192,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',193,'admin_toolbar_tools.extra_links:system.theme_settings_theme.claro','admin_toolbar_tools.extra_links:system.theme_settings','system.theme_settings_theme','theme=claro',_binary 'a:1:{s:5:\"theme\";s:5:\"claro\";}','',_binary 's:5:\"Claro\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,23,191,193,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',194,'system.modules_uninstall','system.modules_list','system.modules_uninstall','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Uninstall module\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,24,194,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',195,'admin_toolbar_tools.extra_links:update.module_install','system.modules_list','update.module_install','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Install new module\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,24,195,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',196,'admin_toolbar_tools.extra_links:update.module_update','system.modules_list','update.module_update','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Update\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,24,196,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',197,'media_library.settings','system.admin_config_media','media_library.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Media Library settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"Manage Media Library settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','media_library',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,197,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',198,'admin_toolbar_tools.extra_links:config.import','config.sync','config.import_full','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Import\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,25,33,34,198,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',199,'admin_toolbar_tools.extra_links:config.export','config.sync','config.export_full','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Export\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,25,33,34,199,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',200,'admin_toolbar.settings','system.admin_config_ui','admin_toolbar.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Admin Toolbar\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"Configure the Admin Toolbar module.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar',1,1,0,0,_binary 'a:0:{}',0,4,6,25,48,200,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',201,'admin_toolbar_tools.settings','system.admin_config_ui','admin_toolbar_tools.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Admin Toolbar Tools\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:41:\"Configure the Admin Toolbar Tools module.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,25,48,201,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',202,'ckeditor5_plugin_pack.settings','system.admin_config_content','ckeditor5_plugin_pack.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"CKEditor 5 Plugin Pack\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"Configure the CKEditor 5 Plugin Pack module.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','ckeditor5_plugin_pack',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,202,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',203,'entity.ckeditor5_template.overview','system.admin_config_content','entity.ckeditor5_template.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"CKEditor 5 Content Templates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:89:\"The template feature allows you to insert predefined content structures into the document\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','ckeditor5_plugin_pack_templates',1,1,0,32,_binary 'a:0:{}',0,4,6,25,51,203,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',204,'admin_toolbar_tools.extra_links:entity.user.field_ui_fields_','entity.user.admin_form','entity.user.field_ui_fields','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,25,53,54,204,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',205,'admin_toolbar_tools.extra_links:entity.entity_form_display.user.default_','entity.user.admin_form','entity.entity_form_display.user.default','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,25,53,54,205,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',206,'admin_toolbar_tools.extra_links:entity.entity_view_display.user.default_','entity.user.admin_form','entity.entity_view_display.user.default','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,25,53,54,206,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',207,'admin_toolbar_tools.extra_links:views_ui.field_list','entity.field_storage_config.collection','views_ui.reports_fields','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Used in views\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,55,59,207,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',208,'admin_toolbar_tools.extra_links:user.admin_create','entity.user.collection','user.admin_create','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,63,208,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',209,'admin_toolbar_tools.extra_links:user.admin_permissions','entity.user.collection','user.admin_permissions','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,3,6,63,209,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',210,'admin_toolbar_tools.extra_links:entity.user_role.collection','entity.user.collection','entity.user_role.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',1,3,6,63,210,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',211,'admin_toolbar_tools.extra_links:user.role_add','admin_toolbar_tools.extra_links:entity.user_role.collection','user.role_add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add role\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-50,_binary 'a:0:{}',0,4,6,63,210,211,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',212,'admin_toolbar_tools.extra_links:entity.user_role.edit_form.anonymous','admin_toolbar_tools.extra_links:entity.user_role.collection','entity.user_role.edit_form','user_role=anonymous',_binary 'a:1:{s:9:\"user_role\";s:9:\"anonymous\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:9:\"user_role\";s:9:\"entity_id\";s:9:\"anonymous\";}',1,4,6,63,210,212,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',213,'admin_toolbar_tools.extra_links:entity.user_role.edit_permissions_form.anonymous','admin_toolbar_tools.extra_links:entity.user_role.edit_form.anonymous','entity.user_role.edit_permissions_form','user_role=anonymous',_binary 'a:1:{s:9:\"user_role\";s:9:\"anonymous\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Edit permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,63,210,212,213,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',214,'admin_toolbar_tools.extra_links:entity.user_role.edit_form.authenticated','admin_toolbar_tools.extra_links:entity.user_role.collection','entity.user_role.edit_form','user_role=authenticated',_binary 'a:1:{s:9:\"user_role\";s:13:\"authenticated\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:2:{s:11:\"entity_type\";s:9:\"user_role\";s:9:\"entity_id\";s:13:\"authenticated\";}',1,4,6,63,210,214,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',215,'admin_toolbar_tools.extra_links:entity.user_role.edit_permissions_form.authenticated','admin_toolbar_tools.extra_links:entity.user_role.edit_form.authenticated','entity.user_role.edit_permissions_form','user_role=authenticated',_binary 'a:1:{s:9:\"user_role\";s:13:\"authenticated\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Edit permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,63,210,214,215,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',216,'admin_toolbar_tools.extra_links:entity.user_role.edit_form.content_editor','admin_toolbar_tools.extra_links:entity.user_role.collection','entity.user_role.edit_form','user_role=content_editor',_binary 'a:1:{s:9:\"user_role\";s:14:\"content_editor\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:2:{s:11:\"entity_type\";s:9:\"user_role\";s:9:\"entity_id\";s:14:\"content_editor\";}',1,4,6,63,210,216,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',217,'admin_toolbar_tools.extra_links:entity.user_role.edit_permissions_form.content_editor','admin_toolbar_tools.extra_links:entity.user_role.edit_form.content_editor','entity.user_role.edit_permissions_form','user_role=content_editor',_binary 'a:1:{s:9:\"user_role\";s:14:\"content_editor\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Edit permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,63,210,216,217,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',218,'admin_toolbar_tools.extra_links:entity.user_role.delete_form.content_editor','admin_toolbar_tools.extra_links:entity.user_role.edit_form.content_editor','entity.user_role.delete_form','user_role=content_editor',_binary 'a:1:{s:9:\"user_role\";s:14:\"content_editor\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,63,210,216,218,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',219,'admin_toolbar_tools.extra_links:entity.user_role.edit_form.administrator','admin_toolbar_tools.extra_links:entity.user_role.collection','entity.user_role.edit_form','user_role=administrator',_binary 'a:1:{s:9:\"user_role\";s:13:\"administrator\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:2:{s:11:\"entity_type\";s:9:\"user_role\";s:9:\"entity_id\";s:13:\"administrator\";}',1,4,6,63,210,219,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',220,'admin_toolbar_tools.extra_links:entity.user_role.edit_permissions_form.administrator','admin_toolbar_tools.extra_links:entity.user_role.edit_form.administrator','entity.user_role.edit_permissions_form','user_role=administrator',_binary 'a:1:{s:9:\"user_role\";s:13:\"administrator\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Edit permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,63,210,219,220,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',221,'admin_toolbar_tools.extra_links:entity.user_role.delete_form.administrator','admin_toolbar_tools.extra_links:entity.user_role.edit_form.administrator','entity.user_role.delete_form','user_role=administrator',_binary 'a:1:{s:9:\"user_role\";s:13:\"administrator\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,5,6,63,210,219,221,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',222,'admin_toolbar_tools.help','system.admin','<front>','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Tools\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-100,_binary 'a:0:{}',1,2,6,222,0,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',223,'system.admin_index','admin_toolbar_tools.help','system.admin_index','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Index\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-100,_binary 'a:0:{}',0,3,6,222,223,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',224,'system.run_cron','admin_toolbar_tools.help','admin_toolbar.run.cron','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Run cron\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-8,_binary 'a:0:{}',0,3,6,222,224,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',225,'system.db_update','admin_toolbar_tools.help','system.db_update','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Run updates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-6,_binary 'a:0:{}',0,3,6,222,225,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',226,'admin_toolbar_tools.flush','admin_toolbar_tools.help','admin_toolbar_tools.flush','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Flush all caches\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-9,_binary 'a:0:{}',1,3,6,222,226,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',227,'admin_toolbar_tools.cssjs','admin_toolbar_tools.flush','admin_toolbar_tools.cssjs','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Flush CSS and JavaScript\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,227,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',228,'admin_toolbar_tools.plugin','admin_toolbar_tools.flush','admin_toolbar_tools.plugin','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Flush plugins cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,228,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',229,'admin_toolbar_tools.flush_static','admin_toolbar_tools.flush','admin_toolbar_tools.flush_static','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Flush static cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,229,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',230,'admin_toolbar_tools.flush_menu','admin_toolbar_tools.flush','admin_toolbar_tools.flush_menu','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Flush routing and links cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,230,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',231,'admin_toolbar_tools.flush_twig','admin_toolbar_tools.flush','admin_toolbar_tools.flush_twig','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Flush twig cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,231,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',232,'admin_toolbar_tools.flush_rendercache','admin_toolbar_tools.flush','admin_toolbar_tools.flush_rendercache','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Flush render cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,232,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',233,'admin_toolbar_tools.theme_rebuild','admin_toolbar_tools.flush','admin_toolbar_tools.theme_rebuild','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Rebuild theme registry\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,233,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',234,'admin_toolbar_tools.extra_links:flush_views','admin_toolbar_tools.flush','admin_toolbar_tools.flush_views','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Flush views cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,222,226,234,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',235,'admin_toolbar_tools.extra_links:user.logout','admin_toolbar_tools.help','user.logout','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Logout\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,10,_binary 'a:0:{}',0,3,6,222,235,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',236,'admin_toolbar_tools.extra_links:system.theme_settings_theme.gin','admin_toolbar_tools.extra_links:system.theme_settings','system.theme_settings_theme','theme=gin',_binary 'a:1:{s:5:\"theme\";s:3:\"gin\";}','',_binary 's:3:\"Gin\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,23,191,236,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',237,'entity.paragraphs_type.collection','system.admin_structure','entity.paragraphs_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Paragraph types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Create and manage Paragraph types.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','paragraphs',1,1,0,0,_binary 'a:0:{}',1,3,6,11,237,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',238,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_accordion',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_accordion\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:13:\"ept_accordion\";}',1,4,6,11,237,238,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',239,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_accordion','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion','entity.paragraph.field_ui_fields','paragraphs_type=ept_accordion',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_accordion\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,238,239,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',240,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_accordion','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion','entity.entity_form_display.paragraph.default','paragraphs_type=ept_accordion',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_accordion\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,238,240,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',241,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_accordion','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion','entity.entity_view_display.paragraph.default','paragraphs_type=ept_accordion',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_accordion\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,238,241,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',242,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_accordion','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion','entity.paragraphs_type.delete_form','paragraphs_type=ept_accordion',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_accordion\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,238,242,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',243,'paragraphs.type_add','entity.paragraphs_type.collection','paragraphs.type_add','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Add paragraph type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','paragraphs',1,1,0,0,_binary 'a:0:{}',0,4,6,11,237,243,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',244,'entity_reference_revisions.delete_orphans','system.admin_config_system','entity_reference_revisions.delete_orphans','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Delete orphaned composite entities\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:90:\"Delete revisions of entities that are no longer used in Entity Reference Revisions fields.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','entity_reference_revisions',1,1,0,30,_binary 'a:0:{}',0,4,6,25,45,244,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',245,'ept_core.settings','system.admin_config_content','ept_core.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Extra Paragraph Types (EPT) settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:75:\"Breakpoints, containers width, colors and other settings for EPT paragraphs\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','ept_core',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,245,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',246,'paragraphs.settings','system.admin_config_content','paragraphs.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Paragraphs settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','paragraphs',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,246,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',247,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion_section','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_accordion_section',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_accordion_section\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:21:\"ept_accordion_section\";}',1,4,6,11,237,247,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',248,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_accordion_section','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion_section','entity.paragraph.field_ui_fields','paragraphs_type=ept_accordion_section',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_accordion_section\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,247,248,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',249,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_accordion_section','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion_section','entity.entity_form_display.paragraph.default','paragraphs_type=ept_accordion_section',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_accordion_section\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,247,249,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',250,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_accordion_section','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion_section','entity.entity_view_display.paragraph.default','paragraphs_type=ept_accordion_section',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_accordion_section\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,247,250,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',251,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_accordion_section','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_accordion_section','entity.paragraphs_type.delete_form','paragraphs_type=ept_accordion_section',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_accordion_section\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,247,251,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',252,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_basic_button','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_basic_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_basic_button\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:16:\"ept_basic_button\";}',1,4,6,11,237,252,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',253,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_basic_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_basic_button','entity.paragraph.field_ui_fields','paragraphs_type=ept_basic_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_basic_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,252,253,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',254,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_basic_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_basic_button','entity.entity_form_display.paragraph.default','paragraphs_type=ept_basic_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_basic_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,252,254,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',255,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_basic_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_basic_button','entity.entity_view_display.paragraph.default','paragraphs_type=ept_basic_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_basic_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,252,255,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',256,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_basic_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_basic_button','entity.paragraphs_type.delete_form','paragraphs_type=ept_basic_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_basic_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,252,256,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',257,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_block','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_block',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_block\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:9:\"ept_block\";}',1,4,6,11,237,257,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',258,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_block','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_block','entity.paragraph.field_ui_fields','paragraphs_type=ept_block',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_block\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,257,258,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',259,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_block','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_block','entity.entity_form_display.paragraph.default','paragraphs_type=ept_block',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_block\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,257,259,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',260,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_block','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_block','entity.entity_view_display.paragraph.default','paragraphs_type=ept_block',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_block\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,257,260,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',261,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_block','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_block','entity.paragraphs_type.delete_form','paragraphs_type=ept_block',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_block\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,257,261,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',262,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_bootstrap_button','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_bootstrap_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:20:\"ept_bootstrap_button\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:20:\"ept_bootstrap_button\";}',1,4,6,11,237,262,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',263,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_bootstrap_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_bootstrap_button','entity.paragraph.field_ui_fields','paragraphs_type=ept_bootstrap_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:20:\"ept_bootstrap_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,262,263,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',264,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_bootstrap_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_bootstrap_button','entity.entity_form_display.paragraph.default','paragraphs_type=ept_bootstrap_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:20:\"ept_bootstrap_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,262,264,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',265,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_bootstrap_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_bootstrap_button','entity.entity_view_display.paragraph.default','paragraphs_type=ept_bootstrap_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:20:\"ept_bootstrap_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,262,265,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',266,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_bootstrap_button','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_bootstrap_button','entity.paragraphs_type.delete_form','paragraphs_type=ept_bootstrap_button',_binary 'a:1:{s:15:\"paragraphs_type\";s:20:\"ept_bootstrap_button\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,262,266,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',267,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_carousel',_binary 'a:1:{s:15:\"paragraphs_type\";s:12:\"ept_carousel\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:12:\"ept_carousel\";}',1,4,6,11,237,267,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',268,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_carousel','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel','entity.paragraph.field_ui_fields','paragraphs_type=ept_carousel',_binary 'a:1:{s:15:\"paragraphs_type\";s:12:\"ept_carousel\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,267,268,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',269,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_carousel','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel','entity.entity_form_display.paragraph.default','paragraphs_type=ept_carousel',_binary 'a:1:{s:15:\"paragraphs_type\";s:12:\"ept_carousel\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,267,269,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',270,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_carousel','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel','entity.entity_view_display.paragraph.default','paragraphs_type=ept_carousel',_binary 'a:1:{s:15:\"paragraphs_type\";s:12:\"ept_carousel\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,267,270,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',271,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_carousel','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel','entity.paragraphs_type.delete_form','paragraphs_type=ept_carousel',_binary 'a:1:{s:15:\"paragraphs_type\";s:12:\"ept_carousel\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,267,271,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',272,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel_item','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_carousel_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_carousel_item\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:17:\"ept_carousel_item\";}',1,4,6,11,237,272,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',273,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_carousel_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel_item','entity.paragraph.field_ui_fields','paragraphs_type=ept_carousel_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_carousel_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,272,273,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',274,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_carousel_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel_item','entity.entity_form_display.paragraph.default','paragraphs_type=ept_carousel_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_carousel_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,272,274,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',275,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_carousel_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel_item','entity.entity_view_display.paragraph.default','paragraphs_type=ept_carousel_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_carousel_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,272,275,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',276,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_carousel_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_carousel_item','entity.paragraphs_type.delete_form','paragraphs_type=ept_carousel_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_carousel_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,272,276,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',277,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_columns','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_columns',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_columns\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:11:\"ept_columns\";}',1,4,6,11,237,277,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',278,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_columns','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_columns','entity.paragraph.field_ui_fields','paragraphs_type=ept_columns',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_columns\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,277,278,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',279,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_columns','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_columns','entity.entity_form_display.paragraph.default','paragraphs_type=ept_columns',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_columns\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,277,279,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',280,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_columns','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_columns','entity.entity_view_display.paragraph.default','paragraphs_type=ept_columns',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_columns\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,277,280,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',281,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_columns','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_columns','entity.paragraphs_type.delete_form','paragraphs_type=ept_columns',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_columns\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,277,281,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',282,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_countdown','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_countdown',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_countdown\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:13:\"ept_countdown\";}',1,4,6,11,237,282,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',283,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_countdown','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_countdown','entity.paragraph.field_ui_fields','paragraphs_type=ept_countdown',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_countdown\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,282,283,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',284,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_countdown','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_countdown','entity.entity_form_display.paragraph.default','paragraphs_type=ept_countdown',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_countdown\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,282,284,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',285,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_countdown','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_countdown','entity.entity_view_display.paragraph.default','paragraphs_type=ept_countdown',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_countdown\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,282,285,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',286,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_countdown','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_countdown','entity.paragraphs_type.delete_form','paragraphs_type=ept_countdown',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_countdown\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,282,286,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',287,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_counter',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_counter\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:11:\"ept_counter\";}',1,4,6,11,237,287,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',288,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_counter','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter','entity.paragraph.field_ui_fields','paragraphs_type=ept_counter',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_counter\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,287,288,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',289,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_counter','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter','entity.entity_form_display.paragraph.default','paragraphs_type=ept_counter',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_counter\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,287,289,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',290,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_counter','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter','entity.entity_view_display.paragraph.default','paragraphs_type=ept_counter',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_counter\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,287,290,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',291,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_counter','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter','entity.paragraphs_type.delete_form','paragraphs_type=ept_counter',_binary 'a:1:{s:15:\"paragraphs_type\";s:11:\"ept_counter\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,287,291,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',292,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter_item','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_counter_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_counter_item\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:16:\"ept_counter_item\";}',1,4,6,11,237,292,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',293,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_counter_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter_item','entity.paragraph.field_ui_fields','paragraphs_type=ept_counter_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_counter_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,292,293,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',294,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_counter_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter_item','entity.entity_form_display.paragraph.default','paragraphs_type=ept_counter_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_counter_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,292,294,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',295,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_counter_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter_item','entity.entity_view_display.paragraph.default','paragraphs_type=ept_counter_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_counter_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,292,295,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',296,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_counter_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_counter_item','entity.paragraphs_type.delete_form','paragraphs_type=ept_counter_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_counter_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,292,296,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',297,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cta','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_cta',_binary 'a:1:{s:15:\"paragraphs_type\";s:7:\"ept_cta\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:7:\"ept_cta\";}',1,4,6,11,237,297,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',298,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_cta','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cta','entity.paragraph.field_ui_fields','paragraphs_type=ept_cta',_binary 'a:1:{s:15:\"paragraphs_type\";s:7:\"ept_cta\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,297,298,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',299,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_cta','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cta','entity.entity_form_display.paragraph.default','paragraphs_type=ept_cta',_binary 'a:1:{s:15:\"paragraphs_type\";s:7:\"ept_cta\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,297,299,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',300,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_cta','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cta','entity.entity_view_display.paragraph.default','paragraphs_type=ept_cta',_binary 'a:1:{s:15:\"paragraphs_type\";s:7:\"ept_cta\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,297,300,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',301,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_cta','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_cta','entity.paragraphs_type.delete_form','paragraphs_type=ept_cta',_binary 'a:1:{s:15:\"paragraphs_type\";s:7:\"ept_cta\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,297,301,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',302,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_hero','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_hero',_binary 'a:1:{s:15:\"paragraphs_type\";s:8:\"ept_hero\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:8:\"ept_hero\";}',1,4,6,11,237,302,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',303,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_hero','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_hero','entity.paragraph.field_ui_fields','paragraphs_type=ept_hero',_binary 'a:1:{s:15:\"paragraphs_type\";s:8:\"ept_hero\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,302,303,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',304,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_hero','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_hero','entity.entity_form_display.paragraph.default','paragraphs_type=ept_hero',_binary 'a:1:{s:15:\"paragraphs_type\";s:8:\"ept_hero\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,302,304,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',305,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_hero','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_hero','entity.entity_view_display.paragraph.default','paragraphs_type=ept_hero',_binary 'a:1:{s:15:\"paragraphs_type\";s:8:\"ept_hero\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,302,305,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',306,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_hero','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_hero','entity.paragraphs_type.delete_form','paragraphs_type=ept_hero',_binary 'a:1:{s:15:\"paragraphs_type\";s:8:\"ept_hero\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,302,306,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',307,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_image',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_image\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:9:\"ept_image\";}',1,4,6,11,237,307,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',308,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_image','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image','entity.paragraph.field_ui_fields','paragraphs_type=ept_image',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,307,308,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',309,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_image','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image','entity.entity_form_display.paragraph.default','paragraphs_type=ept_image',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,307,309,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',310,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_image','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image','entity.entity_view_display.paragraph.default','paragraphs_type=ept_image',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,307,310,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',311,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_image','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image','entity.paragraphs_type.delete_form','paragraphs_type=ept_image',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_image\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,307,311,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',312,'glightbox.admin_settings','system.admin_config_media','glightbox.admin_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"GLightbox settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"Configure the GLightbox settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','glightbox',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,312,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',313,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image_gallery','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_image_gallery',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_image_gallery\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:17:\"ept_image_gallery\";}',1,4,6,11,237,313,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',314,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_image_gallery','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image_gallery','entity.paragraph.field_ui_fields','paragraphs_type=ept_image_gallery',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_image_gallery\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,313,314,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',315,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_image_gallery','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image_gallery','entity.entity_form_display.paragraph.default','paragraphs_type=ept_image_gallery',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_image_gallery\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,313,315,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',316,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_image_gallery','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image_gallery','entity.entity_view_display.paragraph.default','paragraphs_type=ept_image_gallery',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_image_gallery\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,313,316,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',317,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_image_gallery','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_image_gallery','entity.paragraphs_type.delete_form','paragraphs_type=ept_image_gallery',_binary 'a:1:{s:15:\"paragraphs_type\";s:17:\"ept_image_gallery\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,313,317,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',318,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_micromodal','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_micromodal',_binary 'a:1:{s:15:\"paragraphs_type\";s:14:\"ept_micromodal\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:14:\"ept_micromodal\";}',1,4,6,11,237,318,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',319,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_micromodal','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_micromodal','entity.paragraph.field_ui_fields','paragraphs_type=ept_micromodal',_binary 'a:1:{s:15:\"paragraphs_type\";s:14:\"ept_micromodal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,318,319,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',320,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_micromodal','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_micromodal','entity.entity_form_display.paragraph.default','paragraphs_type=ept_micromodal',_binary 'a:1:{s:15:\"paragraphs_type\";s:14:\"ept_micromodal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,318,320,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',321,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_micromodal','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_micromodal','entity.entity_view_display.paragraph.default','paragraphs_type=ept_micromodal',_binary 'a:1:{s:15:\"paragraphs_type\";s:14:\"ept_micromodal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,318,321,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',322,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_micromodal','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_micromodal','entity.paragraphs_type.delete_form','paragraphs_type=ept_micromodal',_binary 'a:1:{s:15:\"paragraphs_type\";s:14:\"ept_micromodal\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,318,322,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',323,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_quote','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_quote',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_quote\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:9:\"ept_quote\";}',1,4,6,11,237,323,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',324,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_quote','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_quote','entity.paragraph.field_ui_fields','paragraphs_type=ept_quote',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_quote\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,323,324,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',325,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_quote','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_quote','entity.entity_form_display.paragraph.default','paragraphs_type=ept_quote',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_quote\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,323,325,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',326,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_quote','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_quote','entity.entity_view_display.paragraph.default','paragraphs_type=ept_quote',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_quote\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,323,326,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',327,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_quote','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_quote','entity.paragraphs_type.delete_form','paragraphs_type=ept_quote',_binary 'a:1:{s:15:\"paragraphs_type\";s:9:\"ept_quote\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,323,327,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',328,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_slick_slider',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_slick_slider\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:16:\"ept_slick_slider\";}',1,4,6,11,237,328,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',329,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_slick_slider','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider','entity.paragraph.field_ui_fields','paragraphs_type=ept_slick_slider',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_slick_slider\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,328,329,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',330,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_slick_slider','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider','entity.entity_form_display.paragraph.default','paragraphs_type=ept_slick_slider',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_slick_slider\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,328,330,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',331,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_slick_slider','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider','entity.entity_view_display.paragraph.default','paragraphs_type=ept_slick_slider',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_slick_slider\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,328,331,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',332,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_slick_slider','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider','entity.paragraphs_type.delete_form','paragraphs_type=ept_slick_slider',_binary 'a:1:{s:15:\"paragraphs_type\";s:16:\"ept_slick_slider\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,328,332,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',333,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider_item','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_slick_slider_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_slick_slider_item\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:21:\"ept_slick_slider_item\";}',1,4,6,11,237,333,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',334,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_slick_slider_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider_item','entity.paragraph.field_ui_fields','paragraphs_type=ept_slick_slider_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_slick_slider_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,333,334,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',335,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_slick_slider_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider_item','entity.entity_form_display.paragraph.default','paragraphs_type=ept_slick_slider_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_slick_slider_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,333,335,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',336,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_slick_slider_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider_item','entity.entity_view_display.paragraph.default','paragraphs_type=ept_slick_slider_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_slick_slider_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,333,336,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',337,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_slick_slider_item','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slick_slider_item','entity.paragraphs_type.delete_form','paragraphs_type=ept_slick_slider_item',_binary 'a:1:{s:15:\"paragraphs_type\";s:21:\"ept_slick_slider_item\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,333,337,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',338,'admin_toolbar_tools.extra_links:paragraphs_type.collection','entity.paragraphs_type.collection','entity.paragraphs_type.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"All types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,-999,_binary 'a:0:{}',0,4,6,11,237,338,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',339,'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slideshow','entity.paragraphs_type.collection','entity.paragraphs_type.edit_form','paragraphs_type=ept_slideshow',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_slideshow\";}','',_binary 's:0:\"\";',_binary 's:0:\"\";','Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:13:\"ept_slideshow\";}',1,4,6,11,237,339,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',340,'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsept_slideshow','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slideshow','entity.paragraph.field_ui_fields','paragraphs_type=ept_slideshow',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_slideshow\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,1,_binary 'a:0:{}',0,5,6,11,237,339,340,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',341,'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultept_slideshow','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slideshow','entity.entity_form_display.paragraph.default','paragraphs_type=ept_slideshow',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_slideshow\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,2,_binary 'a:0:{}',0,5,6,11,237,339,341,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',342,'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ept_slideshow','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slideshow','entity.entity_view_display.paragraph.default','paragraphs_type=ept_slideshow',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_slideshow\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,3,_binary 'a:0:{}',0,5,6,11,237,339,342,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',343,'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ept_slideshow','admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ept_slideshow','entity.paragraphs_type.delete_form','paragraphs_type=ept_slideshow',_binary 'a:1:{s:15:\"paragraphs_type\";s:13:\"ept_slideshow\";}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,5,_binary 'a:0:{}',0,5,6,11,237,339,343,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',346,'admin_toolbar_tools.extra_links:system.theme_settings_theme.ept_light','admin_toolbar_tools.extra_links:system.theme_settings','system.theme_settings_theme','theme=ept_light',_binary 'a:1:{s:5:\"theme\";s:9:\"ept_light\";}','',_binary 's:9:\"EPT Light\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,23,191,346,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',347,'tb_megamenu.admin','system.admin_structure','entity.tb_megamenu.collection','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"TB Mega Menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"List of megamenu items\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','tb_megamenu',1,1,0,0,_binary 'a:0:{}',0,3,6,11,347,0,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('main',348,'menu_link_content:d5043c53-9961-4a60-bb2a-a37bbaaa3961','',NULL,'',_binary 'a:0:{}','https://www.drupal.org/project/ept_core',_binary 's:11:\"EPT modules\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',0,0,1,-47,_binary 'a:1:{s:9:\"entity_id\";s:1:\"1\";}',0,1,348,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('admin',350,'layout_paragraphs.label_settings','system.admin_config_content','layout_paragraphs.label_settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Layout Paragraphs settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:65:\"Configure site-wide settings for Layout Paragraphs field widgets.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','layout_paragraphs',1,1,0,0,_binary 'a:0:{}',0,4,6,25,51,350,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('footer',351,'menu_link_content:9618e6db-485e-4fa0-84d3-b56e8936ef0d','',NULL,'',_binary 'a:0:{}','https://www.linkedin.com/in/ivan-abramenko/',_binary 's:8:\"LinkedIn\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,-49,_binary 'a:1:{s:9:\"entity_id\";s:1:\"3\";}',0,1,351,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('footer',352,'menu_link_content:9a831874-a895-4cc7-ac58-2de2055f7c4b','',NULL,'',_binary 'a:0:{}','https://drupalbook.org/contact',_binary 's:10:\"DrupalBook\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,-46,_binary 'a:1:{s:9:\"entity_id\";s:1:\"4\";}',0,1,352,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('footer',353,'menu_link_content:60ff628e-4af5-44f0-af2a-8bd88c057b15','',NULL,'',_binary 'a:0:{}','https://www.drupal.org/user/1079574/contact',_binary 's:10:\"Drupal.org\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,-48,_binary 'a:1:{s:9:\"entity_id\";s:1:\"5\";}',0,1,353,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('account',354,'menu_link_content:0cdaaebf-f931-4b2e-a1ed-fed2026812e5','',NULL,'',_binary 'a:0:{}','https://www.linkedin.com/in/ivan-abramenko/',_binary 's:8:\"LinkedIn\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,0,_binary 'a:1:{s:9:\"entity_id\";s:1:\"6\";}',0,1,354,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('account',355,'menu_link_content:c099779d-431c-4fb8-831c-02e395b960b7','',NULL,'',_binary 'a:0:{}','https://www.drupal.org/user/1079574/contact',_binary 's:10:\"Drupal.org\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,0,_binary 'a:1:{s:9:\"entity_id\";s:1:\"7\";}',0,1,355,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('account',356,'menu_link_content:5ddd00be-7fb0-4648-8176-b3cdf1a8fbff','',NULL,'',_binary 'a:0:{}','https://drupal.slack.com/archives/C07A942U72P',_binary 's:5:\"Slack\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,0,_binary 'a:1:{s:9:\"entity_id\";s:1:\"8\";}',0,1,356,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('footer',357,'menu_link_content:86cc3040-af4c-4f8b-901a-c9c517ae0ab6','',NULL,'',_binary 'a:0:{}','https://drupal.slack.com/archives/C07A942U72P',_binary 's:5:\"Slack\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,-47,_binary 'a:1:{s:9:\"entity_id\";s:1:\"9\";}',0,1,357,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('account',358,'menu_link_content:f7dcb4f3-cc8d-40eb-944e-073aea38aad3','',NULL,'',_binary 'a:0:{}','https://drupalbook.org/contact',_binary 's:10:\"DrupalBook\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,0,_binary 'a:1:{s:9:\"entity_id\";s:2:\"10\";}',0,1,358,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('main',359,'menu_link_content:b7aae8ff-5c43-4ae2-a08a-7fec98be2568','',NULL,'',_binary 'a:0:{}','https://www.drupal.org/project/ebt_core',_binary 's:11:\"EBT Modules\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:5:\"_self\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',0,0,0,-46,_binary 'a:1:{s:9:\"entity_id\";s:2:\"11\";}',0,1,359,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('main',360,'menu_link_content:99f46f29-6f08-4218-8291-d84b7e07ab0d','',NULL,'',_binary 'a:0:{}','https://drupalbook.org/ept/demo',_binary 's:13:\"Documentation\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:2:{s:10:\"attributes\";a:2:{s:6:\"target\";s:6:\"_blank\";s:5:\"class\";a:1:{i:0;s:0:\"\";}}s:8:\"external\";b:1;}','menu_link_content',1,0,0,-45,_binary 'a:1:{s:9:\"entity_id\";s:2:\"12\";}',0,1,360,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('admin',361,'image_effects.settings','system.admin_config_media','image_effects.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Image Effects\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"Configure Image Effects settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','image_effects',1,1,0,0,_binary 'a:0:{}',0,4,6,25,26,361,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',362,'file_mdm.settings','system.admin_config_system','file_mdm.settings','',_binary 'a:0:{}','',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"File metadata manager\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',_binary 'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"Configure file metadata settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','file_mdm',1,1,0,0,_binary 'a:0:{}',0,4,6,25,45,362,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('admin',363,'admin_toolbar_tools.extra_links:views_ui.what_s_new','entity.view.collection','entity.view.edit_form','view=what_s_new',_binary 'a:1:{s:4:\"view\";s:10:\"what_s_new\";}','',_binary 's:10:\"What\'s New\";',_binary 's:0:\"\";','Drupal\\Core\\Menu\\MenuLinkDefault',_binary 'a:0:{}','admin_toolbar_tools',1,1,0,0,_binary 'a:0:{}',0,4,6,11,22,363,0,0,0,0,0,'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),('main',364,'menu_link_content:fa9e2736-9b20-41fa-9e2c-c19aad723aab','','entity.node.canonical','node=19',_binary 'a:1:{s:4:\"node\";s:2:\"19\";}','',_binary 's:12:\"Listing Page\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}','menu_link_content',1,0,0,-48,_binary 'a:1:{s:9:\"entity_id\";s:2:\"13\";}',0,1,364,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm'),('main',365,'menu_link_content:10f330e8-9bde-4bb7-a57c-c1f39e9a02fd','','<front>','',_binary 'a:0:{}','',_binary 's:12:\"Landing Page\";',NULL,'Drupal\\menu_link_content\\Plugin\\Menu\\MenuLinkContent',_binary 'a:1:{s:10:\"attributes\";a:1:{s:5:\"class\";a:1:{i:0;s:0:\"\";}}}','menu_link_content',1,1,0,-49,_binary 'a:1:{s:9:\"entity_id\";s:2:\"14\";}',0,1,365,0,0,0,0,0,0,0,0,'\\Drupal\\menu_link_content\\Form\\MenuLinkContentForm');
/*!40000 ALTER TABLE `menu_tree` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node`
--

DROP TABLE IF EXISTS `node`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node` (
  `nid` int unsigned NOT NULL AUTO_INCREMENT,
  `vid` int unsigned DEFAULT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`nid`),
  UNIQUE KEY `node_field__uuid__value` (`uuid`),
  UNIQUE KEY `node__vid` (`vid`),
  KEY `node_field__type__target_id` (`type`)
) ENGINE=InnoDB AUTO_INCREMENT=20 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for node entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node`
--

LOCK TABLES `node` WRITE;
/*!40000 ALTER TABLE `node` DISABLE KEYS */;
INSERT INTO `node` VALUES (1,45,'page','b86c7571-14d1-44a5-bd24-0d90f5afff32','en'),(2,46,'article','46723af4-3654-4768-a509-f3dcff3aa671','en'),(3,47,'article','93c7ee44-83da-4807-87bf-52938a3f8291','en'),(4,48,'article','80c0c31c-f0ba-4e94-a37c-614161120c01','en'),(5,49,'article','61fe17c0-3dbe-47c3-84d7-78764a3d1574','en'),(6,50,'article','313679dd-963a-451a-aae2-760701974bf7','en'),(7,51,'article','c23f38e0-cb81-4745-8a07-f272d2210bea','en'),(8,52,'article','193cf44c-9a28-42f9-a551-997a1cbb4c5b','en'),(9,53,'article','f906b600-2fe4-418c-bd9b-4b259a145009','en'),(10,54,'article','d9c0bdfc-bf44-4f32-891b-66a099dea642','en'),(11,55,'article','dd922eaa-0d0f-4340-826e-b6bb47e61d14','en'),(12,56,'article','b51b1456-13ba-4b7c-a734-577a143b7540','en'),(13,57,'article','0716b19b-c10a-4256-bc30-9c22f1ecae6e','en'),(14,58,'article','6d4544fa-9615-4244-8914-a3a7e2cb3e1a','en'),(15,59,'article','041b2e8e-bdad-4e00-a646-c25f1ad58dca','en'),(16,60,'article','86871467-4e91-40db-8246-eadd9d5dd805','en'),(17,61,'article','c122f46b-b6e8-477a-bb9b-5d25da9576ac','en'),(18,62,'article','b66f27fb-6a81-434b-8d07-18e39e605985','en'),(19,68,'page','7f72c5d6-2831-4705-8e3c-9fc19ad7b9b9','en');
/*!40000 ALTER TABLE `node` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node__body`
--

DROP TABLE IF EXISTS `node__body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node__body`
--

LOCK TABLES `node__body` WRITE;
/*!40000 ALTER TABLE `node__body` DISABLE KEYS */;
INSERT INTO `node__body` VALUES ('article',0,2,46,'en',0,'<p>Extra Paragraph Types: Video and Image Gallery module provides ability to add grid gallery with videos and images.</p>','','full_html'),('article',0,3,47,'en',0,'<p>Extra Paragraph Types: Webform module provides ability to add a paragraph with Webform.</p>','','full_html'),('article',0,4,48,'en',0,'<p>Extra Paragraph Types: Webform Popup module provides ability to add Webform in popup. The button and popup are customizable with Settings form. This module will be helpful for creating Contact Us form popup.</p>','','full_html'),('article',0,5,49,'en',0,'<p>Tested and fully functional release. EPT 1.4.x version will support Drupal 9.3+.</p>','','full_html'),('article',0,6,50,'en',0,'<p>Extra Paragraph Types: Stats module provides ability to add Numbers with Text/Icons, Description and Title with WYSIWYG editor.</p>','','full_html'),('article',0,7,51,'en',0,'<p>Extra Paragraph Types: Text module provides ability to insert existing View using Paragraphs.</p>','','full_html'),('article',0,8,52,'en',0,'<p>Extra Block Types: Views module provides ability to add an existing View as EBT Block.</p>','','full_html'),('article',0,9,53,'en',0,'<p>Templates for EPT/EBT blocks and paragraphs now can be overidden in theme template folder by using addionally \'--custom\' suffix in template name.</p>','','full_html'),('article',0,10,54,'en',0,'<p>This release contains:<br>#3418633 by saccard: Ignores customized paragraph--ept-accordion-section--default.html.twig in theme folder</p><p>Templates for EPT/EBT blocks and paragraphs now can be overidden in theme template folder by using addionally \'--custom\' suffix in template name. For example:</p><p>block--block-content--ebt-accordion--custom.html.twig<br>block--block-content--ebt-accordion.html.twig</p><p>paragraph--ept-accordion--default--custom.html.twig<br>paragraph--ept-accordion--custom.html.twig<br>paragraph--ept-accordion--default.html.twig</p>','','full_html'),('article',0,11,55,'en',0,'<p>Extra Paragraph Types: Block module provides ability to insert an existing block as EPT Paragraph.</p>','','full_html'),('article',0,12,56,'en',0,'<p>​Added a new module EBT Starterkit with EBT module generator (for Drupal 12+): drush generate ebt:module</p>','','full_html'),('article',0,13,57,'en',0,'<p>This release contains a new submodule EPT Starterkit.</p><p>EPT Starterkit module allows to generate new EPT modules (for Drush 12+):</p><p>drush generate ept:module<br>Make sure, you use ept_* prefix for machine_name (e.g. ept_tabs, ept_cards). The prefix ept_* is required for EPT block functionality.</p><p>Creating new EPT module</p><p>Start machine name with ept_* prefix, it\'s required for working all EPT modules.</p>','','full_html'),('article',0,14,58,'en',0,'<p>EBT Block module provides ability to insert any Drupal Block: Views, custom content block, programmatically created blocks.</p>','','full_html'),('article',0,15,59,'en',0,'<p>Edit Extra Block Types (EBT): Columns / Container module provides ability to insert columns with other blocks. Columns have settings for column width.</p>','','full_html'),('article',0,16,60,'en',0,'<p>Added Simple EBT settings field widget. This field widget shows only three fields Width, Spacing and Edge to Edge:<br>https://drupalbook.org/ebt/extending-ebt-settings-form</p>','','full_html'),('article',0,17,61,'en',0,'<p>This release added new settings for Background Videos, It also add support for Local Videos.</p>','','full_html'),('article',0,18,62,'en',0,'<p>This release added new settings for Background Videos, It also add support for Local Videos.</p><p>All EBT blocks have next settings for Background Videos.</p>','','full_html');
/*!40000 ALTER TABLE `node__body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node__field_components`
--

DROP TABLE IF EXISTS `node__field_components`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node__field_components` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_components_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_components_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_components_target_id` (`field_components_target_id`),
  KEY `field_components_target_revision_id` (`field_components_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field field_components.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node__field_components`
--

LOCK TABLES `node__field_components` WRITE;
/*!40000 ALTER TABLE `node__field_components` DISABLE KEYS */;
INSERT INTO `node__field_components` VALUES ('page',0,1,45,'en',0,1,531),('page',0,1,45,'en',1,2,532),('page',0,1,45,'en',2,6,536),('page',0,1,45,'en',3,9,539),('page',0,1,45,'en',4,10,540),('page',0,1,45,'en',5,11,541),('page',0,1,45,'en',6,30,545),('page',0,1,45,'en',7,12,546),('page',0,1,45,'en',8,23,557),('page',0,1,45,'en',9,26,560),('page',0,1,45,'en',10,33,563),('page',0,1,45,'en',11,36,567),('page',0,19,68,'en',0,40,580),('page',0,19,68,'en',1,39,581),('page',0,19,68,'en',2,38,582);
/*!40000 ALTER TABLE `node__field_components` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node__field_image`
--

DROP TABLE IF EXISTS `node__field_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node__field_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_image_target_id` (`field_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field field_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node__field_image`
--

LOCK TABLES `node__field_image` WRITE;
/*!40000 ALTER TABLE `node__field_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `node__field_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node__field_tags`
--

DROP TABLE IF EXISTS `node__field_tags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node__field_tags` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_tags_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_tags_target_id` (`field_tags_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field field_tags.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node__field_tags`
--

LOCK TABLES `node__field_tags` WRITE;
/*!40000 ALTER TABLE `node__field_tags` DISABLE KEYS */;
/*!40000 ALTER TABLE `node__field_tags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_access`
--

DROP TABLE IF EXISTS `node_access`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_access` (
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "node".nid this record affects.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "language".langcode of this node.',
  `fallback` tinyint unsigned NOT NULL DEFAULT '1' COMMENT 'Boolean indicating whether this record should be used as a fallback if a language condition is not provided.',
  `gid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The grant ID a user must possess in the specified realm to gain this row''s privileges on the node.',
  `realm` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The realm in which the user must possess the grant ID. Modules can define one or more realms by implementing hook_node_grants().',
  `grant_view` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can view this node.',
  `grant_update` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can edit this node.',
  `grant_delete` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can delete this node.',
  PRIMARY KEY (`nid`,`gid`,`realm`,`langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Identifies which realm/grant pairs a user must possess in…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_access`
--

LOCK TABLES `node_access` WRITE;
/*!40000 ALTER TABLE `node_access` DISABLE KEYS */;
INSERT INTO `node_access` VALUES (0,'',1,0,'all',1,0,0);
/*!40000 ALTER TABLE `node_access` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_field_data`
--

DROP TABLE IF EXISTS `node_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_field_data` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `title` varchar(255) NOT NULL,
  `created` int NOT NULL,
  `changed` int NOT NULL,
  `promote` tinyint NOT NULL,
  `sticky` tinyint NOT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`nid`,`langcode`),
  KEY `node__id__default_langcode__langcode` (`nid`,`default_langcode`,`langcode`),
  KEY `node__vid` (`vid`),
  KEY `node_field__type__target_id` (`type`),
  KEY `node_field__uid__target_id` (`uid`),
  KEY `node_field__created` (`created`),
  KEY `node_field__changed` (`changed`),
  KEY `node__status_type` (`status`,`type`,`nid`),
  KEY `node__frontpage` (`promote`,`status`,`sticky`,`created`),
  KEY `node__title_type` (`title`(191),`type`(4))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for node entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_field_data`
--

LOCK TABLES `node_field_data` WRITE;
/*!40000 ALTER TABLE `node_field_data` DISABLE KEYS */;
INSERT INTO `node_field_data` VALUES (1,45,'page','en',1,1,'Getting Started EPT Page Buider',1728242588,1729024760,0,0,1,1),(2,46,'article','en',1,1,'New EPT Video and Image gallery module!',1665904809,1729063268,1,0,1,1),(3,47,'article','en',1,1,'New EPT Webform module!',1729063625,1729063645,1,0,1,1),(4,48,'article','en',1,1,'New EPT Webform Popup module!',1729063655,1729063666,1,0,1,1),(5,49,'article','en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.0',1697441277,1729063694,1,0,1,1),(6,50,'article','en',1,1,'New EPT Stats module!',1697441305,1729063723,1,0,1,1),(7,51,'article','en',1,1,'New EPT Views module!',1665905333,1729063749,1,0,1,1),(8,52,'article','en',1,1,'New EBT Views module!',1729063823,1729063839,1,0,1,1),(9,53,'article','en',1,1,'EBT (Extra Block Types): Core new release 1.4.16',1697441448,1729063862,1,0,1,1),(10,54,'article','en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.1',1729063871,1729063886,1,0,1,1),(11,55,'article','en',1,1,'New EPT Block module!',1729063895,1729063907,1,0,1,1),(12,56,'article','en',1,1,'EBT (Extra Block Types): Core new release 1.4.21',1665905515,1729063938,1,0,1,1),(13,57,'article','en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.3',1729063947,1729063957,1,0,1,1),(14,58,'article','en',1,1,'New EBT Block module!',1697441570,1729063985,1,0,1,1),(15,59,'article','en',1,1,'New EBT Columns / Container module!',1729063993,1729064008,1,0,1,1),(16,60,'article','en',1,1,'EBT (Extra Block Types): Core new release 1.4.22',1665905632,1729064046,1,0,1,1),(17,61,'article','en',1,1,'EBT (Extra Block Types): Core new release 1.4.24',1729064056,1729064067,1,0,1,1),(18,62,'article','en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.7',1697441675,1729064095,1,0,1,1),(19,68,'page','en',1,1,'What\'s New',1729064448,1729067292,0,0,1,1);
/*!40000 ALTER TABLE `node_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_field_revision`
--

DROP TABLE IF EXISTS `node_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_field_revision` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `title` varchar(255) DEFAULT NULL,
  `created` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `promote` tinyint DEFAULT NULL,
  `sticky` tinyint DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`,`langcode`),
  KEY `node__id__default_langcode__langcode` (`nid`,`default_langcode`,`langcode`),
  KEY `node_field__uid__target_id` (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for node entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_field_revision`
--

LOCK TABLES `node_field_revision` WRITE;
/*!40000 ALTER TABLE `node_field_revision` DISABLE KEYS */;
INSERT INTO `node_field_revision` VALUES (1,1,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728242893,0,0,1,1),(1,2,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728749523,0,0,1,1),(1,3,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728751272,0,0,1,1),(1,4,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728751458,0,0,1,1),(1,5,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728762000,0,0,1,1),(1,6,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728762439,0,0,1,1),(1,7,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728762685,0,0,1,1),(1,8,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728808800,0,0,1,1),(1,9,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728809719,0,0,1,1),(1,10,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728809815,0,0,1,1),(1,11,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728809849,0,0,1,1),(1,12,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728817647,0,0,1,1),(1,13,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728819415,0,0,1,1),(1,14,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728819461,0,0,1,1),(1,15,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728819683,0,0,1,1),(1,16,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728819951,0,0,1,1),(1,17,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728820014,0,0,1,1),(1,18,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728882972,0,0,1,1),(1,19,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728883069,0,0,1,1),(1,20,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728883324,0,0,1,1),(1,21,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728883773,0,0,1,1),(1,22,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728883938,0,0,1,1),(1,23,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728884118,0,0,1,1),(1,24,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728884894,0,0,1,1),(1,25,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728885200,0,0,1,1),(1,26,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728885506,0,0,1,1),(1,27,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728885677,0,0,1,1),(1,28,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728885900,0,0,1,1),(1,29,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728888389,0,0,1,1),(1,30,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728889242,0,0,1,1),(1,31,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728889330,0,0,1,1),(1,32,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728933423,0,0,1,1),(1,33,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728933474,0,0,1,1),(1,34,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728934139,0,0,1,1),(1,35,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728934262,0,0,1,1),(1,36,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728935838,0,0,1,1),(1,37,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728936706,0,0,1,1),(1,38,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728936828,0,0,1,1),(1,39,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728936888,0,0,1,1),(1,40,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728937164,0,0,1,1),(1,41,'en',1,1,'Getting Started EPT Page Buider',1728242588,1728937228,0,0,1,1),(1,42,'en',1,1,'Getting Started EPT Page Buider',1728242588,1729020152,0,0,1,1),(1,43,'en',1,1,'Getting Started EPT Page Buider',1728242588,1729022518,0,0,1,1),(1,44,'en',1,1,'Getting Started EPT Page Buider',1728242588,1729022935,0,0,1,1),(1,45,'en',1,1,'Getting Started EPT Page Buider',1728242588,1729024760,0,0,1,1),(2,46,'en',1,1,'New EPT Video and Image gallery module!',1665904809,1729063268,1,0,1,1),(3,47,'en',1,1,'New EPT Webform module!',1729063625,1729063645,1,0,1,1),(4,48,'en',1,1,'New EPT Webform Popup module!',1729063655,1729063666,1,0,1,1),(5,49,'en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.0',1697441277,1729063694,1,0,1,1),(6,50,'en',1,1,'New EPT Stats module!',1697441305,1729063723,1,0,1,1),(7,51,'en',1,1,'New EPT Views module!',1665905333,1729063749,1,0,1,1),(8,52,'en',1,1,'New EBT Views module!',1729063823,1729063839,1,0,1,1),(9,53,'en',1,1,'EBT (Extra Block Types): Core new release 1.4.16',1697441448,1729063862,1,0,1,1),(10,54,'en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.1',1729063871,1729063886,1,0,1,1),(11,55,'en',1,1,'New EPT Block module!',1729063895,1729063907,1,0,1,1),(12,56,'en',1,1,'EBT (Extra Block Types): Core new release 1.4.21',1665905515,1729063938,1,0,1,1),(13,57,'en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.3',1729063947,1729063957,1,0,1,1),(14,58,'en',1,1,'New EBT Block module!',1697441570,1729063985,1,0,1,1),(15,59,'en',1,1,'New EBT Columns / Container module!',1729063993,1729064008,1,0,1,1),(16,60,'en',1,1,'EBT (Extra Block Types): Core new release 1.4.22',1665905632,1729064046,1,0,1,1),(17,61,'en',1,1,'EBT (Extra Block Types): Core new release 1.4.24',1729064056,1729064067,1,0,1,1),(18,62,'en',1,1,'EPT (Extra Paragraph Types): Core new release 1.4.7',1697441675,1729064095,1,0,1,1),(19,63,'en',1,1,'What\'s New',1729064448,1729064555,0,0,1,1),(19,64,'en',1,1,'What\'s New',1729064448,1729065353,0,0,1,1),(19,65,'en',1,1,'What\'s New',1729064448,1729066913,0,0,1,1),(19,66,'en',1,1,'What\'s New',1729064448,1729066954,0,0,1,1),(19,67,'en',1,1,'What\'s New',1729064448,1729067014,0,0,1,1),(19,68,'en',1,1,'What\'s New',1729064448,1729067292,0,0,1,1);
/*!40000 ALTER TABLE `node_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision`
--

DROP TABLE IF EXISTS `node_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_timestamp` int DEFAULT NULL,
  `revision_log` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`),
  KEY `node__nid` (`nid`),
  KEY `node_field__langcode` (`langcode`),
  KEY `node_field__revision_uid__target_id` (`revision_uid`)
) ENGINE=InnoDB AUTO_INCREMENT=69 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for node entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision`
--

LOCK TABLES `node_revision` WRITE;
/*!40000 ALTER TABLE `node_revision` DISABLE KEYS */;
INSERT INTO `node_revision` VALUES (1,1,'en',1,1728242893,NULL,1),(1,2,'en',1,1728749523,NULL,1),(1,3,'en',1,1728751272,NULL,1),(1,4,'en',1,1728751458,NULL,1),(1,5,'en',1,1728762000,NULL,1),(1,6,'en',1,1728762439,NULL,1),(1,7,'en',1,1728762685,NULL,1),(1,8,'en',1,1728808800,NULL,1),(1,9,'en',1,1728809719,NULL,1),(1,10,'en',1,1728809815,NULL,1),(1,11,'en',1,1728809849,NULL,1),(1,12,'en',1,1728817647,NULL,1),(1,13,'en',1,1728819415,NULL,1),(1,14,'en',1,1728819461,NULL,1),(1,15,'en',1,1728819683,NULL,1),(1,16,'en',1,1728819951,NULL,1),(1,17,'en',1,1728820014,NULL,1),(1,18,'en',1,1728882972,NULL,1),(1,19,'en',1,1728883069,NULL,1),(1,20,'en',1,1728883324,NULL,1),(1,21,'en',1,1728883773,NULL,1),(1,22,'en',1,1728883938,NULL,1),(1,23,'en',1,1728884118,NULL,1),(1,24,'en',1,1728884894,NULL,1),(1,25,'en',1,1728885200,NULL,1),(1,26,'en',1,1728885506,NULL,1),(1,27,'en',1,1728885677,NULL,1),(1,28,'en',1,1728885900,NULL,1),(1,29,'en',1,1728888389,NULL,1),(1,30,'en',1,1728889242,NULL,1),(1,31,'en',1,1728889330,NULL,1),(1,32,'en',1,1728933423,NULL,1),(1,33,'en',1,1728933474,NULL,1),(1,34,'en',1,1728934139,NULL,1),(1,35,'en',1,1728934262,NULL,1),(1,36,'en',1,1728935838,NULL,1),(1,37,'en',1,1728936706,NULL,1),(1,38,'en',1,1728936828,NULL,1),(1,39,'en',1,1728936888,NULL,1),(1,40,'en',1,1728937164,NULL,1),(1,41,'en',1,1728937228,NULL,1),(1,42,'en',1,1729020152,NULL,1),(1,43,'en',1,1729022518,NULL,1),(1,44,'en',1,1729022935,NULL,1),(1,45,'en',1,1729024760,NULL,1),(2,46,'en',1,1729063268,NULL,1),(3,47,'en',1,1729063645,NULL,1),(4,48,'en',1,1729063666,NULL,1),(5,49,'en',1,1729063694,NULL,1),(6,50,'en',1,1729063723,NULL,1),(7,51,'en',1,1729063749,NULL,1),(8,52,'en',1,1729063839,NULL,1),(9,53,'en',1,1729063862,NULL,1),(10,54,'en',1,1729063886,NULL,1),(11,55,'en',1,1729063907,NULL,1),(12,56,'en',1,1729063938,NULL,1),(13,57,'en',1,1729063957,NULL,1),(14,58,'en',1,1729063985,NULL,1),(15,59,'en',1,1729064008,NULL,1),(16,60,'en',1,1729064046,NULL,1),(17,61,'en',1,1729064067,NULL,1),(18,62,'en',1,1729064095,NULL,1),(19,63,'en',1,1729064555,NULL,1),(19,64,'en',1,1729065353,NULL,1),(19,65,'en',1,1729066913,NULL,1),(19,66,'en',1,1729066954,NULL,1),(19,67,'en',1,1729067014,NULL,1),(19,68,'en',1,1729067292,NULL,1);
/*!40000 ALTER TABLE `node_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision__body`
--

DROP TABLE IF EXISTS `node_revision__body`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field body.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision__body`
--

LOCK TABLES `node_revision__body` WRITE;
/*!40000 ALTER TABLE `node_revision__body` DISABLE KEYS */;
INSERT INTO `node_revision__body` VALUES ('article',0,2,46,'en',0,'<p>Extra Paragraph Types: Video and Image Gallery module provides ability to add grid gallery with videos and images.</p>','','full_html'),('article',0,3,47,'en',0,'<p>Extra Paragraph Types: Webform module provides ability to add a paragraph with Webform.</p>','','full_html'),('article',0,4,48,'en',0,'<p>Extra Paragraph Types: Webform Popup module provides ability to add Webform in popup. The button and popup are customizable with Settings form. This module will be helpful for creating Contact Us form popup.</p>','','full_html'),('article',0,5,49,'en',0,'<p>Tested and fully functional release. EPT 1.4.x version will support Drupal 9.3+.</p>','','full_html'),('article',0,6,50,'en',0,'<p>Extra Paragraph Types: Stats module provides ability to add Numbers with Text/Icons, Description and Title with WYSIWYG editor.</p>','','full_html'),('article',0,7,51,'en',0,'<p>Extra Paragraph Types: Text module provides ability to insert existing View using Paragraphs.</p>','','full_html'),('article',0,8,52,'en',0,'<p>Extra Block Types: Views module provides ability to add an existing View as EBT Block.</p>','','full_html'),('article',0,9,53,'en',0,'<p>Templates for EPT/EBT blocks and paragraphs now can be overidden in theme template folder by using addionally \'--custom\' suffix in template name.</p>','','full_html'),('article',0,10,54,'en',0,'<p>This release contains:<br>#3418633 by saccard: Ignores customized paragraph--ept-accordion-section--default.html.twig in theme folder</p><p>Templates for EPT/EBT blocks and paragraphs now can be overidden in theme template folder by using addionally \'--custom\' suffix in template name. For example:</p><p>block--block-content--ebt-accordion--custom.html.twig<br>block--block-content--ebt-accordion.html.twig</p><p>paragraph--ept-accordion--default--custom.html.twig<br>paragraph--ept-accordion--custom.html.twig<br>paragraph--ept-accordion--default.html.twig</p>','','full_html'),('article',0,11,55,'en',0,'<p>Extra Paragraph Types: Block module provides ability to insert an existing block as EPT Paragraph.</p>','','full_html'),('article',0,12,56,'en',0,'<p>​Added a new module EBT Starterkit with EBT module generator (for Drupal 12+): drush generate ebt:module</p>','','full_html'),('article',0,13,57,'en',0,'<p>This release contains a new submodule EPT Starterkit.</p><p>EPT Starterkit module allows to generate new EPT modules (for Drush 12+):</p><p>drush generate ept:module<br>Make sure, you use ept_* prefix for machine_name (e.g. ept_tabs, ept_cards). The prefix ept_* is required for EPT block functionality.</p><p>Creating new EPT module</p><p>Start machine name with ept_* prefix, it\'s required for working all EPT modules.</p>','','full_html'),('article',0,14,58,'en',0,'<p>EBT Block module provides ability to insert any Drupal Block: Views, custom content block, programmatically created blocks.</p>','','full_html'),('article',0,15,59,'en',0,'<p>Edit Extra Block Types (EBT): Columns / Container module provides ability to insert columns with other blocks. Columns have settings for column width.</p>','','full_html'),('article',0,16,60,'en',0,'<p>Added Simple EBT settings field widget. This field widget shows only three fields Width, Spacing and Edge to Edge:<br>https://drupalbook.org/ebt/extending-ebt-settings-form</p>','','full_html'),('article',0,17,61,'en',0,'<p>This release added new settings for Background Videos, It also add support for Local Videos.</p>','','full_html'),('article',0,18,62,'en',0,'<p>This release added new settings for Background Videos, It also add support for Local Videos.</p><p>All EBT blocks have next settings for Background Videos.</p>','','full_html');
/*!40000 ALTER TABLE `node_revision__body` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision__field_components`
--

DROP TABLE IF EXISTS `node_revision__field_components`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision__field_components` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_components_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_components_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_components_target_id` (`field_components_target_id`),
  KEY `field_components_target_revision_id` (`field_components_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field field_components.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision__field_components`
--

LOCK TABLES `node_revision__field_components` WRITE;
/*!40000 ALTER TABLE `node_revision__field_components` DISABLE KEYS */;
INSERT INTO `node_revision__field_components` VALUES ('page',0,1,1,'en',0,1,1),('page',0,1,2,'en',0,1,2),('page',0,1,3,'en',0,1,3),('page',0,1,4,'en',0,1,4),('page',0,1,5,'en',0,1,5),('page',0,1,6,'en',0,1,6),('page',0,1,7,'en',0,1,7),('page',0,1,8,'en',0,1,8),('page',0,1,9,'en',0,1,9),('page',0,1,9,'en',1,2,10),('page',0,1,10,'en',0,1,11),('page',0,1,10,'en',1,2,12),('page',0,1,11,'en',0,1,13),('page',0,1,11,'en',1,2,14),('page',0,1,12,'en',0,1,15),('page',0,1,12,'en',1,2,16),('page',0,1,13,'en',0,1,17),('page',0,1,13,'en',1,2,18),('page',0,1,13,'en',2,6,22),('page',0,1,14,'en',0,1,23),('page',0,1,14,'en',1,2,24),('page',0,1,14,'en',2,6,28),('page',0,1,15,'en',0,1,29),('page',0,1,15,'en',1,2,30),('page',0,1,15,'en',2,6,34),('page',0,1,16,'en',0,1,35),('page',0,1,16,'en',1,2,36),('page',0,1,16,'en',2,6,40),('page',0,1,17,'en',0,1,41),('page',0,1,17,'en',1,2,42),('page',0,1,17,'en',2,6,46),('page',0,1,18,'en',0,1,47),('page',0,1,18,'en',1,2,48),('page',0,1,18,'en',2,6,52),('page',0,1,19,'en',0,1,53),('page',0,1,19,'en',1,2,54),('page',0,1,19,'en',2,6,58),('page',0,1,20,'en',0,1,59),('page',0,1,20,'en',1,2,60),('page',0,1,20,'en',2,6,64),('page',0,1,21,'en',0,1,65),('page',0,1,21,'en',1,2,66),('page',0,1,21,'en',2,6,70),('page',0,1,21,'en',3,9,73),('page',0,1,22,'en',0,1,74),('page',0,1,22,'en',1,2,75),('page',0,1,22,'en',2,6,79),('page',0,1,22,'en',3,9,82),('page',0,1,23,'en',0,1,83),('page',0,1,23,'en',1,2,84),('page',0,1,23,'en',2,6,88),('page',0,1,23,'en',3,9,91),('page',0,1,24,'en',0,1,92),('page',0,1,24,'en',1,2,93),('page',0,1,24,'en',2,6,97),('page',0,1,24,'en',3,9,100),('page',0,1,24,'en',4,10,101),('page',0,1,25,'en',0,1,102),('page',0,1,25,'en',1,2,103),('page',0,1,25,'en',2,6,107),('page',0,1,25,'en',3,9,110),('page',0,1,25,'en',4,10,111),('page',0,1,26,'en',0,1,112),('page',0,1,26,'en',1,2,113),('page',0,1,26,'en',2,6,117),('page',0,1,26,'en',3,9,120),('page',0,1,26,'en',4,10,121),('page',0,1,27,'en',0,1,122),('page',0,1,27,'en',1,2,123),('page',0,1,27,'en',2,6,127),('page',0,1,27,'en',3,9,130),('page',0,1,27,'en',4,10,131),('page',0,1,28,'en',0,1,132),('page',0,1,28,'en',1,2,133),('page',0,1,28,'en',2,6,137),('page',0,1,28,'en',3,9,140),('page',0,1,28,'en',4,10,141),('page',0,1,29,'en',0,1,142),('page',0,1,29,'en',1,2,143),('page',0,1,29,'en',2,6,147),('page',0,1,29,'en',3,9,150),('page',0,1,29,'en',4,10,151),('page',0,1,30,'en',0,1,152),('page',0,1,30,'en',1,2,153),('page',0,1,30,'en',2,6,157),('page',0,1,30,'en',3,9,160),('page',0,1,30,'en',4,10,161),('page',0,1,30,'en',5,11,162),('page',0,1,31,'en',0,1,163),('page',0,1,31,'en',1,2,164),('page',0,1,31,'en',2,6,168),('page',0,1,31,'en',3,9,171),('page',0,1,31,'en',4,10,172),('page',0,1,31,'en',5,11,173),('page',0,1,32,'en',0,1,174),('page',0,1,32,'en',1,2,175),('page',0,1,32,'en',2,6,179),('page',0,1,32,'en',3,9,182),('page',0,1,32,'en',4,10,183),('page',0,1,32,'en',5,11,184),('page',0,1,32,'en',6,12,185),('page',0,1,33,'en',0,1,186),('page',0,1,33,'en',1,2,187),('page',0,1,33,'en',2,6,191),('page',0,1,33,'en',3,9,194),('page',0,1,33,'en',4,10,195),('page',0,1,33,'en',5,11,196),('page',0,1,33,'en',6,12,197),('page',0,1,34,'en',0,1,198),('page',0,1,34,'en',1,2,199),('page',0,1,34,'en',2,6,203),('page',0,1,34,'en',3,9,206),('page',0,1,34,'en',4,10,207),('page',0,1,34,'en',5,11,208),('page',0,1,34,'en',6,12,209),('page',0,1,34,'en',7,23,220),('page',0,1,35,'en',0,1,221),('page',0,1,35,'en',1,2,222),('page',0,1,35,'en',2,6,226),('page',0,1,35,'en',3,9,229),('page',0,1,35,'en',4,10,230),('page',0,1,35,'en',5,11,231),('page',0,1,35,'en',6,12,232),('page',0,1,35,'en',7,23,243),('page',0,1,36,'en',0,1,244),('page',0,1,36,'en',1,2,245),('page',0,1,36,'en',2,6,249),('page',0,1,36,'en',3,9,252),('page',0,1,36,'en',4,10,253),('page',0,1,36,'en',5,11,254),('page',0,1,36,'en',6,12,255),('page',0,1,36,'en',7,23,266),('page',0,1,36,'en',8,26,269),('page',0,1,37,'en',0,1,270),('page',0,1,37,'en',1,2,271),('page',0,1,37,'en',2,6,275),('page',0,1,37,'en',3,9,278),('page',0,1,37,'en',4,10,279),('page',0,1,37,'en',5,11,280),('page',0,1,37,'en',6,30,284),('page',0,1,37,'en',7,12,285),('page',0,1,37,'en',8,23,296),('page',0,1,37,'en',9,26,299),('page',0,1,38,'en',0,1,300),('page',0,1,38,'en',1,2,301),('page',0,1,38,'en',2,6,305),('page',0,1,38,'en',3,9,308),('page',0,1,38,'en',4,10,309),('page',0,1,38,'en',5,11,310),('page',0,1,38,'en',6,30,314),('page',0,1,38,'en',7,12,315),('page',0,1,38,'en',8,23,326),('page',0,1,38,'en',9,26,329),('page',0,1,39,'en',0,1,330),('page',0,1,39,'en',1,2,331),('page',0,1,39,'en',2,6,335),('page',0,1,39,'en',3,9,338),('page',0,1,39,'en',4,10,339),('page',0,1,39,'en',5,11,340),('page',0,1,39,'en',6,30,344),('page',0,1,39,'en',7,12,345),('page',0,1,39,'en',8,23,356),('page',0,1,39,'en',9,26,359),('page',0,1,40,'en',0,1,360),('page',0,1,40,'en',1,2,361),('page',0,1,40,'en',2,6,365),('page',0,1,40,'en',3,9,368),('page',0,1,40,'en',4,10,369),('page',0,1,40,'en',5,11,370),('page',0,1,40,'en',6,30,374),('page',0,1,40,'en',7,12,375),('page',0,1,40,'en',8,23,386),('page',0,1,40,'en',9,26,389),('page',0,1,40,'en',10,33,392),('page',0,1,41,'en',0,1,393),('page',0,1,41,'en',1,2,394),('page',0,1,41,'en',2,6,398),('page',0,1,41,'en',3,9,401),('page',0,1,41,'en',4,10,402),('page',0,1,41,'en',5,11,403),('page',0,1,41,'en',6,30,407),('page',0,1,41,'en',7,12,408),('page',0,1,41,'en',8,23,419),('page',0,1,41,'en',9,26,422),('page',0,1,41,'en',10,33,425),('page',0,1,42,'en',0,1,426),('page',0,1,42,'en',1,2,427),('page',0,1,42,'en',2,6,431),('page',0,1,42,'en',3,9,434),('page',0,1,42,'en',4,10,435),('page',0,1,42,'en',5,11,436),('page',0,1,42,'en',6,30,440),('page',0,1,42,'en',7,12,441),('page',0,1,42,'en',8,23,452),('page',0,1,42,'en',9,26,455),('page',0,1,42,'en',10,33,458),('page',0,1,43,'en',0,1,459),('page',0,1,43,'en',1,2,460),('page',0,1,43,'en',2,6,464),('page',0,1,43,'en',3,9,467),('page',0,1,43,'en',4,10,468),('page',0,1,43,'en',5,11,469),('page',0,1,43,'en',6,30,473),('page',0,1,43,'en',7,12,474),('page',0,1,43,'en',8,23,485),('page',0,1,43,'en',9,26,488),('page',0,1,43,'en',10,33,491),('page',0,1,43,'en',11,36,494),('page',0,1,44,'en',0,1,495),('page',0,1,44,'en',1,2,496),('page',0,1,44,'en',2,6,500),('page',0,1,44,'en',3,9,503),('page',0,1,44,'en',4,10,504),('page',0,1,44,'en',5,11,505),('page',0,1,44,'en',6,30,509),('page',0,1,44,'en',7,12,510),('page',0,1,44,'en',8,23,521),('page',0,1,44,'en',9,26,524),('page',0,1,44,'en',10,33,527),('page',0,1,44,'en',11,36,530),('page',0,1,45,'en',0,1,531),('page',0,1,45,'en',1,2,532),('page',0,1,45,'en',2,6,536),('page',0,1,45,'en',3,9,539),('page',0,1,45,'en',4,10,540),('page',0,1,45,'en',5,11,541),('page',0,1,45,'en',6,30,545),('page',0,1,45,'en',7,12,546),('page',0,1,45,'en',8,23,557),('page',0,1,45,'en',9,26,560),('page',0,1,45,'en',10,33,563),('page',0,1,45,'en',11,36,567),('page',0,19,63,'en',0,38,568),('page',0,19,64,'en',0,39,569),('page',0,19,64,'en',1,38,570),('page',0,19,65,'en',0,40,571),('page',0,19,65,'en',1,39,572),('page',0,19,65,'en',2,38,573),('page',0,19,66,'en',0,40,574),('page',0,19,66,'en',1,39,575),('page',0,19,66,'en',2,38,576),('page',0,19,67,'en',0,40,577),('page',0,19,67,'en',1,39,578),('page',0,19,67,'en',2,38,579),('page',0,19,68,'en',0,40,580),('page',0,19,68,'en',1,39,581),('page',0,19,68,'en',2,38,582);
/*!40000 ALTER TABLE `node_revision__field_components` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision__field_image`
--

DROP TABLE IF EXISTS `node_revision__field_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision__field_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_image_target_id` (`field_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field field_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision__field_image`
--

LOCK TABLES `node_revision__field_image` WRITE;
/*!40000 ALTER TABLE `node_revision__field_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `node_revision__field_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `node_revision__field_tags`
--

DROP TABLE IF EXISTS `node_revision__field_tags`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `node_revision__field_tags` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_tags_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_tags_target_id` (`field_tags_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field field_tags.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `node_revision__field_tags`
--

LOCK TABLES `node_revision__field_tags` WRITE;
/*!40000 ALTER TABLE `node_revision__field_tags` DISABLE KEYS */;
/*!40000 ALTER TABLE `node_revision__field_tags` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_accordion`
--

DROP TABLE IF EXISTS `paragraph__field_ept_accordion`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_accordion` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_accordion_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_accordion_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_accordion_target_id` (`field_ept_accordion_target_id`),
  KEY `field_ept_accordion_target_revision_id` (`field_ept_accordion_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_accordion.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_accordion`
--

LOCK TABLES `paragraph__field_ept_accordion` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_accordion` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_accordion` VALUES ('ept_accordion',0,36,567,'en',0,37,564),('ept_accordion',0,36,567,'en',1,34,565),('ept_accordion',0,36,567,'en',2,35,566);
/*!40000 ALTER TABLE `paragraph__field_ept_accordion` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_accordion_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_accordion_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_accordion_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_accordion_text_value` longtext NOT NULL,
  `field_ept_accordion_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_accordion_text_format` (`field_ept_accordion_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_accordion_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_accordion_text`
--

LOCK TABLES `paragraph__field_ept_accordion_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_accordion_text` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_accordion_text` VALUES ('ept_accordion_section',0,34,565,'en',0,'<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>','full_html'),('ept_accordion_section',0,35,566,'en',0,'<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\" target=\"_blank\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\" target=\"_blank\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\" target=\"_blank\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\" target=\"_blank\">DrupalBook</a></li></ul>','full_html'),('ept_accordion_section',0,37,564,'en',0,'<p>You can install EPT modules as usual Drupal module. Download them with composer, for example:</p><pre><code class=\"language-plaintext\">composer require drupal/ept_tabs</code></pre><p>And then install EPT module as usual.</p><p><a href=\"https://www.drupal.org/docs/develop/using-composer/manage-dependencies#adding-modules\">Download contributed modules using Composer</a></p><p>That\'s it!&nbsp;</p><p>All dependencies will be downloaded with composer automatically.</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_accordion_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_accordion_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_accordion_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_accordion_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_accordion_title_value` longtext NOT NULL,
  `field_ept_accordion_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_accordion_title_format` (`field_ept_accordion_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_accordion_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_accordion_title`
--

LOCK TABLES `paragraph__field_ept_accordion_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_accordion_title` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_accordion_title` VALUES ('ept_accordion_section',0,34,565,'en',0,'<p>Cool! Can I create my own EPT/EBT module?</p>','full_html'),('ept_accordion_section',0,35,566,'en',0,'<p>Send feedback or idea for EPT modules</p>','full_html'),('ept_accordion_section',0,37,564,'en',0,'<p>How to install Extra Paragraph Types (EPT) modules?</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_accordion_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_basic_button_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_basic_button_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_basic_button_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_basic_button_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_basic_button_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_basic_button_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_basic_button_link_uri` (`field_ept_basic_button_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_basic_button…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_basic_button_link`
--

LOCK TABLES `paragraph__field_ept_basic_button_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_basic_button_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_basic_button_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_block_block`
--

DROP TABLE IF EXISTS `paragraph__field_ept_block_block`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_block_block` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_block_block_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ept_block_block_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_block_block_plugin_id` (`field_ept_block_block_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_block_block.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_block_block`
--

LOCK TABLES `paragraph__field_ept_block_block` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_block_block` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_block_block` VALUES ('ept_block',0,39,581,'en',0,'views_exposed_filter_block:what_s_new-block_1',_binary 'a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}');
/*!40000 ALTER TABLE `paragraph__field_ept_block_block` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_bootstrap_button_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_bootstrap_button_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_bootstrap_button_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_bootstrap_button_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_bootstrap_button_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_bootstrap_button_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_bootstrap_button_link_uri` (`field_ept_bootstrap_button_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_bootstrap_button…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_bootstrap_button_link`
--

LOCK TABLES `paragraph__field_ept_bootstrap_button_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_bootstrap_button_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_bootstrap_button_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_carousel`
--

DROP TABLE IF EXISTS `paragraph__field_ept_carousel`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_carousel` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_carousel_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_carousel_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_carousel_target_id` (`field_ept_carousel_target_id`),
  KEY `field_ept_carousel_target_revision_id` (`field_ept_carousel_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_carousel.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_carousel`
--

LOCK TABLES `paragraph__field_ept_carousel` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_carousel` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_carousel` VALUES ('ept_carousel',0,23,557,'en',0,13,547),('ept_carousel',0,23,557,'en',1,14,548),('ept_carousel',0,23,557,'en',2,15,549),('ept_carousel',0,23,557,'en',3,16,550),('ept_carousel',0,23,557,'en',4,17,551),('ept_carousel',0,23,557,'en',5,18,552),('ept_carousel',0,23,557,'en',6,19,553),('ept_carousel',0,23,557,'en',7,20,554),('ept_carousel',0,23,557,'en',8,21,555),('ept_carousel',0,23,557,'en',9,22,556);
/*!40000 ALTER TABLE `paragraph__field_ept_carousel` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_carousel_caption`
--

DROP TABLE IF EXISTS `paragraph__field_ept_carousel_caption`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_carousel_caption` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_carousel_caption_value` longtext NOT NULL,
  `field_ept_carousel_caption_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_carousel_caption_format` (`field_ept_carousel_caption_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_carousel_caption.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_carousel_caption`
--

LOCK TABLES `paragraph__field_ept_carousel_caption` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_carousel_caption` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_carousel_caption` VALUES ('ept_carousel_item',0,13,547,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,14,548,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,15,549,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,16,550,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,17,551,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,18,552,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,19,553,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,20,554,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,21,555,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,22,556,'en',0,'<p>EPT Quote</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_carousel_caption` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_carousel_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_carousel_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_carousel_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_carousel_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_carousel_image_target_id` (`field_ept_carousel_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_carousel_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_carousel_image`
--

LOCK TABLES `paragraph__field_ept_carousel_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_carousel_image` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_carousel_image` VALUES ('ept_carousel_item',0,13,547,'en',0,15),('ept_carousel_item',0,14,548,'en',0,14),('ept_carousel_item',0,15,549,'en',0,13),('ept_carousel_item',0,16,550,'en',0,9),('ept_carousel_item',0,17,551,'en',0,6),('ept_carousel_item',0,18,552,'en',0,4),('ept_carousel_item',0,19,553,'en',0,7),('ept_carousel_item',0,20,554,'en',0,5),('ept_carousel_item',0,21,555,'en',0,10),('ept_carousel_item',0,22,556,'en',0,12);
/*!40000 ALTER TABLE `paragraph__field_ept_carousel_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_clickable_tile`
--

DROP TABLE IF EXISTS `paragraph__field_ept_clickable_tile`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_clickable_tile` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_clickable_tile_value` tinyint NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_clickable_tile.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_clickable_tile`
--

LOCK TABLES `paragraph__field_ept_clickable_tile` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_clickable_tile` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_clickable_tile` VALUES ('ept_tiles_item',0,3,533,'en',0,1),('ept_tiles_item',0,4,534,'en',0,0),('ept_tiles_item',0,5,535,'en',0,1);
/*!40000 ALTER TABLE `paragraph__field_ept_clickable_tile` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_columns`
--

DROP TABLE IF EXISTS `paragraph__field_ept_columns`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_columns` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_columns_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_columns_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_columns_target_id` (`field_ept_columns_target_id`),
  KEY `field_ept_columns_target_revision_id` (`field_ept_columns_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_columns.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_columns`
--

LOCK TABLES `paragraph__field_ept_columns` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_columns` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_columns` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_countdown_date`
--

DROP TABLE IF EXISTS `paragraph__field_ept_countdown_date`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_countdown_date` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_countdown_date_value` varchar(20) NOT NULL COMMENT 'The date value.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_countdown_date_value` (`field_ept_countdown_date_value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_countdown_date.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_countdown_date`
--

LOCK TABLES `paragraph__field_ept_countdown_date` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_countdown_date` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_countdown_date` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_counter_description`
--

DROP TABLE IF EXISTS `paragraph__field_ept_counter_description`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_counter_description` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_description_value` longtext NOT NULL,
  `field_ept_counter_description_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_description_format` (`field_ept_counter_description_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_counter…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_counter_description`
--

LOCK TABLES `paragraph__field_ept_counter_description` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_description` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_description` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_counter_icon`
--

DROP TABLE IF EXISTS `paragraph__field_ept_counter_icon`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_counter_icon` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_icon_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_icon_target_id` (`field_ept_counter_icon_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_counter_icon.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_counter_icon`
--

LOCK TABLES `paragraph__field_ept_counter_icon` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_icon` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_icon` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_counter_items`
--

DROP TABLE IF EXISTS `paragraph__field_ept_counter_items`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_counter_items` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_items_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_counter_items_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_items_target_id` (`field_ept_counter_items_target_id`),
  KEY `field_ept_counter_items_target_revision_id` (`field_ept_counter_items_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_counter_items.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_counter_items`
--

LOCK TABLES `paragraph__field_ept_counter_items` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_items` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_counter_items` VALUES ('ept_counter',0,26,560,'en',0,24,558),('ept_counter',0,26,560,'en',1,25,559);
/*!40000 ALTER TABLE `paragraph__field_ept_counter_items` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_counter_number`
--

DROP TABLE IF EXISTS `paragraph__field_ept_counter_number`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_counter_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_number_value` int NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_counter_number.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_counter_number`
--

LOCK TABLES `paragraph__field_ept_counter_number` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_number` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_counter_number` VALUES ('ept_counter_item',0,24,558,'en',0,25),('ept_counter_item',0,25,559,'en',0,25);
/*!40000 ALTER TABLE `paragraph__field_ept_counter_number` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_counter_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_counter_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_counter_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_title_value` longtext NOT NULL,
  `field_ept_counter_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_title_format` (`field_ept_counter_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_counter_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_counter_title`
--

LOCK TABLES `paragraph__field_ept_counter_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_counter_title` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_counter_title` VALUES ('ept_counter_item',0,24,558,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,25,559,'en',0,'<p>EBT Modules</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_counter_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_cta_column_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_cta_column_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_cta_column_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_cta_column_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_cta_column_image_target_id` (`field_ept_cta_column_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_cta_column_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_cta_column_image`
--

LOCK TABLES `paragraph__field_ept_cta_column_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_cta_column_image` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_cta_column_image` VALUES ('ept_cta',0,11,541,'en',0,16);
/*!40000 ALTER TABLE `paragraph__field_ept_cta_column_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_cta_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_cta_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_cta_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_cta_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_cta_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_cta_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_cta_link_uri` (`field_ept_cta_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_cta_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_cta_link`
--

LOCK TABLES `paragraph__field_ept_cta_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_cta_link` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_cta_link` VALUES ('ept_cta',0,11,541,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph__field_ept_cta_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_cta_second_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_cta_second_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_cta_second_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_cta_second_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_cta_second_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_cta_second_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_cta_second_link_uri` (`field_ept_cta_second_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_cta_second_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_cta_second_link`
--

LOCK TABLES `paragraph__field_ept_cta_second_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_cta_second_link` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_cta_second_link` VALUES ('ept_cta',0,11,541,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph__field_ept_cta_second_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_gallery_item`
--

DROP TABLE IF EXISTS `paragraph__field_ept_gallery_item`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_gallery_item` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_gallery_item_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_gallery_item_target_id` (`field_ept_gallery_item_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_gallery_item.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_gallery_item`
--

LOCK TABLES `paragraph__field_ept_gallery_item` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_gallery_item` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_gallery_item` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_gallery_item_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_gallery_item_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_gallery_item_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_gallery_item_text_value` longtext NOT NULL,
  `field_ept_gallery_item_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_gallery_item_text_format` (`field_ept_gallery_item_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_gallery_item…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_gallery_item_text`
--

LOCK TABLES `paragraph__field_ept_gallery_item_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_gallery_item_text` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_gallery_item_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_hero_column_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_hero_column_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_hero_column_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_column_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_column_image_target_id` (`field_ept_hero_column_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_hero_column…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_hero_column_image`
--

LOCK TABLES `paragraph__field_ept_hero_column_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_hero_column_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_hero_column_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_hero_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_hero_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_hero_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_hero_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_hero_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_link_uri` (`field_ept_hero_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_hero_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_hero_link`
--

LOCK TABLES `paragraph__field_ept_hero_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_hero_link` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_hero_link` VALUES ('ept_hero',0,1,531,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph__field_ept_hero_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_hero_second_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_hero_second_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_hero_second_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_second_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_hero_second_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_hero_second_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_second_link_uri` (`field_ept_hero_second_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_hero_second_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_hero_second_link`
--

LOCK TABLES `paragraph__field_ept_hero_second_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_hero_second_link` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_hero_second_link` VALUES ('ept_hero',0,1,531,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph__field_ept_hero_second_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_hero_title_prefix`
--

DROP TABLE IF EXISTS `paragraph__field_ept_hero_title_prefix`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_hero_title_prefix` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_title_prefix_value` longtext NOT NULL,
  `field_ept_hero_title_prefix_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_title_prefix_format` (`field_ept_hero_title_prefix_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_hero_title…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_hero_title_prefix`
--

LOCK TABLES `paragraph__field_ept_hero_title_prefix` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_hero_title_prefix` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_hero_title_prefix` VALUES ('ept_hero',0,1,531,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,40,580,'en',0,'<p>Listing Page</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_hero_title_prefix` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_target_id` (`field_ept_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_image`
--

LOCK TABLES `paragraph__field_ept_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_image_caption`
--

DROP TABLE IF EXISTS `paragraph__field_ept_image_caption`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_image_caption` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_caption_value` longtext NOT NULL,
  `field_ept_image_caption_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_caption_format` (`field_ept_image_caption_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_image_caption.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_image_caption`
--

LOCK TABLES `paragraph__field_ept_image_caption` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_image_caption` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_image_caption` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_image_gallery`
--

DROP TABLE IF EXISTS `paragraph__field_ept_image_gallery`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_image_gallery` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_gallery_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_gallery_target_id` (`field_ept_image_gallery_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_image_gallery.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_image_gallery`
--

LOCK TABLES `paragraph__field_ept_image_gallery` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_image_gallery` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_image_gallery` VALUES ('ept_image_gallery',0,10,540,'en',0,4),('ept_image_gallery',0,10,540,'en',1,5),('ept_image_gallery',0,10,540,'en',2,6),('ept_image_gallery',0,10,540,'en',3,7),('ept_image_gallery',0,10,540,'en',4,9),('ept_image_gallery',0,10,540,'en',5,10),('ept_image_gallery',0,10,540,'en',6,11),('ept_image_gallery',0,10,540,'en',7,12),('ept_image_gallery',0,10,540,'en',8,13),('ept_image_gallery',0,10,540,'en',9,14),('ept_image_gallery',0,10,540,'en',10,15);
/*!40000 ALTER TABLE `paragraph__field_ept_image_gallery` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_image_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_image_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_image_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_image_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_image_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_link_uri` (`field_ept_image_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_image_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_image_link`
--

LOCK TABLES `paragraph__field_ept_image_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_image_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_image_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_micromodal_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_micromodal_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_micromodal_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_micromodal_title_value` longtext NOT NULL,
  `field_ept_micromodal_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_micromodal_title_format` (`field_ept_micromodal_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_micromodal_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_micromodal_title`
--

LOCK TABLES `paragraph__field_ept_micromodal_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_micromodal_title` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_micromodal_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_quote_author`
--

DROP TABLE IF EXISTS `paragraph__field_ept_quote_author`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_quote_author` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_quote_author_value` longtext NOT NULL,
  `field_ept_quote_author_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_quote_author_format` (`field_ept_quote_author_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_quote_author.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_quote_author`
--

LOCK TABLES `paragraph__field_ept_quote_author` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_quote_author` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_quote_author` VALUES ('ept_quote',0,12,546,'en',0,'<p>Hockey Club</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_quote_author` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_quote_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_quote_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_quote_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_quote_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_quote_image_target_id` (`field_ept_quote_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_quote_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_quote_image`
--

LOCK TABLES `paragraph__field_ept_quote_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_quote_image` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_quote_image` VALUES ('ept_quote',0,12,546,'en',0,18);
/*!40000 ALTER TABLE `paragraph__field_ept_quote_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_settings`
--

DROP TABLE IF EXISTS `paragraph__field_ept_settings`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_settings` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_settings_ept_settings` longblob COMMENT 'Serialized paragraph settings data',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_settings.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_settings`
--

LOCK TABLES `paragraph__field_ept_settings` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_settings` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_settings` VALUES ('ept_hero',0,1,531,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_text',0,2,532,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_tiles',0,6,536,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_stats',0,9,539,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_image_gallery',0,10,540,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_cta',0,11,541,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_quote',0,12,546,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_carousel',0,23,557,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_counter',0,26,560,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_slideshow',0,30,545,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_tabs',0,33,563,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_accordion',0,36,567,'en',0,_binary 'a:12:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"40\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"plus_minus_left\";s:11:\"collapsible\";i:1;s:6:\"closed\";i:1;s:6:\"opened\";i:0;s:16:\"closed_in_tablet\";i:0;s:16:\"closed_in_mobile\";i:0;s:6:\"active\";s:0:\"\";s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_views',0,38,582,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_block',0,39,581,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_hero',0,40,580,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"50\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"50\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}');
/*!40000 ALTER TABLE `paragraph__field_ept_settings` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slick_slider`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slick_slider`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slick_slider` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_slick_slider_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_target_id` (`field_ept_slick_slider_target_id`),
  KEY `field_ept_slick_slider_target_revision_id` (`field_ept_slick_slider_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slick_slider.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slick_slider`
--

LOCK TABLES `paragraph__field_ept_slick_slider` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slick_slider_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slick_slider_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slick_slider_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_image_target_id` (`field_ept_slick_slider_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slick_slider…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slick_slider_image`
--

LOCK TABLES `paragraph__field_ept_slick_slider_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slick_slider_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slick_slider_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slick_slider_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_slick_slider_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_slick_slider_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_link_uri` (`field_ept_slick_slider_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slick_slider…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slick_slider_link`
--

LOCK TABLES `paragraph__field_ept_slick_slider_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slick_slider_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slick_slider_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slick_slider_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_text_value` longtext NOT NULL,
  `field_ept_slick_slider_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_text_format` (`field_ept_slick_slider_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slick_slider…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slick_slider_text`
--

LOCK TABLES `paragraph__field_ept_slick_slider_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider_text` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_slick_slider_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slideshow`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slideshow`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slideshow` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_slideshow_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_target_id` (`field_ept_slideshow_target_id`),
  KEY `field_ept_slideshow_target_revision_id` (`field_ept_slideshow_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slideshow.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slideshow`
--

LOCK TABLES `paragraph__field_ept_slideshow` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_slideshow` VALUES ('ept_slideshow',0,30,545,'en',0,27,542),('ept_slideshow',0,30,545,'en',1,28,543),('ept_slideshow',0,30,545,'en',2,29,544);
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slideshow_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slideshow_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slideshow_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_slideshow_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_slideshow_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_link_uri` (`field_ept_slideshow_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slideshow_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slideshow_link`
--

LOCK TABLES `paragraph__field_ept_slideshow_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slideshow_slide`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slideshow_slide`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slideshow_slide` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_slide_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_slide_target_id` (`field_ept_slideshow_slide_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slideshow_slide.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slideshow_slide`
--

LOCK TABLES `paragraph__field_ept_slideshow_slide` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_slide` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_slideshow_slide` VALUES ('ept_slideshow_item',0,27,542,'en',0,20),('ept_slideshow_item',0,28,543,'en',0,21),('ept_slideshow_item',0,29,544,'en',0,22);
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_slide` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slideshow_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slideshow_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slideshow_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_text_value` longtext NOT NULL,
  `field_ept_slideshow_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_text_format` (`field_ept_slideshow_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slideshow_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slideshow_text`
--

LOCK TABLES `paragraph__field_ept_slideshow_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_text` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_slideshow_text` VALUES ('ept_slideshow_item',0,27,542,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,28,543,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,29,544,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_slideshow_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_slideshow_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_slideshow_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_title_value` longtext NOT NULL,
  `field_ept_slideshow_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_title_format` (`field_ept_slideshow_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_slideshow_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_slideshow_title`
--

LOCK TABLES `paragraph__field_ept_slideshow_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_title` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_slideshow_title` VALUES ('ept_slideshow_item',0,27,542,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,28,543,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,29,544,'en',0,'<p>Settings for javascript plugins</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_slideshow_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_stats`
--

DROP TABLE IF EXISTS `paragraph__field_ept_stats`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_stats` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_stats_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_target_id` (`field_ept_stats_target_id`),
  KEY `field_ept_stats_target_revision_id` (`field_ept_stats_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_stats.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_stats`
--

LOCK TABLES `paragraph__field_ept_stats` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_stats` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_stats` VALUES ('ept_stats',0,9,539,'en',0,7,537),('ept_stats',0,9,539,'en',1,8,538);
/*!40000 ALTER TABLE `paragraph__field_ept_stats` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_stats_item_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_stats_item_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_stats_item_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_image_target_id` (`field_ept_stats_item_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_stats_item_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_stats_item_image`
--

LOCK TABLES `paragraph__field_ept_stats_item_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_stats_item_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_stats_item_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_stats_item_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_stats_item_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_stats_item_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_link_uri` (`field_ept_stats_item_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_stats_item_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_stats_item_link`
--

LOCK TABLES `paragraph__field_ept_stats_item_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_stats_item_number`
--

DROP TABLE IF EXISTS `paragraph__field_ept_stats_item_number`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_stats_item_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_number_value` longtext NOT NULL,
  `field_ept_stats_item_number_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_number_format` (`field_ept_stats_item_number_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_stats_item…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_stats_item_number`
--

LOCK TABLES `paragraph__field_ept_stats_item_number` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_number` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_stats_item_number` VALUES ('ept_stats_item',0,7,537,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,8,538,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_number` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_stats_item_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_stats_item_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_stats_item_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_text_value` longtext NOT NULL,
  `field_ept_stats_item_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_text_format` (`field_ept_stats_item_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_stats_item_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_stats_item_text`
--

LOCK TABLES `paragraph__field_ept_stats_item_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_text` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_stats_item_text` VALUES ('ept_stats_item',0,7,537,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,8,538,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_stats_item_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tab_block`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tab_block`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tab_block` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_block_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ept_tab_block_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_block_plugin_id` (`field_ept_tab_block_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tab_block.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tab_block`
--

LOCK TABLES `paragraph__field_ept_tab_block` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_block` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_block` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tab_content`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tab_content`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tab_content` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_content_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_content_value` (`field_ept_tab_content_value`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tab_content.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tab_content`
--

LOCK TABLES `paragraph__field_ept_tab_content` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_content` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tab_content` VALUES ('ept_tabs_item',0,31,561,'en',0,'text'),('ept_tabs_item',0,32,562,'en',0,'text');
/*!40000 ALTER TABLE `paragraph__field_ept_tab_content` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tab_page`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tab_page`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tab_page` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_page_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_page_target_id` (`field_ept_tab_page_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tab_page.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tab_page`
--

LOCK TABLES `paragraph__field_ept_tab_page` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_page` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_page` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tab_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tab_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tab_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_text_value` longtext NOT NULL,
  `field_ept_tab_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_text_format` (`field_ept_tab_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tab_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tab_text`
--

LOCK TABLES `paragraph__field_ept_tab_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_text` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tab_text` VALUES ('ept_tabs_item',0,31,561,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,562,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_tab_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tab_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tab_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tab_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_title_value` varchar(255) NOT NULL,
  `field_ept_tab_title_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_title_format` (`field_ept_tab_title_format`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tab_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tab_title`
--

LOCK TABLES `paragraph__field_ept_tab_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_title` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tab_title` VALUES ('ept_tabs_item',0,31,561,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,32,562,'en',0,'EBT Modules','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_tab_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tab_views`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tab_views`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tab_views` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_views_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_tab_views_display_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The ID of the display.',
  `field_ept_tab_views_data` longtext COMMENT 'Serialized data.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_views_target_id` (`field_ept_tab_views_target_id`),
  KEY `field_ept_tab_views_display_id` (`field_ept_tab_views_display_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tab_views.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tab_views`
--

LOCK TABLES `paragraph__field_ept_tab_views` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_views` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_tab_views` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tabs`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tabs`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tabs` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tabs_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_tabs_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tabs_target_id` (`field_ept_tabs_target_id`),
  KEY `field_ept_tabs_target_revision_id` (`field_ept_tabs_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tabs.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tabs`
--

LOCK TABLES `paragraph__field_ept_tabs` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tabs` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tabs` VALUES ('ept_tabs',0,33,563,'en',0,31,561),('ept_tabs',0,33,563,'en',1,32,562);
/*!40000 ALTER TABLE `paragraph__field_ept_tabs` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_text_value` longtext NOT NULL,
  `field_ept_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_text_format` (`field_ept_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_text`
--

LOCK TABLES `paragraph__field_ept_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_text` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_text` VALUES ('ept_hero',0,1,531,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_text',0,2,532,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_stats',0,9,539,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_cta',0,11,541,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_quote',0,12,546,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_hero',0,40,580,'en',0,'<p>Stay tuned!</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tiles`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tiles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tiles` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_tiles_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_target_id` (`field_ept_tiles_target_id`),
  KEY `field_ept_tiles_target_revision_id` (`field_ept_tiles_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tiles.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tiles`
--

LOCK TABLES `paragraph__field_ept_tiles` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tiles` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tiles` VALUES ('ept_tiles',0,6,536,'en',0,3,533),('ept_tiles',0,6,536,'en',1,4,534),('ept_tiles',0,6,536,'en',2,5,535);
/*!40000 ALTER TABLE `paragraph__field_ept_tiles` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tiles_image`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tiles_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tiles_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_image_target_id` (`field_ept_tiles_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tiles_image.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tiles_image`
--

LOCK TABLES `paragraph__field_ept_tiles_image` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tiles_link`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tiles_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tiles_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_tiles_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_tiles_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_link_uri` (`field_ept_tiles_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tiles_link.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tiles_link`
--

LOCK TABLES `paragraph__field_ept_tiles_link` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_link` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tiles_link` VALUES ('ept_tiles_item',0,3,533,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,5,535,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tiles_text`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tiles_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tiles_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_text_value` longtext NOT NULL,
  `field_ept_tiles_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_text_format` (`field_ept_tiles_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tiles_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tiles_text`
--

LOCK TABLES `paragraph__field_ept_tiles_text` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_text` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tiles_text` VALUES ('ept_tiles_item',0,3,533,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,4,534,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,5,535,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_tiles_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_tiles_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_tiles_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_title_value` longtext NOT NULL,
  `field_ept_tiles_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_title_format` (`field_ept_tiles_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_tiles_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_tiles_title`
--

LOCK TABLES `paragraph__field_ept_tiles_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_title` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_tiles_title` VALUES ('ept_tiles_item',0,3,533,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,4,534,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,5,535,'en',0,'<p>Start Creating</p>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_tiles_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_title`
--

DROP TABLE IF EXISTS `paragraph__field_ept_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_title_value` longtext NOT NULL,
  `field_ept_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_title_format` (`field_ept_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_title.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_title`
--

LOCK TABLES `paragraph__field_ept_title` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_title` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_title` VALUES ('ept_hero',0,1,531,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_text',0,2,532,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_tiles',0,6,536,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_stats',0,9,539,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_image_gallery',0,10,540,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_cta',0,11,541,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_quote',0,12,546,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_carousel',0,23,557,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_counter',0,26,560,'en',0,'<p>Number of modules</p>','full_html'),('ept_slideshow',0,30,545,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_tabs',0,33,563,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>','full_html'),('ept_accordion',0,36,567,'en',0,'<p>FAQ</p>','full_html'),('ept_hero',0,40,580,'en',0,'<h1>What\'s New</h1>','full_html');
/*!40000 ALTER TABLE `paragraph__field_ept_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_video`
--

DROP TABLE IF EXISTS `paragraph__field_ept_video`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_video` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_video_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_video_target_id` (`field_ept_video_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_video.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_video`
--

LOCK TABLES `paragraph__field_ept_video` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_video` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_video` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_videos_and_images`
--

DROP TABLE IF EXISTS `paragraph__field_ept_videos_and_images`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_videos_and_images` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_videos_and_images_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_videos_and_images_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_videos_and_images_target_id` (`field_ept_videos_and_images_target_id`),
  KEY `field_ept_videos_and_images_target_revision_id` (`field_ept_videos_and_images_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_videos_and…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_videos_and_images`
--

LOCK TABLES `paragraph__field_ept_videos_and_images` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_videos_and_images` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph__field_ept_videos_and_images` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph__field_ept_views_view`
--

DROP TABLE IF EXISTS `paragraph__field_ept_views_view`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph__field_ept_views_view` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_views_view_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_views_view_display_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The ID of the display.',
  `field_ept_views_view_data` longtext COMMENT 'Serialized data.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_views_view_target_id` (`field_ept_views_view_target_id`),
  KEY `field_ept_views_view_display_id` (`field_ept_views_view_display_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ept_views_view.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph__field_ept_views_view`
--

LOCK TABLES `paragraph__field_ept_views_view` WRITE;
/*!40000 ALTER TABLE `paragraph__field_ept_views_view` DISABLE KEYS */;
INSERT INTO `paragraph__field_ept_views_view` VALUES ('ept_views',0,38,582,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}');
/*!40000 ALTER TABLE `paragraph__field_ept_views_view` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_r__32204566b2`
--

DROP TABLE IF EXISTS `paragraph_r__32204566b2`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_r__32204566b2` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_bootstrap_button_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_bootstrap_button_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_bootstrap_button_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_bootstrap_button_link_uri` (`field_ept_bootstrap_button_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_r__32204566b2`
--

LOCK TABLES `paragraph_r__32204566b2` WRITE;
/*!40000 ALTER TABLE `paragraph_r__32204566b2` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_r__32204566b2` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_r__f6562160d8`
--

DROP TABLE IF EXISTS `paragraph_r__f6562160d8`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_r__f6562160d8` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_description_value` longtext NOT NULL,
  `field_ept_counter_description_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_description_format` (`field_ept_counter_description_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_r__f6562160d8`
--

LOCK TABLES `paragraph_r__f6562160d8` WRITE;
/*!40000 ALTER TABLE `paragraph_r__f6562160d8` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_r__f6562160d8` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_accordion`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_accordion`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_accordion` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_accordion_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_accordion_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_accordion_target_id` (`field_ept_accordion_target_id`),
  KEY `field_ept_accordion_target_revision_id` (`field_ept_accordion_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_accordion`
--

LOCK TABLES `paragraph_revision__field_ept_accordion` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_accordion` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_accordion` VALUES ('ept_accordion',0,36,494,'en',0,34,492),('ept_accordion',0,36,494,'en',1,35,493),('ept_accordion',0,36,530,'en',0,34,528),('ept_accordion',0,36,530,'en',1,35,529),('ept_accordion',0,36,567,'en',0,37,564),('ept_accordion',0,36,567,'en',1,34,565),('ept_accordion',0,36,567,'en',2,35,566);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_accordion` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_accordion_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_accordion_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_accordion_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_accordion_text_value` longtext NOT NULL,
  `field_ept_accordion_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_accordion_text_format` (`field_ept_accordion_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_accordion_text`
--

LOCK TABLES `paragraph_revision__field_ept_accordion_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_accordion_text` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_accordion_text` VALUES ('ept_accordion_section',0,34,492,'en',0,'<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>','full_html'),('ept_accordion_section',0,34,528,'en',0,'<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>','full_html'),('ept_accordion_section',0,34,565,'en',0,'<p>Yes, sure, here is documentation for EPT/EBT modules:</p><p><a href=\"https://drupalbook.org/ept/creating-new-ept-module\">https://drupalbook.org/ept/creating-new-ept-module</a></p><p>In short EPT module can be generated with Drush command:</p><pre><code class=\"language-plaintext\">drush generate ept:module</code></pre><p>Then you can extend your new component as usual Drupal Paragraph type.</p><p><a href=\"https://drupalbook.org/ebt/extending-ebt-settings-form\">Extending EBT Settings form</a> - it\'s for EBT (block type), just use ept_ instead of ebt_&nbsp;</p><p>&nbsp;</p>','full_html'),('ept_accordion_section',0,35,493,'en',0,'<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\">DrupalBook</a></li></ul>','full_html'),('ept_accordion_section',0,35,529,'en',0,'<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\" target=\"_blank\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\" target=\"_blank\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\" target=\"_blank\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\" target=\"_blank\">DrupalBook</a></li></ul>','full_html'),('ept_accordion_section',0,35,566,'en',0,'<p>You can send me a message using any of the contact forms below, or by following the link in the header or footer:</p><ul><li><a href=\"https://www.linkedin.com/in/ivan-abramenko/\" target=\"_blank\">LinkedIn</a></li><li><a href=\"https://www.drupal.org/user/1079574/contact\" target=\"_blank\">Drupal.org</a></li><li><a href=\"https://drupal.slack.com/archives/C07A942U72P\" target=\"_blank\">Slack</a></li><li><a href=\"https://drupalbook.org/contact\" target=\"_blank\">DrupalBook</a></li></ul>','full_html'),('ept_accordion_section',0,37,564,'en',0,'<p>You can install EPT modules as usual Drupal module. Download them with composer, for example:</p><pre><code class=\"language-plaintext\">composer require drupal/ept_tabs</code></pre><p>And then install EPT module as usual.</p><p><a href=\"https://www.drupal.org/docs/develop/using-composer/manage-dependencies#adding-modules\">Download contributed modules using Composer</a></p><p>That\'s it!&nbsp;</p><p>All dependencies will be downloaded with composer automatically.</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_accordion_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_accordion_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_accordion_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_accordion_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_accordion_title_value` longtext NOT NULL,
  `field_ept_accordion_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_accordion_title_format` (`field_ept_accordion_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_accordion_title`
--

LOCK TABLES `paragraph_revision__field_ept_accordion_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_accordion_title` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_accordion_title` VALUES ('ept_accordion_section',0,34,492,'en',0,'<p>Cool! Can I create my own EPT/EBT module?</p>','full_html'),('ept_accordion_section',0,34,528,'en',0,'<p>Cool! Can I create my own EPT/EBT module?</p>','full_html'),('ept_accordion_section',0,34,565,'en',0,'<p>Cool! Can I create my own EPT/EBT module?</p>','full_html'),('ept_accordion_section',0,35,493,'en',0,'<p>Send feedback or idea for EPT modules</p>','full_html'),('ept_accordion_section',0,35,529,'en',0,'<p>Send feedback or idea for EPT modules</p>','full_html'),('ept_accordion_section',0,35,566,'en',0,'<p>Send feedback or idea for EPT modules</p>','full_html'),('ept_accordion_section',0,37,564,'en',0,'<p>How to install Extra Paragraph Types (EPT) modules?</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_accordion_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_basic_button_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_basic_button_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_basic_button_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_basic_button_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_basic_button_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_basic_button_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_basic_button_link_uri` (`field_ept_basic_button_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_basic_button_link`
--

LOCK TABLES `paragraph_revision__field_ept_basic_button_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_basic_button_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_basic_button_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_block_block`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_block_block`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_block_block` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_block_block_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ept_block_block_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_block_block_plugin_id` (`field_ept_block_block_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_block_block`
--

LOCK TABLES `paragraph_revision__field_ept_block_block` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_block_block` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_block_block` VALUES ('ept_block',0,39,569,'en',0,'views_exposed_filter_block:what_s_new-block_1',_binary 'a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}'),('ept_block',0,39,572,'en',0,'views_exposed_filter_block:what_s_new-block_1',_binary 'a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}'),('ept_block',0,39,575,'en',0,'views_exposed_filter_block:what_s_new-block_1',_binary 'a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}'),('ept_block',0,39,578,'en',0,'views_exposed_filter_block:what_s_new-block_1',_binary 'a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}'),('ept_block',0,39,581,'en',0,'views_exposed_filter_block:what_s_new-block_1',_binary 'a:5:{s:2:\"id\";s:45:\"views_exposed_filter_block:what_s_new-block_1\";s:5:\"label\";s:0:\"\";s:13:\"label_display\";b:0;s:8:\"provider\";s:5:\"views\";s:11:\"views_label\";s:0:\"\";}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_block_block` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_carousel`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_carousel`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_carousel` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_carousel_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_carousel_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_carousel_target_id` (`field_ept_carousel_target_id`),
  KEY `field_ept_carousel_target_revision_id` (`field_ept_carousel_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_carousel`
--

LOCK TABLES `paragraph_revision__field_ept_carousel` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_carousel` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_carousel` VALUES ('ept_carousel',0,23,220,'en',0,13,210),('ept_carousel',0,23,220,'en',1,14,211),('ept_carousel',0,23,220,'en',2,15,212),('ept_carousel',0,23,220,'en',3,16,213),('ept_carousel',0,23,220,'en',4,17,214),('ept_carousel',0,23,220,'en',5,18,215),('ept_carousel',0,23,220,'en',6,19,216),('ept_carousel',0,23,220,'en',7,20,217),('ept_carousel',0,23,220,'en',8,21,218),('ept_carousel',0,23,220,'en',9,22,219),('ept_carousel',0,23,243,'en',0,13,233),('ept_carousel',0,23,243,'en',1,14,234),('ept_carousel',0,23,243,'en',2,15,235),('ept_carousel',0,23,243,'en',3,16,236),('ept_carousel',0,23,243,'en',4,17,237),('ept_carousel',0,23,243,'en',5,18,238),('ept_carousel',0,23,243,'en',6,19,239),('ept_carousel',0,23,243,'en',7,20,240),('ept_carousel',0,23,243,'en',8,21,241),('ept_carousel',0,23,243,'en',9,22,242),('ept_carousel',0,23,266,'en',0,13,256),('ept_carousel',0,23,266,'en',1,14,257),('ept_carousel',0,23,266,'en',2,15,258),('ept_carousel',0,23,266,'en',3,16,259),('ept_carousel',0,23,266,'en',4,17,260),('ept_carousel',0,23,266,'en',5,18,261),('ept_carousel',0,23,266,'en',6,19,262),('ept_carousel',0,23,266,'en',7,20,263),('ept_carousel',0,23,266,'en',8,21,264),('ept_carousel',0,23,266,'en',9,22,265),('ept_carousel',0,23,296,'en',0,13,286),('ept_carousel',0,23,296,'en',1,14,287),('ept_carousel',0,23,296,'en',2,15,288),('ept_carousel',0,23,296,'en',3,16,289),('ept_carousel',0,23,296,'en',4,17,290),('ept_carousel',0,23,296,'en',5,18,291),('ept_carousel',0,23,296,'en',6,19,292),('ept_carousel',0,23,296,'en',7,20,293),('ept_carousel',0,23,296,'en',8,21,294),('ept_carousel',0,23,296,'en',9,22,295),('ept_carousel',0,23,326,'en',0,13,316),('ept_carousel',0,23,326,'en',1,14,317),('ept_carousel',0,23,326,'en',2,15,318),('ept_carousel',0,23,326,'en',3,16,319),('ept_carousel',0,23,326,'en',4,17,320),('ept_carousel',0,23,326,'en',5,18,321),('ept_carousel',0,23,326,'en',6,19,322),('ept_carousel',0,23,326,'en',7,20,323),('ept_carousel',0,23,326,'en',8,21,324),('ept_carousel',0,23,326,'en',9,22,325),('ept_carousel',0,23,356,'en',0,13,346),('ept_carousel',0,23,356,'en',1,14,347),('ept_carousel',0,23,356,'en',2,15,348),('ept_carousel',0,23,356,'en',3,16,349),('ept_carousel',0,23,356,'en',4,17,350),('ept_carousel',0,23,356,'en',5,18,351),('ept_carousel',0,23,356,'en',6,19,352),('ept_carousel',0,23,356,'en',7,20,353),('ept_carousel',0,23,356,'en',8,21,354),('ept_carousel',0,23,356,'en',9,22,355),('ept_carousel',0,23,386,'en',0,13,376),('ept_carousel',0,23,386,'en',1,14,377),('ept_carousel',0,23,386,'en',2,15,378),('ept_carousel',0,23,386,'en',3,16,379),('ept_carousel',0,23,386,'en',4,17,380),('ept_carousel',0,23,386,'en',5,18,381),('ept_carousel',0,23,386,'en',6,19,382),('ept_carousel',0,23,386,'en',7,20,383),('ept_carousel',0,23,386,'en',8,21,384),('ept_carousel',0,23,386,'en',9,22,385),('ept_carousel',0,23,419,'en',0,13,409),('ept_carousel',0,23,419,'en',1,14,410),('ept_carousel',0,23,419,'en',2,15,411),('ept_carousel',0,23,419,'en',3,16,412),('ept_carousel',0,23,419,'en',4,17,413),('ept_carousel',0,23,419,'en',5,18,414),('ept_carousel',0,23,419,'en',6,19,415),('ept_carousel',0,23,419,'en',7,20,416),('ept_carousel',0,23,419,'en',8,21,417),('ept_carousel',0,23,419,'en',9,22,418),('ept_carousel',0,23,452,'en',0,13,442),('ept_carousel',0,23,452,'en',1,14,443),('ept_carousel',0,23,452,'en',2,15,444),('ept_carousel',0,23,452,'en',3,16,445),('ept_carousel',0,23,452,'en',4,17,446),('ept_carousel',0,23,452,'en',5,18,447),('ept_carousel',0,23,452,'en',6,19,448),('ept_carousel',0,23,452,'en',7,20,449),('ept_carousel',0,23,452,'en',8,21,450),('ept_carousel',0,23,452,'en',9,22,451),('ept_carousel',0,23,485,'en',0,13,475),('ept_carousel',0,23,485,'en',1,14,476),('ept_carousel',0,23,485,'en',2,15,477),('ept_carousel',0,23,485,'en',3,16,478),('ept_carousel',0,23,485,'en',4,17,479),('ept_carousel',0,23,485,'en',5,18,480),('ept_carousel',0,23,485,'en',6,19,481),('ept_carousel',0,23,485,'en',7,20,482),('ept_carousel',0,23,485,'en',8,21,483),('ept_carousel',0,23,485,'en',9,22,484),('ept_carousel',0,23,521,'en',0,13,511),('ept_carousel',0,23,521,'en',1,14,512),('ept_carousel',0,23,521,'en',2,15,513),('ept_carousel',0,23,521,'en',3,16,514),('ept_carousel',0,23,521,'en',4,17,515),('ept_carousel',0,23,521,'en',5,18,516),('ept_carousel',0,23,521,'en',6,19,517),('ept_carousel',0,23,521,'en',7,20,518),('ept_carousel',0,23,521,'en',8,21,519),('ept_carousel',0,23,521,'en',9,22,520),('ept_carousel',0,23,557,'en',0,13,547),('ept_carousel',0,23,557,'en',1,14,548),('ept_carousel',0,23,557,'en',2,15,549),('ept_carousel',0,23,557,'en',3,16,550),('ept_carousel',0,23,557,'en',4,17,551),('ept_carousel',0,23,557,'en',5,18,552),('ept_carousel',0,23,557,'en',6,19,553),('ept_carousel',0,23,557,'en',7,20,554),('ept_carousel',0,23,557,'en',8,21,555),('ept_carousel',0,23,557,'en',9,22,556);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_carousel` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_carousel_caption`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_carousel_caption`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_carousel_caption` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_carousel_caption_value` longtext NOT NULL,
  `field_ept_carousel_caption_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_carousel_caption_format` (`field_ept_carousel_caption_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_carousel_caption`
--

LOCK TABLES `paragraph_revision__field_ept_carousel_caption` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_carousel_caption` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_carousel_caption` VALUES ('ept_carousel_item',0,13,210,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,233,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,256,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,286,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,316,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,346,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,376,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,409,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,442,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,475,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,511,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,13,547,'en',0,'<p>EPT Counter</p>','full_html'),('ept_carousel_item',0,14,211,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,234,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,257,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,287,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,317,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,347,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,377,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,410,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,443,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,476,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,512,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,14,548,'en',0,'<p>EPT Text</p>','full_html'),('ept_carousel_item',0,15,212,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,235,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,258,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,288,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,318,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,348,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,378,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,411,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,444,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,477,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,513,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,15,549,'en',0,'<p>EPT Tiles</p>','full_html'),('ept_carousel_item',0,16,213,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,236,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,259,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,289,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,319,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,349,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,379,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,412,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,445,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,478,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,514,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,16,550,'en',0,'<p>EPT Slick Slider</p>','full_html'),('ept_carousel_item',0,17,214,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,237,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,260,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,290,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,320,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,350,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,380,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,413,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,446,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,479,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,515,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,17,551,'en',0,'<p>EPT Call to action</p>','full_html'),('ept_carousel_item',0,18,215,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,238,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,261,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,291,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,321,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,351,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,381,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,414,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,447,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,480,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,516,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,18,552,'en',0,'<p>EPT Image Gallery</p>','full_html'),('ept_carousel_item',0,19,216,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,239,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,262,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,292,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,322,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,352,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,382,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,415,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,448,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,481,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,517,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,19,553,'en',0,'<p>EPT Tabs</p>','full_html'),('ept_carousel_item',0,20,217,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,240,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,263,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,293,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,323,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,353,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,383,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,416,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,449,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,482,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,518,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,20,554,'en',0,'<p>EPT Accordion/FAQ</p>','full_html'),('ept_carousel_item',0,21,218,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,241,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,264,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,294,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,324,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,354,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,384,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,417,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,450,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,483,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,519,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,21,555,'en',0,'<p>EPT Carousel</p>','full_html'),('ept_carousel_item',0,22,219,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,242,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,265,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,295,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,325,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,355,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,385,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,418,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,451,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,484,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,520,'en',0,'<p>EPT Quote</p>','full_html'),('ept_carousel_item',0,22,556,'en',0,'<p>EPT Quote</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_carousel_caption` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_carousel_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_carousel_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_carousel_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_carousel_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_carousel_image_target_id` (`field_ept_carousel_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_carousel_image`
--

LOCK TABLES `paragraph_revision__field_ept_carousel_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_carousel_image` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_carousel_image` VALUES ('ept_carousel_item',0,13,210,'en',0,15),('ept_carousel_item',0,13,233,'en',0,15),('ept_carousel_item',0,13,256,'en',0,15),('ept_carousel_item',0,13,286,'en',0,15),('ept_carousel_item',0,13,316,'en',0,15),('ept_carousel_item',0,13,346,'en',0,15),('ept_carousel_item',0,13,376,'en',0,15),('ept_carousel_item',0,13,409,'en',0,15),('ept_carousel_item',0,13,442,'en',0,15),('ept_carousel_item',0,13,475,'en',0,15),('ept_carousel_item',0,13,511,'en',0,15),('ept_carousel_item',0,13,547,'en',0,15),('ept_carousel_item',0,14,211,'en',0,14),('ept_carousel_item',0,14,234,'en',0,14),('ept_carousel_item',0,14,257,'en',0,14),('ept_carousel_item',0,14,287,'en',0,14),('ept_carousel_item',0,14,317,'en',0,14),('ept_carousel_item',0,14,347,'en',0,14),('ept_carousel_item',0,14,377,'en',0,14),('ept_carousel_item',0,14,410,'en',0,14),('ept_carousel_item',0,14,443,'en',0,14),('ept_carousel_item',0,14,476,'en',0,14),('ept_carousel_item',0,14,512,'en',0,14),('ept_carousel_item',0,14,548,'en',0,14),('ept_carousel_item',0,15,212,'en',0,13),('ept_carousel_item',0,15,235,'en',0,13),('ept_carousel_item',0,15,258,'en',0,13),('ept_carousel_item',0,15,288,'en',0,13),('ept_carousel_item',0,15,318,'en',0,13),('ept_carousel_item',0,15,348,'en',0,13),('ept_carousel_item',0,15,378,'en',0,13),('ept_carousel_item',0,15,411,'en',0,13),('ept_carousel_item',0,15,444,'en',0,13),('ept_carousel_item',0,15,477,'en',0,13),('ept_carousel_item',0,15,513,'en',0,13),('ept_carousel_item',0,15,549,'en',0,13),('ept_carousel_item',0,16,213,'en',0,9),('ept_carousel_item',0,16,236,'en',0,9),('ept_carousel_item',0,16,259,'en',0,9),('ept_carousel_item',0,16,289,'en',0,9),('ept_carousel_item',0,16,319,'en',0,9),('ept_carousel_item',0,16,349,'en',0,9),('ept_carousel_item',0,16,379,'en',0,9),('ept_carousel_item',0,16,412,'en',0,9),('ept_carousel_item',0,16,445,'en',0,9),('ept_carousel_item',0,16,478,'en',0,9),('ept_carousel_item',0,16,514,'en',0,9),('ept_carousel_item',0,16,550,'en',0,9),('ept_carousel_item',0,17,214,'en',0,6),('ept_carousel_item',0,17,237,'en',0,6),('ept_carousel_item',0,17,260,'en',0,6),('ept_carousel_item',0,17,290,'en',0,6),('ept_carousel_item',0,17,320,'en',0,6),('ept_carousel_item',0,17,350,'en',0,6),('ept_carousel_item',0,17,380,'en',0,6),('ept_carousel_item',0,17,413,'en',0,6),('ept_carousel_item',0,17,446,'en',0,6),('ept_carousel_item',0,17,479,'en',0,6),('ept_carousel_item',0,17,515,'en',0,6),('ept_carousel_item',0,17,551,'en',0,6),('ept_carousel_item',0,18,215,'en',0,4),('ept_carousel_item',0,18,238,'en',0,4),('ept_carousel_item',0,18,261,'en',0,4),('ept_carousel_item',0,18,291,'en',0,4),('ept_carousel_item',0,18,321,'en',0,4),('ept_carousel_item',0,18,351,'en',0,4),('ept_carousel_item',0,18,381,'en',0,4),('ept_carousel_item',0,18,414,'en',0,4),('ept_carousel_item',0,18,447,'en',0,4),('ept_carousel_item',0,18,480,'en',0,4),('ept_carousel_item',0,18,516,'en',0,4),('ept_carousel_item',0,18,552,'en',0,4),('ept_carousel_item',0,19,216,'en',0,7),('ept_carousel_item',0,19,239,'en',0,7),('ept_carousel_item',0,19,262,'en',0,7),('ept_carousel_item',0,19,292,'en',0,7),('ept_carousel_item',0,19,322,'en',0,7),('ept_carousel_item',0,19,352,'en',0,7),('ept_carousel_item',0,19,382,'en',0,7),('ept_carousel_item',0,19,415,'en',0,7),('ept_carousel_item',0,19,448,'en',0,7),('ept_carousel_item',0,19,481,'en',0,7),('ept_carousel_item',0,19,517,'en',0,7),('ept_carousel_item',0,19,553,'en',0,7),('ept_carousel_item',0,20,217,'en',0,5),('ept_carousel_item',0,20,240,'en',0,5),('ept_carousel_item',0,20,263,'en',0,5),('ept_carousel_item',0,20,293,'en',0,5),('ept_carousel_item',0,20,323,'en',0,5),('ept_carousel_item',0,20,353,'en',0,5),('ept_carousel_item',0,20,383,'en',0,5),('ept_carousel_item',0,20,416,'en',0,5),('ept_carousel_item',0,20,449,'en',0,5),('ept_carousel_item',0,20,482,'en',0,5),('ept_carousel_item',0,20,518,'en',0,5),('ept_carousel_item',0,20,554,'en',0,5),('ept_carousel_item',0,21,218,'en',0,10),('ept_carousel_item',0,21,241,'en',0,10),('ept_carousel_item',0,21,264,'en',0,10),('ept_carousel_item',0,21,294,'en',0,10),('ept_carousel_item',0,21,324,'en',0,10),('ept_carousel_item',0,21,354,'en',0,10),('ept_carousel_item',0,21,384,'en',0,10),('ept_carousel_item',0,21,417,'en',0,10),('ept_carousel_item',0,21,450,'en',0,10),('ept_carousel_item',0,21,483,'en',0,10),('ept_carousel_item',0,21,519,'en',0,10),('ept_carousel_item',0,21,555,'en',0,10),('ept_carousel_item',0,22,219,'en',0,12),('ept_carousel_item',0,22,242,'en',0,12),('ept_carousel_item',0,22,265,'en',0,12),('ept_carousel_item',0,22,295,'en',0,12),('ept_carousel_item',0,22,325,'en',0,12),('ept_carousel_item',0,22,355,'en',0,12),('ept_carousel_item',0,22,385,'en',0,12),('ept_carousel_item',0,22,418,'en',0,12),('ept_carousel_item',0,22,451,'en',0,12),('ept_carousel_item',0,22,484,'en',0,12),('ept_carousel_item',0,22,520,'en',0,12),('ept_carousel_item',0,22,556,'en',0,12);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_carousel_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_clickable_tile`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_clickable_tile`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_clickable_tile` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_clickable_tile_value` tinyint NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_clickable_tile`
--

LOCK TABLES `paragraph_revision__field_ept_clickable_tile` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_clickable_tile` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_clickable_tile` VALUES ('ept_tiles_item',0,3,19,'en',0,1),('ept_tiles_item',0,3,25,'en',0,1),('ept_tiles_item',0,3,31,'en',0,1),('ept_tiles_item',0,3,37,'en',0,1),('ept_tiles_item',0,3,43,'en',0,1),('ept_tiles_item',0,3,49,'en',0,1),('ept_tiles_item',0,3,55,'en',0,1),('ept_tiles_item',0,3,61,'en',0,1),('ept_tiles_item',0,3,67,'en',0,1),('ept_tiles_item',0,3,76,'en',0,1),('ept_tiles_item',0,3,85,'en',0,1),('ept_tiles_item',0,3,94,'en',0,1),('ept_tiles_item',0,3,104,'en',0,1),('ept_tiles_item',0,3,114,'en',0,1),('ept_tiles_item',0,3,124,'en',0,1),('ept_tiles_item',0,3,134,'en',0,1),('ept_tiles_item',0,3,144,'en',0,1),('ept_tiles_item',0,3,154,'en',0,1),('ept_tiles_item',0,3,165,'en',0,1),('ept_tiles_item',0,3,176,'en',0,1),('ept_tiles_item',0,3,188,'en',0,1),('ept_tiles_item',0,3,200,'en',0,1),('ept_tiles_item',0,3,223,'en',0,1),('ept_tiles_item',0,3,246,'en',0,1),('ept_tiles_item',0,3,272,'en',0,1),('ept_tiles_item',0,3,302,'en',0,1),('ept_tiles_item',0,3,332,'en',0,1),('ept_tiles_item',0,3,362,'en',0,1),('ept_tiles_item',0,3,395,'en',0,1),('ept_tiles_item',0,3,428,'en',0,1),('ept_tiles_item',0,3,461,'en',0,1),('ept_tiles_item',0,3,497,'en',0,1),('ept_tiles_item',0,3,533,'en',0,1),('ept_tiles_item',0,4,20,'en',0,0),('ept_tiles_item',0,4,26,'en',0,0),('ept_tiles_item',0,4,32,'en',0,0),('ept_tiles_item',0,4,38,'en',0,0),('ept_tiles_item',0,4,44,'en',0,0),('ept_tiles_item',0,4,50,'en',0,0),('ept_tiles_item',0,4,56,'en',0,0),('ept_tiles_item',0,4,62,'en',0,0),('ept_tiles_item',0,4,68,'en',0,0),('ept_tiles_item',0,4,77,'en',0,0),('ept_tiles_item',0,4,86,'en',0,0),('ept_tiles_item',0,4,95,'en',0,0),('ept_tiles_item',0,4,105,'en',0,0),('ept_tiles_item',0,4,115,'en',0,0),('ept_tiles_item',0,4,125,'en',0,0),('ept_tiles_item',0,4,135,'en',0,0),('ept_tiles_item',0,4,145,'en',0,0),('ept_tiles_item',0,4,155,'en',0,0),('ept_tiles_item',0,4,166,'en',0,0),('ept_tiles_item',0,4,177,'en',0,0),('ept_tiles_item',0,4,189,'en',0,0),('ept_tiles_item',0,4,201,'en',0,0),('ept_tiles_item',0,4,224,'en',0,0),('ept_tiles_item',0,4,247,'en',0,0),('ept_tiles_item',0,4,273,'en',0,0),('ept_tiles_item',0,4,303,'en',0,0),('ept_tiles_item',0,4,333,'en',0,0),('ept_tiles_item',0,4,363,'en',0,0),('ept_tiles_item',0,4,396,'en',0,0),('ept_tiles_item',0,4,429,'en',0,0),('ept_tiles_item',0,4,462,'en',0,0),('ept_tiles_item',0,4,498,'en',0,0),('ept_tiles_item',0,4,534,'en',0,0),('ept_tiles_item',0,5,21,'en',0,1),('ept_tiles_item',0,5,27,'en',0,1),('ept_tiles_item',0,5,33,'en',0,1),('ept_tiles_item',0,5,39,'en',0,1),('ept_tiles_item',0,5,45,'en',0,1),('ept_tiles_item',0,5,51,'en',0,1),('ept_tiles_item',0,5,57,'en',0,1),('ept_tiles_item',0,5,63,'en',0,1),('ept_tiles_item',0,5,69,'en',0,1),('ept_tiles_item',0,5,78,'en',0,1),('ept_tiles_item',0,5,87,'en',0,1),('ept_tiles_item',0,5,96,'en',0,1),('ept_tiles_item',0,5,106,'en',0,1),('ept_tiles_item',0,5,116,'en',0,1),('ept_tiles_item',0,5,126,'en',0,1),('ept_tiles_item',0,5,136,'en',0,1),('ept_tiles_item',0,5,146,'en',0,1),('ept_tiles_item',0,5,156,'en',0,1),('ept_tiles_item',0,5,167,'en',0,1),('ept_tiles_item',0,5,178,'en',0,1),('ept_tiles_item',0,5,190,'en',0,1),('ept_tiles_item',0,5,202,'en',0,1),('ept_tiles_item',0,5,225,'en',0,1),('ept_tiles_item',0,5,248,'en',0,1),('ept_tiles_item',0,5,274,'en',0,1),('ept_tiles_item',0,5,304,'en',0,1),('ept_tiles_item',0,5,334,'en',0,1),('ept_tiles_item',0,5,364,'en',0,1),('ept_tiles_item',0,5,397,'en',0,1),('ept_tiles_item',0,5,430,'en',0,1),('ept_tiles_item',0,5,463,'en',0,1),('ept_tiles_item',0,5,499,'en',0,1),('ept_tiles_item',0,5,535,'en',0,1);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_clickable_tile` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_columns`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_columns`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_columns` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_columns_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_columns_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_columns_target_id` (`field_ept_columns_target_id`),
  KEY `field_ept_columns_target_revision_id` (`field_ept_columns_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_columns`
--

LOCK TABLES `paragraph_revision__field_ept_columns` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_columns` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_columns` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_countdown_date`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_countdown_date`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_countdown_date` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_countdown_date_value` varchar(20) NOT NULL COMMENT 'The date value.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_countdown_date_value` (`field_ept_countdown_date_value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_countdown_date`
--

LOCK TABLES `paragraph_revision__field_ept_countdown_date` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_countdown_date` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_countdown_date` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_counter_icon`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_counter_icon`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_counter_icon` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_icon_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_icon_target_id` (`field_ept_counter_icon_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_counter_icon`
--

LOCK TABLES `paragraph_revision__field_ept_counter_icon` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_icon` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_icon` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_counter_items`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_counter_items`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_counter_items` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_items_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_counter_items_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_items_target_id` (`field_ept_counter_items_target_id`),
  KEY `field_ept_counter_items_target_revision_id` (`field_ept_counter_items_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_counter_items`
--

LOCK TABLES `paragraph_revision__field_ept_counter_items` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_items` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_counter_items` VALUES ('ept_counter',0,26,269,'en',0,24,267),('ept_counter',0,26,269,'en',1,25,268),('ept_counter',0,26,299,'en',0,24,297),('ept_counter',0,26,299,'en',1,25,298),('ept_counter',0,26,329,'en',0,24,327),('ept_counter',0,26,329,'en',1,25,328),('ept_counter',0,26,359,'en',0,24,357),('ept_counter',0,26,359,'en',1,25,358),('ept_counter',0,26,389,'en',0,24,387),('ept_counter',0,26,389,'en',1,25,388),('ept_counter',0,26,422,'en',0,24,420),('ept_counter',0,26,422,'en',1,25,421),('ept_counter',0,26,455,'en',0,24,453),('ept_counter',0,26,455,'en',1,25,454),('ept_counter',0,26,488,'en',0,24,486),('ept_counter',0,26,488,'en',1,25,487),('ept_counter',0,26,524,'en',0,24,522),('ept_counter',0,26,524,'en',1,25,523),('ept_counter',0,26,560,'en',0,24,558),('ept_counter',0,26,560,'en',1,25,559);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_items` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_counter_number`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_counter_number`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_counter_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_number_value` int NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_counter_number`
--

LOCK TABLES `paragraph_revision__field_ept_counter_number` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_number` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_counter_number` VALUES ('ept_counter_item',0,24,267,'en',0,25),('ept_counter_item',0,24,297,'en',0,25),('ept_counter_item',0,24,327,'en',0,25),('ept_counter_item',0,24,357,'en',0,25),('ept_counter_item',0,24,387,'en',0,25),('ept_counter_item',0,24,420,'en',0,25),('ept_counter_item',0,24,453,'en',0,25),('ept_counter_item',0,24,486,'en',0,25),('ept_counter_item',0,24,522,'en',0,25),('ept_counter_item',0,24,558,'en',0,25),('ept_counter_item',0,25,268,'en',0,25),('ept_counter_item',0,25,298,'en',0,25),('ept_counter_item',0,25,328,'en',0,25),('ept_counter_item',0,25,358,'en',0,25),('ept_counter_item',0,25,388,'en',0,25),('ept_counter_item',0,25,421,'en',0,25),('ept_counter_item',0,25,454,'en',0,25),('ept_counter_item',0,25,487,'en',0,25),('ept_counter_item',0,25,523,'en',0,25),('ept_counter_item',0,25,559,'en',0,25);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_number` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_counter_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_counter_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_counter_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_counter_title_value` longtext NOT NULL,
  `field_ept_counter_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_counter_title_format` (`field_ept_counter_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_counter_title`
--

LOCK TABLES `paragraph_revision__field_ept_counter_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_title` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_counter_title` VALUES ('ept_counter_item',0,24,267,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,297,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,327,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,357,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,387,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,420,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,453,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,486,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,522,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,24,558,'en',0,'<p>EPT Modules</p>','full_html'),('ept_counter_item',0,25,268,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,298,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,328,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,358,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,388,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,421,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,454,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,487,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,523,'en',0,'<p>EBT Modules</p>','full_html'),('ept_counter_item',0,25,559,'en',0,'<p>EBT Modules</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_counter_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_cta_column_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_cta_column_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_cta_column_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_cta_column_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_cta_column_image_target_id` (`field_ept_cta_column_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_cta…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_cta_column_image`
--

LOCK TABLES `paragraph_revision__field_ept_cta_column_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_cta_column_image` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_cta_column_image` VALUES ('ept_cta',0,11,162,'en',0,16),('ept_cta',0,11,173,'en',0,16),('ept_cta',0,11,184,'en',0,16),('ept_cta',0,11,196,'en',0,16),('ept_cta',0,11,208,'en',0,16),('ept_cta',0,11,231,'en',0,16),('ept_cta',0,11,254,'en',0,16),('ept_cta',0,11,280,'en',0,16),('ept_cta',0,11,310,'en',0,16),('ept_cta',0,11,340,'en',0,16),('ept_cta',0,11,370,'en',0,16),('ept_cta',0,11,403,'en',0,16),('ept_cta',0,11,436,'en',0,16),('ept_cta',0,11,469,'en',0,16),('ept_cta',0,11,505,'en',0,16),('ept_cta',0,11,541,'en',0,16);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_cta_column_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_cta_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_cta_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_cta_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_cta_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_cta_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_cta_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_cta_link_uri` (`field_ept_cta_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_cta…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_cta_link`
--

LOCK TABLES `paragraph_revision__field_ept_cta_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_cta_link` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_cta_link` VALUES ('ept_cta',0,11,162,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,173,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,184,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,196,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,208,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,231,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,254,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,280,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,310,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,340,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,370,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,403,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,436,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,469,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,505,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}'),('ept_cta',0,11,541,'en',0,'https://www.drupal.org/project/glightbox','GLightbox module',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_cta_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_cta_second_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_cta_second_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_cta_second_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_cta_second_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_cta_second_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_cta_second_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_cta_second_link_uri` (`field_ept_cta_second_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_cta…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_cta_second_link`
--

LOCK TABLES `paragraph_revision__field_ept_cta_second_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_cta_second_link` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_cta_second_link` VALUES ('ept_cta',0,11,162,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,173,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,184,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,196,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,208,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,231,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,254,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,280,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,310,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,340,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,370,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,403,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,436,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,469,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,505,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}'),('ept_cta',0,11,541,'en',0,'https://biati-digital.github.io/glightbox/','GLightbox site',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_cta_second_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_gallery_item`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_gallery_item`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_gallery_item` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_gallery_item_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_gallery_item_target_id` (`field_ept_gallery_item_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_gallery_item`
--

LOCK TABLES `paragraph_revision__field_ept_gallery_item` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_gallery_item` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_gallery_item` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_gallery_item_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_gallery_item_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_gallery_item_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_gallery_item_text_value` longtext NOT NULL,
  `field_ept_gallery_item_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_gallery_item_text_format` (`field_ept_gallery_item_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_gallery_item_text`
--

LOCK TABLES `paragraph_revision__field_ept_gallery_item_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_gallery_item_text` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_gallery_item_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_hero_column_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_hero_column_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_hero_column_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_column_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_column_image_target_id` (`field_ept_hero_column_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_hero…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_hero_column_image`
--

LOCK TABLES `paragraph_revision__field_ept_hero_column_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_column_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_column_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_hero_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_hero_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_hero_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_hero_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_hero_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_link_uri` (`field_ept_hero_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_hero…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_hero_link`
--

LOCK TABLES `paragraph_revision__field_ept_hero_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_link` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_hero_link` VALUES ('ept_hero',0,1,4,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,5,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,6,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,7,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,8,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,9,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,11,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,13,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,15,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,17,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,23,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,29,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,35,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,41,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,47,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,53,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,59,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,65,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,74,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,83,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,92,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,102,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,112,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,122,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,132,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,142,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,152,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,163,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,174,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,186,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,198,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,221,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,244,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,270,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,300,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,330,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,360,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,393,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,426,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,459,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,495,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_hero',0,1,531,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_hero_second_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_hero_second_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_hero_second_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_second_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_hero_second_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_hero_second_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_second_link_uri` (`field_ept_hero_second_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_hero…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_hero_second_link`
--

LOCK TABLES `paragraph_revision__field_ept_hero_second_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_second_link` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_hero_second_link` VALUES ('ept_hero',0,1,4,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,5,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,6,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,7,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,8,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,9,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,11,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,13,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,15,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,17,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,23,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,29,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,35,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,41,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,47,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,53,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,59,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,65,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,74,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,83,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,92,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,102,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,112,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,122,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,132,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,142,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,152,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,163,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,174,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,186,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,198,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,221,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,244,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,270,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,300,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,330,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,360,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,393,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,426,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,459,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,495,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_hero',0,1,531,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_second_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_hero_title_prefix`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_hero_title_prefix`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_hero_title_prefix` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_hero_title_prefix_value` longtext NOT NULL,
  `field_ept_hero_title_prefix_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_hero_title_prefix_format` (`field_ept_hero_title_prefix_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_hero…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_hero_title_prefix`
--

LOCK TABLES `paragraph_revision__field_ept_hero_title_prefix` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_title_prefix` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_hero_title_prefix` VALUES ('ept_hero',0,1,1,'en',0,'<p>Demo page</p>','basic_html'),('ept_hero',0,1,2,'en',0,'<h2>EPT (Extra Block Types) Demo page</h2>','basic_html'),('ept_hero',0,1,3,'en',0,'<p>EPT (Extra Block Types) Demo page</p>','full_html'),('ept_hero',0,1,4,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,5,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,6,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,7,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,8,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,9,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,11,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,13,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,15,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,17,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,23,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,29,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,35,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,41,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,47,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,53,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,59,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,65,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,74,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,83,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,92,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,102,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,112,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,122,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,132,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,142,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,152,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,163,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,174,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,186,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,198,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,221,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,244,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,270,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,300,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,330,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,360,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,393,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,426,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,459,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,495,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,1,531,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Demo page</span></p>','full_html'),('ept_hero',0,40,571,'en',0,'<p>Listing Page</p>','full_html'),('ept_hero',0,40,574,'en',0,'<p>Listing Page</p>','full_html'),('ept_hero',0,40,577,'en',0,'<p>Listing Page</p>','full_html'),('ept_hero',0,40,580,'en',0,'<p>Listing Page</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_hero_title_prefix` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_target_id` (`field_ept_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_image`
--

LOCK TABLES `paragraph_revision__field_ept_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_image_caption`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_image_caption`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_image_caption` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_caption_value` longtext NOT NULL,
  `field_ept_image_caption_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_caption_format` (`field_ept_image_caption_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_image_caption`
--

LOCK TABLES `paragraph_revision__field_ept_image_caption` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image_caption` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image_caption` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_image_gallery`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_image_gallery`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_image_gallery` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_gallery_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_gallery_target_id` (`field_ept_image_gallery_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_image_gallery`
--

LOCK TABLES `paragraph_revision__field_ept_image_gallery` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image_gallery` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_image_gallery` VALUES ('ept_image_gallery',0,10,101,'en',0,4),('ept_image_gallery',0,10,101,'en',1,5),('ept_image_gallery',0,10,101,'en',2,6),('ept_image_gallery',0,10,111,'en',0,4),('ept_image_gallery',0,10,111,'en',1,5),('ept_image_gallery',0,10,111,'en',2,6),('ept_image_gallery',0,10,111,'en',3,7),('ept_image_gallery',0,10,121,'en',0,4),('ept_image_gallery',0,10,121,'en',1,5),('ept_image_gallery',0,10,121,'en',2,6),('ept_image_gallery',0,10,121,'en',3,7),('ept_image_gallery',0,10,131,'en',0,4),('ept_image_gallery',0,10,131,'en',1,5),('ept_image_gallery',0,10,131,'en',2,6),('ept_image_gallery',0,10,131,'en',3,7),('ept_image_gallery',0,10,141,'en',0,4),('ept_image_gallery',0,10,141,'en',1,5),('ept_image_gallery',0,10,141,'en',2,6),('ept_image_gallery',0,10,141,'en',3,7),('ept_image_gallery',0,10,141,'en',4,9),('ept_image_gallery',0,10,151,'en',0,4),('ept_image_gallery',0,10,151,'en',1,5),('ept_image_gallery',0,10,151,'en',2,6),('ept_image_gallery',0,10,151,'en',3,7),('ept_image_gallery',0,10,151,'en',4,9),('ept_image_gallery',0,10,151,'en',5,10),('ept_image_gallery',0,10,151,'en',6,11),('ept_image_gallery',0,10,151,'en',7,12),('ept_image_gallery',0,10,151,'en',8,13),('ept_image_gallery',0,10,151,'en',9,14),('ept_image_gallery',0,10,151,'en',10,15),('ept_image_gallery',0,10,161,'en',0,4),('ept_image_gallery',0,10,161,'en',1,5),('ept_image_gallery',0,10,161,'en',2,6),('ept_image_gallery',0,10,161,'en',3,7),('ept_image_gallery',0,10,161,'en',4,9),('ept_image_gallery',0,10,161,'en',5,10),('ept_image_gallery',0,10,161,'en',6,11),('ept_image_gallery',0,10,161,'en',7,12),('ept_image_gallery',0,10,161,'en',8,13),('ept_image_gallery',0,10,161,'en',9,14),('ept_image_gallery',0,10,161,'en',10,15),('ept_image_gallery',0,10,172,'en',0,4),('ept_image_gallery',0,10,172,'en',1,5),('ept_image_gallery',0,10,172,'en',2,6),('ept_image_gallery',0,10,172,'en',3,7),('ept_image_gallery',0,10,172,'en',4,9),('ept_image_gallery',0,10,172,'en',5,10),('ept_image_gallery',0,10,172,'en',6,11),('ept_image_gallery',0,10,172,'en',7,12),('ept_image_gallery',0,10,172,'en',8,13),('ept_image_gallery',0,10,172,'en',9,14),('ept_image_gallery',0,10,172,'en',10,15),('ept_image_gallery',0,10,183,'en',0,4),('ept_image_gallery',0,10,183,'en',1,5),('ept_image_gallery',0,10,183,'en',2,6),('ept_image_gallery',0,10,183,'en',3,7),('ept_image_gallery',0,10,183,'en',4,9),('ept_image_gallery',0,10,183,'en',5,10),('ept_image_gallery',0,10,183,'en',6,11),('ept_image_gallery',0,10,183,'en',7,12),('ept_image_gallery',0,10,183,'en',8,13),('ept_image_gallery',0,10,183,'en',9,14),('ept_image_gallery',0,10,183,'en',10,15),('ept_image_gallery',0,10,195,'en',0,4),('ept_image_gallery',0,10,195,'en',1,5),('ept_image_gallery',0,10,195,'en',2,6),('ept_image_gallery',0,10,195,'en',3,7),('ept_image_gallery',0,10,195,'en',4,9),('ept_image_gallery',0,10,195,'en',5,10),('ept_image_gallery',0,10,195,'en',6,11),('ept_image_gallery',0,10,195,'en',7,12),('ept_image_gallery',0,10,195,'en',8,13),('ept_image_gallery',0,10,195,'en',9,14),('ept_image_gallery',0,10,195,'en',10,15),('ept_image_gallery',0,10,207,'en',0,4),('ept_image_gallery',0,10,207,'en',1,5),('ept_image_gallery',0,10,207,'en',2,6),('ept_image_gallery',0,10,207,'en',3,7),('ept_image_gallery',0,10,207,'en',4,9),('ept_image_gallery',0,10,207,'en',5,10),('ept_image_gallery',0,10,207,'en',6,11),('ept_image_gallery',0,10,207,'en',7,12),('ept_image_gallery',0,10,207,'en',8,13),('ept_image_gallery',0,10,207,'en',9,14),('ept_image_gallery',0,10,207,'en',10,15),('ept_image_gallery',0,10,230,'en',0,4),('ept_image_gallery',0,10,230,'en',1,5),('ept_image_gallery',0,10,230,'en',2,6),('ept_image_gallery',0,10,230,'en',3,7),('ept_image_gallery',0,10,230,'en',4,9),('ept_image_gallery',0,10,230,'en',5,10),('ept_image_gallery',0,10,230,'en',6,11),('ept_image_gallery',0,10,230,'en',7,12),('ept_image_gallery',0,10,230,'en',8,13),('ept_image_gallery',0,10,230,'en',9,14),('ept_image_gallery',0,10,230,'en',10,15),('ept_image_gallery',0,10,253,'en',0,4),('ept_image_gallery',0,10,253,'en',1,5),('ept_image_gallery',0,10,253,'en',2,6),('ept_image_gallery',0,10,253,'en',3,7),('ept_image_gallery',0,10,253,'en',4,9),('ept_image_gallery',0,10,253,'en',5,10),('ept_image_gallery',0,10,253,'en',6,11),('ept_image_gallery',0,10,253,'en',7,12),('ept_image_gallery',0,10,253,'en',8,13),('ept_image_gallery',0,10,253,'en',9,14),('ept_image_gallery',0,10,253,'en',10,15),('ept_image_gallery',0,10,279,'en',0,4),('ept_image_gallery',0,10,279,'en',1,5),('ept_image_gallery',0,10,279,'en',2,6),('ept_image_gallery',0,10,279,'en',3,7),('ept_image_gallery',0,10,279,'en',4,9),('ept_image_gallery',0,10,279,'en',5,10),('ept_image_gallery',0,10,279,'en',6,11),('ept_image_gallery',0,10,279,'en',7,12),('ept_image_gallery',0,10,279,'en',8,13),('ept_image_gallery',0,10,279,'en',9,14),('ept_image_gallery',0,10,279,'en',10,15),('ept_image_gallery',0,10,309,'en',0,4),('ept_image_gallery',0,10,309,'en',1,5),('ept_image_gallery',0,10,309,'en',2,6),('ept_image_gallery',0,10,309,'en',3,7),('ept_image_gallery',0,10,309,'en',4,9),('ept_image_gallery',0,10,309,'en',5,10),('ept_image_gallery',0,10,309,'en',6,11),('ept_image_gallery',0,10,309,'en',7,12),('ept_image_gallery',0,10,309,'en',8,13),('ept_image_gallery',0,10,309,'en',9,14),('ept_image_gallery',0,10,309,'en',10,15),('ept_image_gallery',0,10,339,'en',0,4),('ept_image_gallery',0,10,339,'en',1,5),('ept_image_gallery',0,10,339,'en',2,6),('ept_image_gallery',0,10,339,'en',3,7),('ept_image_gallery',0,10,339,'en',4,9),('ept_image_gallery',0,10,339,'en',5,10),('ept_image_gallery',0,10,339,'en',6,11),('ept_image_gallery',0,10,339,'en',7,12),('ept_image_gallery',0,10,339,'en',8,13),('ept_image_gallery',0,10,339,'en',9,14),('ept_image_gallery',0,10,339,'en',10,15),('ept_image_gallery',0,10,369,'en',0,4),('ept_image_gallery',0,10,369,'en',1,5),('ept_image_gallery',0,10,369,'en',2,6),('ept_image_gallery',0,10,369,'en',3,7),('ept_image_gallery',0,10,369,'en',4,9),('ept_image_gallery',0,10,369,'en',5,10),('ept_image_gallery',0,10,369,'en',6,11),('ept_image_gallery',0,10,369,'en',7,12),('ept_image_gallery',0,10,369,'en',8,13),('ept_image_gallery',0,10,369,'en',9,14),('ept_image_gallery',0,10,369,'en',10,15),('ept_image_gallery',0,10,402,'en',0,4),('ept_image_gallery',0,10,402,'en',1,5),('ept_image_gallery',0,10,402,'en',2,6),('ept_image_gallery',0,10,402,'en',3,7),('ept_image_gallery',0,10,402,'en',4,9),('ept_image_gallery',0,10,402,'en',5,10),('ept_image_gallery',0,10,402,'en',6,11),('ept_image_gallery',0,10,402,'en',7,12),('ept_image_gallery',0,10,402,'en',8,13),('ept_image_gallery',0,10,402,'en',9,14),('ept_image_gallery',0,10,402,'en',10,15),('ept_image_gallery',0,10,435,'en',0,4),('ept_image_gallery',0,10,435,'en',1,5),('ept_image_gallery',0,10,435,'en',2,6),('ept_image_gallery',0,10,435,'en',3,7),('ept_image_gallery',0,10,435,'en',4,9),('ept_image_gallery',0,10,435,'en',5,10),('ept_image_gallery',0,10,435,'en',6,11),('ept_image_gallery',0,10,435,'en',7,12),('ept_image_gallery',0,10,435,'en',8,13),('ept_image_gallery',0,10,435,'en',9,14),('ept_image_gallery',0,10,435,'en',10,15),('ept_image_gallery',0,10,468,'en',0,4),('ept_image_gallery',0,10,468,'en',1,5),('ept_image_gallery',0,10,468,'en',2,6),('ept_image_gallery',0,10,468,'en',3,7),('ept_image_gallery',0,10,468,'en',4,9),('ept_image_gallery',0,10,468,'en',5,10),('ept_image_gallery',0,10,468,'en',6,11),('ept_image_gallery',0,10,468,'en',7,12),('ept_image_gallery',0,10,468,'en',8,13),('ept_image_gallery',0,10,468,'en',9,14),('ept_image_gallery',0,10,468,'en',10,15),('ept_image_gallery',0,10,504,'en',0,4),('ept_image_gallery',0,10,504,'en',1,5),('ept_image_gallery',0,10,504,'en',2,6),('ept_image_gallery',0,10,504,'en',3,7),('ept_image_gallery',0,10,504,'en',4,9),('ept_image_gallery',0,10,504,'en',5,10),('ept_image_gallery',0,10,504,'en',6,11),('ept_image_gallery',0,10,504,'en',7,12),('ept_image_gallery',0,10,504,'en',8,13),('ept_image_gallery',0,10,504,'en',9,14),('ept_image_gallery',0,10,504,'en',10,15),('ept_image_gallery',0,10,540,'en',0,4),('ept_image_gallery',0,10,540,'en',1,5),('ept_image_gallery',0,10,540,'en',2,6),('ept_image_gallery',0,10,540,'en',3,7),('ept_image_gallery',0,10,540,'en',4,9),('ept_image_gallery',0,10,540,'en',5,10),('ept_image_gallery',0,10,540,'en',6,11),('ept_image_gallery',0,10,540,'en',7,12),('ept_image_gallery',0,10,540,'en',8,13),('ept_image_gallery',0,10,540,'en',9,14),('ept_image_gallery',0,10,540,'en',10,15);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image_gallery` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_image_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_image_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_image_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_image_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_image_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_image_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_image_link_uri` (`field_ept_image_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_image_link`
--

LOCK TABLES `paragraph_revision__field_ept_image_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_image_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_micromodal_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_micromodal_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_micromodal_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_micromodal_title_value` longtext NOT NULL,
  `field_ept_micromodal_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_micromodal_title_format` (`field_ept_micromodal_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_micromodal_title`
--

LOCK TABLES `paragraph_revision__field_ept_micromodal_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_micromodal_title` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_micromodal_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_quote_author`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_quote_author`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_quote_author` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_quote_author_value` longtext NOT NULL,
  `field_ept_quote_author_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_quote_author_format` (`field_ept_quote_author_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_quote_author`
--

LOCK TABLES `paragraph_revision__field_ept_quote_author` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_quote_author` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_quote_author` VALUES ('ept_quote',0,12,185,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,197,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,209,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,232,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,255,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,285,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,315,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,345,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,375,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,408,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,441,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,474,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,510,'en',0,'<p>Hockey Club</p>','full_html'),('ept_quote',0,12,546,'en',0,'<p>Hockey Club</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_quote_author` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_quote_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_quote_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_quote_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_quote_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_quote_image_target_id` (`field_ept_quote_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_quote_image`
--

LOCK TABLES `paragraph_revision__field_ept_quote_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_quote_image` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_quote_image` VALUES ('ept_quote',0,12,185,'en',0,18),('ept_quote',0,12,197,'en',0,18),('ept_quote',0,12,209,'en',0,18),('ept_quote',0,12,232,'en',0,18),('ept_quote',0,12,255,'en',0,18),('ept_quote',0,12,285,'en',0,18),('ept_quote',0,12,315,'en',0,18),('ept_quote',0,12,345,'en',0,18),('ept_quote',0,12,375,'en',0,18),('ept_quote',0,12,408,'en',0,18),('ept_quote',0,12,441,'en',0,18),('ept_quote',0,12,474,'en',0,18),('ept_quote',0,12,510,'en',0,18),('ept_quote',0,12,546,'en',0,18);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_quote_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_settings`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_settings`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_settings` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_settings_ept_settings` longblob COMMENT 'Serialized paragraph settings data',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_settings`
--

LOCK TABLES `paragraph_revision__field_ept_settings` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_settings` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_settings` VALUES ('ept_hero',0,1,1,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,2,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,3,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,4,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,5,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,6,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,7,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,8,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,9,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,11,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,13,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,15,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,17,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,23,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,29,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,35,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,41,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,47,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,53,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,59,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,65,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,74,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,83,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,92,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,102,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,112,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,122,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,132,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,142,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,152,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,163,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,174,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,186,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,198,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,221,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,244,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,270,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,300,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,330,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,360,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,393,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,426,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,459,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,495,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,1,531,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"1\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:1;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#ffffff\";s:22:\"hover_background_color\";s:7:\"#0a5987\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_text',0,2,10,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_text',0,2,12,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,14,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,16,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,18,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,24,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,30,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,36,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,42,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,48,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,54,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,60,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,66,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,75,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,84,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,93,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,103,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,113,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,123,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,133,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,143,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,153,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,164,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,175,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,187,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,199,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,222,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,245,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,271,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,301,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,331,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,361,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,394,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,427,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,460,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,496,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_text',0,2,532,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"20\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:4:\"none\";s:10:\"strip_tags\";i:0;}}'),('ept_tiles',0,6,22,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,28,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,34,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,40,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,46,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:9:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,52,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,58,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"2\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,64,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,70,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,79,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,88,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,97,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,107,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,117,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,127,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,137,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,147,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,157,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,168,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,179,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,191,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,203,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,226,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,249,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,275,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,305,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,335,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,365,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,398,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,431,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,464,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,500,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_tiles',0,6,536,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"60\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"3\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"bottom left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:13:\"three_columns\";}'),('ept_stats',0,9,73,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:16:\"stats_in_squares\";}'),('ept_stats',0,9,82,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,91,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,100,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,110,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,120,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,130,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,140,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,150,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,160,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,171,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,182,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,194,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,206,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,229,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,252,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,278,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,308,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,338,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,368,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,401,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,434,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,467,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,503,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_stats',0,9,539,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"stats_in_column\";}'),('ept_image_gallery',0,10,101,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,111,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,121,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,131,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,141,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,151,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,161,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,172,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,183,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,195,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,207,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,230,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,253,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,279,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,309,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,339,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,369,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,402,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,435,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,468,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,504,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_image_gallery',0,10,540,'en',0,_binary 'a:4:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:1:\"8\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:12:\"bottom right\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"400px 400px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:12:\"four_columns\";}'),('ept_cta',0,11,162,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,173,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,184,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,196,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,208,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,231,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,254,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,280,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,310,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,340,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,370,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,403,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,436,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,469,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,505,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_cta',0,11,541,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"17\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:8:\"parallax\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:11:\"two_columns\";s:13:\"align_content\";s:4:\"left\";s:14:\"image_position\";s:5:\"right\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:1;s:17:\"hover_title_color\";s:7:\"#eeeeee\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_quote',0,12,185,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,197,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,209,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,232,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,255,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,285,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,315,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,345,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,375,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,408,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,441,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,474,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,510,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_quote',0,12,546,'en',0,_binary 'a:5:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:12:\"quote_styles\";a:1:{s:6:\"styles\";s:7:\"persona\";}s:6:\"styles\";s:7:\"persona\";}'),('ept_carousel',0,23,220,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,243,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,266,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,296,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,326,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,356,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,386,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,419,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,452,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,485,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,521,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_carousel',0,23,557,'en',0,_binary 'a:22:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:11:\"center left\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:11:\"300px 300px\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:5:\"basic\";s:4:\"mode\";s:8:\"carousel\";s:4:\"axis\";s:10:\"horizontal\";s:5:\"items\";s:1:\"3\";s:6:\"gutter\";s:1:\"0\";s:11:\"edgePadding\";s:1:\"0\";s:9:\"autoWidth\";i:0;s:10:\"fixedWidth\";s:0:\"\";s:7:\"slideBy\";s:1:\"1\";s:6:\"center\";i:0;s:9:\"arrowKeys\";i:0;s:5:\"speed\";s:3:\"300\";s:4:\"loop\";i:1;s:10:\"autoHeight\";i:0;s:10:\"additional\";a:13:{s:11:\"viewportMax\";s:0:\"\";s:6:\"rewind\";i:0;s:5:\"touch\";i:1;s:9:\"mouseDrag\";i:0;s:10:\"swipeAngle\";s:2:\"15\";s:24:\"preventActionWhenRunning\";i:0;s:20:\"preventScrollOnTouch\";s:4:\"none\";s:6:\"nested\";s:4:\"none\";s:9:\"freezable\";i:0;s:7:\"disable\";i:0;s:10:\"startIndex\";s:1:\"0\";s:15:\"useLocalStorage\";i:0;s:5:\"nonce\";s:0:\"\";}s:10:\"responsive\";a:3:{s:6:\"mobile\";a:5:{s:10:\"breakpoint\";s:3:\"576\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:6:\"tablet\";a:5:{s:10:\"breakpoint\";s:3:\"992\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}s:7:\"desktop\";a:5:{s:10:\"breakpoint\";s:4:\"1200\";s:5:\"items\";s:0:\"\";s:7:\"slideBy\";s:0:\"\";s:6:\"gutter\";s:0:\"\";s:11:\"edgePadding\";s:0:\"\";}}s:8:\"controls\";a:7:{s:8:\"controls\";i:1;s:16:\"controlsPosition\";s:3:\"top\";s:16:\"controlsTextPrev\";s:4:\"prev\";s:16:\"controlsTextNext\";s:4:\"next\";s:3:\"nav\";i:1;s:11:\"navPosition\";s:6:\"bottom\";s:15:\"navAsThumbnails\";i:0;}s:8:\"autoplay\";a:10:{s:8:\"autoplay\";i:0;s:16:\"autoplayPosition\";s:3:\"top\";s:15:\"autoplayTimeout\";s:4:\"5000\";s:17:\"autoplayDirection\";s:7:\"forward\";s:17:\"autoplayTextStart\";s:0:\"\";s:16:\"autoplayTextStop\";s:0:\"\";s:18:\"autoplayHoverPause\";i:0;s:14:\"autoplayButton\";s:0:\"\";s:20:\"autoplayButtonOutput\";i:1;s:25:\"autoplayResetOnVisibility\";i:1;}s:7:\"animate\";a:4:{s:9:\"animateIn\";s:10:\"tns-fadeIn\";s:10:\"animateOut\";s:11:\"tns-fadeOut\";s:13:\"animateNormal\";s:11:\"tns-fadeOut\";s:12:\"animateDelay\";s:0:\"\";}}'),('ept_counter',0,26,269,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,299,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,329,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,359,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,389,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,422,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,455,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,488,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,524,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_counter',0,26,560,'en',0,_binary 'a:17:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:11:\"two_columns\";s:8:\"startVal\";s:1:\"0\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:13:\"decimalPlaces\";s:1:\"0\";s:8:\"duration\";s:1:\"2\";s:11:\"useGrouping\";i:1;s:9:\"separator\";s:5:\"comma\";s:9:\"useEasing\";i:1;s:20:\"smartEasingThreshold\";s:3:\"999\";s:17:\"smartEasingAmount\";s:3:\"333\";s:15:\"enableScrollSpy\";i:1;s:14:\"scrollSpyDelay\";s:1:\"0\";s:13:\"scrollSpyOnce\";i:0;}'),('ept_slideshow',0,30,284,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:0;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,314,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,344,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,374,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,407,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,440,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,473,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,509,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_slideshow',0,30,545,'en',0,_binary 'a:18:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"10\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"20\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:9:\"animation\";s:4:\"fade\";s:9:\"direction\";s:10:\"horizontal\";s:7:\"reverse\";i:0;s:13:\"animationLoop\";i:1;s:12:\"smoothHeight\";i:1;s:7:\"startAt\";s:1:\"0\";s:9:\"slideshow\";i:0;s:14:\"animationSpeed\";s:3:\"600\";s:14:\"slideshowSpeed\";s:4:\"7000\";s:9:\"initDelay\";s:1:\"0\";s:9:\"randomize\";i:0;s:14:\"fadeFirstSlide\";i:1;s:13:\"thumbCaptions\";i:0;s:9:\"usability\";a:8:{s:12:\"pauseOnHover\";i:0;s:10:\"controlNav\";i:1;s:12:\"directionNav\";i:1;s:8:\"prevText\";s:8:\"Previous\";s:8:\"nextText\";s:4:\"Next\";s:9:\"pausePlay\";i:0;s:9:\"pauseText\";s:5:\"Pause\";s:8:\"playText\";s:4:\"Play\";}s:8:\"carousel\";a:6:{s:9:\"itemWidth\";s:1:\"0\";s:10:\"itemMargin\";s:1:\"0\";s:8:\"minItems\";s:1:\"1\";s:8:\"maxItems\";s:1:\"0\";s:4:\"move\";s:1:\"0\";s:13:\"allowOneSlide\";i:1;}}'),('ept_tabs',0,33,392,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_tabs',0,33,425,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_tabs',0,33,458,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_tabs',0,33,491,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_tabs',0,33,527,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_tabs',0,33,563,'en',0,_binary 'a:9:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"30\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"30\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"30\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:6:\"xsmall\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:7:\"default\";s:6:\"active\";s:0:\"\";s:11:\"collapsible\";i:0;s:6:\"closed\";i:0;s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_accordion',0,36,494,'en',0,_binary 'a:12:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"40\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"plus_minus_left\";s:11:\"collapsible\";i:1;s:6:\"closed\";i:1;s:6:\"opened\";i:0;s:16:\"closed_in_tablet\";i:0;s:16:\"closed_in_mobile\";i:0;s:6:\"active\";s:0:\"\";s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_accordion',0,36,530,'en',0,_binary 'a:12:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"40\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"plus_minus_left\";s:11:\"collapsible\";i:1;s:6:\"closed\";i:1;s:6:\"opened\";i:0;s:16:\"closed_in_tablet\";i:0;s:16:\"closed_in_mobile\";i:0;s:6:\"active\";s:0:\"\";s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_accordion',0,36,567,'en',0,_binary 'a:12:{s:26:\"pass_options_to_javascript\";b:1;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"20\";s:12:\"padding_left\";s:2:\"40\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:5:\"small\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}s:6:\"styles\";s:15:\"plus_minus_left\";s:11:\"collapsible\";i:1;s:6:\"closed\";i:1;s:6:\"opened\";i:0;s:16:\"closed_in_tablet\";i:0;s:16:\"closed_in_mobile\";i:0;s:6:\"active\";s:0:\"\";s:7:\"disable\";i:0;s:11:\"heightStyle\";s:7:\"content\";}'),('ept_views',0,38,568,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_views',0,38,570,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_views',0,38,573,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_views',0,38,576,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_views',0,38,579,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_views',0,38,582,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:2:\"40\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"40\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"40\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_block',0,39,569,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_block',0,39,572,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_block',0,39,575,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_block',0,39,578,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#dddddd\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_block',0,39,581,'en',0,_binary 'a:3:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:7:\"#030e30\";s:16:\"background_media\";N;s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:1;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h2\";s:10:\"strip_tags\";i:1;}}'),('ept_hero',0,40,571,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,40,574,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"50\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"50\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,40,577,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"50\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"50\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}'),('ept_hero',0,40,580,'en',0,_binary 'a:24:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:2:\"50\";s:13:\"padding_right\";s:2:\"20\";s:14:\"padding_bottom\";s:2:\"50\";s:12:\"padding_left\";s:2:\"20\";}}}s:14:\"other_settings\";a:10:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";s:2:\"19\";s:25:\"background_video_settings\";a:14:{s:8:\"autoPlay\";i:1;s:12:\"showControls\";i:0;s:4:\"mute\";i:1;s:7:\"startAt\";s:1:\"0\";s:7:\"opacity\";s:1:\"1\";s:10:\"addOverlay\";i:1;s:12:\"overlayColor\";s:7:\"#000000\";s:12:\"overlayAlpha\";s:3:\"0.3\";s:4:\"loop\";i:1;s:15:\"stopMovieOnBlur\";i:1;s:17:\"playOnlyIfVisible\";i:0;s:10:\"coverImage\";N;s:11:\"useOnMobile\";i:1;s:19:\"mobileFallbackImage\";N;}s:25:\"background_image_settings\";a:3:{s:19:\"background_position\";s:7:\"default\";s:26:\"background_position_custom\";s:0:\"\";s:22:\"background_size_custom\";s:0:\"\";}s:22:\"background_image_style\";s:5:\"cover\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:7:\"default\";}}s:13:\"title_options\";a:2:{s:13:\"title_wrapper\";s:2:\"h1\";s:10:\"strip_tags\";i:1;}s:12:\"link_options\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:6:\"styles\";s:10:\"one_column\";s:7:\"overlay\";i:0;s:13:\"overlay_color\";s:7:\"#000000\";s:13:\"overlay_alpha\";s:3:\"0.6\";s:14:\"image_position\";s:4:\"left\";s:18:\"image_order_mobile\";s:11:\"image_first\";s:17:\"mobile_breakpoint\";s:3:\"640\";s:13:\"link_options2\";a:12:{s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:0:\"\";s:16:\"background_color\";s:0:\"\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";N;s:5:\"shape\";N;s:4:\"size\";N;s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}s:15:\"open_in_new_tab\";i:0;s:12:\"add_nofollow\";i:0;s:11:\"title_color\";s:7:\"#ffffff\";s:16:\"background_color\";s:7:\"#0d77b5\";s:19:\"custom_hover_colors\";i:0;s:17:\"hover_title_color\";s:0:\"\";s:22:\"hover_background_color\";s:0:\"\";s:9:\"alignment\";s:4:\"left\";s:5:\"shape\";s:6:\"square\";s:4:\"size\";s:6:\"medium\";s:9:\"stretched\";i:0;s:17:\"custom_class_name\";s:0:\"\";}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_settings` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slick_slider`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slick_slider`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slick_slider` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_slick_slider_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_target_id` (`field_ept_slick_slider_target_id`),
  KEY `field_ept_slick_slider_target_revision_id` (`field_ept_slick_slider_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slick_slider`
--

LOCK TABLES `paragraph_revision__field_ept_slick_slider` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slick_slider_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slick_slider_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slick_slider_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_image_target_id` (`field_ept_slick_slider_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slick_slider_image`
--

LOCK TABLES `paragraph_revision__field_ept_slick_slider_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slick_slider_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slick_slider_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slick_slider_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_slick_slider_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_slick_slider_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_link_uri` (`field_ept_slick_slider_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slick_slider_link`
--

LOCK TABLES `paragraph_revision__field_ept_slick_slider_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slick_slider_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slick_slider_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slick_slider_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slick_slider_text_value` longtext NOT NULL,
  `field_ept_slick_slider_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slick_slider_text_format` (`field_ept_slick_slider_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slick_slider_text`
--

LOCK TABLES `paragraph_revision__field_ept_slick_slider_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider_text` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slick_slider_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slideshow`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slideshow`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slideshow` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_slideshow_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_target_id` (`field_ept_slideshow_target_id`),
  KEY `field_ept_slideshow_target_revision_id` (`field_ept_slideshow_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slideshow`
--

LOCK TABLES `paragraph_revision__field_ept_slideshow` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_slideshow` VALUES ('ept_slideshow',0,30,284,'en',0,27,281),('ept_slideshow',0,30,284,'en',1,28,282),('ept_slideshow',0,30,284,'en',2,29,283),('ept_slideshow',0,30,314,'en',0,27,311),('ept_slideshow',0,30,314,'en',1,28,312),('ept_slideshow',0,30,314,'en',2,29,313),('ept_slideshow',0,30,344,'en',0,27,341),('ept_slideshow',0,30,344,'en',1,28,342),('ept_slideshow',0,30,344,'en',2,29,343),('ept_slideshow',0,30,374,'en',0,27,371),('ept_slideshow',0,30,374,'en',1,28,372),('ept_slideshow',0,30,374,'en',2,29,373),('ept_slideshow',0,30,407,'en',0,27,404),('ept_slideshow',0,30,407,'en',1,28,405),('ept_slideshow',0,30,407,'en',2,29,406),('ept_slideshow',0,30,440,'en',0,27,437),('ept_slideshow',0,30,440,'en',1,28,438),('ept_slideshow',0,30,440,'en',2,29,439),('ept_slideshow',0,30,473,'en',0,27,470),('ept_slideshow',0,30,473,'en',1,28,471),('ept_slideshow',0,30,473,'en',2,29,472),('ept_slideshow',0,30,509,'en',0,27,506),('ept_slideshow',0,30,509,'en',1,28,507),('ept_slideshow',0,30,509,'en',2,29,508),('ept_slideshow',0,30,545,'en',0,27,542),('ept_slideshow',0,30,545,'en',1,28,543),('ept_slideshow',0,30,545,'en',2,29,544);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slideshow_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slideshow_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slideshow_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_slideshow_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_slideshow_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_link_uri` (`field_ept_slideshow_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slideshow_link`
--

LOCK TABLES `paragraph_revision__field_ept_slideshow_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slideshow_slide`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slideshow_slide`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slideshow_slide` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_slide_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_slide_target_id` (`field_ept_slideshow_slide_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slideshow_slide`
--

LOCK TABLES `paragraph_revision__field_ept_slideshow_slide` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_slide` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_slideshow_slide` VALUES ('ept_slideshow_item',0,27,281,'en',0,20),('ept_slideshow_item',0,27,311,'en',0,20),('ept_slideshow_item',0,27,341,'en',0,20),('ept_slideshow_item',0,27,371,'en',0,20),('ept_slideshow_item',0,27,404,'en',0,20),('ept_slideshow_item',0,27,437,'en',0,20),('ept_slideshow_item',0,27,470,'en',0,20),('ept_slideshow_item',0,27,506,'en',0,20),('ept_slideshow_item',0,27,542,'en',0,20),('ept_slideshow_item',0,28,282,'en',0,21),('ept_slideshow_item',0,28,312,'en',0,21),('ept_slideshow_item',0,28,342,'en',0,21),('ept_slideshow_item',0,28,372,'en',0,21),('ept_slideshow_item',0,28,405,'en',0,21),('ept_slideshow_item',0,28,438,'en',0,21),('ept_slideshow_item',0,28,471,'en',0,21),('ept_slideshow_item',0,28,507,'en',0,21),('ept_slideshow_item',0,28,543,'en',0,21),('ept_slideshow_item',0,29,283,'en',0,22),('ept_slideshow_item',0,29,313,'en',0,22),('ept_slideshow_item',0,29,343,'en',0,22),('ept_slideshow_item',0,29,373,'en',0,22),('ept_slideshow_item',0,29,406,'en',0,22),('ept_slideshow_item',0,29,439,'en',0,22),('ept_slideshow_item',0,29,472,'en',0,22),('ept_slideshow_item',0,29,508,'en',0,22),('ept_slideshow_item',0,29,544,'en',0,22);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_slide` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slideshow_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slideshow_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slideshow_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_text_value` longtext NOT NULL,
  `field_ept_slideshow_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_text_format` (`field_ept_slideshow_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slideshow_text`
--

LOCK TABLES `paragraph_revision__field_ept_slideshow_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_text` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_slideshow_text` VALUES ('ept_slideshow_item',0,27,281,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,311,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,341,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,371,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,404,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,437,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,470,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,506,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,27,542,'en',0,'<p>Margin, padding, border for each component. You can also set type of border and color.</p>','full_html'),('ept_slideshow_item',0,28,282,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,312,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,342,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,372,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,405,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,438,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,471,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,507,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,28,543,'en',0,'<p>Each component has settings for background color, image, video. Image and Videos settings allows to adjust options via usual Drupal form.</p>','full_html'),('ept_slideshow_item',0,29,283,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,313,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,343,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,373,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,406,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,439,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,472,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,508,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html'),('ept_slideshow_item',0,29,544,'en',0,'<p>You can set up options for javascript plugins from the same configuration form for component.</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_slideshow_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_slideshow_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_slideshow_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_slideshow_title_value` longtext NOT NULL,
  `field_ept_slideshow_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_slideshow_title_format` (`field_ept_slideshow_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_slideshow_title`
--

LOCK TABLES `paragraph_revision__field_ept_slideshow_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_title` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_slideshow_title` VALUES ('ept_slideshow_item',0,27,281,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,311,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,341,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,371,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,404,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,437,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,470,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,506,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,27,542,'en',0,'<p>DOM Box settings</p>','full_html'),('ept_slideshow_item',0,28,282,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,312,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,342,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,372,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,405,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,438,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,471,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,507,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,28,543,'en',0,'<p>Background color, image or video.</p>','full_html'),('ept_slideshow_item',0,29,283,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,313,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,343,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,373,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,406,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,439,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,472,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,508,'en',0,'<p>Settings for javascript plugins</p>','full_html'),('ept_slideshow_item',0,29,544,'en',0,'<p>Settings for javascript plugins</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_slideshow_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_stats`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_stats`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_stats` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_stats_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_target_id` (`field_ept_stats_target_id`),
  KEY `field_ept_stats_target_revision_id` (`field_ept_stats_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_stats`
--

LOCK TABLES `paragraph_revision__field_ept_stats` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_stats` VALUES ('ept_stats',0,9,73,'en',0,7,71),('ept_stats',0,9,73,'en',1,8,72),('ept_stats',0,9,82,'en',0,7,80),('ept_stats',0,9,82,'en',1,8,81),('ept_stats',0,9,91,'en',0,7,89),('ept_stats',0,9,91,'en',1,8,90),('ept_stats',0,9,100,'en',0,7,98),('ept_stats',0,9,100,'en',1,8,99),('ept_stats',0,9,110,'en',0,7,108),('ept_stats',0,9,110,'en',1,8,109),('ept_stats',0,9,120,'en',0,7,118),('ept_stats',0,9,120,'en',1,8,119),('ept_stats',0,9,130,'en',0,7,128),('ept_stats',0,9,130,'en',1,8,129),('ept_stats',0,9,140,'en',0,7,138),('ept_stats',0,9,140,'en',1,8,139),('ept_stats',0,9,150,'en',0,7,148),('ept_stats',0,9,150,'en',1,8,149),('ept_stats',0,9,160,'en',0,7,158),('ept_stats',0,9,160,'en',1,8,159),('ept_stats',0,9,171,'en',0,7,169),('ept_stats',0,9,171,'en',1,8,170),('ept_stats',0,9,182,'en',0,7,180),('ept_stats',0,9,182,'en',1,8,181),('ept_stats',0,9,194,'en',0,7,192),('ept_stats',0,9,194,'en',1,8,193),('ept_stats',0,9,206,'en',0,7,204),('ept_stats',0,9,206,'en',1,8,205),('ept_stats',0,9,229,'en',0,7,227),('ept_stats',0,9,229,'en',1,8,228),('ept_stats',0,9,252,'en',0,7,250),('ept_stats',0,9,252,'en',1,8,251),('ept_stats',0,9,278,'en',0,7,276),('ept_stats',0,9,278,'en',1,8,277),('ept_stats',0,9,308,'en',0,7,306),('ept_stats',0,9,308,'en',1,8,307),('ept_stats',0,9,338,'en',0,7,336),('ept_stats',0,9,338,'en',1,8,337),('ept_stats',0,9,368,'en',0,7,366),('ept_stats',0,9,368,'en',1,8,367),('ept_stats',0,9,401,'en',0,7,399),('ept_stats',0,9,401,'en',1,8,400),('ept_stats',0,9,434,'en',0,7,432),('ept_stats',0,9,434,'en',1,8,433),('ept_stats',0,9,467,'en',0,7,465),('ept_stats',0,9,467,'en',1,8,466),('ept_stats',0,9,503,'en',0,7,501),('ept_stats',0,9,503,'en',1,8,502),('ept_stats',0,9,539,'en',0,7,537),('ept_stats',0,9,539,'en',1,8,538);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_stats_item_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_stats_item_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_stats_item_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_image_target_id` (`field_ept_stats_item_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_stats_item_image`
--

LOCK TABLES `paragraph_revision__field_ept_stats_item_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_stats_item_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_stats_item_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_stats_item_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_stats_item_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_stats_item_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_link_uri` (`field_ept_stats_item_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_stats_item_link`
--

LOCK TABLES `paragraph_revision__field_ept_stats_item_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_link` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_stats_item_number`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_stats_item_number`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_stats_item_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_number_value` longtext NOT NULL,
  `field_ept_stats_item_number_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_number_format` (`field_ept_stats_item_number_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_stats_item_number`
--

LOCK TABLES `paragraph_revision__field_ept_stats_item_number` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_number` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_stats_item_number` VALUES ('ept_stats_item',0,7,71,'en',0,'<p><span style=\"background-color:rgb(255,255,255);color:rgb(34,34,34);\"><span style=\"-webkit-text-stroke-width:0px;display:inline !important;float:none;font-family:NotoSans, system-ui, sans-serif;font-size:16px;font-style:normal;font-variant-caps:normal;font-variant-ligatures:normal;font-weight:400;letter-spacing:normal;orphans:2;text-align:right;text-decoration-color:initial;text-decoration-style:initial;text-decoration-thickness:initial;text-indent:0px;text-transform:none;white-space:normal;widows:2;word-spacing:0px;\">721,320</span></span></p>','full_html'),('ept_stats_item',0,7,80,'en',0,'<p><span style=\"background-color:rgb(255,255,255);color:rgb(34,34,34);\"><span style=\"-webkit-text-stroke-width:0px;display:inline !important;float:none;font-family:NotoSans, system-ui, sans-serif;font-size:16px;font-style:normal;font-variant-caps:normal;font-variant-ligatures:normal;font-weight:400;letter-spacing:normal;orphans:2;text-align:right;text-decoration-color:initial;text-decoration-style:initial;text-decoration-thickness:initial;text-indent:0px;text-transform:none;white-space:normal;widows:2;word-spacing:0px;\">721,320</span></span></p>','full_html'),('ept_stats_item',0,7,89,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,98,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,108,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,118,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,128,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,138,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,148,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,158,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,169,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,180,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,192,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,204,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,227,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,250,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,276,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,306,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,336,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,366,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,399,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,432,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,465,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,501,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,7,537,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">721,320</span></p>','full_html'),('ept_stats_item',0,8,72,'en',0,'<p>238,556</p>','full_html'),('ept_stats_item',0,8,81,'en',0,'<p>238,556</p>','full_html'),('ept_stats_item',0,8,90,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,99,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,109,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,119,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,129,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,139,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,149,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,159,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,170,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,181,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,193,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,205,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,228,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,251,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,277,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,307,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,337,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,367,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,400,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,433,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,466,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,502,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html'),('ept_stats_item',0,8,538,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">238,556</span></p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_number` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_stats_item_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_stats_item_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_stats_item_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_stats_item_text_value` longtext NOT NULL,
  `field_ept_stats_item_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_stats_item_text_format` (`field_ept_stats_item_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_stats_item_text`
--

LOCK TABLES `paragraph_revision__field_ept_stats_item_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_text` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_stats_item_text` VALUES ('ept_stats_item',0,7,71,'en',0,'<p>Websites use Drupal</p>','full_html'),('ept_stats_item',0,7,80,'en',0,'<p>Websites use Drupal</p>','full_html'),('ept_stats_item',0,7,89,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,98,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,108,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,118,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,128,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,138,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,148,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,158,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,169,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,180,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,192,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,204,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,227,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,250,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,276,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,306,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,336,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,366,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,399,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,432,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,465,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,501,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,7,537,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Websites use Drupal</span></p>','full_html'),('ept_stats_item',0,8,72,'en',0,'<p>Usage statistics for Paragraphs module</p>','full_html'),('ept_stats_item',0,8,81,'en',0,'<p>Usage statistics for Paragraphs module</p>','full_html'),('ept_stats_item',0,8,90,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,99,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,109,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,119,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,129,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,139,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,149,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,159,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,170,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,181,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,193,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,205,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,228,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,251,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,277,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,307,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,337,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,367,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,400,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,433,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,466,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,502,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html'),('ept_stats_item',0,8,538,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Usage statistics for Paragraphs module</span></p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_stats_item_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tab_block`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tab_block`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tab_block` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_block_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ept_tab_block_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_block_plugin_id` (`field_ept_tab_block_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tab…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tab_block`
--

LOCK TABLES `paragraph_revision__field_ept_tab_block` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_block` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_block` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tab_content`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tab_content`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tab_content` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_content_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_content_value` (`field_ept_tab_content_value`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tab…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tab_content`
--

LOCK TABLES `paragraph_revision__field_ept_tab_content` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_content` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tab_content` VALUES ('ept_tabs_item',0,31,390,'en',0,'text'),('ept_tabs_item',0,31,423,'en',0,'text'),('ept_tabs_item',0,31,456,'en',0,'text'),('ept_tabs_item',0,31,489,'en',0,'text'),('ept_tabs_item',0,31,525,'en',0,'text'),('ept_tabs_item',0,31,561,'en',0,'text'),('ept_tabs_item',0,32,391,'en',0,'text'),('ept_tabs_item',0,32,424,'en',0,'text'),('ept_tabs_item',0,32,457,'en',0,'text'),('ept_tabs_item',0,32,490,'en',0,'text'),('ept_tabs_item',0,32,526,'en',0,'text'),('ept_tabs_item',0,32,562,'en',0,'text');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_content` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tab_page`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tab_page`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tab_page` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_page_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_page_target_id` (`field_ept_tab_page_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tab…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tab_page`
--

LOCK TABLES `paragraph_revision__field_ept_tab_page` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_page` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_page` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tab_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tab_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tab_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_text_value` longtext NOT NULL,
  `field_ept_tab_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_text_format` (`field_ept_tab_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tab…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tab_text`
--

LOCK TABLES `paragraph_revision__field_ept_tab_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_text` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tab_text` VALUES ('ept_tabs_item',0,31,390,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,31,423,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,31,456,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,31,489,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,31,525,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,31,561,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ept_accordion\" title=\"EPT Accordion / FAQ\" rel=\"nofollow\">EPT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ept_basic_button\" title=\"EPT Basic Button\" rel=\"nofollow\">EPT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ept_block\" title=\"EPT Block\" rel=\"nofollow\">EPT Block</a></li><li><a href=\"https://www.drupal.org/project/ept_bootstrap_button\" title=\"EPT Bootstrap Button\" rel=\"nofollow\">EPT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ept_cta\" title=\"EPT Call to Action\" rel=\"nofollow\">EPT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ept_carousel\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ept_columns\" title=\"EPT Columns\" rel=\"nofollow\">EPT Columns / Container</a></li><li><a href=\"https://www.drupal.org/project/ept_countdown\" title=\"EPT Countdown\" rel=\"nofollow\">EPT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ept_counter\" title=\"EPT Counter\" rel=\"nofollow\">EPT Counter</a></li><li><a href=\"https://www.drupal.org/project/ept_image\" rel=\"nofollow\">EPT Image</a></li><li><a href=\"https://www.drupal.org/project/ept_image_gallery\" rel=\"nofollow\">EPT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_micromodal\" rel=\"nofollow\">EPT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ept_quote\" title=\"EPT Quote\" rel=\"nofollow\">EPT Quote</a></li><li><a href=\"https://www.drupal.org/project/ept_slick_slider\" rel=\"nofollow\">EPT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ept_slideshow\" rel=\"nofollow\">EPT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ept_stats\" rel=\"nofollow\">EPT Stats</a></li><li><a href=\"https://www.drupal.org/project/ept_tabs\" title=\"EPT Tabs\" rel=\"nofollow\">EPT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ept_text\" rel=\"nofollow\">EPT Text</a></li><li><a href=\"https://www.drupal.org/project/ept_tiles\" rel=\"nofollow\">EPT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ept_timeline\" rel=\"nofollow\">EPT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ept_video\" rel=\"nofollow\">EPT Video</a></li><li><a href=\"https://www.drupal.org/project/ept_video_and_image_gallery\" rel=\"nofollow\">EPT Video and Image gallery</a></li><li><a href=\"https://www.drupal.org/project/ept_views\" rel=\"nofollow\">EPT Views</a></li><li><a href=\"https://www.drupal.org/project/ept_webform\" rel=\"nofollow\">EPT Webform</a></li><li><a href=\"https://www.drupal.org/project/ept_webform_popup\" rel=\"nofollow\">EPT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,391,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,424,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,457,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,490,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,526,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html'),('ept_tabs_item',0,32,562,'en',0,'<ul><li><a href=\"https://www.drupal.org/project/ebt_accordion\" title=\"EBT Accordion / FAQ\" rel=\"nofollow\">EBT Accordion / FAQ</a></li><li><a href=\"https://www.drupal.org/project/ebt_basic_button\" title=\"EBT Basic Button\" rel=\"nofollow\">EBT Basic Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_block\" title=\"EBT Block\" rel=\"nofollow\">EBT Block</a></li><li><a href=\"https://www.drupal.org/project/ebt_bootstrap_button\" title=\"EBT Bootstrap Button\" rel=\"nofollow\">EBT Bootstrap Button</a></li><li><a href=\"https://www.drupal.org/project/ebt_cta\" title=\"EBT Call to Action\" rel=\"nofollow\">EBT Call to Action</a></li><li><a href=\"https://www.drupal.org/project/ebt_carousel\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Carousel</a></li><li><a href=\"https://www.drupal.org/project/ebt_columns\" title=\"EBT Columns\" rel=\"nofollow\">EBT Columns</a></li><li><a href=\"https://www.drupal.org/project/ebt_countdown\" title=\"EBT Countdown\" rel=\"nofollow\">EBT Countdown</a></li><li><a href=\"https://www.drupal.org/project/ebt_counter\" title=\"EBT Counter\" rel=\"nofollow\">EBT Counter</a></li><li><a href=\"https://www.drupal.org/project/ebt_image\" rel=\"nofollow\">EBT Image</a></li><li><a href=\"https://www.drupal.org/project/ebt_image_gallery\" rel=\"nofollow\">EBT Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_micromodal\" rel=\"nofollow\">EBT Micromodal</a></li><li><a href=\"https://www.drupal.org/project/ebt_quote\" title=\"EBT Quote\" rel=\"nofollow\">EBT Quote</a></li><li><a href=\"https://www.drupal.org/project/ebt_slick_slider\" rel=\"nofollow\">EBT Slick Slider</a></li><li><a href=\"https://www.drupal.org/project/ebt_slideshow\" rel=\"nofollow\">EBT Slideshow</a></li><li><a href=\"https://www.drupal.org/project/ebt_stats\" rel=\"nofollow\">EBT Stats</a></li><li><a href=\"https://www.drupal.org/project/ebt_tabs\" title=\"EBT Tabs\" rel=\"nofollow\">EBT Tabs</a></li><li><a href=\"https://www.drupal.org/project/ebt_text\" rel=\"nofollow\">EBT Text</a></li><li><a href=\"https://www.drupal.org/project/ebt_tiles\" rel=\"nofollow\">EBT Tiles</a></li><li><a href=\"https://www.drupal.org/project/ebt_timeline\" rel=\"nofollow\">EBT Timeline</a></li><li><a href=\"https://www.drupal.org/project/ebt_video\" rel=\"nofollow\">EBT Video</a></li><li><a href=\"https://www.drupal.org/project/ebt_video_and_image_gallery\" rel=\"nofollow\">EBT Video and Image Gallery</a></li><li><a href=\"https://www.drupal.org/project/ebt_views\" rel=\"nofollow\">EBT Views</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform\" rel=\"nofollow\">EBT Webform</a></li><li><a href=\"https://www.drupal.org/project/ebt_webform_popup\" rel=\"nofollow\">EBT Webform Popup</a></li></ul>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tab_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tab_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tab_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_title_value` varchar(255) NOT NULL,
  `field_ept_tab_title_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_title_format` (`field_ept_tab_title_format`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tab…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tab_title`
--

LOCK TABLES `paragraph_revision__field_ept_tab_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_title` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tab_title` VALUES ('ept_tabs_item',0,31,390,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,31,423,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,31,456,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,31,489,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,31,525,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,31,561,'en',0,'EPT modules','full_html'),('ept_tabs_item',0,32,391,'en',0,'EBT Modules','full_html'),('ept_tabs_item',0,32,424,'en',0,'EBT Modules','full_html'),('ept_tabs_item',0,32,457,'en',0,'EBT Modules','full_html'),('ept_tabs_item',0,32,490,'en',0,'EBT Modules','full_html'),('ept_tabs_item',0,32,526,'en',0,'EBT Modules','full_html'),('ept_tabs_item',0,32,562,'en',0,'EBT Modules','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tab_views`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tab_views`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tab_views` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tab_views_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_tab_views_display_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The ID of the display.',
  `field_ept_tab_views_data` longtext COMMENT 'Serialized data.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tab_views_target_id` (`field_ept_tab_views_target_id`),
  KEY `field_ept_tab_views_display_id` (`field_ept_tab_views_display_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tab…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tab_views`
--

LOCK TABLES `paragraph_revision__field_ept_tab_views` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_views` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tab_views` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tabs`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tabs`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tabs` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tabs_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_tabs_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tabs_target_id` (`field_ept_tabs_target_id`),
  KEY `field_ept_tabs_target_revision_id` (`field_ept_tabs_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_tabs.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tabs`
--

LOCK TABLES `paragraph_revision__field_ept_tabs` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tabs` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tabs` VALUES ('ept_tabs',0,33,392,'en',0,31,390),('ept_tabs',0,33,392,'en',1,32,391),('ept_tabs',0,33,425,'en',0,31,423),('ept_tabs',0,33,425,'en',1,32,424),('ept_tabs',0,33,458,'en',0,31,456),('ept_tabs',0,33,458,'en',1,32,457),('ept_tabs',0,33,491,'en',0,31,489),('ept_tabs',0,33,491,'en',1,32,490),('ept_tabs',0,33,527,'en',0,31,525),('ept_tabs',0,33,527,'en',1,32,526),('ept_tabs',0,33,563,'en',0,31,561),('ept_tabs',0,33,563,'en',1,32,562);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tabs` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_text_value` longtext NOT NULL,
  `field_ept_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_text_format` (`field_ept_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept_text.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_text`
--

LOCK TABLES `paragraph_revision__field_ept_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_text` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_text` VALUES ('ept_hero',0,1,1,'en',0,'<p>Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</p>','basic_html'),('ept_hero',0,1,2,'en',0,'<p>Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</p>','basic_html'),('ept_hero',0,1,3,'en',0,'<p>Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</p>','full_html'),('ept_hero',0,1,4,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</span></p>','full_html'),('ept_hero',0,1,5,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</span></p>','full_html'),('ept_hero',0,1,6,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</span></p>','full_html'),('ept_hero',0,1,7,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Welcome EBT Page Builder Demo site. I hope you will find a lot of useful components.</span></p>','full_html'),('ept_hero',0,1,8,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,9,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,11,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,13,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,15,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,17,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,23,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,29,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,35,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,41,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,47,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,53,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,59,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,65,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,74,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,83,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,92,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,102,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,112,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,122,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,132,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,142,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,152,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,163,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,174,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,186,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,198,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,221,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,244,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,270,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,300,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,330,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,360,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,393,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,426,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,459,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,495,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_hero',0,1,531,'en',0,'<p><span style=\"color:hsl(0,0%,100%);\">Flexible, Reusable, and Customizable Content Layouts for a Seamless Editing Experience</span></p>','full_html'),('ept_text',0,2,10,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,12,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,14,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,16,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,18,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,24,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,30,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,36,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,42,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,48,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,54,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,60,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,66,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,75,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,84,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,93,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,103,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,113,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,123,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,133,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,143,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,153,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,164,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,175,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,187,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,199,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,222,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,245,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,271,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,301,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,331,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,361,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,394,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,427,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,460,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,496,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_text',0,2,532,'en',0,'<p>EPT modules provide Drupal users with an extended range of paragraph types, offering you complete control over content presentation. Whether you\'re building landing pages, blogs, or portfolios, EPT makes it easier to break away from rigid templates and embrace flexibility. Customize each type to suit your unique needs and create reusable components that reduce development time.</p>','full_html'),('ept_stats',0,9,73,'en',0,'<p>Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</p>','full_html'),('ept_stats',0,9,82,'en',0,'<p>Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</p>','full_html'),('ept_stats',0,9,91,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,100,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,110,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,120,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,130,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,140,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,150,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,160,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,171,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,182,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,194,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,206,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,229,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,252,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,278,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,308,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,338,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,368,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,401,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,434,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,467,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,503,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_stats',0,9,539,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">Drupal Paragraphs is a powerful module that allows you to create reusable content components called \"paragraph types.\" These flexible content blocks let you design rich, dynamic layouts without relying on a fixed template structure. With Paragraphs, content creators can mix and match various elements—text, images, videos, and more—to build custom layouts.</span></p>','full_html'),('ept_cta',0,11,162,'en',0,'<p>EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</p>','full_html'),('ept_cta',0,11,173,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,184,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,196,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,208,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,231,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,254,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,280,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,310,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,340,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,370,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,403,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,436,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,469,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,505,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_cta',0,11,541,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules come with seamless integration of the GLightbox JavaScript plugin, providing a modern and sleek lightbox experience for media content. Whether it\'s images, videos, or galleries, GLightbox ensures that your media is displayed beautifully with smooth animations and responsive design. This powerful combination enhances the user experience, making your content more interactive and visually engaging.</span></p>','full_html'),('ept_quote',0,12,185,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,197,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,209,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,232,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,255,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,285,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,315,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,345,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,375,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,408,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,441,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,474,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,510,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_quote',0,12,546,'en',0,'<p>Install any number of EBT/EPT modules for blocks/paragraphs you need.&nbsp;</p>','full_html'),('ept_hero',0,40,571,'en',0,'<p>Stay tuned!</p>','full_html'),('ept_hero',0,40,574,'en',0,'<p>Stay tuned!</p>','full_html'),('ept_hero',0,40,577,'en',0,'<p>Stay tuned!</p>','full_html'),('ept_hero',0,40,580,'en',0,'<p>Stay tuned!</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tiles`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tiles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tiles` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_tiles_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_target_id` (`field_ept_tiles_target_id`),
  KEY `field_ept_tiles_target_revision_id` (`field_ept_tiles_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tiles`
--

LOCK TABLES `paragraph_revision__field_ept_tiles` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tiles` VALUES ('ept_tiles',0,6,22,'en',0,3,19),('ept_tiles',0,6,22,'en',1,4,20),('ept_tiles',0,6,22,'en',2,5,21),('ept_tiles',0,6,28,'en',0,3,25),('ept_tiles',0,6,28,'en',1,4,26),('ept_tiles',0,6,28,'en',2,5,27),('ept_tiles',0,6,34,'en',0,3,31),('ept_tiles',0,6,34,'en',1,4,32),('ept_tiles',0,6,34,'en',2,5,33),('ept_tiles',0,6,40,'en',0,3,37),('ept_tiles',0,6,40,'en',1,4,38),('ept_tiles',0,6,40,'en',2,5,39),('ept_tiles',0,6,46,'en',0,3,43),('ept_tiles',0,6,46,'en',1,4,44),('ept_tiles',0,6,46,'en',2,5,45),('ept_tiles',0,6,52,'en',0,3,49),('ept_tiles',0,6,52,'en',1,4,50),('ept_tiles',0,6,52,'en',2,5,51),('ept_tiles',0,6,58,'en',0,3,55),('ept_tiles',0,6,58,'en',1,4,56),('ept_tiles',0,6,58,'en',2,5,57),('ept_tiles',0,6,64,'en',0,3,61),('ept_tiles',0,6,64,'en',1,4,62),('ept_tiles',0,6,64,'en',2,5,63),('ept_tiles',0,6,70,'en',0,3,67),('ept_tiles',0,6,70,'en',1,4,68),('ept_tiles',0,6,70,'en',2,5,69),('ept_tiles',0,6,79,'en',0,3,76),('ept_tiles',0,6,79,'en',1,4,77),('ept_tiles',0,6,79,'en',2,5,78),('ept_tiles',0,6,88,'en',0,3,85),('ept_tiles',0,6,88,'en',1,4,86),('ept_tiles',0,6,88,'en',2,5,87),('ept_tiles',0,6,97,'en',0,3,94),('ept_tiles',0,6,97,'en',1,4,95),('ept_tiles',0,6,97,'en',2,5,96),('ept_tiles',0,6,107,'en',0,3,104),('ept_tiles',0,6,107,'en',1,4,105),('ept_tiles',0,6,107,'en',2,5,106),('ept_tiles',0,6,117,'en',0,3,114),('ept_tiles',0,6,117,'en',1,4,115),('ept_tiles',0,6,117,'en',2,5,116),('ept_tiles',0,6,127,'en',0,3,124),('ept_tiles',0,6,127,'en',1,4,125),('ept_tiles',0,6,127,'en',2,5,126),('ept_tiles',0,6,137,'en',0,3,134),('ept_tiles',0,6,137,'en',1,4,135),('ept_tiles',0,6,137,'en',2,5,136),('ept_tiles',0,6,147,'en',0,3,144),('ept_tiles',0,6,147,'en',1,4,145),('ept_tiles',0,6,147,'en',2,5,146),('ept_tiles',0,6,157,'en',0,3,154),('ept_tiles',0,6,157,'en',1,4,155),('ept_tiles',0,6,157,'en',2,5,156),('ept_tiles',0,6,168,'en',0,3,165),('ept_tiles',0,6,168,'en',1,4,166),('ept_tiles',0,6,168,'en',2,5,167),('ept_tiles',0,6,179,'en',0,3,176),('ept_tiles',0,6,179,'en',1,4,177),('ept_tiles',0,6,179,'en',2,5,178),('ept_tiles',0,6,191,'en',0,3,188),('ept_tiles',0,6,191,'en',1,4,189),('ept_tiles',0,6,191,'en',2,5,190),('ept_tiles',0,6,203,'en',0,3,200),('ept_tiles',0,6,203,'en',1,4,201),('ept_tiles',0,6,203,'en',2,5,202),('ept_tiles',0,6,226,'en',0,3,223),('ept_tiles',0,6,226,'en',1,4,224),('ept_tiles',0,6,226,'en',2,5,225),('ept_tiles',0,6,249,'en',0,3,246),('ept_tiles',0,6,249,'en',1,4,247),('ept_tiles',0,6,249,'en',2,5,248),('ept_tiles',0,6,275,'en',0,3,272),('ept_tiles',0,6,275,'en',1,4,273),('ept_tiles',0,6,275,'en',2,5,274),('ept_tiles',0,6,305,'en',0,3,302),('ept_tiles',0,6,305,'en',1,4,303),('ept_tiles',0,6,305,'en',2,5,304),('ept_tiles',0,6,335,'en',0,3,332),('ept_tiles',0,6,335,'en',1,4,333),('ept_tiles',0,6,335,'en',2,5,334),('ept_tiles',0,6,365,'en',0,3,362),('ept_tiles',0,6,365,'en',1,4,363),('ept_tiles',0,6,365,'en',2,5,364),('ept_tiles',0,6,398,'en',0,3,395),('ept_tiles',0,6,398,'en',1,4,396),('ept_tiles',0,6,398,'en',2,5,397),('ept_tiles',0,6,431,'en',0,3,428),('ept_tiles',0,6,431,'en',1,4,429),('ept_tiles',0,6,431,'en',2,5,430),('ept_tiles',0,6,464,'en',0,3,461),('ept_tiles',0,6,464,'en',1,4,462),('ept_tiles',0,6,464,'en',2,5,463),('ept_tiles',0,6,500,'en',0,3,497),('ept_tiles',0,6,500,'en',1,4,498),('ept_tiles',0,6,500,'en',2,5,499),('ept_tiles',0,6,536,'en',0,3,533),('ept_tiles',0,6,536,'en',1,4,534),('ept_tiles',0,6,536,'en',2,5,535);
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tiles_image`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tiles_image`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tiles_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_image_target_id` (`field_ept_tiles_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tiles_image`
--

LOCK TABLES `paragraph_revision__field_ept_tiles_image` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_image` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_image` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tiles_link`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tiles_link`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tiles_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ept_tiles_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ept_tiles_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_link_uri` (`field_ept_tiles_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tiles_link`
--

LOCK TABLES `paragraph_revision__field_ept_tiles_link` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_link` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tiles_link` VALUES ('ept_tiles_item',0,3,19,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,25,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,31,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,37,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,43,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,49,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,55,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,61,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,67,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,76,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,85,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,94,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,104,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,114,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,124,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,134,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,144,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,154,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,165,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,176,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,188,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,200,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,223,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,246,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,272,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,302,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,332,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,362,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,395,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,428,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,461,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,497,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,3,533,'en',0,'https://www.drupal.org/project/ept_core','Download',_binary 'a:0:{}'),('ept_tiles_item',0,5,21,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,27,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,33,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,39,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,45,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,51,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,57,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,63,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,69,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,78,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,87,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,96,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,106,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,116,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,126,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,136,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,146,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,156,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,167,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,178,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,190,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,202,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,225,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,248,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,274,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,304,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,334,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,364,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,397,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,430,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,463,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,499,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}'),('ept_tiles_item',0,5,535,'en',0,'https://drupalbook.org/ept/demo','EPT Documentation',_binary 'a:0:{}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_link` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tiles_text`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tiles_text`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tiles_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_text_value` longtext NOT NULL,
  `field_ept_tiles_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_text_format` (`field_ept_tiles_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tiles_text`
--

LOCK TABLES `paragraph_revision__field_ept_tiles_text` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_text` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tiles_text` VALUES ('ept_tiles_item',0,3,19,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,25,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,31,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,37,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,43,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,49,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,55,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,61,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,67,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,76,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,85,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,94,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,104,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,114,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,124,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,134,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,144,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,154,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,165,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,176,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,188,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,200,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,223,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,246,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,272,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,302,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,332,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,362,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,395,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,428,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,461,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,497,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,3,533,'en',0,'<p>Download and install the Extra Paragraph Types modules via Drupal\'s module directory</p>','full_html'),('ept_tiles_item',0,4,20,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,26,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,32,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,38,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,44,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,50,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,56,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,62,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,68,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,77,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,86,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,95,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,105,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,115,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,125,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,135,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,145,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,155,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,166,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,177,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,189,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,201,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,224,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,247,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,273,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,303,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,333,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,363,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,396,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,429,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,462,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,498,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,4,534,'en',0,'<p>Enable and configure paragraph types based on your project needs</p>','full_html'),('ept_tiles_item',0,5,21,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,27,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,33,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,39,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,45,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,51,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,57,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,63,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,69,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,78,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,87,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,96,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,106,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,116,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,126,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,136,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,146,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,156,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,167,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,178,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,190,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,202,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,225,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,248,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,274,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,304,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,334,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,364,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,397,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,430,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,463,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,499,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html'),('ept_tiles_item',0,5,535,'en',0,'<p>Build dynamic content layouts with ease and empower your content team to take control of the website</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_text` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_tiles_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_tiles_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_tiles_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_tiles_title_value` longtext NOT NULL,
  `field_ept_tiles_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_tiles_title_format` (`field_ept_tiles_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_tiles_title`
--

LOCK TABLES `paragraph_revision__field_ept_tiles_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_title` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_tiles_title` VALUES ('ept_tiles_item',0,3,19,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,25,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,31,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,37,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,43,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,49,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,55,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,61,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,67,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,76,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,85,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,94,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,104,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,114,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,124,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,134,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,144,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,154,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,165,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,176,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,188,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,200,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,223,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,246,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,272,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,302,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,332,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,362,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,395,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,428,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,461,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,497,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,3,533,'en',0,'<p>Install EPT Modules</p>','full_html'),('ept_tiles_item',0,4,20,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,26,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,32,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,38,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,44,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,50,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,56,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,62,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,68,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,77,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,86,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,95,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,105,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,115,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,125,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,135,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,145,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,155,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,166,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,177,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,189,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,201,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,224,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,247,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,273,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,303,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,333,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,363,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,396,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,429,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,462,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,498,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,4,534,'en',0,'<p>Configure Paragraph Types</p>','full_html'),('ept_tiles_item',0,5,21,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,27,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,33,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,39,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,45,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,51,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,57,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,63,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,69,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,78,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,87,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,96,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,106,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,116,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,126,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,136,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,146,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,156,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,167,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,178,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,190,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,202,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,225,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,248,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,274,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,304,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,334,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,364,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,397,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,430,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,463,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,499,'en',0,'<p>Start Creating</p>','full_html'),('ept_tiles_item',0,5,535,'en',0,'<p>Start Creating</p>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_tiles_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_title`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_title`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_title_value` longtext NOT NULL,
  `field_ept_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_title_format` (`field_ept_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_title`
--

LOCK TABLES `paragraph_revision__field_ept_title` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_title` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_title` VALUES ('ept_hero',0,1,1,'en',0,'<p>EPT Page Builder - Getting Started</p>','basic_html'),('ept_hero',0,1,2,'en',0,'<p>EPT Page Builder - Getting Started</p>','basic_html'),('ept_hero',0,1,3,'en',0,'<p>EPT Page Builder - Getting Started</p>','full_html'),('ept_hero',0,1,4,'en',0,'<h1><span style=\"color:hsl(0, 0%, 100%);\">EPT (Extra Paragraph Types) Page Builder</span></h1>','full_html'),('ept_hero',0,1,5,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">EPT (Extra Paragraph Types) Page Builder</span></h1>','full_html'),('ept_hero',0,1,6,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">EPT (Extra Paragraph Types) Page Builder</span></h1>','full_html'),('ept_hero',0,1,7,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">EPT (Extra Paragraph Types) Page Builder</span></h1>','full_html'),('ept_hero',0,1,8,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,9,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,11,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,13,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,15,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,17,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,23,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,29,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,35,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,41,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,47,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,53,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,59,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,65,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,74,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,83,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,92,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,102,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,112,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,122,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,132,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,142,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,152,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,163,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,174,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,186,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,198,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,221,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,244,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,270,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,300,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,330,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,360,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,393,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,426,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,459,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,495,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_hero',0,1,531,'en',0,'<h1><span style=\"color:hsl(0,0%,100%);\">Supercharge Your Drupal Site with Extra Paragraph Types (EPT) Modules</span></h1>','full_html'),('ept_text',0,2,10,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,12,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,14,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,16,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,18,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,24,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,30,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,36,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,42,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,48,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,54,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,60,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,66,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,75,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,84,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,93,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,103,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,113,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,123,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,133,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,143,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,153,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,164,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,175,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,187,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,199,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,222,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,245,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,271,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,301,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,331,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,361,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,394,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,427,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,460,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,496,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_text',0,2,532,'en',0,'<h2 class=\"text-align-center\">Why Choose EPT?</h2>','full_html'),('ept_tiles',0,6,52,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,58,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,64,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,70,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,79,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,88,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,97,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,107,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,117,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,127,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,137,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,147,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,157,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,168,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,179,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,191,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,203,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,226,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,249,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,275,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,305,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,335,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,365,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,398,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,431,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,464,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,500,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_tiles',0,6,536,'en',0,'<div class=\"page-break\" style=\"page-break-after:always;\"><span style=\"display:none;\">&nbsp;</span></div><p>&nbsp;</p>','full_html'),('ept_stats',0,9,73,'en',0,'<p>What Are Drupal Paragraphs?</p>','full_html'),('ept_stats',0,9,82,'en',0,'<p>What Are Drupal Paragraphs?</p>','full_html'),('ept_stats',0,9,91,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,100,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,110,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,120,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,130,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,140,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,150,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,160,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,171,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,182,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,194,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,206,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,229,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,252,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,278,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,308,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,338,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,368,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,401,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,434,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,467,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,503,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_stats',0,9,539,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">What Are Drupal Paragraphs?</span></p>','full_html'),('ept_image_gallery',0,10,101,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,111,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,121,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,131,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,141,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,151,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,161,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,172,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,183,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,195,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,207,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,230,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,253,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,279,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,309,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,339,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,369,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,402,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,435,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,468,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,504,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_image_gallery',0,10,540,'en',0,'<p>You can download a bunch of EPT modules from Drupal.org</p>','full_html'),('ept_cta',0,11,162,'en',0,'<p>EPT modules uses GLightbox for Image/Video in popups</p>','full_html'),('ept_cta',0,11,173,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,184,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,196,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,208,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,231,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,254,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,280,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,310,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,340,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,370,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,403,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,436,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,469,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,505,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_cta',0,11,541,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT modules uses GLightbox for Image/Video in popups</span></p>','full_html'),('ept_quote',0,12,185,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,197,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,209,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,232,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,255,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,285,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,315,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,345,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,375,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,408,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,441,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,474,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,510,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_quote',0,12,546,'en',0,'<p>You can start from one module.</p>','full_html'),('ept_carousel',0,23,220,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,243,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,266,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,296,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,326,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,356,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,386,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,419,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,452,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,485,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,521,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_carousel',0,23,557,'en',0,'<p>Find and download your Extra Paragraph Type</p>','full_html'),('ept_counter',0,26,269,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,299,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,329,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,359,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,389,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,422,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,455,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,488,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,524,'en',0,'<p>Number of modules</p>','full_html'),('ept_counter',0,26,560,'en',0,'<p>Number of modules</p>','full_html'),('ept_slideshow',0,30,284,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,314,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,344,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,374,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,407,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,440,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,473,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,509,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_slideshow',0,30,545,'en',0,'<p>Each EPT module has rich settings</p>','full_html'),('ept_tabs',0,33,392,'en',0,'<p>List of all Extra Paragraph Types (EPT) and Extra Block Types (EBT)&nbsp;</p>','full_html'),('ept_tabs',0,33,425,'en',0,'<p>List of all Extra Paragraph Types (EPT) and Extra Block Types (EBT)&nbsp;</p>','full_html'),('ept_tabs',0,33,458,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>','full_html'),('ept_tabs',0,33,491,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>','full_html'),('ept_tabs',0,33,527,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>','full_html'),('ept_tabs',0,33,563,'en',0,'<p><span style=\"color:hsl(0, 0%, 100%);\">EPT and EBT modules&nbsp;</span></p>','full_html'),('ept_accordion',0,36,494,'en',0,'<p>FAQ</p>','full_html'),('ept_accordion',0,36,530,'en',0,'<p>FAQ</p>','full_html'),('ept_accordion',0,36,567,'en',0,'<p>FAQ</p>','full_html'),('ept_hero',0,40,571,'en',0,'<p>What\'s New</p>','full_html'),('ept_hero',0,40,574,'en',0,'<p>What\'s New</p>','full_html'),('ept_hero',0,40,577,'en',0,'<h1>What\'s New</h1>','full_html'),('ept_hero',0,40,580,'en',0,'<h1>What\'s New</h1>','full_html');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_title` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_video`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_video`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_video` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_video_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_video_target_id` (`field_ept_video_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_video`
--

LOCK TABLES `paragraph_revision__field_ept_video` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_video` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_video` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_videos_and_images`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_videos_and_images`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_videos_and_images` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_videos_and_images_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_videos_and_images_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_videos_and_images_target_id` (`field_ept_videos_and_images_target_id`),
  KEY `field_ept_videos_and_images_target_revision_id` (`field_ept_videos_and_images_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_videos_and_images`
--

LOCK TABLES `paragraph_revision__field_ept_videos_and_images` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_videos_and_images` DISABLE KEYS */;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_videos_and_images` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraph_revision__field_ept_views_view`
--

DROP TABLE IF EXISTS `paragraph_revision__field_ept_views_view`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraph_revision__field_ept_views_view` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ept_views_view_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `field_ept_views_view_display_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The ID of the display.',
  `field_ept_views_view_data` longtext COMMENT 'Serialized data.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ept_views_view_target_id` (`field_ept_views_view_target_id`),
  KEY `field_ept_views_view_display_id` (`field_ept_views_view_display_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ept…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraph_revision__field_ept_views_view`
--

LOCK TABLES `paragraph_revision__field_ept_views_view` WRITE;
/*!40000 ALTER TABLE `paragraph_revision__field_ept_views_view` DISABLE KEYS */;
INSERT INTO `paragraph_revision__field_ept_views_view` VALUES ('ept_views',0,38,568,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}'),('ept_views',0,38,570,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}'),('ept_views',0,38,573,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}'),('ept_views',0,38,576,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}'),('ept_views',0,38,579,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}'),('ept_views',0,38,582,'en',0,'what_s_new','block_1','a:6:{s:8:\"argument\";N;s:6:\"header\";N;s:5:\"limit\";N;s:6:\"offset\";N;s:5:\"pager\";N;s:5:\"title\";N;}');
/*!40000 ALTER TABLE `paragraph_revision__field_ept_views_view` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraphs_item`
--

DROP TABLE IF EXISTS `paragraphs_item`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraphs_item` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `paragraph_field__uuid__value` (`uuid`),
  UNIQUE KEY `paragraph__revision_id` (`revision_id`),
  KEY `paragraph_field__type__target_id` (`type`)
) ENGINE=InnoDB AUTO_INCREMENT=41 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for paragraph entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraphs_item`
--

LOCK TABLES `paragraphs_item` WRITE;
/*!40000 ALTER TABLE `paragraphs_item` DISABLE KEYS */;
INSERT INTO `paragraphs_item` VALUES (1,531,'ept_hero','088e8f36-aa92-4779-a6f3-20855a3bee73','en'),(2,532,'ept_text','be1571de-b029-444e-be82-de9318b229ad','en'),(3,533,'ept_tiles_item','34bcf35b-46b1-40fe-945d-8fb70d8699b6','en'),(4,534,'ept_tiles_item','ca1814e1-24d2-4312-87ce-300646c90af5','en'),(5,535,'ept_tiles_item','41b512ea-5da1-4d79-8932-848dd65fbede','en'),(6,536,'ept_tiles','f427a33f-64f8-4506-99c7-a8605b1df563','en'),(7,537,'ept_stats_item','26311542-79cb-4dbd-afae-5eaaa37c8c3e','en'),(8,538,'ept_stats_item','13a0b97c-311e-4742-821b-d4d27041731f','en'),(9,539,'ept_stats','926f3603-0a5c-4fc3-9d32-eddfeb355833','en'),(10,540,'ept_image_gallery','c2140955-0941-4cea-a839-676831aacf2d','en'),(11,541,'ept_cta','df2b4021-56a6-496c-a770-df39af537eee','en'),(12,546,'ept_quote','7926a1d4-73de-4662-af2c-f956f44efc2a','en'),(13,547,'ept_carousel_item','28a6aa54-d81c-41d1-8295-fe11ca28099a','en'),(14,548,'ept_carousel_item','a4eac7aa-822e-4fa3-9455-c1bb581a624f','en'),(15,549,'ept_carousel_item','d1b58918-ffa2-4bce-bfbc-c9deb44b5867','en'),(16,550,'ept_carousel_item','468f6ab7-7312-46ae-bcf6-ef603e838f68','en'),(17,551,'ept_carousel_item','8b37f259-e19c-4f81-822b-4ab3f83ede48','en'),(18,552,'ept_carousel_item','b4ee429d-8ae5-494d-8349-f1d7bc895fac','en'),(19,553,'ept_carousel_item','e1a17a42-8975-45f0-ad79-d1e16708218e','en'),(20,554,'ept_carousel_item','290eb5f2-3408-46ba-9d87-618c1395cd44','en'),(21,555,'ept_carousel_item','7e05ae91-dba8-4b5b-8a2e-3bf8b09bf8cf','en'),(22,556,'ept_carousel_item','eeac7ad1-b0a3-4898-a4e2-4e0aadfa2e09','en'),(23,557,'ept_carousel','9d2e5c79-3f95-4416-adba-4ad4ae7683d3','en'),(24,558,'ept_counter_item','b7e52e90-6342-4ad9-9dc2-55f13a47c86b','en'),(25,559,'ept_counter_item','ce5d0752-e11c-4fcb-9b52-46d8c45b4a74','en'),(26,560,'ept_counter','face81f9-5400-406b-a64c-0c7717518193','en'),(27,542,'ept_slideshow_item','99c07029-1a55-4c8b-9253-35a63ab6dfb4','en'),(28,543,'ept_slideshow_item','3c06beb1-0396-43fd-9447-84df05591b3f','en'),(29,544,'ept_slideshow_item','73569f80-2633-4a12-9cfb-720de0540f8c','en'),(30,545,'ept_slideshow','ad02f753-e8f8-4eb7-b574-b8e8d4b78e5b','en'),(31,561,'ept_tabs_item','03e1362a-b7df-4469-b71d-5195bdeb4904','en'),(32,562,'ept_tabs_item','3747fc91-691d-4dac-a4df-e51cf0a0d5a1','en'),(33,563,'ept_tabs','bc10cacf-328a-491e-9ba0-4d72f49bdd4c','en'),(34,565,'ept_accordion_section','37923327-88d4-4fe3-84e9-3d4b9eef2c3e','en'),(35,566,'ept_accordion_section','05578525-caa1-4526-aa56-56d6d3e9b6fc','en'),(36,567,'ept_accordion','c1d65509-37e9-4ef2-9c23-fbd78fe17204','en'),(37,564,'ept_accordion_section','c2fdfa00-3d9e-4e59-89a0-05f5ebf0ed9a','en'),(38,582,'ept_views','27496e1b-7e55-4ef1-a324-6a0afdd5dce4','en'),(39,581,'ept_block','6e8df8b3-0097-4c28-a044-a1ffc40d37ea','en'),(40,580,'ept_hero','93872b1e-0586-4e38-b8a5-5edca3c418e7','en');
/*!40000 ALTER TABLE `paragraphs_item` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraphs_item_field_data`
--

DROP TABLE IF EXISTS `paragraphs_item_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraphs_item_field_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `created` int DEFAULT NULL,
  `parent_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `parent_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `parent_field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `behavior_settings` longtext,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `paragraph__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `paragraph__revision_id` (`revision_id`),
  KEY `paragraph_field__type__target_id` (`type`),
  KEY `paragraph__status_type` (`status`,`type`,`id`),
  KEY `paragraphs__parent_fields` (`parent_type`,`parent_id`,`parent_field_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for paragraph entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraphs_item_field_data`
--

LOCK TABLES `paragraphs_item_field_data` WRITE;
/*!40000 ALTER TABLE `paragraphs_item_field_data` DISABLE KEYS */;
INSERT INTO `paragraphs_item_field_data` VALUES (1,531,'ept_hero','en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,532,'ept_text','en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,533,'ept_tiles_item','en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,534,'ept_tiles_item','en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,535,'ept_tiles_item','en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,536,'ept_tiles','en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,537,'ept_stats_item','en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,538,'ept_stats_item','en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,539,'ept_stats','en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,540,'ept_image_gallery','en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,541,'ept_cta','en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,546,'ept_quote','en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,547,'ept_carousel_item','en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,548,'ept_carousel_item','en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,549,'ept_carousel_item','en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,550,'ept_carousel_item','en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,551,'ept_carousel_item','en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,552,'ept_carousel_item','en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,553,'ept_carousel_item','en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,554,'ept_carousel_item','en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,555,'ept_carousel_item','en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,556,'ept_carousel_item','en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,557,'ept_carousel','en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,558,'ept_counter_item','en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,559,'ept_counter_item','en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,560,'ept_counter','en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,542,'ept_slideshow_item','en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,543,'ept_slideshow_item','en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,544,'ept_slideshow_item','en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,545,'ept_slideshow','en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,561,'ept_tabs_item','en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(32,562,'ept_tabs_item','en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(33,563,'ept_tabs','en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(34,565,'ept_accordion_section','en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,NULL),(35,566,'ept_accordion_section','en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,NULL),(36,567,'ept_accordion','en',1,1729022156,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(37,564,'ept_accordion_section','en',1,1729024475,'36','paragraph','field_ept_accordion','a:0:{}',1,1),(38,582,'ept_views','en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(39,581,'ept_block','en',1,1729065292,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(40,580,'ept_hero','en',1,1729066868,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL);
/*!40000 ALTER TABLE `paragraphs_item_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraphs_item_revision`
--

DROP TABLE IF EXISTS `paragraphs_item_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraphs_item_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `paragraph__id` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=583 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for paragraph entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraphs_item_revision`
--

LOCK TABLES `paragraphs_item_revision` WRITE;
/*!40000 ALTER TABLE `paragraphs_item_revision` DISABLE KEYS */;
INSERT INTO `paragraphs_item_revision` VALUES (1,1,'en',1),(1,2,'en',1),(1,3,'en',1),(1,4,'en',1),(1,5,'en',1),(1,6,'en',1),(1,7,'en',1),(1,8,'en',1),(1,9,'en',1),(2,10,'en',1),(1,11,'en',1),(2,12,'en',1),(1,13,'en',1),(2,14,'en',1),(1,15,'en',1),(2,16,'en',1),(1,17,'en',1),(2,18,'en',1),(3,19,'en',1),(4,20,'en',1),(5,21,'en',1),(6,22,'en',1),(1,23,'en',1),(2,24,'en',1),(3,25,'en',1),(4,26,'en',1),(5,27,'en',1),(6,28,'en',1),(1,29,'en',1),(2,30,'en',1),(3,31,'en',1),(4,32,'en',1),(5,33,'en',1),(6,34,'en',1),(1,35,'en',1),(2,36,'en',1),(3,37,'en',1),(4,38,'en',1),(5,39,'en',1),(6,40,'en',1),(1,41,'en',1),(2,42,'en',1),(3,43,'en',1),(4,44,'en',1),(5,45,'en',1),(6,46,'en',1),(1,47,'en',1),(2,48,'en',1),(3,49,'en',1),(4,50,'en',1),(5,51,'en',1),(6,52,'en',1),(1,53,'en',1),(2,54,'en',1),(3,55,'en',1),(4,56,'en',1),(5,57,'en',1),(6,58,'en',1),(1,59,'en',1),(2,60,'en',1),(3,61,'en',1),(4,62,'en',1),(5,63,'en',1),(6,64,'en',1),(1,65,'en',1),(2,66,'en',1),(3,67,'en',1),(4,68,'en',1),(5,69,'en',1),(6,70,'en',1),(7,71,'en',1),(8,72,'en',1),(9,73,'en',1),(1,74,'en',1),(2,75,'en',1),(3,76,'en',1),(4,77,'en',1),(5,78,'en',1),(6,79,'en',1),(7,80,'en',1),(8,81,'en',1),(9,82,'en',1),(1,83,'en',1),(2,84,'en',1),(3,85,'en',1),(4,86,'en',1),(5,87,'en',1),(6,88,'en',1),(7,89,'en',1),(8,90,'en',1),(9,91,'en',1),(1,92,'en',1),(2,93,'en',1),(3,94,'en',1),(4,95,'en',1),(5,96,'en',1),(6,97,'en',1),(7,98,'en',1),(8,99,'en',1),(9,100,'en',1),(10,101,'en',1),(1,102,'en',1),(2,103,'en',1),(3,104,'en',1),(4,105,'en',1),(5,106,'en',1),(6,107,'en',1),(7,108,'en',1),(8,109,'en',1),(9,110,'en',1),(10,111,'en',1),(1,112,'en',1),(2,113,'en',1),(3,114,'en',1),(4,115,'en',1),(5,116,'en',1),(6,117,'en',1),(7,118,'en',1),(8,119,'en',1),(9,120,'en',1),(10,121,'en',1),(1,122,'en',1),(2,123,'en',1),(3,124,'en',1),(4,125,'en',1),(5,126,'en',1),(6,127,'en',1),(7,128,'en',1),(8,129,'en',1),(9,130,'en',1),(10,131,'en',1),(1,132,'en',1),(2,133,'en',1),(3,134,'en',1),(4,135,'en',1),(5,136,'en',1),(6,137,'en',1),(7,138,'en',1),(8,139,'en',1),(9,140,'en',1),(10,141,'en',1),(1,142,'en',1),(2,143,'en',1),(3,144,'en',1),(4,145,'en',1),(5,146,'en',1),(6,147,'en',1),(7,148,'en',1),(8,149,'en',1),(9,150,'en',1),(10,151,'en',1),(1,152,'en',1),(2,153,'en',1),(3,154,'en',1),(4,155,'en',1),(5,156,'en',1),(6,157,'en',1),(7,158,'en',1),(8,159,'en',1),(9,160,'en',1),(10,161,'en',1),(11,162,'en',1),(1,163,'en',1),(2,164,'en',1),(3,165,'en',1),(4,166,'en',1),(5,167,'en',1),(6,168,'en',1),(7,169,'en',1),(8,170,'en',1),(9,171,'en',1),(10,172,'en',1),(11,173,'en',1),(1,174,'en',1),(2,175,'en',1),(3,176,'en',1),(4,177,'en',1),(5,178,'en',1),(6,179,'en',1),(7,180,'en',1),(8,181,'en',1),(9,182,'en',1),(10,183,'en',1),(11,184,'en',1),(12,185,'en',1),(1,186,'en',1),(2,187,'en',1),(3,188,'en',1),(4,189,'en',1),(5,190,'en',1),(6,191,'en',1),(7,192,'en',1),(8,193,'en',1),(9,194,'en',1),(10,195,'en',1),(11,196,'en',1),(12,197,'en',1),(1,198,'en',1),(2,199,'en',1),(3,200,'en',1),(4,201,'en',1),(5,202,'en',1),(6,203,'en',1),(7,204,'en',1),(8,205,'en',1),(9,206,'en',1),(10,207,'en',1),(11,208,'en',1),(12,209,'en',1),(13,210,'en',1),(14,211,'en',1),(15,212,'en',1),(16,213,'en',1),(17,214,'en',1),(18,215,'en',1),(19,216,'en',1),(20,217,'en',1),(21,218,'en',1),(22,219,'en',1),(23,220,'en',1),(1,221,'en',1),(2,222,'en',1),(3,223,'en',1),(4,224,'en',1),(5,225,'en',1),(6,226,'en',1),(7,227,'en',1),(8,228,'en',1),(9,229,'en',1),(10,230,'en',1),(11,231,'en',1),(12,232,'en',1),(13,233,'en',1),(14,234,'en',1),(15,235,'en',1),(16,236,'en',1),(17,237,'en',1),(18,238,'en',1),(19,239,'en',1),(20,240,'en',1),(21,241,'en',1),(22,242,'en',1),(23,243,'en',1),(1,244,'en',1),(2,245,'en',1),(3,246,'en',1),(4,247,'en',1),(5,248,'en',1),(6,249,'en',1),(7,250,'en',1),(8,251,'en',1),(9,252,'en',1),(10,253,'en',1),(11,254,'en',1),(12,255,'en',1),(13,256,'en',1),(14,257,'en',1),(15,258,'en',1),(16,259,'en',1),(17,260,'en',1),(18,261,'en',1),(19,262,'en',1),(20,263,'en',1),(21,264,'en',1),(22,265,'en',1),(23,266,'en',1),(24,267,'en',1),(25,268,'en',1),(26,269,'en',1),(1,270,'en',1),(2,271,'en',1),(3,272,'en',1),(4,273,'en',1),(5,274,'en',1),(6,275,'en',1),(7,276,'en',1),(8,277,'en',1),(9,278,'en',1),(10,279,'en',1),(11,280,'en',1),(27,281,'en',1),(28,282,'en',1),(29,283,'en',1),(30,284,'en',1),(12,285,'en',1),(13,286,'en',1),(14,287,'en',1),(15,288,'en',1),(16,289,'en',1),(17,290,'en',1),(18,291,'en',1),(19,292,'en',1),(20,293,'en',1),(21,294,'en',1),(22,295,'en',1),(23,296,'en',1),(24,297,'en',1),(25,298,'en',1),(26,299,'en',1),(1,300,'en',1),(2,301,'en',1),(3,302,'en',1),(4,303,'en',1),(5,304,'en',1),(6,305,'en',1),(7,306,'en',1),(8,307,'en',1),(9,308,'en',1),(10,309,'en',1),(11,310,'en',1),(27,311,'en',1),(28,312,'en',1),(29,313,'en',1),(30,314,'en',1),(12,315,'en',1),(13,316,'en',1),(14,317,'en',1),(15,318,'en',1),(16,319,'en',1),(17,320,'en',1),(18,321,'en',1),(19,322,'en',1),(20,323,'en',1),(21,324,'en',1),(22,325,'en',1),(23,326,'en',1),(24,327,'en',1),(25,328,'en',1),(26,329,'en',1),(1,330,'en',1),(2,331,'en',1),(3,332,'en',1),(4,333,'en',1),(5,334,'en',1),(6,335,'en',1),(7,336,'en',1),(8,337,'en',1),(9,338,'en',1),(10,339,'en',1),(11,340,'en',1),(27,341,'en',1),(28,342,'en',1),(29,343,'en',1),(30,344,'en',1),(12,345,'en',1),(13,346,'en',1),(14,347,'en',1),(15,348,'en',1),(16,349,'en',1),(17,350,'en',1),(18,351,'en',1),(19,352,'en',1),(20,353,'en',1),(21,354,'en',1),(22,355,'en',1),(23,356,'en',1),(24,357,'en',1),(25,358,'en',1),(26,359,'en',1),(1,360,'en',1),(2,361,'en',1),(3,362,'en',1),(4,363,'en',1),(5,364,'en',1),(6,365,'en',1),(7,366,'en',1),(8,367,'en',1),(9,368,'en',1),(10,369,'en',1),(11,370,'en',1),(27,371,'en',1),(28,372,'en',1),(29,373,'en',1),(30,374,'en',1),(12,375,'en',1),(13,376,'en',1),(14,377,'en',1),(15,378,'en',1),(16,379,'en',1),(17,380,'en',1),(18,381,'en',1),(19,382,'en',1),(20,383,'en',1),(21,384,'en',1),(22,385,'en',1),(23,386,'en',1),(24,387,'en',1),(25,388,'en',1),(26,389,'en',1),(31,390,'en',1),(32,391,'en',1),(33,392,'en',1),(1,393,'en',1),(2,394,'en',1),(3,395,'en',1),(4,396,'en',1),(5,397,'en',1),(6,398,'en',1),(7,399,'en',1),(8,400,'en',1),(9,401,'en',1),(10,402,'en',1),(11,403,'en',1),(27,404,'en',1),(28,405,'en',1),(29,406,'en',1),(30,407,'en',1),(12,408,'en',1),(13,409,'en',1),(14,410,'en',1),(15,411,'en',1),(16,412,'en',1),(17,413,'en',1),(18,414,'en',1),(19,415,'en',1),(20,416,'en',1),(21,417,'en',1),(22,418,'en',1),(23,419,'en',1),(24,420,'en',1),(25,421,'en',1),(26,422,'en',1),(31,423,'en',1),(32,424,'en',1),(33,425,'en',1),(1,426,'en',1),(2,427,'en',1),(3,428,'en',1),(4,429,'en',1),(5,430,'en',1),(6,431,'en',1),(7,432,'en',1),(8,433,'en',1),(9,434,'en',1),(10,435,'en',1),(11,436,'en',1),(27,437,'en',1),(28,438,'en',1),(29,439,'en',1),(30,440,'en',1),(12,441,'en',1),(13,442,'en',1),(14,443,'en',1),(15,444,'en',1),(16,445,'en',1),(17,446,'en',1),(18,447,'en',1),(19,448,'en',1),(20,449,'en',1),(21,450,'en',1),(22,451,'en',1),(23,452,'en',1),(24,453,'en',1),(25,454,'en',1),(26,455,'en',1),(31,456,'en',1),(32,457,'en',1),(33,458,'en',1),(1,459,'en',1),(2,460,'en',1),(3,461,'en',1),(4,462,'en',1),(5,463,'en',1),(6,464,'en',1),(7,465,'en',1),(8,466,'en',1),(9,467,'en',1),(10,468,'en',1),(11,469,'en',1),(27,470,'en',1),(28,471,'en',1),(29,472,'en',1),(30,473,'en',1),(12,474,'en',1),(13,475,'en',1),(14,476,'en',1),(15,477,'en',1),(16,478,'en',1),(17,479,'en',1),(18,480,'en',1),(19,481,'en',1),(20,482,'en',1),(21,483,'en',1),(22,484,'en',1),(23,485,'en',1),(24,486,'en',1),(25,487,'en',1),(26,488,'en',1),(31,489,'en',1),(32,490,'en',1),(33,491,'en',1),(34,492,'en',1),(35,493,'en',1),(36,494,'en',1),(1,495,'en',1),(2,496,'en',1),(3,497,'en',1),(4,498,'en',1),(5,499,'en',1),(6,500,'en',1),(7,501,'en',1),(8,502,'en',1),(9,503,'en',1),(10,504,'en',1),(11,505,'en',1),(27,506,'en',1),(28,507,'en',1),(29,508,'en',1),(30,509,'en',1),(12,510,'en',1),(13,511,'en',1),(14,512,'en',1),(15,513,'en',1),(16,514,'en',1),(17,515,'en',1),(18,516,'en',1),(19,517,'en',1),(20,518,'en',1),(21,519,'en',1),(22,520,'en',1),(23,521,'en',1),(24,522,'en',1),(25,523,'en',1),(26,524,'en',1),(31,525,'en',1),(32,526,'en',1),(33,527,'en',1),(34,528,'en',1),(35,529,'en',1),(36,530,'en',1),(1,531,'en',1),(2,532,'en',1),(3,533,'en',1),(4,534,'en',1),(5,535,'en',1),(6,536,'en',1),(7,537,'en',1),(8,538,'en',1),(9,539,'en',1),(10,540,'en',1),(11,541,'en',1),(27,542,'en',1),(28,543,'en',1),(29,544,'en',1),(30,545,'en',1),(12,546,'en',1),(13,547,'en',1),(14,548,'en',1),(15,549,'en',1),(16,550,'en',1),(17,551,'en',1),(18,552,'en',1),(19,553,'en',1),(20,554,'en',1),(21,555,'en',1),(22,556,'en',1),(23,557,'en',1),(24,558,'en',1),(25,559,'en',1),(26,560,'en',1),(31,561,'en',1),(32,562,'en',1),(33,563,'en',1),(37,564,'en',1),(34,565,'en',1),(35,566,'en',1),(36,567,'en',1),(38,568,'en',1),(39,569,'en',1),(38,570,'en',1),(40,571,'en',1),(39,572,'en',1),(38,573,'en',1),(40,574,'en',1),(39,575,'en',1),(38,576,'en',1),(40,577,'en',1),(39,578,'en',1),(38,579,'en',1),(40,580,'en',1),(39,581,'en',1),(38,582,'en',1);
/*!40000 ALTER TABLE `paragraphs_item_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `paragraphs_item_revision_field_data`
--

DROP TABLE IF EXISTS `paragraphs_item_revision_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `paragraphs_item_revision_field_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `created` int DEFAULT NULL,
  `parent_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `parent_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `parent_field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `behavior_settings` longtext,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `paragraph__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `paragraphs__parent_fields` (`parent_type`,`parent_id`,`parent_field_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for paragraph entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `paragraphs_item_revision_field_data`
--

LOCK TABLES `paragraphs_item_revision_field_data` WRITE;
/*!40000 ALTER TABLE `paragraphs_item_revision_field_data` DISABLE KEYS */;
INSERT INTO `paragraphs_item_revision_field_data` VALUES (1,1,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,2,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,3,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,4,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,5,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,6,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,7,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,8,'en',1,1728242667,'1','node','field_components','a:0:{}',1,1),(1,9,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(2,10,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,11,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,12,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,13,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(2,14,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(1,15,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(2,16,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(1,17,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,18,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,19,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,1),(4,20,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,1),(5,21,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,1),(6,22,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,23,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,24,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,25,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,26,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,27,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,28,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,29,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,30,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,31,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,32,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,33,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,34,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,35,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,36,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,37,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,38,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,39,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,40,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,41,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,42,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,43,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,44,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,45,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,46,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,47,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,48,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,49,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,50,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,51,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,52,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,53,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,54,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,55,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,56,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,57,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,58,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,59,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,60,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,61,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,62,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,63,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,64,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,65,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,66,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,67,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,68,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,69,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,70,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,71,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,1),(8,72,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,1),(9,73,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,74,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,75,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,76,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,77,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,78,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,79,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,80,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,81,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,82,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,83,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,84,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,85,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,86,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,87,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,88,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,89,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,1),(8,90,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,1),(9,91,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,92,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,93,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,94,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,95,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,96,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,97,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,98,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,99,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,100,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,101,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,102,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,103,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,104,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,105,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,106,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,107,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,108,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,109,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,110,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,111,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,112,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,113,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,114,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,115,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,116,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,117,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,118,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,119,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,120,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,121,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,122,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,123,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,124,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,125,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,126,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,127,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(7,128,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,129,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,130,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,131,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(1,132,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,133,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,134,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,135,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,136,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,137,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,138,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,139,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,140,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,141,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,142,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,143,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,144,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,145,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,146,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,147,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,148,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,149,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,150,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,151,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,152,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,153,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,154,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,155,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,156,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,157,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,158,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,159,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,160,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,161,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,162,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,163,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,164,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,165,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,166,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,167,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,168,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,169,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,170,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,171,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,172,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,173,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,174,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,175,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,176,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,177,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,178,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,179,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,180,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,181,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,182,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,183,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,184,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,185,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,186,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,187,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,188,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,189,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,190,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,191,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,192,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,193,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,194,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,195,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,196,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,197,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,198,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,199,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,200,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,201,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,202,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,203,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,204,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,205,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,206,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,207,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,208,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,209,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,210,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(14,211,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(15,212,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(16,213,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(17,214,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(18,215,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(19,216,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(20,217,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(21,218,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(22,219,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,1),(23,220,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,221,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,222,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,223,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,224,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,225,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,226,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,227,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,228,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,229,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,230,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,231,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,232,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,233,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,234,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,235,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,236,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,237,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,238,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,239,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,240,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,241,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,242,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,243,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,244,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,245,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,246,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,247,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,248,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,249,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,250,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,251,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,252,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,253,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,254,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,255,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,256,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,257,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,258,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,259,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,260,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,261,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,262,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,263,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,264,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,265,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,266,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,267,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,1),(25,268,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,1),(26,269,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,270,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,271,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,272,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,273,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,274,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,275,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,276,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,277,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,278,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,279,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,280,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,281,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,1),(28,282,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,1),(29,283,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,1),(30,284,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(12,285,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,286,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,287,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,288,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,289,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,290,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,291,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,292,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,293,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,294,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,295,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,296,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,297,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,298,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,299,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(1,300,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,301,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,302,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,303,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,304,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,305,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,306,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,307,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,308,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,309,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,310,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,311,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,312,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,313,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,314,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(12,315,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,316,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,317,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,318,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,319,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,320,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,321,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,322,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,323,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,324,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,325,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,326,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,327,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,328,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,329,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(1,330,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,331,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,332,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,333,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,334,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,335,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,336,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,337,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,338,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,339,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,340,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,341,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,342,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,343,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,344,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(12,345,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,346,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,347,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,348,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,349,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,350,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,351,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,352,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,353,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,354,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,355,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,356,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,357,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,358,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,359,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(1,360,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,361,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,362,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,363,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,364,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,365,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,366,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,367,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,368,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,369,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,370,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,371,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,372,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,373,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,374,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,375,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,376,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,377,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,378,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,379,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,380,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,381,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,382,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,383,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,384,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,385,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,386,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,387,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,388,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,389,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,390,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,1),(32,391,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,1),(33,392,'en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,393,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,394,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,395,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,396,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,397,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,398,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,399,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,400,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,401,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,402,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,403,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,404,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,405,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,406,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,407,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,408,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,409,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,410,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,411,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,412,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,413,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,414,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,415,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,416,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,417,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,418,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,419,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,420,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,421,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,422,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,423,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(32,424,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(33,425,'en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,426,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,427,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,428,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,429,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,430,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,431,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,432,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,433,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,434,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,435,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,436,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,437,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,438,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,439,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,440,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,441,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,442,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,443,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,444,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,445,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,446,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,447,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,448,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,449,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,450,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,451,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,452,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,453,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,454,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,455,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,456,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(32,457,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(33,458,'en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,459,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,460,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,461,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,462,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,463,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,464,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,465,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,466,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,467,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,468,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,469,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,470,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,471,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,472,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,473,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,474,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,475,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,476,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,477,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,478,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,479,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,480,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,481,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,482,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,483,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,484,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,485,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,486,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,487,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,488,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,489,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(32,490,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(33,491,'en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(34,492,'en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,1),(35,493,'en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,1),(36,494,'en',1,1729022156,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,495,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,496,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,497,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,498,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,499,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,500,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,501,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,502,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,503,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,504,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,505,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,506,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,507,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,508,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,509,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,510,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,511,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,512,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,513,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,514,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,515,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,516,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,517,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,518,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,519,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,520,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,521,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,522,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,523,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,524,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,525,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(32,526,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(33,527,'en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(34,528,'en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,NULL),(35,529,'en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,1),(36,530,'en',1,1729022156,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(1,531,'en',1,1728242667,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(2,532,'en',1,1728809668,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(3,533,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(4,534,'en',1,1728819245,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(5,535,'en',1,1728819327,'6','paragraph','field_ept_tiles','a:0:{}',1,NULL),(6,536,'en',1,1728819327,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(7,537,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(8,538,'en',1,1728883680,'9','paragraph','field_ept_stats','a:0:{}',1,NULL),(9,539,'en',1,1728883680,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(10,540,'en',1,1728884868,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(11,541,'en',1,1728888715,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(27,542,'en',1,1728936096,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(28,543,'en',1,1728936240,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(29,544,'en',1,1728936467,'30','paragraph','field_ept_slideshow','a:0:{}',1,NULL),(30,545,'en',1,1728936575,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(12,546,'en',1,1728933345,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(13,547,'en',1,1728933651,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(14,548,'en',1,1728933677,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(15,549,'en',1,1728933705,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(16,550,'en',1,1728933742,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(17,551,'en',1,1728933774,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(18,552,'en',1,1728933815,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(19,553,'en',1,1728933850,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(20,554,'en',1,1728933885,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(21,555,'en',1,1728933921,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(22,556,'en',1,1728933949,'23','paragraph','field_ept_carousel','a:0:{}',1,NULL),(23,557,'en',1,1728934054,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(24,558,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(25,559,'en',1,1728935787,'26','paragraph','field_ept_counter_items','a:0:{}',1,NULL),(26,560,'en',1,1728935787,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(31,561,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(32,562,'en',1,1728937075,'33','paragraph','field_ept_tabs','a:0:{}',1,NULL),(33,563,'en',1,1728937075,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(37,564,'en',1,1729024475,'36','paragraph','field_ept_accordion','a:0:{}',1,1),(34,565,'en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,NULL),(35,566,'en',1,1729022156,'36','paragraph','field_ept_accordion','a:0:{}',1,NULL),(36,567,'en',1,1729022156,'1','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(38,568,'en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(39,569,'en',1,1729065292,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(38,570,'en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(40,571,'en',1,1729066868,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(39,572,'en',1,1729065292,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(38,573,'en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(40,574,'en',1,1729066868,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(39,575,'en',1,1729065292,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(38,576,'en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(40,577,'en',1,1729066868,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(39,578,'en',1,1729065292,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(38,579,'en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(40,580,'en',1,1729066868,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL),(39,581,'en',1,1729065292,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,1),(38,582,'en',1,1729064495,'19','node','field_components','a:1:{s:17:\"layout_paragraphs\";a:2:{s:11:\"parent_uuid\";N;s:6:\"region\";N;}}',1,NULL);
/*!40000 ALTER TABLE `paragraphs_item_revision_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `path_alias`
--

DROP TABLE IF EXISTS `path_alias`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `path_alias` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `path` varchar(255) DEFAULT NULL,
  `alias` varchar(255) DEFAULT NULL,
  `status` tinyint NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `path_alias_field__uuid__value` (`uuid`),
  UNIQUE KEY `path_alias__revision_id` (`revision_id`),
  KEY `path_alias__alias_langcode_id_status` (`alias`(191),`langcode`,`id`,`status`),
  KEY `path_alias__path_langcode_id_status` (`path`(191),`langcode`,`id`,`status`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for path_alias entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `path_alias`
--

LOCK TABLES `path_alias` WRITE;
/*!40000 ALTER TABLE `path_alias` DISABLE KEYS */;
INSERT INTO `path_alias` VALUES (1,1,'88aa9d05-9cea-4b1c-a0a8-c3feb0fe14d0','en','/node/19','/whats-new',1);
/*!40000 ALTER TABLE `path_alias` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `path_alias_revision`
--

DROP TABLE IF EXISTS `path_alias_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `path_alias_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `path` varchar(255) DEFAULT NULL,
  `alias` varchar(255) DEFAULT NULL,
  `status` tinyint NOT NULL,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `path_alias__id` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for path_alias entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `path_alias_revision`
--

LOCK TABLES `path_alias_revision` WRITE;
/*!40000 ALTER TABLE `path_alias_revision` DISABLE KEYS */;
INSERT INTO `path_alias_revision` VALUES (1,1,'en','/node/19','/whats-new',1,1);
/*!40000 ALTER TABLE `path_alias_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `queue`
--

DROP TABLE IF EXISTS `queue`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `queue` (
  `item_id` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique item ID.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The queue name.',
  `data` longblob COMMENT 'The arbitrary data for the item.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'Timestamp when the claim lease expires on the item.',
  `created` bigint NOT NULL DEFAULT '0' COMMENT 'Timestamp when the item was created.',
  PRIMARY KEY (`item_id`),
  KEY `name_created` (`name`,`created`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB AUTO_INCREMENT=269 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores items in queues.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `queue`
--

LOCK TABLES `queue` WRITE;
/*!40000 ALTER TABLE `queue` DISABLE KEYS */;
INSERT INTO `queue` VALUES (267,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:17:\"views_year_filter\";s:4:\"info\";a:6:{s:4:\"name\";s:17:\"Views Year Filter\";s:7:\"package\";s:4:\"Date\";s:7:\"version\";s:5:\"2.1.5\";s:7:\"project\";s:17:\"views_year_filter\";s:9:\"datestamp\";i:1726675379;s:16:\"_info_file_ctime\";i:1729064379;}s:9:\"datestamp\";i:1726675379;s:8:\"includes\";a:1:{s:17:\"views_year_filter\";s:17:\"Views Year Filter\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1729064453),(268,'update_fetch_tasks',_binary 'a:6:{s:4:\"name\";s:22:\"better_exposed_filters\";s:4:\"info\";a:6:{s:4:\"name\";s:22:\"Better Exposed Filters\";s:7:\"package\";s:5:\"Views\";s:7:\"version\";s:5:\"7.0.2\";s:7:\"project\";s:22:\"better_exposed_filters\";s:9:\"datestamp\";i:1729001182;s:16:\"_info_file_ctime\";i:1729066392;}s:9:\"datestamp\";i:1729001182;s:8:\"includes\";a:1:{s:22:\"better_exposed_filters\";s:22:\"Better Exposed Filters\";}s:12:\"project_type\";s:6:\"module\";s:14:\"project_status\";b:1;}',0,1729066497);
/*!40000 ALTER TABLE `queue` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `router`
--

DROP TABLE IF EXISTS `router`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `router` (
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Machine name of this route',
  `path` varchar(255) NOT NULL DEFAULT '' COMMENT 'The path for this URI',
  `pattern_outline` varchar(255) NOT NULL DEFAULT '' COMMENT 'The pattern',
  `fit` int NOT NULL DEFAULT '0' COMMENT 'A numeric representation of how specific the path is.',
  `route` longblob COMMENT 'A serialized Route object',
  `number_parts` smallint NOT NULL DEFAULT '0' COMMENT 'Number of parts in this router path.',
  PRIMARY KEY (`name`),
  KEY `pattern_outline_parts` (`pattern_outline`(191),`number_parts`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maps paths to various callbacks (access, page and title)';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `router`
--

LOCK TABLES `router` WRITE;
/*!40000 ALTER TABLE `router` DISABLE KEYS */;
INSERT INTO `router` VALUES ('<button>','/','/',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"_no_path\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',1),('<current>','/<current>','/<current>',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/<current>\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:0:{}s:7:\"options\";a:2:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/\\<current\\>$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/<current>\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:10:\"/<current>\";s:8:\"numParts\";i:1;}}',1),('<front>','/','/',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:6:\"_title\";s:4:\"Home\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',1),('<nolink>','/','/',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"_no_path\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',1),('<none>','/','/',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"_no_path\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',1),('admin_toolbar.run.cron','/run-cron','/run-cron',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:9:\"/run-cron\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:65:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::runCron\";s:6:\"_title\";s:8:\"Run cron\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/run\\-cron$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/run-cron\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:9:\"/run-cron\";s:8:\"numParts\";i:1;}}',1),('admin_toolbar.settings','/admin/config/user-interface/admin-toolbar','/admin/config/user-interface/admin-toolbar',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/config/user-interface/admin-toolbar\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\admin_toolbar\\Form\\AdminToolbarSettingsForm\";s:6:\"_title\";s:22:\"Admin Toolbar settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/config/user\\-interface/admin\\-toolbar$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/admin-toolbar\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:42:\"/admin/config/user-interface/admin-toolbar\";s:8:\"numParts\";i:4;}}',4),('admin_toolbar_tools.cssjs','/admin/flush/cssjs','/admin/flush/cssjs',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/admin/flush/cssjs\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushJsCss\";s:6:\"_title\";s:24:\"Flush CSS and JavaScript\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/admin/flush/cssjs$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/admin/flush/cssjs\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/admin/flush/cssjs\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.flush','/admin/flush','/admin/flush',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/admin/flush\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:66:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushAll\";s:6:\"_title\";s:16:\"Flush all caches\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/admin/flush$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/admin/flush\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/admin/flush\";s:8:\"numParts\";i:2;}}',2),('admin_toolbar_tools.flush_menu','/admin/flush/menu','/admin/flush/menu',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/admin/flush/menu\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:67:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushMenu\";s:6:\"_title\";s:4:\"Menu\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/admin/flush/menu$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/flush/menu\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:17:\"/admin/flush/menu\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.flush_rendercache','/admin/flush/rendercache','/admin/flush/rendercache',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/flush/rendercache\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:69:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::cacheRender\";s:6:\"_title\";s:12:\"Render cache\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/flush/rendercache$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/flush/rendercache\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/flush/rendercache\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.flush_static','/admin/flush/static-caches','/admin/flush/static-caches',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/flush/static-caches\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:69:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushStatic\";s:6:\"_title\";s:13:\"Static caches\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/admin/flush/static\\-caches$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/flush/static-caches\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:26:\"/admin/flush/static-caches\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.flush_twig','/admin/flush/twig','/admin/flush/twig',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/admin/flush/twig\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:67:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushTwig\";s:6:\"_title\";s:4:\"Twig\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/admin/flush/twig$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/flush/twig\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:17:\"/admin/flush/twig\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.flush_views','/admin/flush/views','/admin/flush/views',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/admin/flush/views\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushViews\";s:6:\"_title\";s:5:\"Views\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/admin/flush/views$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/admin/flush/views\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/admin/flush/views\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.plugin','/admin/flush/plugin','/admin/flush/plugin',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/flush/plugin\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:70:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushPlugins\";s:6:\"_title\";s:6:\"Plugin\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/flush/plugin$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/flush/plugin\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/flush/plugin\";s:8:\"numParts\";i:3;}}',3),('admin_toolbar_tools.settings','/admin/config/user-interface/admin-toolbar-tools','/admin/config/user-interface/admin-toolbar-tools',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/config/user-interface/admin-toolbar-tools\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:62:\"\\Drupal\\admin_toolbar_tools\\Form\\AdminToolbarToolsSettingsForm\";s:6:\"_title\";s:28:\"Admin Toolbar Tools settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/config/user\\-interface/admin\\-toolbar\\-tools$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/admin/config/user-interface/admin-toolbar-tools\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:48:\"/admin/config/user-interface/admin-toolbar-tools\";s:8:\"numParts\";i:4;}}',4),('admin_toolbar_tools.theme_rebuild','/admin/flush/theme_rebuild','/admin/flush/theme_rebuild',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/flush/theme_rebuild\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:70:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::themeRebuild\";s:6:\"_title\";s:13:\"Theme Rebuild\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/flush/theme_rebuild$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/flush/theme_rebuild\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:26:\"/admin/flush/theme_rebuild\";s:8:\"numParts\";i:3;}}',3),('announcements_feed.announcement','/admin/announcements_feed','/admin/announcements_feed',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/announcements_feed\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:74:\"\\Drupal\\announcements_feed\\Controller\\AnnounceController::getAnnouncements\";s:6:\"_title\";s:23:\"Community announcements\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"access announcements\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/announcements_feed$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/announcements_feed\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:25:\"/admin/announcements_feed\";s:8:\"numParts\";i:2;}}',2),('big_pipe.nojs','/big_pipe/no-js','/big_pipe/no-js',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:15:\"/big_pipe/no-js\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\big_pipe\\Controller\\BigPipeController:setNoJsCookie\";s:6:\"_title\";s:19:\"BigPipe no-JS check\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:23:\"{^/big_pipe/no\\-js$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/big_pipe/no-js\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:15:\"/big_pipe/no-js\";s:8:\"numParts\";i:2;}}',2),('block.admin_add','/admin/structure/block/add/{plugin_id}/{theme}','/admin/structure/block/add/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/block/add/{plugin_id}/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:66:\"\\Drupal\\block\\Controller\\BlockAddController::blockAddConfigureForm\";s:5:\"theme\";N;s:6:\"_title\";s:15:\"Configure block\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"plugin_id\";i:1;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/structure/block/add/(?P<plugin_id>[^/]++)(?:/(?P<theme>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"plugin_id\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/block/add\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"plugin_id\";i:1;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/structure/block/add/%\";s:8:\"numParts\";i:6;}}',6),('block.admin_demo','/admin/structure/block/demo/{theme}','/admin/structure/block/demo/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/block/demo/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:46:\"\\Drupal\\block\\Controller\\BlockController::demo\";s:15:\"_title_callback\";s:21:\"theme_handler:getName\";}s:12:\"requirements\";a:2:{s:13:\"_access_theme\";s:4:\"TRUE\";s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:18:\"access_check.theme\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/block/demo/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/block/demo\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:29:\"/admin/structure/block/demo/%\";s:8:\"numParts\";i:5;}}',5),('block.admin_display','/admin/structure/block','/admin/structure/block',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:53:\"\\Drupal\\block\\Controller\\BlockListController::listing\";s:6:\"_title\";s:12:\"Block layout\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/block\";s:8:\"numParts\";i:3;}}',3),('block.admin_display_theme','/admin/structure/block/list/{theme}','/admin/structure/block/list/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/block/list/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:53:\"\\Drupal\\block\\Controller\\BlockListController::listing\";s:6:\"_title\";s:12:\"Block layout\";}s:12:\"requirements\";a:2:{s:13:\"_access_theme\";s:4:\"TRUE\";s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:18:\"access_check.theme\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/block/list/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/block/list\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:29:\"/admin/structure/block/list/%\";s:8:\"numParts\";i:5;}}',5),('block.admin_library','/admin/structure/block/library/{theme}','/admin/structure/block/library/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/structure/block/library/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\block\\Controller\\BlockLibraryController::listBlocks\";s:6:\"_title\";s:11:\"Place block\";}s:12:\"requirements\";a:2:{s:13:\"_access_theme\";s:4:\"TRUE\";s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:18:\"access_check.theme\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/structure/block/library/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/structure/block/library\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:32:\"/admin/structure/block/library/%\";s:8:\"numParts\";i:5;}}',5),('block.category_autocomplete','/block-category/autocomplete','/block-category/autocomplete',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/block-category/autocomplete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:69:\"\\Drupal\\block\\Controller\\CategoryAutocompleteController::autocomplete\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/block\\-category/autocomplete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/block-category/autocomplete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:28:\"/block-category/autocomplete\";s:8:\"numParts\";i:2;}}',2),('block_content.add_form','/block/add/{block_content_type}','/block/add/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/block/add/{block_content_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\block_content\\Controller\\BlockContentController::addForm\";s:15:\"_title_callback\";s:72:\"\\Drupal\\block_content\\Controller\\BlockContentController::getAddFormTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:34:\"block_content:{block_content_type}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/block/add/(?P<block_content_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/block/add\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:12:\"/block/add/%\";s:8:\"numParts\";i:3;}}',3),('block_content.add_page','/block/add','/block/add',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/block/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\block_content\\Controller\\BlockContentController::add\";s:6:\"_title\";s:17:\"Add content block\";}s:12:\"requirements\";a:1:{s:25:\"_entity_create_any_access\";s:13:\"block_content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.entity_create_any\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/block/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/block/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:10:\"/block/add\";s:8:\"numParts\";i:2;}}',2),('block_content.type_add','/admin/structure/block-content/add','/admin/structure/block-content/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/structure/block-content/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"block_content_type.add\";s:6:\"_title\";s:3:\"Add\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:18:\"block_content_type\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/admin/structure/block\\-content/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/structure/block-content/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/structure/block-content/add\";s:8:\"numParts\";i:4;}}',4),('ckeditor5.media_entity_metadata','/ckeditor5/{editor}/media-entity-metadata','/ckeditor5/%/media-entity-metadata',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/ckeditor5/{editor}/media-entity-metadata\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:74:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5MediaController::mediaEntityMetadata\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:10:\"editor.use\";s:14:\"_custom_access\";s:61:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5MediaController::access\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"editor\";a:2:{s:4:\"type\";s:13:\"entity:editor\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:3:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";i:2;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"editor\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/ckeditor5/(?P<editor>[^/]++)/media\\-entity\\-metadata$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/media-entity-metadata\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"editor\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/ckeditor5\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"editor\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:34:\"/ckeditor5/%/media-entity-metadata\";s:8:\"numParts\";i:3;}}',3),('ckeditor5.upload_image','/ckeditor5/upload-image/{editor}','/ckeditor5/upload-image/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/ckeditor5/upload-image/{editor}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:61:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5ImageController::upload\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:10:\"editor.use\";s:14:\"_custom_access\";s:79:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5ImageController::imageUploadEnabledAccess\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"editor\";a:2:{s:4:\"type\";s:13:\"entity:editor\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:3:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";i:2;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"editor\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/ckeditor5/upload\\-image/(?P<editor>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"editor\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/ckeditor5/upload-image\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"editor\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:25:\"/ckeditor5/upload-image/%\";s:8:\"numParts\";i:3;}}',3),('ckeditor5_plugin_pack.settings','/admin/config/ckeditor5-plugin-pack','/admin/config/ckeditor5-plugin-pack',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/config/ckeditor5-plugin-pack\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"\\Drupal\\ckeditor5_plugin_pack\\Form\\SettingsForm\";s:6:\"_title\";s:31:\"CKEditor 5 Plugin Pack settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/ckeditor5\\-plugin\\-pack$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/ckeditor5-plugin-pack\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:35:\"/admin/config/ckeditor5-plugin-pack\";s:8:\"numParts\";i:3;}}',3),('comment.admin','/admin/content/comment','/admin/content/comment',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/content/comment\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"comment\";s:10:\"display_id\";s:14:\"page_published\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"administer comments\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/content/comment$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/content/comment\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/content/comment\";s:8:\"numParts\";i:3;}}',3),('comment.admin_approval','/admin/content/comment/approval','/admin/content/comment/approval',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/content/comment/approval\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"comment\";s:10:\"display_id\";s:15:\"page_unapproved\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"administer comments\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/content/comment/approval$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/content/comment/approval\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/content/comment/approval\";s:8:\"numParts\";i:4;}}',4),('comment.approve','/comment/{comment}/approve','/comment/%/approve',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/comment/{comment}/approve\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:7:\"Approve\";s:11:\"_controller\";s:60:\"\\Drupal\\comment\\Controller\\CommentController::commentApprove\";s:11:\"entity_type\";s:7:\"comment\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:15:\"comment.approve\";s:11:\"_csrf_token\";s:4:\"TRUE\";s:7:\"comment\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"comment\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"comment\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/comment/(?P<comment>\\d+)/approve$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/approve\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:7:\"comment\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"comment\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:18:\"/comment/%/approve\";s:8:\"numParts\";i:3;}}',3),('comment.multiple_delete_confirm','/admin/content/comment/delete','/admin/content/comment/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/content/comment/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:6:\"Delete\";s:5:\"_form\";s:42:\"\\Drupal\\comment\\Form\\ConfirmDeleteMultiple\";s:14:\"entity_type_id\";s:7:\"comment\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:7:\"comment\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/content/comment/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/content/comment/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/content/comment/delete\";s:8:\"numParts\";i:4;}}',4),('comment.new_comments_node_links','/comments/render_new_comments_node_links','/comments/render_new_comments_node_links',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/comments/render_new_comments_node_links\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:72:\"\\Drupal\\comment\\Controller\\CommentController::renderNewCommentsNodeLinks\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/comments/render_new_comments_node_links$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/comments/render_new_comments_node_links\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:40:\"/comments/render_new_comments_node_links\";s:8:\"numParts\";i:2;}}',2),('comment.node_redirect','/comment/{node}/reply','/comment/%/reply',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/comment/{node}/reply\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\comment\\Controller\\CommentController::redirectNode\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:9:\"node.view\";s:20:\"_module_dependencies\";s:4:\"node\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/comment/(?P<node>\\d+)/reply$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/reply\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:16:\"/comment/%/reply\";s:8:\"numParts\";i:3;}}',3),('comment.reply','/comment/reply/{entity_type}/{entity}/{field_name}/{pid}','/comment/reply/%/%/%',24,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/comment/reply/{entity_type}/{entity}/{field_name}/{pid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:58:\"\\Drupal\\comment\\Controller\\CommentController::getReplyForm\";s:6:\"_title\";s:15:\"Add new comment\";s:3:\"pid\";N;}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:61:\"\\Drupal\\comment\\Controller\\CommentController::replyFormAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:20:\"entity:{entity_type}\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:11:\"entity_type\";i:1;s:6:\"entity\";i:2;s:10:\"field_name\";i:3;s:3:\"pid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/comment/reply/(?P<entity_type>[^/]++)/(?P<entity>[^/]++)/(?P<field_name>[^/]++)(?:/(?P<pid>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"pid\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/comment/reply\";}}s:9:\"path_vars\";a:4:{i:0;s:11:\"entity_type\";i:1;s:6:\"entity\";i:2;s:10:\"field_name\";i:3;s:3:\"pid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:24;s:14:\"patternOutline\";s:20:\"/comment/reply/%/%/%\";s:8:\"numParts\";i:6;}}',6),('config.diff','/admin/config/development/configuration/sync/diff/{source_name}/{target_name}','/admin/config/development/configuration/sync/diff/%',126,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/config/development/configuration/sync/diff/{source_name}/{target_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\config\\Controller\\ConfigController::diff\";s:11:\"target_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"synchronize configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"source_name\";i:1;s:11:\"target_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/config/development/configuration/sync/diff/(?P<source_name>[^/]++)(?:/(?P<target_name>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"source_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:49:\"/admin/config/development/configuration/sync/diff\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"source_name\";i:1;s:11:\"target_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:126;s:14:\"patternOutline\";s:51:\"/admin/config/development/configuration/sync/diff/%\";s:8:\"numParts\";i:8;}}',8),('config.diff_collection','/admin/config/development/configuration/sync/diff_collection/{collection}/{source_name}/{target_name}','/admin/config/development/configuration/sync/diff_collection/%/%',252,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:101:\"/admin/config/development/configuration/sync/diff_collection/{collection}/{source_name}/{target_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\config\\Controller\\ConfigController::diff\";s:11:\"target_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"synchronize configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:10:\"collection\";i:1;s:11:\"source_name\";i:2;s:11:\"target_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:143:\"{^/admin/config/development/configuration/sync/diff_collection/(?P<collection>[^/]++)/(?P<source_name>[^/]++)(?:/(?P<target_name>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"source_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"collection\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:60:\"/admin/config/development/configuration/sync/diff_collection\";}}s:9:\"path_vars\";a:3:{i:0;s:10:\"collection\";i:1;s:11:\"source_name\";i:2;s:11:\"target_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:252;s:14:\"patternOutline\";s:64:\"/admin/config/development/configuration/sync/diff_collection/%/%\";s:8:\"numParts\";i:9;}}',9),('config.export_download','/admin/config/development/configuration/full/export-download','/admin/config/development/configuration/full/export-download',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/development/configuration/full/export-download\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\config\\Controller\\ConfigController::downloadExport\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/development/configuration/full/export\\-download$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:60:\"/admin/config/development/configuration/full/export-download\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:60:\"/admin/config/development/configuration/full/export-download\";s:8:\"numParts\";i:6;}}',6),('config.export_full','/admin/config/development/configuration/full/export','/admin/config/development/configuration/full/export',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/development/configuration/full/export\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\config\\Form\\ConfigExportForm\";s:6:\"_title\";s:6:\"Export\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/config/development/configuration/full/export$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/development/configuration/full/export\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:51:\"/admin/config/development/configuration/full/export\";s:8:\"numParts\";i:6;}}',6),('config.export_single','/admin/config/development/configuration/single/export/{config_type}/{config_name}','/admin/config/development/configuration/single/export',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/config/development/configuration/single/export/{config_type}/{config_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:13:\"Single export\";s:5:\"_form\";s:42:\"\\Drupal\\config\\Form\\ConfigSingleExportForm\";s:11:\"config_type\";N;s:11:\"config_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"config_type\";i:1;s:11:\"config_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:118:\"{^/admin/config/development/configuration/single/export(?:/(?P<config_type>[^/]++)(?:/(?P<config_name>[^/]++))?)?$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"config_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"config_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:53:\"/admin/config/development/configuration/single/export\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"config_type\";i:1;s:11:\"config_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:53:\"/admin/config/development/configuration/single/export\";s:8:\"numParts\";i:8;}}',8),('config.import_full','/admin/config/development/configuration/full/import','/admin/config/development/configuration/full/import',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/development/configuration/full/import\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\config\\Form\\ConfigImportForm\";s:6:\"_title\";s:6:\"Import\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"import configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/config/development/configuration/full/import$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/development/configuration/full/import\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:51:\"/admin/config/development/configuration/full/import\";s:8:\"numParts\";i:6;}}',6),('config.import_single','/admin/config/development/configuration/single/import','/admin/config/development/configuration/single/import',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/development/configuration/single/import\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:13:\"Single import\";s:5:\"_form\";s:42:\"\\Drupal\\config\\Form\\ConfigSingleImportForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"import configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/admin/config/development/configuration/single/import$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:53:\"/admin/config/development/configuration/single/import\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:53:\"/admin/config/development/configuration/single/import\";s:8:\"numParts\";i:6;}}',6),('config.sync','/admin/config/development/configuration','/admin/config/development/configuration',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/config/development/configuration\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:30:\"\\Drupal\\config\\Form\\ConfigSync\";s:6:\"_title\";s:11:\"Synchronize\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"synchronize configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/admin/config/development/configuration$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/development/configuration\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/config/development/configuration\";s:8:\"numParts\";i:4;}}',4),('contact.form_add','/admin/structure/contact/add','/admin/structure/contact/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/structure/contact/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"contact_form.add\";s:6:\"_title\";s:16:\"Add contact form\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer contact forms\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/structure/contact/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/contact/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/structure/contact/add\";s:8:\"numParts\";i:4;}}',4),('contact.site_page','/contact','/contact',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:8:\"/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:7:\"Contact\";s:11:\"_controller\";s:61:\"\\Drupal\\contact\\Controller\\ContactController::contactSitePage\";s:12:\"contact_form\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"access site-wide contact form\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:15:\"{^/contact$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/contact\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:8:\"/contact\";s:8:\"numParts\";i:1;}}',1),('contextual.render','/contextual/render','/contextual/render',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/contextual/render\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:47:\"\\Drupal\\contextual\\ContextualController::render\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"access contextual links\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/contextual/render$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/contextual/render\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:18:\"/contextual/render\";s:8:\"numParts\";i:2;}}',2),('dblog.access_denied','/admin/reports/access-denied','/admin/reports/access-denied',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/access-denied\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:26:\"Top \'access denied\' errors\";s:11:\"_controller\";s:56:\"\\Drupal\\dblog\\Controller\\DbLogController::topLogMessages\";s:4:\"type\";s:13:\"access denied\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/access\\-denied$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/access-denied\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/reports/access-denied\";s:8:\"numParts\";i:3;}}',3),('dblog.confirm','/admin/reports/dblog/confirm','/admin/reports/dblog/confirm',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/dblog/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\dblog\\Form\\DblogClearLogConfirmForm\";s:6:\"_title\";s:34:\"Confirm delete recent log messages\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/reports/dblog/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/dblog/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/reports/dblog/confirm\";s:8:\"numParts\";i:4;}}',4),('dblog.event','/admin/reports/dblog/event/{event_id}','/admin/reports/dblog/event/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/reports/dblog/event/{event_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\dblog\\Controller\\DbLogController::eventDetails\";s:6:\"_title\";s:7:\"Details\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"event_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/reports/dblog/event/(?P<event_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"event_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/reports/dblog/event\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"event_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/reports/dblog/event/%\";s:8:\"numParts\";i:5;}}',5),('dblog.overview','/admin/reports/dblog','/admin/reports/dblog',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/reports/dblog\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:8:\"watchdog\";s:10:\"display_id\";s:4:\"page\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"access site reports\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/reports/dblog$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/reports/dblog\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/reports/dblog\";s:8:\"numParts\";i:3;}}',3),('dblog.page_not_found','/admin/reports/page-not-found','/admin/reports/page-not-found',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/reports/page-not-found\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:27:\"Top \'page not found\' errors\";s:11:\"_controller\";s:56:\"\\Drupal\\dblog\\Controller\\DbLogController::topLogMessages\";s:4:\"type\";s:14:\"page not found\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/page\\-not\\-found$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/reports/page-not-found\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:29:\"/admin/reports/page-not-found\";s:8:\"numParts\";i:3;}}',3),('dblog.search','/admin/reports/search','/admin/reports/search',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/reports/search\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:56:\"\\Drupal\\dblog\\Controller\\DbLogController::topLogMessages\";s:6:\"_title\";s:18:\"Top search phrases\";s:4:\"type\";s:6:\"search\";}s:12:\"requirements\";a:2:{s:20:\"_module_dependencies\";s:6:\"search\";s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/reports/search$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/reports/search\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/reports/search\";s:8:\"numParts\";i:3;}}',3),('editor.filter_xss','/editor/filter_xss/{filter_format}','/editor/filter_xss/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/editor/filter_xss/{filter_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:42:\"\\Drupal\\editor\\EditorController::filterXss\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"filter_format.use\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/editor/filter_xss/(?P<filter_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/editor/filter_xss\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:20:\"/editor/filter_xss/%\";s:8:\"numParts\";i:3;}}',3),('entity.block.delete_form','/admin/structure/block/manage/{block}/delete','/admin/structure/block/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/block/manage/{block}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"block.delete\";s:6:\"_title\";s:12:\"Remove block\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/block/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.block.disable','/admin/structure/block/manage/{block}/disable','/admin/structure/block/manage/%/disable',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/structure/block/manage/{block}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\block\\Controller\\BlockController::performOperation\";s:2:\"op\";s:7:\"disable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:13:\"block.disable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/block/manage/%/disable\";s:8:\"numParts\";i:6;}}',6),('entity.block.edit_form','/admin/structure/block/manage/{block}','/admin/structure/block/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/structure/block/manage/{block}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"block.default\";s:6:\"_title\";s:15:\"Configure block\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"block.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/structure/block/manage/(?P<block>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:31:\"/admin/structure/block/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.block.enable','/admin/structure/block/manage/{block}/enable','/admin/structure/block/manage/%/enable',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/block/manage/{block}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\block\\Controller\\BlockController::performOperation\";s:2:\"op\";s:6:\"enable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"block.enable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/block/manage/%/enable\";s:8:\"numParts\";i:6;}}',6),('entity.block_content.canonical','/admin/content/block/{block_content}','/admin/content/block/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/content/block/{block_content}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"block_content.edit\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.update\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/content/block/(?P<block_content>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:22:\"/admin/content/block/%\";s:8:\"numParts\";i:4;}}',4),('entity.block_content.collection','/admin/content/block','/admin/content/block',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"block_content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:20:\"access block library\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/block\";s:8:\"numParts\";i:3;}}',3),('entity.block_content.delete_form','/admin/content/block/{block_content}/delete','/admin/content/block/%/delete',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/content/block/{block_content}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"block_content.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.delete\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/admin/content/block/(?P<block_content>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:29:\"/admin/content/block/%/delete\";s:8:\"numParts\";i:5;}}',5),('entity.block_content.edit_form','/admin/content/block/{block_content}','/admin/content/block/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/content/block/{block_content}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:18:\"block_content.edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.update\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/content/block/(?P<block_content>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:22:\"/admin/content/block/%\";s:8:\"numParts\";i:4;}}',4),('entity.block_content.field_ui_fields','/admin/structure/block-content/manage/{block_content_type}/fields','/admin/structure/block-content/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/block-content/manage/{block_content_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/block-content/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.block_content.revision_delete_form','/admin/content/block/{block_content}/revision/{block_content_revision}/delete','/admin/content/block/%/revision/%/delete',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"block_content.revision-delete\";s:6:\"_title\";s:15:\"Delete revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:38:\"block_content_revision.delete revision\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"block_content_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:block_content\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/content/block/(?P<block_content>[^/]++)/revision/(?P<block_content_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"block_content_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"block_content\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:40:\"/admin/content/block/%/revision/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.block_content.revision_revert_form','/admin/content/block/{block_content}/revision/{block_content_revision}/revert','/admin/content/block/%/revision/%/revert',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"block_content.revision-revert\";s:6:\"_title\";s:15:\"Revert revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:29:\"block_content_revision.revert\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"block_content_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:block_content\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/content/block/(?P<block_content>[^/]++)/revision/(?P<block_content_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"block_content_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"block_content\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:40:\"/admin/content/block/%/revision/%/revert\";s:8:\"numParts\";i:7;}}',7),('entity.block_content.version_history','/admin/content/block/{block_content}/revisions','/admin/content/block/%/revisions',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/content/block/{block_content}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"Drupal\\Core\\Entity\\Controller\\VersionHistoryController\";s:6:\"_title\";s:9:\"Revisions\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:32:\"block_content.view all revisions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"entity_type_id\";s:13:\"block_content\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/content/block/(?P<block_content>[^/]++)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"block_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:32:\"/admin/content/block/%/revisions\";s:8:\"numParts\";i:5;}}',5),('entity.block_content_type.collection','/admin/structure/block-content','/admin/structure/block-content',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/structure/block-content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:18:\"block_content_type\";s:6:\"_title\";s:11:\"Block types\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer block types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/block\\-content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/structure/block-content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:30:\"/admin/structure/block-content\";s:8:\"numParts\";i:3;}}',3),('entity.block_content_type.delete_form','/admin/structure/block-content/manage/{block_content_type}/delete','/admin/structure/block-content/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/block-content/manage/{block_content_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"block_content_type.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"block_content_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/block-content/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.block_content_type.edit_form','/admin/structure/block-content/manage/{block_content_type}','/admin/structure/block-content/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/block-content/manage/{block_content_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"block_content_type.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"block_content_type.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:39:\"/admin/structure/block-content/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.block_content_type.entity_permissions_form','/admin/structure/block-content/manage/{block_content_type}/permissions','/admin/structure/block-content/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/block-content/manage/{block_content_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:13:\"block_content\";s:18:\"bundle_entity_type\";s:18:\"block_content_type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:3:{s:4:\"type\";s:25:\"entity:block_content_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:51:\"/admin/structure/block-content/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.ckeditor5_template.add_form','/admin/config/ckeditor5-templates/content-templates/add','/admin/config/ckeditor5-templates/content-templates/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"ckeditor5_template.add\";s:6:\"_title\";s:24:\"Add a CKEditor5 Template\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";s:8:\"numParts\";i:5;}}',5),('entity.ckeditor5_template.collection','/admin/config/ckeditor5-templates/content-templates','/admin/config/ckeditor5-templates/content-templates',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/ckeditor5-templates/content-templates\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:18:\"ckeditor5_template\";s:6:\"_title\";s:41:\"CKEditor5 Content Templates Configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/admin/config/ckeditor5\\-templates/content\\-templates$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:51:\"/admin/config/ckeditor5-templates/content-templates\";s:8:\"numParts\";i:4;}}',4),('entity.ckeditor5_template.delete_form','/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/delete','/admin/config/ckeditor5-templates/content-templates/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"ckeditor5_template.delete\";s:6:\"_title\";s:27:\"Delete a CKEditor5 Template\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"ckeditor5_template\";a:2:{s:4:\"type\";s:25:\"entity:ckeditor5_template\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/(?P<ckeditor5_template>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"ckeditor5_template\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:60:\"/admin/config/ckeditor5-templates/content-templates/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.ckeditor5_template.edit_form','/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}','/admin/config/ckeditor5-templates/content-templates/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"ckeditor5_template.edit\";s:6:\"_title\";s:25:\"Edit a CKEditor5 Template\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"ckeditor5_template\";a:2:{s:4:\"type\";s:25:\"entity:ckeditor5_template\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:91:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/(?P<ckeditor5_template>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"ckeditor5_template\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:53:\"/admin/config/ckeditor5-templates/content-templates/%\";s:8:\"numParts\";i:5;}}',5),('entity.comment.canonical','/comment/{comment}','/comment/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/comment/{comment}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:15:\"_title_callback\";s:67:\"\\Drupal\\comment\\Controller\\CommentController::commentPermalinkTitle\";s:11:\"_controller\";s:62:\"\\Drupal\\comment\\Controller\\CommentController::commentPermalink\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"comment.view\";s:7:\"comment\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"comment\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"comment\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/comment/(?P<comment>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:7:\"comment\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"comment\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:10:\"/comment/%\";s:8:\"numParts\";i:2;}}',2),('entity.comment.delete_form','/comment/{comment}/delete','/comment/%/delete',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/comment/{comment}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:6:\"Delete\";s:12:\"_entity_form\";s:14:\"comment.delete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"comment.delete\";s:7:\"comment\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"comment\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"comment\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/comment/(?P<comment>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:7:\"comment\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"comment\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/comment/%/delete\";s:8:\"numParts\";i:3;}}',3),('entity.comment.delete_multiple_form','/admin/content/comment/delete','/admin/content/comment/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/content/comment/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:6:\"Delete\";s:5:\"_form\";s:42:\"\\Drupal\\comment\\Form\\ConfirmDeleteMultiple\";s:14:\"entity_type_id\";s:7:\"comment\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:7:\"comment\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/content/comment/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/content/comment/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/content/comment/delete\";s:8:\"numParts\";i:4;}}',4),('entity.comment.edit_form','/comment/{comment}/edit','/comment/%/edit',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/comment/{comment}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:4:\"Edit\";s:12:\"_entity_form\";s:15:\"comment.default\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"comment.update\";s:7:\"comment\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"comment\";a:2:{s:4:\"type\";s:14:\"entity:comment\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"comment\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/comment/(?P<comment>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:7:\"comment\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/comment\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"comment\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/comment/%/edit\";s:8:\"numParts\";i:3;}}',3),('entity.comment.field_ui_fields','/admin/structure/comment/manage/{comment_type}/fields','/admin/structure/comment/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/comment/manage/{comment_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"administer comment fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/comment/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.comment_type.add_form','/admin/structure/comment/types/add','/admin/structure/comment/types/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/structure/comment/types/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"comment_type.add\";s:6:\"_title\";s:16:\"Add comment type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer comment types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/structure/comment/types/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/structure/comment/types/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/structure/comment/types/add\";s:8:\"numParts\";i:5;}}',5),('entity.comment_type.collection','/admin/structure/comment','/admin/structure/comment',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/structure/comment\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:12:\"comment_type\";s:6:\"_title\";s:13:\"Comment types\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer comment types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/structure/comment$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/structure/comment\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/structure/comment\";s:8:\"numParts\";i:3;}}',3),('entity.comment_type.delete_form','/admin/structure/comment/manage/{comment_type}/delete','/admin/structure/comment/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/comment/manage/{comment_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"comment_type.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"comment_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/comment/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.comment_type.edit_form','/admin/structure/comment/manage/{comment_type}','/admin/structure/comment/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/comment/manage/{comment_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"comment_type.edit\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"comment_type.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/structure/comment/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.comment_type.entity_permissions_form','/admin/structure/comment/manage/{comment_type}/permissions','/admin/structure/comment/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/comment/manage/{comment_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:7:\"comment\";s:18:\"bundle_entity_type\";s:12:\"comment_type\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:22:\"administer permissions\";s:14:\"_custom_access\";s:47:\"\\Drupal\\user\\Form\\EntityPermissionsForm::access\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:3:{s:4:\"type\";s:19:\"entity:comment_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:45:\"/admin/structure/comment/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.contact_form.canonical','/contact/{contact_form}','/contact/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/contact/{contact_form}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:7:\"Contact\";s:11:\"_controller\";s:61:\"\\Drupal\\contact\\Controller\\ContactController::contactSitePage\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"contact_form.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/contact/(?P<contact_form>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:10:\"/contact/%\";s:8:\"numParts\";i:2;}}',2),('entity.contact_form.collection','/admin/structure/contact','/admin/structure/contact',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/structure/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:12:\"contact_form\";s:6:\"_title\";s:13:\"Contact forms\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer contact forms\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/structure/contact$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/structure/contact\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/structure/contact\";s:8:\"numParts\";i:3;}}',3),('entity.contact_form.delete_form','/admin/structure/contact/manage/{contact_form}/delete','/admin/structure/contact/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/contact/manage/{contact_form}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"contact_form.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"contact_form.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/contact/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.contact_form.edit_form','/admin/structure/contact/manage/{contact_form}','/admin/structure/contact/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/contact/manage/{contact_form}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"contact_form.edit\";s:6:\"_title\";s:17:\"Edit contact form\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"contact_form.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/structure/contact/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.contact_form.entity_permissions_form','/admin/structure/contact/manage/{contact_form}/permissions','/admin/structure/contact/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/contact/manage/{contact_form}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:18:\"bundle_entity_type\";s:12:\"contact_form\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:22:\"administer permissions\";s:14:\"_custom_access\";s:47:\"\\Drupal\\user\\Form\\EntityPermissionsForm::access\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:3:{s:4:\"type\";s:19:\"entity:contact_form\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:45:\"/admin/structure/contact/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.contact_message.field_ui_fields','/admin/structure/contact/manage/{contact_form}/fields','/admin/structure/contact/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/contact/manage/{contact_form}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/contact/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.date_format.collection','/admin/config/regional/date-time','/admin/config/regional/date-time',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/regional/date-time\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:11:\"date_format\";s:6:\"_title\";s:21:\"Date and time formats\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/regional/date\\-time$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/regional/date-time\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/config/regional/date-time\";s:8:\"numParts\";i:4;}}',4),('entity.date_format.delete_form','/admin/config/regional/date-time/formats/manage/{date_format}/delete','/admin/config/regional/date-time/formats/manage/%/delete',253,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/config/regional/date-time/formats/manage/{date_format}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"date_format.delete\";s:6:\"_title\";s:18:\"Delete date format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"date_format.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"date_format\";a:2:{s:4:\"type\";s:18:\"entity:date_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"date_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"date_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/regional/date-time/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"date_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:253;s:14:\"patternOutline\";s:56:\"/admin/config/regional/date-time/formats/manage/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.date_format.edit_form','/admin/config/regional/date-time/formats/manage/{date_format}','/admin/config/regional/date-time/formats/manage/%',126,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/config/regional/date-time/formats/manage/{date_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"date_format.edit\";s:6:\"_title\";s:16:\"Edit date format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"date_format.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"date_format\";a:2:{s:4:\"type\";s:18:\"entity:date_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"date_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"date_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/regional/date-time/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"date_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:126;s:14:\"patternOutline\";s:49:\"/admin/config/regional/date-time/formats/manage/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.block_content.default','/admin/structure/block-content/manage/{block_content_type}/form-display','/admin/structure/block-content/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/block-content/manage/{block_content_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:52:\"/admin/structure/block-content/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.block_content.form_mode','/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}','/admin/structure/block-content/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:54:\"/admin/structure/block-content/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.comment.default','/admin/structure/comment/manage/{comment_type}/form-display','/admin/structure/comment/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/comment/manage/{comment_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/comment/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.comment.form_mode','/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}','/admin/structure/comment/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:48:\"/admin/structure/comment/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.contact_message.default','/admin/structure/contact/manage/{contact_form}/form-display','/admin/structure/contact/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/contact/manage/{contact_form}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/contact/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.contact_message.form_mode','/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}','/admin/structure/contact/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:48:\"/admin/structure/contact/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.media.default','/admin/structure/media/manage/{media_type}/form-display','/admin/structure/media/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/media/manage/{media_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:44:\"/admin/structure/media/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.media.form_mode','/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}','/admin/structure/media/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:46:\"/admin/structure/media/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.node.default','/admin/structure/types/manage/{node_type}/form-display','/admin/structure/types/manage/%/form-display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/types/manage/{node_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:44:\"/admin/structure/types/manage/%/form-display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.node.form_mode','/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}','/admin/structure/types/manage/%/form-display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:46:\"/admin/structure/types/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.paragraph.default','/admin/structure/paragraphs_type/{paragraphs_type}/form-display','/admin/structure/paragraphs_type/%/form-display',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:47:\"/admin/structure/paragraphs_type/%/form-display\";s:8:\"numParts\";i:5;}}',5),('entity.entity_form_display.paragraph.form_mode','/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}','/admin/structure/paragraphs_type/%/form-display/%',58,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:58;s:14:\"patternOutline\";s:49:\"/admin/structure/paragraphs_type/%/form-display/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_display.taxonomy_term.default','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display','/admin/structure/taxonomy/manage/%/overview/form-display',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/taxonomy/manage/%/overview/form-display\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_display.taxonomy_term.form_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}','/admin/structure/taxonomy/manage/%/overview/form-display/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:121:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:58:\"/admin/structure/taxonomy/manage/%/overview/form-display/%\";s:8:\"numParts\";i:8;}}',8),('entity.entity_form_display.user.default','/admin/config/people/accounts/form-display','/admin/config/people/accounts/form-display',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/config/people/accounts/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer user form display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/config/people/accounts/form\\-display$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:42:\"/admin/config/people/accounts/form-display\";s:8:\"numParts\";i:5;}}',5),('entity.entity_form_display.user.form_mode','/admin/config/people/accounts/form-display/{form_mode_name}','/admin/config/people/accounts/form-display/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/people/accounts/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer user form display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/people/accounts/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/config/people/accounts/form-display/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_mode.add_form','/admin/structure/display-modes/form/add/{entity_type_id}','/admin/structure/display-modes/form/add/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/display-modes/form/add/{entity_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"entity_form_mode.add\";s:6:\"_title\";s:13:\"Add form mode\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/display\\-modes/form/add/(?P<entity_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/form/add\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:41:\"/admin/structure/display-modes/form/add/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_form_mode.collection','/admin/structure/display-modes/form','/admin/structure/display-modes/form',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/display-modes/form\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:16:\"entity_form_mode\";s:6:\"_title\";s:10:\"Form modes\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/structure/display\\-modes/form$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/structure/display-modes/form\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/admin/structure/display-modes/form\";s:8:\"numParts\";i:4;}}',4),('entity.entity_form_mode.delete_form','/admin/structure/display-modes/form/manage/{entity_form_mode}/delete','/admin/structure/display-modes/form/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/display-modes/form/manage/{entity_form_mode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"entity_form_mode.delete\";s:6:\"_title\";s:16:\"Delete form mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_form_mode.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_form_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_form_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_form_mode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/form/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/structure/display-modes/form/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.entity_form_mode.edit_form','/admin/structure/display-modes/form/manage/{entity_form_mode}','/admin/structure/display-modes/form/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/display-modes/form/manage/{entity_form_mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"entity_form_mode.edit\";s:6:\"_title\";s:14:\"Edit form mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_form_mode.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_form_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_form_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_form_mode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/form/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/structure/display-modes/form/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.block_content.default','/admin/structure/block-content/manage/{block_content_type}/display','/admin/structure/block-content/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/block-content/manage/{block_content_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:47:\"/admin/structure/block-content/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.block_content.view_mode','/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}','/admin/structure/block-content/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:49:\"/admin/structure/block-content/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.comment.default','/admin/structure/comment/manage/{comment_type}/display','/admin/structure/comment/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/comment/manage/{comment_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/comment/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.comment.view_mode','/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}','/admin/structure/comment/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:43:\"/admin/structure/comment/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.contact_message.default','/admin/structure/contact/manage/{contact_form}/display','/admin/structure/contact/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/contact/manage/{contact_form}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/contact/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.contact_message.view_mode','/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}','/admin/structure/contact/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:43:\"/admin/structure/contact/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.media.default','/admin/structure/media/manage/{media_type}/display','/admin/structure/media/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/media/manage/{media_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/media/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.media.view_mode','/admin/structure/media/manage/{media_type}/display/{view_mode_name}','/admin/structure/media/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/media/manage/{media_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:41:\"/admin/structure/media/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.node.default','/admin/structure/types/manage/{node_type}/display','/admin/structure/types/manage/%/display',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/structure/types/manage/{node_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/types/manage/%/display\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.node.view_mode','/admin/structure/types/manage/{node_type}/display/{view_mode_name}','/admin/structure/types/manage/%/display/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:41:\"/admin/structure/types/manage/%/display/%\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.paragraph.default','/admin/structure/paragraphs_type/{paragraphs_type}/display','/admin/structure/paragraphs_type/%/display',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/paragraphs_type/{paragraphs_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:42:\"/admin/structure/paragraphs_type/%/display\";s:8:\"numParts\";i:5;}}',5),('entity.entity_view_display.paragraph.view_mode','/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}','/admin/structure/paragraphs_type/%/display/%',58,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:58;s:14:\"patternOutline\";s:44:\"/admin/structure/paragraphs_type/%/display/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_display.taxonomy_term.default','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display','/admin/structure/taxonomy/manage/%/overview/display',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:51:\"/admin/structure/taxonomy/manage/%/overview/display\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_display.taxonomy_term.view_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}','/admin/structure/taxonomy/manage/%/overview/display/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:53:\"/admin/structure/taxonomy/manage/%/overview/display/%\";s:8:\"numParts\";i:8;}}',8),('entity.entity_view_display.user.default','/admin/config/people/accounts/display','/admin/config/people/accounts/display',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/people/accounts/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer user display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/people/accounts/display$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:37:\"/admin/config/people/accounts/display\";s:8:\"numParts\";i:5;}}',5),('entity.entity_view_display.user.view_mode','/admin/config/people/accounts/display/{view_mode_name}','/admin/config/people/accounts/display/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/people/accounts/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer user display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:39:\"/admin/config/people/accounts/display/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_mode.add_form','/admin/structure/display-modes/view/add/{entity_type_id}','/admin/structure/display-modes/view/add/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/display-modes/view/add/{entity_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"entity_view_mode.add\";s:6:\"_title\";s:13:\"Add view mode\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/display\\-modes/view/add/(?P<entity_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/view/add\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:41:\"/admin/structure/display-modes/view/add/%\";s:8:\"numParts\";i:6;}}',6),('entity.entity_view_mode.collection','/admin/structure/display-modes/view','/admin/structure/display-modes/view',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/display-modes/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:16:\"entity_view_mode\";s:6:\"_title\";s:10:\"View modes\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/structure/display\\-modes/view$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/structure/display-modes/view\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/admin/structure/display-modes/view\";s:8:\"numParts\";i:4;}}',4),('entity.entity_view_mode.delete_form','/admin/structure/display-modes/view/manage/{entity_view_mode}/delete','/admin/structure/display-modes/view/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/display-modes/view/manage/{entity_view_mode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"entity_view_mode.delete\";s:6:\"_title\";s:16:\"Delete view mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_view_mode.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_view_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_view_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_view_mode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/view/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/structure/display-modes/view/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.entity_view_mode.edit_form','/admin/structure/display-modes/view/manage/{entity_view_mode}','/admin/structure/display-modes/view/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/display-modes/view/manage/{entity_view_mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"entity_view_mode.edit\";s:6:\"_title\";s:14:\"Edit view mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_view_mode.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_view_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_view_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_view_mode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/view/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/structure/display-modes/view/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.field_config.block_content_field_delete_form','/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/delete','/admin/structure/block-content/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:55:\"/admin/structure/block-content/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.block_content_field_edit_form','/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}','/admin/structure/block-content/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:48:\"/admin/structure/block-content/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.comment_field_delete_form','/admin/structure/comment/manage/{comment_type}/fields/{field_config}/delete','/admin/structure/comment/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/comment/manage/{comment_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/comment/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.comment_field_edit_form','/admin/structure/comment/manage/{comment_type}/fields/{field_config}','/admin/structure/comment/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/comment/manage/{comment_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:42:\"/admin/structure/comment/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.contact_message_field_delete_form','/admin/structure/contact/manage/{contact_form}/fields/{field_config}/delete','/admin/structure/contact/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/contact/manage/{contact_form}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/contact/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.contact_message_field_edit_form','/admin/structure/contact/manage/{contact_form}/fields/{field_config}','/admin/structure/contact/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/contact/manage/{contact_form}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:42:\"/admin/structure/contact/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.media_field_delete_form','/admin/structure/media/manage/{media_type}/fields/{field_config}/delete','/admin/structure/media/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/media/manage/{media_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:47:\"/admin/structure/media/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.media_field_edit_form','/admin/structure/media/manage/{media_type}/fields/{field_config}','/admin/structure/media/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/media/manage/{media_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:91:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:40:\"/admin/structure/media/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.node_field_delete_form','/admin/structure/types/manage/{node_type}/fields/{field_config}/delete','/admin/structure/types/manage/%/fields/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/types/manage/{node_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:97:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:47:\"/admin/structure/types/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.node_field_edit_form','/admin/structure/types/manage/{node_type}/fields/{field_config}','/admin/structure/types/manage/%/fields/%',122,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/types/manage/{node_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:40:\"/admin/structure/types/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.paragraph_field_delete_form','/admin/structure/paragraphs_type/{paragraphs_type}/fields/{field_config}/delete','/admin/structure/paragraphs_type/%/fields/%/delete',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:50:\"/admin/structure/paragraphs_type/%/fields/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.paragraph_field_edit_form','/admin/structure/paragraphs_type/{paragraphs_type}/fields/{field_config}','/admin/structure/paragraphs_type/%/fields/%',58,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:58;s:14:\"patternOutline\";s:43:\"/admin/structure/paragraphs_type/%/fields/%\";s:8:\"numParts\";i:6;}}',6),('entity.field_config.taxonomy_term_field_delete_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/delete','/admin/structure/taxonomy/manage/%/overview/fields/%/delete',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:92:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:119:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:59:\"/admin/structure/taxonomy/manage/%/overview/fields/%/delete\";s:8:\"numParts\";i:9;}}',9),('entity.field_config.taxonomy_term_field_edit_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}','/admin/structure/taxonomy/manage/%/overview/fields/%',246,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:112:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:52:\"/admin/structure/taxonomy/manage/%/overview/fields/%\";s:8:\"numParts\";i:8;}}',8),('entity.field_config.user_field_delete_form','/admin/config/people/accounts/fields/{field_config}/delete','/admin/config/people/accounts/fields/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/config/people/accounts/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:45:\"/admin/config/people/accounts/fields/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.field_config.user_field_edit_form','/admin/config/people/accounts/fields/{field_config}','/admin/config/people/accounts/fields/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/people/accounts/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:38:\"/admin/config/people/accounts/fields/%\";s:8:\"numParts\";i:6;}}',6),('entity.field_storage_config.collection','/admin/reports/fields','/admin/reports/fields',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/reports/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:20:\"field_storage_config\";s:6:\"_title\";s:10:\"Field list\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/reports/fields$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/reports/fields\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/reports/fields\";s:8:\"numParts\";i:3;}}',3),('entity.file.delete_form','/file/{file}/delete','/file/%/delete',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/file/{file}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"file.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:4:\"file\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"file.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"file\";a:2:{s:4:\"type\";s:11:\"entity:file\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"file\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/file/(?P<file>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"file\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/file\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"file\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/file/%/delete\";s:8:\"numParts\";i:3;}}',3),('entity.filter_format.disable','/admin/config/content/formats/manage/{filter_format}/disable','/admin/config/content/formats/manage/%/disable',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/content/formats/manage/{filter_format}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"filter_format.disable\";s:6:\"_title\";s:19:\"Disable text format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:21:\"filter_format.disable\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/content/formats/manage/%/disable\";s:8:\"numParts\";i:7;}}',7),('entity.filter_format.edit_form','/admin/config/content/formats/manage/{filter_format}','/admin/config/content/formats/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/config/content/formats/manage/{filter_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"filter_format.edit\";s:15:\"_title_callback\";s:52:\"\\Drupal\\filter\\Controller\\FilterController::getLabel\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:20:\"filter_format.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:38:\"/admin/config/content/formats/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.image_style.collection','/admin/config/media/image-styles','/admin/config/media/image-styles',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/media/image-styles\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:11:\"image_style\";s:6:\"_title\";s:12:\"Image styles\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/media/image\\-styles$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/media/image-styles\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/config/media/image-styles\";s:8:\"numParts\";i:4;}}',4),('entity.image_style.delete_form','/admin/config/media/image-styles/manage/{image_style}/delete','/admin/config/media/image-styles/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/media/image-styles/manage/{image_style}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"image_style.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"image_style.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"image_style\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"image_style\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:48:\"/admin/config/media/image-styles/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.image_style.edit_form','/admin/config/media/image-styles/manage/{image_style}','/admin/config/media/image-styles/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/media/image-styles/manage/{image_style}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"image_style.edit\";s:6:\"_title\";s:10:\"Edit style\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"image_style\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"image_style\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:41:\"/admin/config/media/image-styles/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.image_style.flush_form','/admin/config/media/image-styles/manage/{image_style}/flush','/admin/config/media/image-styles/manage/%/flush',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/media/image-styles/manage/{image_style}/flush\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"image_style.flush\";s:6:\"_title\";s:5:\"Flush\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"image_style\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/flush$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/flush\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"image_style\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:47:\"/admin/config/media/image-styles/manage/%/flush\";s:8:\"numParts\";i:7;}}',7),('entity.media.add_form','/media/add/{media_type}','/media/add/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/media/add/{media_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:9:\"media.add\";s:14:\"entity_type_id\";s:5:\"media\";s:15:\"_title_callback\";s:62:\"Drupal\\Core\\Entity\\Controller\\EntityController::addBundleTitle\";s:16:\"bundle_parameter\";s:10:\"media_type\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:18:\"media:{media_type}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:3:{s:4:\"type\";s:17:\"entity:media_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/media/add/(?P<media_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/media/add\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:12:\"/media/add/%\";s:8:\"numParts\";i:3;}}',3),('entity.media.add_page','/media/add','/media/add',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/media/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:55:\"Drupal\\Core\\Entity\\Controller\\EntityController::addPage\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";s:14:\"entity_type_id\";s:5:\"media\";}s:12:\"requirements\";a:1:{s:25:\"_entity_create_any_access\";s:5:\"media\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.entity_create_any\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/media/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/media/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:10:\"/media/add\";s:8:\"numParts\";i:2;}}',2),('entity.media.canonical','/media/{media}/edit','/media/%/edit',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/media/{media}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:10:\"media.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"media.update\";s:5:\"media\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/media/(?P<media>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:13:\"/media/%/edit\";s:8:\"numParts\";i:3;}}',3),('entity.media.collection','/admin/content/media','/admin/content/media',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/media\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"media\";s:10:\"display_id\";s:15:\"media_page_list\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access media overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/media$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/media\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/media\";s:8:\"numParts\";i:3;}}',3),('entity.media.delete_form','/media/{media}/delete','/media/%/delete',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/media/{media}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"media.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"media.delete\";s:5:\"media\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/media/(?P<media>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/media/%/delete\";s:8:\"numParts\";i:3;}}',3),('entity.media.delete_multiple_form','/media/delete','/media/delete',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/media/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"Drupal\\Core\\Entity\\Form\\DeleteMultipleForm\";s:14:\"entity_type_id\";s:5:\"media\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:5:\"media\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/media/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/media/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/media/delete\";s:8:\"numParts\";i:2;}}',2),('entity.media.edit_form','/media/{media}/edit','/media/%/edit',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/media/{media}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:10:\"media.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"media.update\";s:5:\"media\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/media/(?P<media>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:13:\"/media/%/edit\";s:8:\"numParts\";i:3;}}',3),('entity.media.field_ui_fields','/admin/structure/media/manage/{media_type}/fields','/admin/structure/media/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/structure/media/manage/{media_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer media fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/media/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.media.revision','/media/{media}/revisions/{media_revision}/view','/media/%/revisions/%/view',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/media/{media}/revisions/{media_revision}/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController\";s:15:\"_title_callback\";s:65:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:28:\"media_revision.view revision\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:14:\"media_revision\";a:2:{s:4:\"type\";s:21:\"entity_revision:media\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/media/(?P<media>[^/]++)/revisions/(?P<media_revision>[^/]++)/view$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"media_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"media\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:25:\"/media/%/revisions/%/view\";s:8:\"numParts\";i:5;}}',5),('entity.media.revision_delete_form','/media/{media}/revision/{media_revision}/delete','/media/%/revision/%/delete',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/media/{media}/revision/{media_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"media.revision-delete\";s:6:\"_title\";s:15:\"Delete revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:30:\"media_revision.delete revision\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:14:\"media_revision\";a:2:{s:4:\"type\";s:21:\"entity_revision:media\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/media/(?P<media>[^/]++)/revision/(?P<media_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"media_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"media\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/media/%/revision/%/delete\";s:8:\"numParts\";i:5;}}',5),('entity.media.revision_revert_form','/media/{media}/revision/{media_revision}/revert','/media/%/revision/%/revert',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/media/{media}/revision/{media_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"media.revision-revert\";s:6:\"_title\";s:15:\"Revert revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:21:\"media_revision.revert\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:14:\"media_revision\";a:2:{s:4:\"type\";s:21:\"entity_revision:media\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/media/(?P<media>[^/]++)/revision/(?P<media_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"media_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"media\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/media/%/revision/%/revert\";s:8:\"numParts\";i:5;}}',5),('entity.media.version_history','/media/{media}/revisions','/media/%/revisions',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/media/{media}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"Drupal\\Core\\Entity\\Controller\\VersionHistoryController\";s:6:\"_title\";s:9:\"Revisions\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"media.view all revisions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"entity_type_id\";s:5:\"media\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/media/(?P<media>[^/]++)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:18:\"/media/%/revisions\";s:8:\"numParts\";i:3;}}',3),('entity.media_type.add_form','/admin/structure/media/add','/admin/structure/media/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/structure/media/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:14:\"media_type.add\";s:14:\"entity_type_id\";s:10:\"media_type\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:10:\"media_type\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/structure/media/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/media/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/structure/media/add\";s:8:\"numParts\";i:4;}}',4),('entity.media_type.collection','/admin/structure/media','/admin/structure/media',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/media\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:10:\"media_type\";s:6:\"_title\";s:11:\"Media types\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer media types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/media$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/media\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/media\";s:8:\"numParts\";i:3;}}',3),('entity.media_type.delete_form','/admin/structure/media/manage/{media_type}/delete','/admin/structure/media/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/structure/media/manage/{media_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"media_type.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"media_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/media/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.media_type.edit_form','/admin/structure/media/manage/{media_type}','/admin/structure/media/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/media/manage/{media_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"media_type.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"media_type.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:31:\"/admin/structure/media/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.media_type.entity_permissions_form','/admin/structure/media/manage/{media_type}/permissions','/admin/structure/media/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/media/manage/{media_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:5:\"media\";s:18:\"bundle_entity_type\";s:10:\"media_type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:10:\"media_type\";a:3:{s:4:\"type\";s:17:\"entity:media_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/media/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.menu.add_form','/admin/structure/menu/add','/admin/structure/menu/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/structure/menu/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:8:\"menu.add\";s:6:\"_title\";s:8:\"Add menu\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:4:\"menu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/structure/menu/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/structure/menu/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/structure/menu/add\";s:8:\"numParts\";i:4;}}',4),('entity.menu.add_link_form','/admin/structure/menu/manage/{menu}/add','/admin/structure/menu/manage/%/add',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/menu/manage/{menu}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\menu_link_content\\Controller\\MenuController::addLink\";s:6:\"_title\";s:13:\"Add menu link\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:17:\"menu_link_content\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:56:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:34:\"/admin/structure/menu/manage/%/add\";s:8:\"numParts\";i:6;}}',6),('entity.menu.collection','/admin/structure/menu','/admin/structure/menu',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/structure/menu\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:4:\"menu\";s:6:\"_title\";s:5:\"Menus\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:15:\"administer menu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/structure/menu$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/structure/menu\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/structure/menu\";s:8:\"numParts\";i:3;}}',3),('entity.menu.delete_form','/admin/structure/menu/manage/{menu}/delete','/admin/structure/menu/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/menu/manage/{menu}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"menu.delete\";s:6:\"_title\";s:11:\"Delete menu\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"menu.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/structure/menu/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.menu.edit_form','/admin/structure/menu/manage/{menu}','/admin/structure/menu/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/menu/manage/{menu}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:9:\"menu.edit\";s:15:\"_title_callback\";s:52:\"\\Drupal\\menu_ui\\Controller\\MenuController::menuTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"menu.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:30:\"/admin/structure/menu/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.menu_link_content.canonical','/admin/structure/menu/item/{menu_link_content}/edit','/admin/structure/menu/item/%/edit',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"menu_link_content.default\";s:6:\"_title\";s:14:\"Edit menu link\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"menu_link_content.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:33:\"/admin/structure/menu/item/%/edit\";s:8:\"numParts\";i:6;}}',6),('entity.menu_link_content.delete_form','/admin/structure/menu/item/{menu_link_content}/delete','/admin/structure/menu/item/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/menu/item/{menu_link_content}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:24:\"menu_link_content.delete\";s:6:\"_title\";s:16:\"Delete menu link\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"menu_link_content.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:35:\"/admin/structure/menu/item/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.menu_link_content.edit_form','/admin/structure/menu/item/{menu_link_content}/edit','/admin/structure/menu/item/%/edit',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"menu_link_content.default\";s:6:\"_title\";s:14:\"Edit menu link\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"menu_link_content.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:33:\"/admin/structure/menu/item/%/edit\";s:8:\"numParts\";i:6;}}',6),('entity.node.canonical','/node/{node}','/node/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/node/{node}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\node\\Controller\\NodeViewController::view\";s:15:\"_title_callback\";s:49:\"\\Drupal\\node\\Controller\\NodeViewController::title\";}s:12:\"requirements\";a:2:{s:4:\"node\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"node.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/node/(?P<node>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:7:\"/node/%\";s:8:\"numParts\";i:2;}}',2),('entity.node.delete_form','/node/{node}/delete','/node/%/delete',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/node/{node}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"node.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:4:\"node\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"node.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/node/(?P<node>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/node/%/delete\";s:8:\"numParts\";i:3;}}',3),('entity.node.delete_multiple_form','/admin/content/node/delete','/admin/content/node/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/content/node/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\node\\Form\\DeleteMultiple\";s:14:\"entity_type_id\";s:4:\"node\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:4:\"node\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/content/node/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/content/node/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/content/node/delete\";s:8:\"numParts\";i:4;}}',4),('entity.node.edit_form','/node/{node}/edit','/node/%/edit',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/node/{node}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:9:\"node.edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"node.update\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/node/(?P<node>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:12:\"/node/%/edit\";s:8:\"numParts\";i:3;}}',3),('entity.node.field_ui_fields','/admin/structure/types/manage/{node_type}/fields','/admin/structure/types/manage/%/fields',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/types/manage/{node_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/types/manage/%/fields\";s:8:\"numParts\";i:6;}}',6),('entity.node.preview','/node/preview/{node_preview}/{view_mode_id}','/node/preview/%/%',12,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/node/preview/{node_preview}/{view_mode_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:51:\"\\Drupal\\node\\Controller\\NodePreviewController::view\";s:15:\"_title_callback\";s:52:\"\\Drupal\\node\\Controller\\NodePreviewController::title\";}s:12:\"requirements\";a:1:{s:20:\"_node_preview_access\";s:14:\"{node_preview}\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"node_preview\";a:2:{s:4:\"type\";s:12:\"node_preview\";s:9:\"converter\";s:42:\"drupal.proxy_original_service.node_preview\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:25:\"access_check.node.preview\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"node_preview\";i:1;s:12:\"view_mode_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/node/preview/(?P<node_preview>[^/]++)/(?P<view_mode_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"view_mode_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"node_preview\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/node/preview\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"node_preview\";i:1;s:12:\"view_mode_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:12;s:14:\"patternOutline\";s:17:\"/node/preview/%/%\";s:8:\"numParts\";i:4;}}',4),('entity.node.revision','/node/{node}/revisions/{node_revision}/view','/node/%/revisions/%/view',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/node/{node}/revisions/{node_revision}/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:52:\"\\Drupal\\node\\Controller\\NodeController::revisionShow\";s:15:\"_title_callback\";s:57:\"\\Drupal\\node\\Controller\\NodeController::revisionPageTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"node_revision.view revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/view$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:24:\"/node/%/revisions/%/view\";s:8:\"numParts\";i:5;}}',5),('entity.node.version_history','/node/{node}/revisions','/node/%/revisions',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/node/{node}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:9:\"Revisions\";s:11:\"_controller\";s:56:\"\\Drupal\\node\\Controller\\NodeController::revisionOverview\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:23:\"node.view all revisions\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/node/(?P<node>\\d+)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/node/%/revisions\";s:8:\"numParts\";i:3;}}',3),('entity.node_type.collection','/admin/structure/types','/admin/structure/types',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/types\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:9:\"node_type\";s:6:\"_title\";s:13:\"Content types\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/types$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/types\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/types\";s:8:\"numParts\";i:3;}}',3),('entity.node_type.delete_form','/admin/structure/types/manage/{node_type}/delete','/admin/structure/types/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/types/manage/{node_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"node_type.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"node_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/types/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.node_type.edit_form','/admin/structure/types/manage/{node_type}','/admin/structure/types/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/types/manage/{node_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"node_type.edit\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:31:\"/admin/structure/types/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.node_type.entity_permissions_form','/admin/structure/types/manage/{node_type}/permissions','/admin/structure/types/manage/%/permissions',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/types/manage/{node_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:4:\"node\";s:18:\"bundle_entity_type\";s:9:\"node_type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:3:{s:4:\"type\";s:16:\"entity:node_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/types/manage/%/permissions\";s:8:\"numParts\";i:6;}}',6),('entity.paragraph.field_ui_fields','/admin/structure/paragraphs_type/{paragraphs_type}/fields','/admin/structure/paragraphs_type/%/fields',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraph fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:41:\"/admin/structure/paragraphs_type/%/fields\";s:8:\"numParts\";i:5;}}',5),('entity.paragraphs_type.collection','/admin/structure/paragraphs_type','/admin/structure/paragraphs_type',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/structure/paragraphs_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:15:\"paragraphs_type\";s:6:\"_title\";s:16:\"Paragraphs types\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraphs types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/structure/paragraphs_type$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:32:\"/admin/structure/paragraphs_type\";s:8:\"numParts\";i:3;}}',3),('entity.paragraphs_type.delete_form','/admin/structure/paragraphs_type/{paragraphs_type}/delete','/admin/structure/paragraphs_type/%/delete',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/paragraphs_type/{paragraphs_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"paragraphs_type.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraphs types\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:41:\"/admin/structure/paragraphs_type/%/delete\";s:8:\"numParts\";i:5;}}',5),('entity.paragraphs_type.edit_form','/admin/structure/paragraphs_type/{paragraphs_type}','/admin/structure/paragraphs_type/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/paragraphs_type/{paragraphs_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:20:\"paragraphs_type.edit\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraphs types\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:34:\"/admin/structure/paragraphs_type/%\";s:8:\"numParts\";i:4;}}',4),('entity.path_alias.add_form','/admin/config/search/path/add','/admin/config/search/path/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/search/path/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:18:\"path_alias.default\";s:14:\"entity_type_id\";s:10:\"path_alias\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:10:\"path_alias\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/search/path/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/search/path/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:29:\"/admin/config/search/path/add\";s:8:\"numParts\";i:5;}}',5),('entity.path_alias.collection','/admin/config/search/path','/admin/config/search/path',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/config/search/path\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:10:\"path_alias\";s:6:\"_title\";s:11:\"URL aliases\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer url aliases\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/config/search/path$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/config/search/path\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/config/search/path\";s:8:\"numParts\";i:4;}}',4),('entity.path_alias.delete_form','/admin/config/search/path/delete/{path_alias}','/admin/config/search/path/delete/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/search/path/delete/{path_alias}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"path_alias.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:17:\"path_alias.delete\";s:10:\"path_alias\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"path_alias\";a:2:{s:4:\"type\";s:17:\"entity:path_alias\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"path_alias\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/config/search/path/delete/(?P<path_alias>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:10:\"path_alias\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/search/path/delete\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"path_alias\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:34:\"/admin/config/search/path/delete/%\";s:8:\"numParts\";i:6;}}',6),('entity.path_alias.edit_form','/admin/config/search/path/edit/{path_alias}','/admin/config/search/path/edit/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/config/search/path/edit/{path_alias}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"path_alias.default\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:17:\"path_alias.update\";s:10:\"path_alias\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"path_alias\";a:2:{s:4:\"type\";s:17:\"entity:path_alias\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"path_alias\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/admin/config/search/path/edit/(?P<path_alias>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:10:\"path_alias\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/search/path/edit\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"path_alias\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:32:\"/admin/config/search/path/edit/%\";s:8:\"numParts\";i:6;}}',6),('entity.search_page.collection','/admin/config/search/pages','/admin/config/search/pages',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/config/search/pages\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:11:\"search_page\";s:6:\"_title\";s:12:\"Search pages\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer search\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/config/search/pages$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/config/search/pages\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/config/search/pages\";s:8:\"numParts\";i:4;}}',4),('entity.search_page.delete_form','/admin/config/search/pages/manage/{search_page}/delete','/admin/config/search/pages/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/search/pages/manage/{search_page}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"search_page.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"search_page.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"search_page\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"search_page\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"search_page\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/search/pages/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"search_page\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:42:\"/admin/config/search/pages/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.search_page.disable','/admin/config/search/pages/manage/{search_page}/disable','/admin/config/search/pages/manage/%/disable',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/config/search/pages/manage/{search_page}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\search\\Controller\\SearchController::performOperation\";s:2:\"op\";s:7:\"disable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:19:\"search_page.disable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"search_page\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"search_page\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"search_page\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/search/pages/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"search_page\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:43:\"/admin/config/search/pages/manage/%/disable\";s:8:\"numParts\";i:7;}}',7),('entity.search_page.edit_form','/admin/config/search/pages/manage/{search_page}','/admin/config/search/pages/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/search/pages/manage/{search_page}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"search_page.edit\";s:15:\"_title_callback\";s:53:\"\\Drupal\\search\\Controller\\SearchController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"search_page.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"search_page\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"search_page\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"search_page\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/search/pages/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"search_page\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:35:\"/admin/config/search/pages/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.search_page.enable','/admin/config/search/pages/manage/{search_page}/enable','/admin/config/search/pages/manage/%/enable',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/search/pages/manage/{search_page}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\search\\Controller\\SearchController::performOperation\";s:2:\"op\";s:6:\"enable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:18:\"search_page.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"search_page\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"search_page\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"search_page\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/search/pages/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"search_page\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:42:\"/admin/config/search/pages/manage/%/enable\";s:8:\"numParts\";i:7;}}',7),('entity.search_page.set_default','/admin/config/search/pages/manage/{search_page}/set-default','/admin/config/search/pages/manage/%/set-default',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/search/pages/manage/{search_page}/set-default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:56:\"\\Drupal\\search\\Controller\\SearchController::setAsDefault\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:18:\"search_page.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"search_page\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"search_page\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)/set\\-default$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/set-default\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"search_page\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/search/pages/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"search_page\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:47:\"/admin/config/search/pages/manage/%/set-default\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut.canonical','/admin/config/user-interface/shortcut/link/{shortcut}','/admin/config/user-interface/shortcut/link/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"shortcut.default\";s:6:\"_title\";s:4:\"Edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"shortcut.update\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/config/user-interface/shortcut/link/%\";s:8:\"numParts\";i:6;}}',6),('entity.shortcut.delete_form','/admin/config/user-interface/shortcut/link/{shortcut}/delete','/admin/config/user-interface/shortcut/link/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/user-interface/shortcut/link/{shortcut}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"shortcut.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"shortcut.delete\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/config/user-interface/shortcut/link/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut.edit_form','/admin/config/user-interface/shortcut/link/{shortcut}','/admin/config/user-interface/shortcut/link/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"shortcut.default\";s:6:\"_title\";s:4:\"Edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"shortcut.update\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/config/user-interface/shortcut/link/%\";s:8:\"numParts\";i:6;}}',6),('entity.shortcut.link_delete_inline','/admin/config/user-interface/shortcut/link/{shortcut}/delete-inline','/admin/config/user-interface/shortcut/link/%/delete-inline',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/config/user-interface/shortcut/link/{shortcut}/delete-inline\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:72:\"\\Drupal\\shortcut\\Controller\\ShortcutController::deleteShortcutLinkInline\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:15:\"shortcut.delete\";s:11:\"_csrf_token\";s:4:\"TRUE\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)/delete\\-inline$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/delete-inline\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:58:\"/admin/config/user-interface/shortcut/link/%/delete-inline\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut_set.collection','/admin/config/user-interface/shortcut','/admin/config/user-interface/shortcut',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/user-interface/shortcut\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:12:\"shortcut_set\";s:6:\"_title\";s:9:\"Shortcuts\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer shortcuts\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/user\\-interface/shortcut$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/user-interface/shortcut\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/user-interface/shortcut\";s:8:\"numParts\";i:4;}}',4),('entity.shortcut_set.customize_form','/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize','/admin/config/user-interface/shortcut/manage/%/customize',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"shortcut_set.customize\";s:6:\"_title\";s:10:\"List links\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"shortcut_set.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/customize$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/customize\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:56:\"/admin/config/user-interface/shortcut/manage/%/customize\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut_set.delete_form','/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete','/admin/config/user-interface/shortcut/manage/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"shortcut_set.delete\";s:6:\"_title\";s:19:\"Delete shortcut set\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"shortcut_set.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:53:\"/admin/config/user-interface/shortcut/manage/%/delete\";s:8:\"numParts\";i:7;}}',7),('entity.shortcut_set.edit_form','/admin/config/user-interface/shortcut/manage/{shortcut_set}','/admin/config/user-interface/shortcut/manage/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"shortcut_set.edit\";s:6:\"_title\";s:17:\"Edit shortcut set\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"shortcut_set.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:46:\"/admin/config/user-interface/shortcut/manage/%\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.add_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/add','/admin/structure/taxonomy/manage/%/add',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\taxonomy\\Controller\\TaxonomyController::addForm\";s:6:\"_title\";s:8:\"Add term\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:35:\"taxonomy_term:{taxonomy_vocabulary}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/taxonomy/manage/%/add\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.canonical','/taxonomy/term/{taxonomy_term}','/taxonomy/term/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/taxonomy/term/{taxonomy_term}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:57:\"\\Drupal\\taxonomy\\Controller\\TaxonomyController::termTitle\";s:7:\"view_id\";s:13:\"taxonomy_term\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:14:\"access content\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:13:\"taxonomy_term\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:16:\"/taxonomy/term/%\";s:8:\"numParts\";i:3;}}',3),('entity.taxonomy_term.delete_form','/taxonomy/term/{taxonomy_term}/delete','/taxonomy/term/%/delete',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/taxonomy/term/{taxonomy_term}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"taxonomy_term.delete\";s:6:\"_title\";s:11:\"Delete term\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"taxonomy_term.delete\";s:13:\"taxonomy_term\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/taxonomy/term/(?P<taxonomy_term>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:23:\"/taxonomy/term/%/delete\";s:8:\"numParts\";i:4;}}',4),('entity.taxonomy_term.edit_form','/taxonomy/term/{taxonomy_term}/edit','/taxonomy/term/%/edit',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/taxonomy/term/{taxonomy_term}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"taxonomy_term.default\";s:6:\"_title\";s:9:\"Edit term\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"taxonomy_term.update\";s:13:\"taxonomy_term\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/taxonomy/term/(?P<taxonomy_term>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:21:\"/taxonomy/term/%/edit\";s:8:\"numParts\";i:4;}}',4),('entity.taxonomy_term.field_ui_fields','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields','/admin/structure/taxonomy/manage/%/overview/fields',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/taxonomy/manage/%/overview/fields\";s:8:\"numParts\";i:7;}}',7),('entity.taxonomy_term.revision','/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view','/taxonomy/term/%/revision/%/view',53,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController\";s:15:\"_title_callback\";s:65:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:36:\"taxonomy_term_revision.view revision\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"taxonomy_term_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:taxonomy_term\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:96:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/view$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"taxonomy_term_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:53;s:14:\"patternOutline\";s:32:\"/taxonomy/term/%/revision/%/view\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.revision_delete_form','/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete','/taxonomy/term/%/revision/%/delete',53,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"taxonomy_term.revision-delete\";s:6:\"_title\";s:15:\"Delete revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:38:\"taxonomy_term_revision.delete revision\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"taxonomy_term_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:taxonomy_term\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"taxonomy_term_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:53;s:14:\"patternOutline\";s:34:\"/taxonomy/term/%/revision/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.revision_revert_form','/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert','/taxonomy/term/%/revision/%/revert',53,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"taxonomy_term.revision-revert\";s:6:\"_title\";s:15:\"Revert revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:29:\"taxonomy_term_revision.revert\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"taxonomy_term_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:taxonomy_term\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"taxonomy_term_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:53;s:14:\"patternOutline\";s:34:\"/taxonomy/term/%/revision/%/revert\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_term.version_history','/taxonomy/term/{taxonomy_term}/revisions','/taxonomy/term/%/revisions',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/taxonomy/term/{taxonomy_term}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"Drupal\\Core\\Entity\\Controller\\VersionHistoryController\";s:6:\"_title\";s:9:\"Revisions\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:32:\"taxonomy_term.view all revisions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:26:\"/taxonomy/term/%/revisions\";s:8:\"numParts\";i:4;}}',4),('entity.taxonomy_vocabulary.add_form','/admin/structure/taxonomy/add','/admin/structure/taxonomy/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/structure/taxonomy/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:27:\"taxonomy_vocabulary.default\";s:14:\"entity_type_id\";s:19:\"taxonomy_vocabulary\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:19:\"taxonomy_vocabulary\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/structure/taxonomy/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/taxonomy/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/structure/taxonomy/add\";s:8:\"numParts\";i:4;}}',4),('entity.taxonomy_vocabulary.collection','/admin/structure/taxonomy','/admin/structure/taxonomy',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/structure/taxonomy\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:19:\"taxonomy_vocabulary\";s:6:\"_title\";s:8:\"Taxonomy\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:44:\"administer taxonomy+access taxonomy overview\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/structure/taxonomy$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/structure/taxonomy\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/structure/taxonomy\";s:8:\"numParts\";i:3;}}',3),('entity.taxonomy_vocabulary.delete_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete','/admin/structure/taxonomy/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:26:\"taxonomy_vocabulary.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:26:\"taxonomy_vocabulary.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/taxonomy/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_vocabulary.edit_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}','/admin/structure/taxonomy/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:27:\"taxonomy_vocabulary.default\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:26:\"taxonomy_vocabulary.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:34:\"/admin/structure/taxonomy/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.taxonomy_vocabulary.entity_permissions_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions','/admin/structure/taxonomy/manage/%/overview/permissions',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:18:\"bundle_entity_type\";s:19:\"taxonomy_vocabulary\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:3:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/overview/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:55:\"/admin/structure/taxonomy/manage/%/overview/permissions\";s:8:\"numParts\";i:7;}}',7),('entity.taxonomy_vocabulary.overview_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview','/admin/structure/taxonomy/manage/%/overview',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";s:5:\"_form\";s:34:\"Drupal\\taxonomy\\Form\\OverviewTerms\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:44:\"taxonomy_vocabulary.access taxonomy overview\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:3:{s:21:\"with_config_overrides\";b:1;s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/overview\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/taxonomy/manage/%/overview\";s:8:\"numParts\";i:6;}}',6),('entity.taxonomy_vocabulary.reset_form','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset','/admin/structure/taxonomy/manage/%/reset',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"taxonomy_vocabulary.reset\";s:6:\"_title\";s:5:\"Reset\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:37:\"taxonomy_vocabulary.reset all weights\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:3:{s:21:\"with_config_overrides\";b:1;s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/reset$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/reset\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/taxonomy/manage/%/reset\";s:8:\"numParts\";i:6;}}',6),('entity.tb_megamenu.add_form','/admin/structure/tb-megamenu/add','/admin/structure/tb-megamenu/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/structure/tb-megamenu/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"tb_megamenu.add\";s:6:\"_title\";s:15:\"Add a Mega Menu\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer tb_megamenu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/structure/tb\\-megamenu/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/tb-megamenu/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/structure/tb-megamenu/add\";s:8:\"numParts\";i:4;}}',4),('entity.tb_megamenu.collection','/admin/structure/tb-megamenu','/admin/structure/tb-megamenu',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/structure/tb-megamenu\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:11:\"tb_megamenu\";s:6:\"_title\";s:12:\"TB Mega Menu\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer tb_megamenu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/structure/tb\\-megamenu$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/tb-megamenu\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/structure/tb-megamenu\";s:8:\"numParts\";i:3;}}',3),('entity.tb_megamenu.delete_form','/admin/structure/tb-megamenu/{tb_megamenu}/delete','/admin/structure/tb-megamenu/%/delete',29,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/structure/tb-megamenu/{tb_megamenu}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"tb_megamenu.delete\";s:6:\"_title\";s:16:\"Delete Mega Menu\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:22:\"administer tb_megamenu\";s:11:\"tb_megamenu\";s:14:\"[a-zA-Z0-9_-]+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"tb_megamenu\";a:2:{s:4:\"type\";s:18:\"entity:tb_megamenu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"tb_megamenu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/tb\\-megamenu/(?P<tb_megamenu>[a-zA-Z0-9_-]+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:14:\"[a-zA-Z0-9_-]+\";i:3;s:11:\"tb_megamenu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/tb-megamenu\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"tb_megamenu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:37:\"/admin/structure/tb-megamenu/%/delete\";s:8:\"numParts\";i:5;}}',5),('entity.tb_megamenu.edit_form','/admin/structure/tb-megamenu/{tb_megamenu}','/admin/structure/tb-megamenu/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/tb-megamenu/{tb_megamenu}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:19:\"Config TB Mega Menu\";s:11:\"_controller\";s:72:\"\\Drupal\\tb_megamenu\\Controller\\TBMegaMenuAdminController::configMegaMenu\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:22:\"administer tb_megamenu\";s:11:\"tb_megamenu\";s:14:\"[a-zA-Z0-9_-]+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"tb_megamenu\";a:2:{s:4:\"type\";s:18:\"entity:tb_megamenu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"tb_megamenu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/tb\\-megamenu/(?P<tb_megamenu>[a-zA-Z0-9_-]+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:14:\"[a-zA-Z0-9_-]+\";i:3;s:11:\"tb_megamenu\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/tb-megamenu\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"tb_megamenu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:30:\"/admin/structure/tb-megamenu/%\";s:8:\"numParts\";i:4;}}',4),('entity.user.admin_form','/admin/config/people/accounts','/admin/config/people/accounts',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/people/accounts\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\user\\AccountSettingsForm\";s:6:\"_title\";s:16:\"Account settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer account settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/people/accounts$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/people/accounts\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/people/accounts\";s:8:\"numParts\";i:4;}}',4),('entity.user.cancel_form','/user/{user}/cancel','/user/%/cancel',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/user/{user}/cancel\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:14:\"Cancel account\";s:12:\"_entity_form\";s:11:\"user.cancel\";}s:12:\"requirements\";a:2:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"user.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/user/(?P<user>\\d+)/cancel$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/cancel\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/user/%/cancel\";s:8:\"numParts\";i:3;}}',3),('entity.user.canonical','/user/{user}','/user/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/user/{user}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_view\";s:9:\"user.full\";s:15:\"_title_callback\";s:48:\"Drupal\\user\\Controller\\UserController::userTitle\";}s:12:\"requirements\";a:2:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"user.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/user/(?P<user>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:7:\"/user/%\";s:8:\"numParts\";i:2;}}',2),('entity.user.collection','/admin/people','/admin/people',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/admin/people\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:17:\"user_admin_people\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:16:\"administer users\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/admin/people$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/admin/people\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/admin/people\";s:8:\"numParts\";i:2;}}',2),('entity.user.contact_form','/user/{user}/contact','/user/%/contact',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/user/{user}/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:7:\"Contact\";s:11:\"_controller\";s:65:\"\\Drupal\\contact\\Controller\\ContactController::contactPersonalPage\";}s:12:\"requirements\";a:2:{s:28:\"_access_contact_personal_tab\";s:4:\"TRUE\";s:4:\"user\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:29:\"access_check.contact_personal\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/user/(?P<user>\\d+)/contact$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/contact\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/user/%/contact\";s:8:\"numParts\";i:3;}}',3),('entity.user.edit_form','/user/{user}/edit','/user/%/edit',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/user/{user}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"user.default\";s:15:\"_title_callback\";s:48:\"Drupal\\user\\Controller\\UserController::userTitle\";}s:12:\"requirements\";a:2:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"user.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/user/(?P<user>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:12:\"/user/%/edit\";s:8:\"numParts\";i:3;}}',3),('entity.user.field_ui_fields','/admin/config/people/accounts/fields','/admin/config/people/accounts/fields',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/config/people/accounts/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/config/people/accounts/fields$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:36:\"/admin/config/people/accounts/fields\";s:8:\"numParts\";i:5;}}',5),('entity.user_role.collection','/admin/people/roles','/admin/people/roles',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/people/roles\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:9:\"user_role\";s:6:\"_title\";s:5:\"Roles\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/people/roles$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/people/roles\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/people/roles\";s:8:\"numParts\";i:3;}}',3),('entity.user_role.delete_form','/admin/people/roles/manage/{user_role}/delete','/admin/people/roles/manage/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/people/roles/manage/{user_role}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"user_role.delete\";s:6:\"_title\";s:11:\"Delete role\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"user_role.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"user_role\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/people/roles/manage/(?P<user_role>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/people/roles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"user_role\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:35:\"/admin/people/roles/manage/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.user_role.edit_form','/admin/people/roles/manage/{user_role}','/admin/people/roles/manage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/people/roles/manage/{user_role}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"user_role.default\";s:6:\"_title\";s:9:\"Edit role\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"user_role.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"user_role\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/people/roles/manage/(?P<user_role>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/people/roles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"user_role\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/people/roles/manage/%\";s:8:\"numParts\";i:5;}}',5),('entity.user_role.edit_permissions_form','/admin/people/permissions/{user_role}','/admin/people/permissions/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/people/permissions/{user_role}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:49:\"\\Drupal\\user\\Form\\UserPermissionsRoleSpecificForm\";s:6:\"_title\";s:9:\"Edit role\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"user_role.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"user_role\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/people/permissions/(?P<user_role>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/people/permissions\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"user_role\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:27:\"/admin/people/permissions/%\";s:8:\"numParts\";i:4;}}',4),('entity.view.break_lock_form','/admin/structure/views/view/{view}/break-lock','/admin/structure/views/view/%/break-lock',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/structure/views/view/{view}/break-lock\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"view.break_lock\";s:6:\"_title\";s:10:\"Break lock\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:15:\"view.break-lock\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/structure/views/view/(?P<view>[^/]++)/break\\-lock$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/break-lock\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/views/view/%/break-lock\";s:8:\"numParts\";i:6;}}',6),('entity.view.collection','/admin/structure/views','/admin/structure/views',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/views\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:4:\"view\";s:6:\"_title\";s:5:\"Views\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/views$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/views\";s:8:\"numParts\";i:3;}}',3),('entity.view.delete_form','/admin/structure/views/view/{view}/delete','/admin/structure/views/view/%/delete',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/views/view/{view}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"view.delete\";s:6:\"_title\";s:11:\"Delete view\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"view.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/views/view/(?P<view>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:36:\"/admin/structure/views/view/%/delete\";s:8:\"numParts\";i:6;}}',6),('entity.view.disable','/admin/structure/views/view/{view}/disable','/admin/structure/views/view/%/disable',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/views/view/{view}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::ajaxOperation\";s:2:\"op\";s:7:\"disable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"view.disable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/structure/views/view/(?P<view>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/structure/views/view/%/disable\";s:8:\"numParts\";i:6;}}',6),('entity.view.duplicate_form','/admin/structure/views/view/{view}/duplicate','/admin/structure/views/view/%/duplicate',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/views/view/{view}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"view.duplicate\";s:6:\"_title\";s:14:\"Duplicate view\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"view.duplicate\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/structure/views/view/(?P<view>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/views/view/%/duplicate\";s:8:\"numParts\";i:6;}}',6),('entity.view.edit_display_form','/admin/structure/views/view/{view}/edit/{display_id}','/admin/structure/views/view/%/edit',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/structure/views/view/{view}/edit/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::edit\";s:10:\"display_id\";N;}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"view.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/views/view/(?P<view>[^/]++)/edit(?:/(?P<display_id>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:34:\"/admin/structure/views/view/%/edit\";s:8:\"numParts\";i:7;}}',7),('entity.view.edit_form','/admin/structure/views/view/{view}','/admin/structure/views/view/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/structure/views/view/{view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::edit\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"view.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/structure/views/view/(?P<view>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:29:\"/admin/structure/views/view/%\";s:8:\"numParts\";i:5;}}',5),('entity.view.enable','/admin/structure/views/view/{view}/enable','/admin/structure/views/view/%/enable',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/views/view/{view}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::ajaxOperation\";s:2:\"op\";s:6:\"enable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.enable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/views/view/(?P<view>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:36:\"/admin/structure/views/view/%/enable\";s:8:\"numParts\";i:6;}}',6),('entity.view.preview_form','/admin/structure/views/view/{view}/preview/{display_id}','/admin/structure/views/view/%/preview',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/views/view/{view}/preview/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"view.preview\";s:10:\"display_id\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/views/view/(?P<view>[^/]++)/preview(?:/(?P<display_id>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/preview\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/structure/views/view/%/preview\";s:8:\"numParts\";i:7;}}',7),('entity_reference_revisions.delete_orphans','/admin/config/system/delete-orphans','/admin/config/system/delete-orphans',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/config/system/delete-orphans\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:74:\"Drupal\\entity_reference_revisions\\Form\\OrphanedCompositeEntitiesDeleteForm\";s:6:\"_title\";s:34:\"Delete orphaned composite entities\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"delete orphan revisions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/config/system/delete\\-orphans$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/system/delete-orphans\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/admin/config/system/delete-orphans\";s:8:\"numParts\";i:4;}}',4),('ept_core.settings','/admin/config/content/ept-core','/admin/config/content/ept-core',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/config/content/ept-core\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:41:\"\\Drupal\\ept_core\\Form\\EptCoreSettingsForm\";s:6:\"_title\";s:36:\"Extra Paragraph Types (EPT) settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/config/content/ept\\-core$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/content/ept-core\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/admin/config/content/ept-core\";s:8:\"numParts\";i:4;}}',4),('field_ui.display_mode','/admin/structure/display-modes','/admin/structure/display-modes',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/structure/display-modes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:13:\"Display modes\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:24:\"administer display modes\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/display\\-modes$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/structure/display-modes\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:30:\"/admin/structure/display-modes\";s:8:\"numParts\";i:3;}}',3),('field_ui.entity_form_mode_add','/admin/structure/display-modes/form/add','/admin/structure/display-modes/form/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/display-modes/form/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:78:\"\\Drupal\\field_ui\\Controller\\EntityDisplayModeController::formModeTypeSelection\";s:6:\"_title\";s:28:\"Choose form mode entity type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/display\\-modes/form/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/form/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/display-modes/form/add\";s:8:\"numParts\";i:5;}}',5),('field_ui.entity_view_mode_add','/admin/structure/display-modes/view/add','/admin/structure/display-modes/view/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/display-modes/view/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:78:\"\\Drupal\\field_ui\\Controller\\EntityDisplayModeController::viewModeTypeSelection\";s:6:\"_title\";s:28:\"Choose view mode entity type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/display\\-modes/view/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/view/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/display-modes/view/add\";s:8:\"numParts\";i:5;}}',5),('field_ui.field_add_block_content','/admin/structure/block-content/manage/{block_content_type}/add-field/{entity_type}/{field_name}','/admin/structure/block-content/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:95:\"/admin/structure/block-content/manage/{block_content_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:53:\"/admin/structure/block-content/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_comment','/admin/structure/comment/manage/{comment_type}/add-field/{entity_type}/{field_name}','/admin/structure/comment/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/comment/manage/{comment_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"administer comment fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:121:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:47:\"/admin/structure/comment/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_contact_message','/admin/structure/contact/manage/{contact_form}/add-field/{entity_type}/{field_name}','/admin/structure/contact/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/contact/manage/{contact_form}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:121:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:47:\"/admin/structure/contact/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_media','/admin/structure/media/manage/{media_type}/add-field/{entity_type}/{field_name}','/admin/structure/media/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/media/manage/{media_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer media fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:45:\"/admin/structure/media/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_node','/admin/structure/types/manage/{node_type}/add-field/{entity_type}/{field_name}','/admin/structure/types/manage/%/add-field/%/%',244,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/types/manage/{node_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:116:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:45:\"/admin/structure/types/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_add_paragraph','/admin/structure/paragraphs_type/{paragraphs_type}/add-field/{entity_type}/{field_name}','/admin/structure/paragraphs_type/%/add-field/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/paragraphs_type/{paragraphs_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraph fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:125:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:48:\"/admin/structure/paragraphs_type/%/add-field/%/%\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_add_taxonomy_term','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/add-field/{entity_type}/{field_name}','/admin/structure/taxonomy/manage/%/overview/add-field/%/%',492,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:100:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:138:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/overview/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:492;s:14:\"patternOutline\";s:57:\"/admin/structure/taxonomy/manage/%/overview/add-field/%/%\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_add_user','/admin/config/people/accounts/add-field/{entity_type}/{field_name}','/admin/config/people/accounts/add-field/%/%',124,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/config/people/accounts/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"entity_type\";i:1;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/config/people/accounts/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/people/accounts/add-field\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"entity_type\";i:1;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:124;s:14:\"patternOutline\";s:43:\"/admin/config/people/accounts/add-field/%/%\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_block_content.display','/admin/structure/block-content/manage/{block_content_type}/display/add-group','/admin/structure/block-content/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/block-content/manage/{block_content_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:57:\"/admin/structure/block-content/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_block_content.display.view_mode','/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/add-group','/admin/structure/block-content/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:122:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:59:\"/admin/structure/block-content/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_block_content.form_display','/admin/structure/block-content/manage/{block_content_type}/form-display/add-group','/admin/structure/block-content/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/block-content/manage/{block_content_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:62:\"/admin/structure/block-content/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_block_content.form_display.form_mode','/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/add-group','/admin/structure/block-content/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:128:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:64:\"/admin/structure/block-content/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_comment.display','/admin/structure/comment/manage/{comment_type}/display/add-group','/admin/structure/comment/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/comment/manage/{comment_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:51:\"/admin/structure/comment/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_comment.display.view_mode','/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}/add-group','/admin/structure/comment/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/comment/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_comment.form_display','/admin/structure/comment/manage/{comment_type}/form-display/add-group','/admin/structure/comment/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/structure/comment/manage/{comment_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/comment/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_comment.form_display.form_mode','/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}/add-group','/admin/structure/comment/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:58:\"/admin/structure/comment/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_contact_message.display','/admin/structure/contact/manage/{contact_form}/display/add-group','/admin/structure/contact/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/contact/manage/{contact_form}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:51:\"/admin/structure/contact/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_contact_message.display.view_mode','/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/add-group','/admin/structure/contact/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/contact/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_contact_message.form_display','/admin/structure/contact/manage/{contact_form}/form-display/add-group','/admin/structure/contact/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/structure/contact/manage/{contact_form}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/contact/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_contact_message.form_display.form_mode','/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/add-group','/admin/structure/contact/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:58:\"/admin/structure/contact/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_media.display','/admin/structure/media/manage/{media_type}/display/add-group','/admin/structure/media/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/media/manage/{media_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:49:\"/admin/structure/media/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_media.display.view_mode','/admin/structure/media/manage/{media_type}/display/{view_mode_name}/add-group','/admin/structure/media/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/structure/media/manage/{media_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/media/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_media.form_display','/admin/structure/media/manage/{media_type}/form-display/add-group','/admin/structure/media/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/media/manage/{media_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:54:\"/admin/structure/media/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_media.form_display.form_mode','/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}/add-group','/admin/structure/media/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/media/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_node.display','/admin/structure/types/manage/{node_type}/display/add-group','/admin/structure/types/manage/%/display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/types/manage/{node_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:49:\"/admin/structure/types/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_node.display.view_mode','/admin/structure/types/manage/{node_type}/display/{view_mode_name}/add-group','/admin/structure/types/manage/%/display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/types/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_node.form_display','/admin/structure/types/manage/{node_type}/form-display/add-group','/admin/structure/types/manage/%/form-display/add-group',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/types/manage/{node_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:54:\"/admin/structure/types/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_node.form_display.form_mode','/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/add-group','/admin/structure/types/manage/%/form-display/%/add-group',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:110:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/types/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_paragraph.display','/admin/structure/paragraphs_type/{paragraphs_type}/display/add-group','/admin/structure/paragraphs_type/%/display/add-group',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:52:\"/admin/structure/paragraphs_type/%/display/add-group\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_group_add_paragraph.display.view_mode','/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/add-group','/admin/structure/paragraphs_type/%/display/%/add-group',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:54:\"/admin/structure/paragraphs_type/%/display/%/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_paragraph.form_display','/admin/structure/paragraphs_type/{paragraphs_type}/form-display/add-group','/admin/structure/paragraphs_type/%/form-display/add-group',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:57:\"/admin/structure/paragraphs_type/%/form-display/add-group\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_group_add_paragraph.form_display.form_mode','/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}/add-group','/admin/structure/paragraphs_type/%/form-display/%/add-group',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:90:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:119:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:59:\"/admin/structure/paragraphs_type/%/form-display/%/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_taxonomy_term.display','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/add-group','/admin/structure/taxonomy/manage/%/overview/display/add-group',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/overview/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:61:\"/admin/structure/taxonomy/manage/%/overview/display/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_taxonomy_term.display.view_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/add-group','/admin/structure/taxonomy/manage/%/overview/display/%/add-group',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:63:\"/admin/structure/taxonomy/manage/%/overview/display/%/add-group\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_add_taxonomy_term.form_display','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/add-group','/admin/structure/taxonomy/manage/%/overview/form-display/add-group',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/overview/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:66:\"/admin/structure/taxonomy/manage/%/overview/form-display/add-group\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_add_taxonomy_term.form_display.form_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/add-group','/admin/structure/taxonomy/manage/%/overview/form-display/%/add-group',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:103:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:132:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:68:\"/admin/structure/taxonomy/manage/%/overview/form-display/%/add-group\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_add_user.display','/admin/config/people/accounts/display/add-group','/admin/config/people/accounts/display/add-group',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/people/accounts/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/config/people/accounts/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/people/accounts/display/add-group\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:47:\"/admin/config/people/accounts/display/add-group\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_group_add_user.display.view_mode','/admin/config/people/accounts/display/{view_mode_name}/add-group','/admin/config/people/accounts/display/%/add-group',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/config/people/accounts/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:49:\"/admin/config/people/accounts/display/%/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_add_user.form_display','/admin/config/people/accounts/form-display/add-group','/admin/config/people/accounts/form-display/add-group',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/config/people/accounts/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/config/people/accounts/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/people/accounts/form-display/add-group\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:52:\"/admin/config/people/accounts/form-display/add-group\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_group_add_user.form_display.form_mode','/admin/config/people/accounts/form-display/{form_mode_name}/add-group','/admin/config/people/accounts/form-display/%/add-group',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/config/people/accounts/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/config/people/accounts/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:54:\"/admin/config/people/accounts/form-display/%/add-group\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_delete_block_content.display','/admin/structure/block-content/manage/{block_content_type}/display/{field_group_name}/delete','/admin/structure/block-content/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:92:\"/admin/structure/block-content/manage/{block_content_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:120:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/block-content/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_block_content.display.view_mode','/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/block-content/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:109:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:147:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:58:\"/admin/structure/block-content/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_block_content.form_display','/admin/structure/block-content/manage/{block_content_type}/form-display/{field_group_name}/delete','/admin/structure/block-content/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:61:\"/admin/structure/block-content/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_block_content.form_display.form_mode','/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/block-content/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:114:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:153:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:63:\"/admin/structure/block-content/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_comment.display','/admin/structure/comment/manage/{comment_type}/display/{field_group_name}/delete','/admin/structure/comment/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/comment/manage/{comment_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/comment/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_comment.display.view_mode','/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/comment/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/comment/manage/{comment_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer comment display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:52:\"/admin/structure/comment/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_comment.form_display','/admin/structure/comment/manage/{comment_type}/form-display/{field_group_name}/delete','/admin/structure/comment/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/comment/manage/{comment_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"comment_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:55:\"/admin/structure/comment/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_comment.form_display.form_mode','/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/comment/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:102:\"/admin/structure/comment/manage/{comment_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:7:\"comment\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer comment form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"comment_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:140:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"comment_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:57:\"/admin/structure/comment/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_contact_message.display','/admin/structure/contact/manage/{contact_form}/display/{field_group_name}/delete','/admin/structure/contact/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/contact/manage/{contact_form}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/contact/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_contact_message.display.view_mode','/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/contact/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:52:\"/admin/structure/contact/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_contact_message.form_display','/admin/structure/contact/manage/{contact_form}/form-display/{field_group_name}/delete','/admin/structure/contact/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/contact/manage/{contact_form}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:55:\"/admin/structure/contact/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_contact_message.form_display.form_mode','/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/contact/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:102:\"/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:140:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:57:\"/admin/structure/contact/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_media.display','/admin/structure/media/manage/{media_type}/display/{field_group_name}/delete','/admin/structure/media/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/media/manage/{media_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:103:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:48:\"/admin/structure/media/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_media.display.view_mode','/admin/structure/media/manage/{media_type}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/media/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/media/manage/{media_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:130:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:50:\"/admin/structure/media/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_media.form_display','/admin/structure/media/manage/{media_type}/form-display/{field_group_name}/delete','/admin/structure/media/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/media/manage/{media_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/media/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_media.form_display.form_mode','/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/media/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:136:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:55:\"/admin/structure/media/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_node.display','/admin/structure/types/manage/{node_type}/display/{field_group_name}/delete','/admin/structure/types/manage/%/display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/types/manage/{node_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:48:\"/admin/structure/types/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_node.display.view_mode','/admin/structure/types/manage/{node_type}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/types/manage/%/display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:92:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:129:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:50:\"/admin/structure/types/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_node.form_display','/admin/structure/types/manage/{node_type}/form-display/{field_group_name}/delete','/admin/structure/types/manage/%/form-display/%/delete',245,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/types/manage/{node_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/types/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_node.form_display.form_mode','/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/types/manage/%/form-display/%/%/delete',489,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:135:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:55:\"/admin/structure/types/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_paragraph.display','/admin/structure/paragraphs_type/{paragraphs_type}/display/{field_group_name}/delete','/admin/structure/paragraphs_type/%/display/%/delete',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:84:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:51:\"/admin/structure/paragraphs_type/%/display/%/delete\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_delete_paragraph.display.view_mode','/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/paragraphs_type/%/display/%/%/delete',233,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:101:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:138:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:233;s:14:\"patternOutline\";s:53:\"/admin/structure/paragraphs_type/%/display/%/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_paragraph.form_display','/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{field_group_name}/delete','/admin/structure/paragraphs_type/%/form-display/%/delete',117,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:56:\"/admin/structure/paragraphs_type/%/form-display/%/delete\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_delete_paragraph.form_display.form_mode','/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/paragraphs_type/%/form-display/%/%/delete',233,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:106:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:144:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:233;s:14:\"patternOutline\";s:58:\"/admin/structure/paragraphs_type/%/form-display/%/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_taxonomy_term.display','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{field_group_name}/delete','/admin/structure/taxonomy/manage/%/overview/display/%/delete',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:124:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:60:\"/admin/structure/taxonomy/manage/%/overview/display/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_taxonomy_term.display.view_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/{field_group_name}/delete','/admin/structure/taxonomy/manage/%/overview/display/%/%/delete',985,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:114:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:151:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:985;s:14:\"patternOutline\";s:62:\"/admin/structure/taxonomy/manage/%/overview/display/%/%/delete\";s:8:\"numParts\";i:10;}}',10),('field_ui.field_group_delete_taxonomy_term.form_display','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{field_group_name}/delete','/admin/structure/taxonomy/manage/%/overview/form-display/%/delete',493,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:102:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:130:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:65:\"/admin/structure/taxonomy/manage/%/overview/form-display/%/delete\";s:8:\"numParts\";i:9;}}',9),('field_ui.field_group_delete_taxonomy_term.form_display.form_mode','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/{field_group_name}/delete','/admin/structure/taxonomy/manage/%/overview/form-display/%/%/delete',985,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:119:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:157:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:985;s:14:\"patternOutline\";s:67:\"/admin/structure/taxonomy/manage/%/overview/form-display/%/%/delete\";s:8:\"numParts\";i:10;}}',10),('field_ui.field_group_delete_user.display','/admin/config/people/accounts/display/{field_group_name}/delete','/admin/config/people/accounts/display/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/config/people/accounts/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/config/people/accounts/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/people/accounts/display/%/delete\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_delete_user.display.view_mode','/admin/config/people/accounts/display/{view_mode_name}/{field_group_name}/delete','/admin/config/people/accounts/display/%/%/delete',249,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/config/people/accounts/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"view_mode_name\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"view_mode_name\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:249;s:14:\"patternOutline\";s:48:\"/admin/config/people/accounts/display/%/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_group_delete_user.form_display','/admin/config/people/accounts/form-display/{field_group_name}/delete','/admin/config/people/accounts/form-display/%/delete',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/config/people/accounts/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/config/people/accounts/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/config/people/accounts/form-display/%/delete\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_group_delete_user.form_display.form_mode','/admin/config/people/accounts/form-display/{form_mode_name}/{field_group_name}/delete','/admin/config/people/accounts/form-display/%/%/delete',249,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/config/people/accounts/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"form_mode_name\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/config/people/accounts/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"form_mode_name\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:249;s:14:\"patternOutline\";s:53:\"/admin/config/people/accounts/form-display/%/%/delete\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_storage_config_add_block_content','/admin/structure/block-content/manage/{block_content_type}/fields/add-field','/admin/structure/block-content/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/block-content/manage/{block_content_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/block-content/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_comment','/admin/structure/comment/manage/{comment_type}/fields/add-field','/admin/structure/comment/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/comment/manage/{comment_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"administer comment fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/comment/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_contact_message','/admin/structure/contact/manage/{contact_form}/fields/add-field','/admin/structure/contact/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/contact/manage/{contact_form}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/contact/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_media','/admin/structure/media/manage/{media_type}/fields/add-field','/admin/structure/media/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/media/manage/{media_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer media fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:48:\"/admin/structure/media/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_node','/admin/structure/types/manage/{node_type}/fields/add-field','/admin/structure/types/manage/%/fields/add-field',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/types/manage/{node_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:48:\"/admin/structure/types/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_add_paragraph','/admin/structure/paragraphs_type/{paragraphs_type}/fields/add-field','/admin/structure/paragraphs_type/%/fields/add-field',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraph fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:51:\"/admin/structure/paragraphs_type/%/fields/add-field\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_storage_config_add_taxonomy_term','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/add-field','/admin/structure/taxonomy/manage/%/overview/fields/add-field',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/overview/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:60:\"/admin/structure/taxonomy/manage/%/overview/fields/add-field\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_storage_config_add_user','/admin/config/people/accounts/fields/add-field','/admin/config/people/accounts/fields/add-field',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/config/people/accounts/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/config/people/accounts/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/admin/config/people/accounts/fields/add-field\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:46:\"/admin/config/people/accounts/fields/add-field\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_storage_config_reuse_block_content','/admin/structure/block-content/manage/{block_content_type}/fields/reuse','/admin/structure/block-content/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/block-content/manage/{block_content_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:52:\"/admin/structure/block-content/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_comment','/admin/structure/comment/manage/{comment_type}/fields/reuse','/admin/structure/comment/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/comment/manage/{comment_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:7:\"comment\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:25:\"administer comment fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"comment_type\";a:2:{s:4:\"type\";s:19:\"entity:comment_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"comment_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/comment/manage/(?P<comment_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"comment_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/comment/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"comment_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:46:\"/admin/structure/comment/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_contact_message','/admin/structure/contact/manage/{contact_form}/fields/reuse','/admin/structure/contact/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/contact/manage/{contact_form}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:46:\"/admin/structure/contact/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_media','/admin/structure/media/manage/{media_type}/fields/reuse','/admin/structure/media/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/media/manage/{media_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:23:\"administer media fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:44:\"/admin/structure/media/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_node','/admin/structure/types/manage/{node_type}/fields/reuse','/admin/structure/types/manage/%/fields/reuse',123,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/types/manage/{node_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:44:\"/admin/structure/types/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',7),('field_ui.field_storage_config_reuse_paragraph','/admin/structure/paragraphs_type/{paragraphs_type}/fields/reuse','/admin/structure/paragraphs_type/%/fields/reuse',59,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:27:\"administer paragraph fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/admin/structure/paragraphs_type/%/fields/reuse\";s:8:\"numParts\";i:6;}}',6),('field_ui.field_storage_config_reuse_taxonomy_term','/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/reuse','/admin/structure/taxonomy/manage/%/overview/fields/reuse',247,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:56:\"/admin/structure/taxonomy/manage/%/overview/fields/reuse\";s:8:\"numParts\";i:8;}}',8),('field_ui.field_storage_config_reuse_user','/admin/config/people/accounts/fields/reuse','/admin/config/people/accounts/fields/reuse',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/config/people/accounts/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/admin/config/people/accounts/fields/reuse$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/fields/reuse\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:42:\"/admin/config/people/accounts/fields/reuse\";s:8:\"numParts\";i:6;}}',6),('file.ajax_progress','/file/progress/{key}','/file/progress/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/file/progress/{key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\file\\Controller\\FileWidgetAjaxController::progress\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/file/progress/(?P<key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/file/progress\";}}s:9:\"path_vars\";a:1:{i:0;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:16:\"/file/progress/%\";s:8:\"numParts\";i:3;}}',3),('file_mdm.settings','/admin/config/system/file_mdm','/admin/config/system/file_mdm',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/system/file_mdm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\file_mdm\\Form\\SettingsForm\";s:6:\"_title\";s:21:\"File metadata manager\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/system/file_mdm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/system/file_mdm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/system/file_mdm\";s:8:\"numParts\";i:4;}}',4),('filter.admin_overview','/admin/config/content/formats','/admin/config/content/formats',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/content/formats\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:13:\"filter_format\";s:6:\"_title\";s:24:\"Text formats and editors\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer filters\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/content/formats$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/content/formats\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/content/formats\";s:8:\"numParts\";i:4;}}',4),('filter.format_add','/admin/config/content/formats/add','/admin/config/content/formats/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/content/formats/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"filter_format.add\";s:6:\"_title\";s:15:\"Add text format\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:13:\"filter_format\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/content/formats/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/content/formats/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:33:\"/admin/config/content/formats/add\";s:8:\"numParts\";i:5;}}',5),('filter.tips','/filter/tips/{filter_format}','/filter/tips/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/filter/tips/{filter_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\filter\\Controller\\FilterController::filterTips\";s:6:\"_title\";s:12:\"Compose tips\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"filter_format.use\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/filter/tips/(?P<filter_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/filter/tips\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:14:\"/filter/tips/%\";s:8:\"numParts\";i:3;}}',3),('filter.tips_all','/filter/tips','/filter/tips',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/filter/tips\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\filter\\Controller\\FilterController::filterTips\";s:6:\"_title\";s:12:\"Compose tips\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/filter/tips$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/filter/tips\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/filter/tips\";s:8:\"numParts\";i:2;}}',2),('glightbox.admin_settings','/admin/config/media/glightbox','/admin/config/media/glightbox',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/media/glightbox\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"\\Drupal\\glightbox\\Form\\GLightboxSettingsForm\";s:6:\"_title\";s:18:\"GLightbox settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/media/glightbox$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/media/glightbox\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/media/glightbox\";s:8:\"numParts\";i:4;}}',4),('help.help_topic','/admin/help/topic/{id}','/admin/help/topic/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/help/topic/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:64:\"\\Drupal\\help\\Controller\\HelpTopicPluginController::viewHelpTopic\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"access help pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/help/topic/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/help/topic\";}}s:9:\"path_vars\";a:1:{i:0;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:19:\"/admin/help/topic/%\";s:8:\"numParts\";i:4;}}',4),('help.main','/admin/help','/admin/help',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/admin/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\help\\Controller\\HelpController::helpMain\";s:6:\"_title\";s:4:\"Help\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"access help pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/admin/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/admin/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/admin/help\";s:8:\"numParts\";i:2;}}',2),('help.page','/admin/help/{name}','/admin/help/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/admin/help/{name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\help\\Controller\\HelpController::helpPage\";s:6:\"_title\";s:4:\"Help\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"access help pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/help/(?P<name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/admin/help\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:13:\"/admin/help/%\";s:8:\"numParts\";i:3;}}',3),('history.get_last_node_view','/history/get_node_read_timestamps','/history/get_node_read_timestamps',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/history/get_node_read_timestamps\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:67:\"\\Drupal\\history\\Controller\\HistoryController::getNodeReadTimestamps\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/history/get_node_read_timestamps$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/history/get_node_read_timestamps\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:33:\"/history/get_node_read_timestamps\";s:8:\"numParts\";i:2;}}',2),('history.read_node','/history/{node}/read','/history/%/read',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/history/{node}/read\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:54:\"\\Drupal\\history\\Controller\\HistoryController::readNode\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:9:\"node.view\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/history/(?P<node>\\d+)/read$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/read\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/history\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/history/%/read\";s:8:\"numParts\";i:3;}}',3),('image.effect_add_form','/admin/config/media/image-styles/manage/{image_style}/add/{image_effect}','/admin/config/media/image-styles/manage/%/add/%',250,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/config/media/image-styles/manage/{image_style}/add/{image_effect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\image\\Form\\ImageEffectAddForm\";s:6:\"_title\";s:16:\"Add image effect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/add/(?P<image_effect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"image_effect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:250;s:14:\"patternOutline\";s:47:\"/admin/config/media/image-styles/manage/%/add/%\";s:8:\"numParts\";i:8;}}',8),('image.effect_delete','/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}/delete','/admin/config/media/image-styles/manage/%/effects/%/delete',501,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\image\\Form\\ImageEffectDeleteForm\";s:6:\"_title\";s:19:\"Delete image effect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/effects/(?P<image_effect>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"image_effect\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/effects\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:58:\"/admin/config/media/image-styles/manage/%/effects/%/delete\";s:8:\"numParts\";i:9;}}',9),('image.effect_edit_form','/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}','/admin/config/media/image-styles/manage/%/effects/%',250,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:38:\"\\Drupal\\image\\Form\\ImageEffectEditForm\";s:6:\"_title\";s:17:\"Edit image effect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/effects/(?P<image_effect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"image_effect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/effects\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:250;s:14:\"patternOutline\";s:51:\"/admin/config/media/image-styles/manage/%/effects/%\";s:8:\"numParts\";i:8;}}',8),('image.style_add','/admin/config/media/image-styles/add','/admin/config/media/image-styles/add',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/config/media/image-styles/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"image_style.add\";s:6:\"_title\";s:15:\"Add image style\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/media/image\\-styles/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/media/image-styles/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:36:\"/admin/config/media/image-styles/add\";s:8:\"numParts\";i:5;}}',5),('image.style_private','/system/files/styles/{image_style}/{scheme}','/system/files/styles/%/%',28,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/system/files/styles/{image_style}/{scheme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:62:\"\\Drupal\\image\\Controller\\ImageStyleDownloadController::deliver\";s:26:\"required_derivative_scheme\";s:7:\"private\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/system/files/styles/(?P<image_style>[^/]++)/(?P<scheme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"scheme\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/system/files/styles\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:28;s:14:\"patternOutline\";s:24:\"/system/files/styles/%/%\";s:8:\"numParts\";i:5;}}',5),('image.style_public','/sites/default/files/styles/{image_style}/{scheme}','/sites/default/files/styles/%/%',60,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/sites/default/files/styles/{image_style}/{scheme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:61:\"Drupal\\image\\Controller\\ImageStyleDownloadController::deliver\";s:26:\"required_derivative_scheme\";s:6:\"public\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/sites/default/files/styles/(?P<image_style>[^/]++)/(?P<scheme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"scheme\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/sites/default/files/styles\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:60;s:14:\"patternOutline\";s:31:\"/sites/default/files/styles/%/%\";s:8:\"numParts\";i:6;}}',6),('image_effects.settings','/admin/config/media/image_effects','/admin/config/media/image_effects',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/media/image_effects\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\image_effects\\Form\\SettingsForm\";s:6:\"_title\";s:13:\"Image Effects\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/media/image_effects$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/media/image_effects\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/config/media/image_effects\";s:8:\"numParts\";i:4;}}',4),('layout_paragraphs.builder.choose_component','/layout-paragraphs-builder/{layout_paragraphs_layout}/choose-component','/layout-paragraphs-builder/%/choose-component',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/layout-paragraphs-builder/{layout_paragraphs_layout}/choose-component\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\layout_paragraphs\\Controller\\ChooseComponentController::list\";s:9:\"operation\";s:6:\"create\";}s:12:\"requirements\";a:1:{s:33:\"_layout_paragraphs_builder_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:24:\"layout_paragraphs_layout\";a:2:{s:34:\"layout_paragraphs_layout_tempstore\";b:1;s:9:\"converter\";s:43:\"layout_paragraphs.param_converter.tempstore\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:32:\"layout_paragraphs.builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:24:\"layout_paragraphs_layout\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/layout\\-paragraphs\\-builder/(?P<layout_paragraphs_layout>[^/]++)/choose\\-component$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/choose-component\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:24:\"layout_paragraphs_layout\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout-paragraphs-builder\";}}s:9:\"path_vars\";a:1:{i:0;s:24:\"layout_paragraphs_layout\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:45:\"/layout-paragraphs-builder/%/choose-component\";s:8:\"numParts\";i:3;}}',3),('layout_paragraphs.builder.delete_item','/layout-paragraphs-builder/{layout_paragraphs_layout}/delete/{component_uuid}','/layout-paragraphs-builder/%/delete/%',10,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/layout-paragraphs-builder/{layout_paragraphs_layout}/delete/{component_uuid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:50:\"\\Drupal\\layout_paragraphs\\Form\\DeleteComponentForm\";s:9:\"operation\";s:6:\"delete\";}s:12:\"requirements\";a:1:{s:33:\"_layout_paragraphs_builder_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:24:\"layout_paragraphs_layout\";a:2:{s:34:\"layout_paragraphs_layout_tempstore\";b:1;s:9:\"converter\";s:43:\"layout_paragraphs.param_converter.tempstore\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:32:\"layout_paragraphs.builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:14:\"component_uuid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/layout\\-paragraphs\\-builder/(?P<layout_paragraphs_layout>[^/]++)/delete/(?P<component_uuid>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"component_uuid\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:24:\"layout_paragraphs_layout\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout-paragraphs-builder\";}}s:9:\"path_vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:14:\"component_uuid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:37:\"/layout-paragraphs-builder/%/delete/%\";s:8:\"numParts\";i:4;}}',4),('layout_paragraphs.builder.duplicate_item','/layout-paragraphs-builder/{layout_paragraphs_layout}/duplicate/{source_uuid}','/layout-paragraphs-builder/%/duplicate/%',10,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/layout-paragraphs-builder/{layout_paragraphs_layout}/duplicate/{source_uuid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:67:\"\\Drupal\\layout_paragraphs\\Controller\\DuplicateController::duplicate\";s:9:\"operation\";s:9:\"duplicate\";}s:12:\"requirements\";a:1:{s:33:\"_layout_paragraphs_builder_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:24:\"layout_paragraphs_layout\";a:2:{s:34:\"layout_paragraphs_layout_tempstore\";b:1;s:9:\"converter\";s:43:\"layout_paragraphs.param_converter.tempstore\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:32:\"layout_paragraphs.builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:11:\"source_uuid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/layout\\-paragraphs\\-builder/(?P<layout_paragraphs_layout>[^/]++)/duplicate/(?P<source_uuid>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"source_uuid\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:24:\"layout_paragraphs_layout\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout-paragraphs-builder\";}}s:9:\"path_vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:11:\"source_uuid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:40:\"/layout-paragraphs-builder/%/duplicate/%\";s:8:\"numParts\";i:4;}}',4),('layout_paragraphs.builder.edit_item','/layout-paragraphs-builder/{layout_paragraphs_layout}/edit/{component_uuid}','/layout-paragraphs-builder/%/edit/%',10,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/layout-paragraphs-builder/{layout_paragraphs_layout}/edit/{component_uuid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:48:\"\\Drupal\\layout_paragraphs\\Form\\EditComponentForm\";s:9:\"operation\";s:6:\"update\";}s:12:\"requirements\";a:1:{s:33:\"_layout_paragraphs_builder_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:24:\"layout_paragraphs_layout\";a:2:{s:34:\"layout_paragraphs_layout_tempstore\";b:1;s:9:\"converter\";s:43:\"layout_paragraphs.param_converter.tempstore\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:32:\"layout_paragraphs.builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:14:\"component_uuid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/layout\\-paragraphs\\-builder/(?P<layout_paragraphs_layout>[^/]++)/edit/(?P<component_uuid>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"component_uuid\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:24:\"layout_paragraphs_layout\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout-paragraphs-builder\";}}s:9:\"path_vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:14:\"component_uuid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:35:\"/layout-paragraphs-builder/%/edit/%\";s:8:\"numParts\";i:4;}}',4),('layout_paragraphs.builder.formatter','/layout-paragraphs-builder/formatter/{entity_type}/{entity}/{field_name}/{view_mode}','/layout-paragraphs-builder/formatter/%/%/%/%',48,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:84:\"/layout-paragraphs-builder/formatter/{entity_type}/{entity}/{field_name}/{view_mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:77:\"\\Drupal\\layout_paragraphs\\Controller\\LayoutParagraphsBuilderController::build\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:78:\"\\Drupal\\layout_paragraphs\\Controller\\LayoutParagraphsBuilderController::access\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:3:{s:4:\"type\";s:20:\"entity:{entity_type}\";s:20:\"load_latest_revision\";b:1;s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:11:\"entity_type\";i:1;s:6:\"entity\";i:2;s:10:\"field_name\";i:3;s:9:\"view_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:133:\"{^/layout\\-paragraphs\\-builder/formatter/(?P<entity_type>[^/]++)/(?P<entity>[^/]++)/(?P<field_name>[^/]++)/(?P<view_mode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"view_mode\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"entity\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/layout-paragraphs-builder/formatter\";}}s:9:\"path_vars\";a:4:{i:0;s:11:\"entity_type\";i:1;s:6:\"entity\";i:2;s:10:\"field_name\";i:3;s:9:\"view_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:48;s:14:\"patternOutline\";s:44:\"/layout-paragraphs-builder/formatter/%/%/%/%\";s:8:\"numParts\";i:6;}}',6),('layout_paragraphs.builder.insert','/layout-paragraphs-builder/{layout_paragraphs_layout}/insert/{paragraph_type_id}','/layout-paragraphs-builder/%/insert/%',10,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/layout-paragraphs-builder/{layout_paragraphs_layout}/insert/{paragraph_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:72:\"\\Drupal\\layout_paragraphs\\Controller\\ComponentFormController::insertForm\";s:9:\"operation\";s:6:\"create\";}s:12:\"requirements\";a:1:{s:33:\"_layout_paragraphs_builder_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:24:\"layout_paragraphs_layout\";a:2:{s:34:\"layout_paragraphs_layout_tempstore\";b:1;s:9:\"converter\";s:43:\"layout_paragraphs.param_converter.tempstore\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:32:\"layout_paragraphs.builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:17:\"paragraph_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/layout\\-paragraphs\\-builder/(?P<layout_paragraphs_layout>[^/]++)/insert/(?P<paragraph_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"paragraph_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/insert\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:24:\"layout_paragraphs_layout\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout-paragraphs-builder\";}}s:9:\"path_vars\";a:2:{i:0;s:24:\"layout_paragraphs_layout\";i:1;s:17:\"paragraph_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:37:\"/layout-paragraphs-builder/%/insert/%\";s:8:\"numParts\";i:4;}}',4),('layout_paragraphs.builder.reorder','/layout-paragraphs-builder/{layout_paragraphs_layout}/reorder','/layout-paragraphs-builder/%/reorder',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/layout-paragraphs-builder/{layout_paragraphs_layout}/reorder\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:61:\"\\Drupal\\layout_paragraphs\\Controller\\ReorderController::build\";s:9:\"operation\";s:7:\"reorder\";}s:12:\"requirements\";a:1:{s:33:\"_layout_paragraphs_builder_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:24:\"layout_paragraphs_layout\";a:2:{s:34:\"layout_paragraphs_layout_tempstore\";b:1;s:9:\"converter\";s:43:\"layout_paragraphs.param_converter.tempstore\";}s:14:\"paragraph_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:32:\"layout_paragraphs.builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:24:\"layout_paragraphs_layout\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/layout\\-paragraphs\\-builder/(?P<layout_paragraphs_layout>[^/]++)/reorder$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/reorder\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:24:\"layout_paragraphs_layout\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout-paragraphs-builder\";}}s:9:\"path_vars\";a:1:{i:0;s:24:\"layout_paragraphs_layout\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:36:\"/layout-paragraphs-builder/%/reorder\";s:8:\"numParts\";i:3;}}',3),('layout_paragraphs.label_settings','/admin/config/content/layout_paragraphs/labels','/admin/config/content/layout_paragraphs/labels',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/config/content/layout_paragraphs/labels\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:59:\"\\Drupal\\layout_paragraphs\\Form\\LayoutParagraphsSettingsForm\";s:6:\"_title\";s:24:\"Layout Paragraphs Labels\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/admin/config/content/layout_paragraphs/labels$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/admin/config/content/layout_paragraphs/labels\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:46:\"/admin/config/content/layout_paragraphs/labels\";s:8:\"numParts\";i:5;}}',5),('layout_paragraphs.modal_settings','/admin/config/content/layout_paragraphs/modal-settings','/admin/config/content/layout_paragraphs/modal-settings',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/content/layout_paragraphs/modal-settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:64:\"\\Drupal\\layout_paragraphs\\Form\\LayoutParagraphsModalSettingsForm\";s:6:\"_title\";s:32:\"Layout Paragraphs Modal Settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/config/content/layout_paragraphs/modal\\-settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:54:\"/admin/config/content/layout_paragraphs/modal-settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:54:\"/admin/config/content/layout_paragraphs/modal-settings\";s:8:\"numParts\";i:5;}}',5),('layout_paragraphs.section_settings','/admin/config/content/layout_paragraphs/sections','/admin/config/content/layout_paragraphs/sections',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/config/content/layout_paragraphs/sections\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:67:\"\\Drupal\\layout_paragraphs\\Form\\LayoutParagraphsSectionsSettingsForm\";s:6:\"_title\";s:26:\"Layout Paragraphs Sections\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/config/content/layout_paragraphs/sections$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/admin/config/content/layout_paragraphs/sections\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:48:\"/admin/config/content/layout_paragraphs/sections\";s:8:\"numParts\";i:5;}}',5),('media.filter.preview','/media/{filter_format}/preview','/media/%/preview',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/media/{filter_format}/preview\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:55:\"\\Drupal\\media\\Controller\\MediaFilterController::preview\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:17:\"filter_format.use\";s:14:\"_custom_access\";s:74:\"\\Drupal\\media\\Controller\\MediaFilterController::formatUsesMediaEmbedFilter\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/media/(?P<filter_format>[^/]++)/preview$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/preview\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:16:\"/media/%/preview\";s:8:\"numParts\";i:3;}}',3),('media.oembed_iframe','/media/oembed','/media/oembed',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/media/oembed\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:55:\"\\Drupal\\media\\Controller\\OEmbedIframeController::render\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:10:\"view media\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/media/oembed$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/media/oembed\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/media/oembed\";s:8:\"numParts\";i:2;}}',2),('media.settings','/admin/config/media/media-settings','/admin/config/media/media-settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/media/media-settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\media\\Form\\MediaSettingsForm\";s:6:\"_title\";s:14:\"Media settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer media\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/admin/config/media/media\\-settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/media/media-settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/config/media/media-settings\";s:8:\"numParts\";i:4;}}',4),('media_library.settings','/admin/config/media/media-library','/admin/config/media/media-library',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/media/media-library\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\media_library\\Form\\SettingsForm\";s:6:\"_title\";s:22:\"Media Library settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer media\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/media/media\\-library$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/media/media-library\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/config/media/media-library\";s:8:\"numParts\";i:4;}}',4),('media_library.ui','/media-library','/media-library',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/media-library\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:32:\"media_library.ui_builder:buildUi\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:36:\"media_library.ui_builder:checkAccess\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:22:\"{^/media\\-library$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/media-library\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:14:\"/media-library\";s:8:\"numParts\";i:1;}}',1),('menu_ui.link_edit','/admin/structure/menu/link/{menu_link_plugin}/edit','/admin/structure/menu/link/%/edit',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/menu/link/{menu_link_plugin}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\menu_ui\\Form\\MenuLinkEditForm\";s:6:\"_title\";s:14:\"Edit menu link\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:15:\"administer menu\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"menu_link_plugin\";a:2:{s:4:\"type\";s:16:\"menu_link_plugin\";s:9:\"converter\";s:54:\"drupal.proxy_original_service.paramconverter.menu_link\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/menu/link/(?P<menu_link_plugin>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"menu_link_plugin\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/link\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:33:\"/admin/structure/menu/link/%/edit\";s:8:\"numParts\";i:6;}}',6),('menu_ui.link_reset','/admin/structure/menu/link/{menu_link_plugin}/reset','/admin/structure/menu/link/%/reset',61,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/menu/link/{menu_link_plugin}/reset\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:38:\"\\Drupal\\menu_ui\\Form\\MenuLinkResetForm\";s:6:\"_title\";s:15:\"Reset menu link\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:15:\"administer menu\";s:14:\"_custom_access\";s:56:\"\\Drupal\\menu_ui\\Form\\MenuLinkResetForm::linkIsResettable\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"menu_link_plugin\";a:2:{s:4:\"type\";s:16:\"menu_link_plugin\";s:9:\"converter\";s:54:\"drupal.proxy_original_service.paramconverter.menu_link\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/menu/link/(?P<menu_link_plugin>[^/]++)/reset$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/reset\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"menu_link_plugin\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/link\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:34:\"/admin/structure/menu/link/%/reset\";s:8:\"numParts\";i:6;}}',6),('menu_ui.parent_options_js','/admin/structure/menu/parents','/admin/structure/menu/parents',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/structure/menu/parents\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:59:\"\\Drupal\\menu_ui\\Controller\\MenuController::getParentOptions\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:15:\"administer menu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/structure/menu/parents$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/menu/parents\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/structure/menu/parents\";s:8:\"numParts\";i:4;}}',4),('node.add','/node/add/{node_type}','/node/add/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/node/add/{node_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"node.default\";s:15:\"_title_callback\";s:52:\"\\Drupal\\node\\Controller\\NodeController::addPageTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:16:\"node:{node_type}\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:3:{s:4:\"type\";s:16:\"entity:node_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/node/add/(?P<node_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/node/add\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:11:\"/node/add/%\";s:8:\"numParts\";i:3;}}',3),('node.add_page','/node/add','/node/add',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:9:\"/node/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:11:\"Add content\";s:11:\"_controller\";s:47:\"\\Drupal\\node\\Controller\\NodeController::addPage\";}s:12:\"requirements\";a:1:{s:25:\"_entity_create_any_access\";s:4:\"node\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.entity_create_any\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:16:\"{^/node/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/node/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:9:\"/node/add\";s:8:\"numParts\";i:2;}}',2),('node.configure_rebuild_confirm','/admin/reports/status/rebuild','/admin/reports/status/rebuild',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/reports/status/rebuild\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:40:\"\\Drupal\\node\\Form\\RebuildPermissionsForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer nodes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/status/rebuild$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/reports/status/rebuild\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/reports/status/rebuild\";s:8:\"numParts\";i:4;}}',4),('node.multiple_delete_confirm','/admin/content/node/delete','/admin/content/node/delete',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/content/node/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\node\\Form\\DeleteMultiple\";s:14:\"entity_type_id\";s:4:\"node\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:4:\"node\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/content/node/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/content/node/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/content/node/delete\";s:8:\"numParts\";i:4;}}',4),('node.revision_delete_confirm','/node/{node}/revisions/{node_revision}/delete','/node/%/revisions/%/delete',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/node/{node}/revisions/{node_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\node\\Form\\NodeRevisionDeleteForm\";s:6:\"_title\";s:23:\"Delete earlier revision\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"node_revision.delete revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/node/%/revisions/%/delete\";s:8:\"numParts\";i:5;}}',5),('node.revision_revert_confirm','/node/{node}/revisions/{node_revision}/revert','/node/%/revisions/%/revert',21,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/node/{node}/revisions/{node_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\node\\Form\\NodeRevisionRevertForm\";s:6:\"_title\";s:26:\"Revert to earlier revision\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"node_revision.revert revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/node/%/revisions/%/revert\";s:8:\"numParts\";i:5;}}',5),('node.revision_revert_translation_confirm','/node/{node}/revisions/{node_revision}/revert/{langcode}','/node/%/revisions/%/revert/%',42,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/node/{node}/revisions/{node_revision}/revert/{langcode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\node\\Form\\NodeRevisionRevertTranslationForm\";s:6:\"_title\";s:43:\"Revert to earlier revision of a translation\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"node_revision.revert revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/revert/(?P<langcode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:42;s:14:\"patternOutline\";s:28:\"/node/%/revisions/%/revert/%\";s:8:\"numParts\";i:6;}}',6),('node.type_add','/admin/structure/types/add','/admin/structure/types/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/structure/types/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"node_type.add\";s:6:\"_title\";s:16:\"Add content type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/structure/types/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/types/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/structure/types/add\";s:8:\"numParts\";i:4;}}',4),('paragraphs.settings','/admin/config/content/paragraphs','/admin/config/content/paragraphs',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/content/paragraphs\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:46:\"\\Drupal\\paragraphs\\Form\\ParagraphsSettingsForm\";s:6:\"_title\";s:19:\"Paragraphs settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer paragraphs settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/config/content/paragraphs$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/content/paragraphs\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/config/content/paragraphs\";s:8:\"numParts\";i:4;}}',4),('paragraphs.type_add','/admin/structure/paragraphs_type/add','/admin/structure/paragraphs_type/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/structure/paragraphs_type/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"paragraphs_type.add\";s:6:\"_title\";s:19:\"Add Paragraphs type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraphs types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/structure/paragraphs_type/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/structure/paragraphs_type/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:36:\"/admin/structure/paragraphs_type/add\";s:8:\"numParts\";i:4;}}',4),('search.add_type','/admin/config/search/pages/add/{search_plugin_id}','/admin/config/search/pages/add/%',62,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/config/search/pages/add/{search_plugin_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"search_page.add\";s:6:\"_title\";s:19:\"Add new search page\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:11:\"search_page\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"search_plugin_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/admin/config/search/pages/add/(?P<search_plugin_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"search_plugin_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/search/pages/add\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"search_plugin_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:32:\"/admin/config/search/pages/add/%\";s:8:\"numParts\";i:6;}}',6),('search.help_help_search','/search/help/help','/search/help/help',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/search/help/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:53:\"Drupal\\search\\Controller\\SearchController::searchHelp\";s:6:\"_title\";s:15:\"About searching\";s:6:\"entity\";s:11:\"help_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/search/help/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/search/help/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:17:\"/search/help/help\";s:8:\"numParts\";i:3;}}',3),('search.help_node_search','/search/node/help','/search/node/help',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/search/node/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:53:\"Drupal\\search\\Controller\\SearchController::searchHelp\";s:6:\"_title\";s:15:\"About searching\";s:6:\"entity\";s:11:\"node_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/search/node/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/search/node/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:17:\"/search/node/help\";s:8:\"numParts\";i:3;}}',3),('search.help_user_search','/search/user/help','/search/user/help',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/search/user/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:53:\"Drupal\\search\\Controller\\SearchController::searchHelp\";s:6:\"_title\";s:15:\"About searching\";s:6:\"entity\";s:11:\"user_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/search/user/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/search/user/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:17:\"/search/user/help\";s:8:\"numParts\";i:3;}}',3),('search.reindex_confirm','/admin/config/search/pages/reindex','/admin/config/search/pages/reindex',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/search/pages/reindex\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\search\\Form\\ReindexConfirm\";s:6:\"_title\";s:11:\"Clear index\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer search\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/search/pages/reindex$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/pages/reindex\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/config/search/pages/reindex\";s:8:\"numParts\";i:5;}}',5),('search.view','/search','/search',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:7:\"/search\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:61:\"Drupal\\search\\Controller\\SearchController::redirectSearchPage\";s:6:\"_title\";s:6:\"Search\";s:6:\"entity\";s:11:\"node_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:14:\"{^/search$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/search\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:7:\"/search\";s:8:\"numParts\";i:1;}}',1),('search.view_help_search','/search/help','/search/help',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/search/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:47:\"Drupal\\search\\Controller\\SearchController::view\";s:6:\"_title\";s:6:\"Search\";s:6:\"entity\";s:11:\"help_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/search/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/search/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/search/help\";s:8:\"numParts\";i:2;}}',2),('search.view_node_search','/search/node','/search/node',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/search/node\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:47:\"Drupal\\search\\Controller\\SearchController::view\";s:6:\"_title\";s:6:\"Search\";s:6:\"entity\";s:11:\"node_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/search/node$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/search/node\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/search/node\";s:8:\"numParts\";i:2;}}',2),('search.view_user_search','/search/user','/search/user',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/search/user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:47:\"Drupal\\search\\Controller\\SearchController::view\";s:6:\"_title\";s:6:\"Search\";s:6:\"entity\";s:11:\"user_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/search/user$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/search/user\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/search/user\";s:8:\"numParts\";i:2;}}',2),('shortcut.link_add','/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link','/admin/config/user-interface/shortcut/manage/%/add-link',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\shortcut\\Controller\\ShortcutController::addForm\";s:6:\"_title\";s:8:\"Add link\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:23:\"shortcut:{shortcut_set}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/add\\-link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/add-link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:55:\"/admin/config/user-interface/shortcut/manage/%/add-link\";s:8:\"numParts\";i:7;}}',7),('shortcut.link_add_inline','/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link-inline','/admin/config/user-interface/shortcut/manage/%/add-link-inline',125,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link-inline\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:72:\"\\Drupal\\shortcut\\Controller\\ShortcutSetController::addShortcutLinkInline\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:19:\"shortcut_set.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/add\\-link\\-inline$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/add-link-inline\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:62:\"/admin/config/user-interface/shortcut/manage/%/add-link-inline\";s:8:\"numParts\";i:7;}}',7),('shortcut.set_add','/admin/config/user-interface/shortcut/add-set','/admin/config/user-interface/shortcut/add-set',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/user-interface/shortcut/add-set\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"shortcut_set.add\";s:6:\"_title\";s:16:\"Add shortcut set\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:12:\"shortcut_set\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/config/user\\-interface/shortcut/add\\-set$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/config/user-interface/shortcut/add-set\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:45:\"/admin/config/user-interface/shortcut/add-set\";s:8:\"numParts\";i:5;}}',5),('shortcut.set_switch','/user/{user}/shortcuts','/user/%/shortcuts',5,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/user/{user}/shortcuts\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\shortcut\\Form\\SwitchShortcutSet\";s:6:\"_title\";s:9:\"Shortcuts\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:52:\"\\Drupal\\shortcut\\Form\\SwitchShortcutSet::checkAccess\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"user\";s:3:\"\\d+\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/user/(?P<user>[^/]++)/shortcuts$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/shortcuts\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/user/%/shortcuts\";s:8:\"numParts\";i:3;}}',3),('system.401','/system/401','/system/401',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/401\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on401\";s:6:\"_title\";s:12:\"Unauthorized\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/401$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/401\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/401\";s:8:\"numParts\";i:2;}}',2),('system.403','/system/403','/system/403',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/403\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on403\";s:6:\"_title\";s:13:\"Access denied\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/403$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/403\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/403\";s:8:\"numParts\";i:2;}}',2),('system.404','/system/404','/system/404',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/404\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on404\";s:6:\"_title\";s:14:\"Page not found\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/404$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/404\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/404\";s:8:\"numParts\";i:2;}}',2),('system.4xx','/system/4xx','/system/4xx',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/4xx\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on4xx\";s:6:\"_title\";s:12:\"Client error\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/4xx$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/4xx\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/4xx\";s:8:\"numParts\";i:2;}}',2),('system.admin','/admin','/admin',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:6:\"/admin\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:14:\"Administration\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:13:\"{^/admin$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/admin\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:6:\"/admin\";s:8:\"numParts\";i:1;}}',1),('system.admin_compact_page','/admin/compact/{mode}','/admin/compact',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/compact/{mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\system\\Controller\\SystemController::compactPage\";s:4:\"mode\";s:3:\"off\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"access administration pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/compact(?:/(?P<mode>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"mode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/compact\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/compact\";s:8:\"numParts\";i:3;}}',3),('system.admin_config','/admin/config','/admin/config',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/admin/config\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\SystemController::overview\";s:7:\"link_id\";s:19:\"system.admin_config\";s:6:\"_title\";s:13:\"Configuration\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:27:\"_access_admin_overview_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:32:\"access_check.admin_overview_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/admin/config$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/admin/config\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/admin/config\";s:8:\"numParts\";i:2;}}',2),('system.admin_config_content','/admin/config/content','/admin/config/content',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/config/content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:17:\"Content authoring\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/config/content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/config/content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/config/content\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_development','/admin/config/development','/admin/config/development',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/config/development\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:11:\"Development\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/config/development$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/config/development\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/config/development\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_media','/admin/config/media','/admin/config/media',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/config/media\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:5:\"Media\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/config/media$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/config/media\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/config/media\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_regional','/admin/config/regional','/admin/config/regional',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/config/regional\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:19:\"Region and language\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/config/regional$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/config/regional\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/config/regional\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_search','/admin/config/search','/admin/config/search',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/config/search\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:19:\"Search and metadata\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/config/search$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/config/search\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/config/search\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_services','/admin/config/services','/admin/config/services',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/config/services\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:12:\"Web services\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/config/services$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/config/services\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/config/services\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_system','/admin/config/system','/admin/config/system',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/config/system\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:6:\"System\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/config/system$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/config/system\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/config/system\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_ui','/admin/config/user-interface','/admin/config/user-interface',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/config/user-interface\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:14:\"User interface\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/user\\-interface$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/user-interface\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/config/user-interface\";s:8:\"numParts\";i:3;}}',3),('system.admin_config_workflow','/admin/config/workflow','/admin/config/workflow',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/config/workflow\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:8:\"Workflow\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/config/workflow$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/config/workflow\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/config/workflow\";s:8:\"numParts\";i:3;}}',3),('system.admin_content','/admin/content','/admin/content',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:23:\"access content overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/content\";s:8:\"numParts\";i:2;}}',2),('system.admin_index','/admin/index','/admin/index',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/admin/index\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\system\\Controller\\AdminController::index\";s:6:\"_title\";s:14:\"Administration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"access administration pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/admin/index$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/admin/index\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/admin/index\";s:8:\"numParts\";i:2;}}',2),('system.admin_reports','/admin/reports','/admin/reports',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/reports\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:7:\"Reports\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"access site reports\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/reports$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/reports\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/reports\";s:8:\"numParts\";i:2;}}',2),('system.admin_structure','/admin/structure','/admin/structure',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:16:\"/admin/structure\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:9:\"Structure\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:23:\"{^/admin/structure$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/admin/structure\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:16:\"/admin/structure\";s:8:\"numParts\";i:2;}}',2),('system.batch_page.html','/batch','/batch',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:6:\"/batch\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\BatchController::batchPage\";s:15:\"_title_callback\";s:57:\"\\Drupal\\system\\Controller\\BatchController::batchPageTitle\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:12:\"_no_big_pipe\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:13:\"{^/batch$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/batch\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:6:\"/batch\";s:8:\"numParts\";i:1;}}',1),('system.batch_page.json','/batch','/batch',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:6:\"/batch\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\BatchController::batchPage\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:13:\"{^/batch$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/batch\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:6:\"/batch\";s:8:\"numParts\";i:1;}}',1),('system.cron','/cron/{key}','/cron/%',2,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/cron/{key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:34:\"\\Drupal\\system\\CronController::run\";}s:12:\"requirements\";a:1:{s:19:\"_access_system_cron\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:17:\"access_check.cron\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/cron/(?P<key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/cron\";}}s:9:\"path_vars\";a:1:{i:0;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:7:\"/cron/%\";s:8:\"numParts\";i:2;}}',2),('system.cron_settings','/admin/config/system/cron','/admin/config/system/cron',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/config/system/cron\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:28:\"\\Drupal\\system\\Form\\CronForm\";s:6:\"_title\";s:4:\"Cron\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/config/system/cron$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/config/system/cron\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/config/system/cron\";s:8:\"numParts\";i:4;}}',4),('system.csrftoken','/session/token','/session/token',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/session/token\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:56:\"\\Drupal\\system\\Controller\\CsrfTokenController::csrfToken\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/session/token$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/session/token\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/session/token\";s:8:\"numParts\";i:2;}}',2),('system.css_asset','/sites/default/files/css/{file_name}','/sites/default/files/css/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/sites/default/files/css/{file_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"Drupal\\system\\Controller\\CssAssetController::deliver\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"file_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/sites/default/files/css/(?P<file_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"file_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/sites/default/files/css\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"file_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:26:\"/sites/default/files/css/%\";s:8:\"numParts\";i:5;}}',5),('system.date_format_add','/admin/config/regional/date-time/formats/add','/admin/config/regional/date-time/formats/add',63,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/config/regional/date-time/formats/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"date_format.add\";s:6:\"_title\";s:15:\"Add date format\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/config/regional/date\\-time/formats/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/regional/date-time/formats/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:44:\"/admin/config/regional/date-time/formats/add\";s:8:\"numParts\";i:6;}}',6),('system.db_update','/update.php/{op}','/update.php',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:16:\"/update.php/{op}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:2:\"op\";s:4:\"info\";}s:12:\"requirements\";a:1:{s:21:\"_access_system_update\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"default_url_options\";a:1:{s:15:\"path_processing\";b:0;}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:22:\"access_check.db_update\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:2:\"op\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/update\\.php(?:/(?P<op>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"op\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/update.php\";}}s:9:\"path_vars\";a:1:{i:0;s:2:\"op\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:11:\"/update.php\";s:8:\"numParts\";i:2;}}',2),('system.development_settings','/admin/config/development/settings','/admin/config/development/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/development/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\system\\Form\\DevelopmentSettingsForm\";s:6:\"_title\";s:20:\"Development settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/development/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/development/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/config/development/settings\";s:8:\"numParts\";i:4;}}',4),('system.entity_autocomplete','/entity_reference_autocomplete/{target_type}/{selection_handler}/{selection_settings_key}','/entity_reference_autocomplete/%/%/%',8,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/entity_reference_autocomplete/{target_type}/{selection_handler}/{selection_settings_key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:74:\"\\Drupal\\system\\Controller\\EntityAutocompleteController::handleAutocomplete\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:11:\"target_type\";i:1;s:17:\"selection_handler\";i:2;s:22:\"selection_settings_key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/entity_reference_autocomplete/(?P<target_type>[^/]++)/(?P<selection_handler>[^/]++)/(?P<selection_settings_key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"selection_settings_key\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"selection_handler\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/entity_reference_autocomplete\";}}s:9:\"path_vars\";a:3:{i:0;s:11:\"target_type\";i:1;s:17:\"selection_handler\";i:2;s:22:\"selection_settings_key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:8;s:14:\"patternOutline\";s:36:\"/entity_reference_autocomplete/%/%/%\";s:8:\"numParts\";i:4;}}',4),('system.files','/system/files/{scheme}','/system/files',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/system/files/{scheme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:47:\"\\Drupal\\system\\FileDownloadController::download\";s:6:\"scheme\";s:7:\"private\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"scheme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/system/files(?:/(?P<scheme>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"scheme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/system/files\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"scheme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/system/files\";s:8:\"numParts\";i:3;}}',3),('system.file_system_settings','/admin/config/media/file-system','/admin/config/media/file-system',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/config/media/file-system\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\system\\Form\\FileSystemForm\";s:6:\"_title\";s:11:\"File system\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/config/media/file\\-system$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/config/media/file-system\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/config/media/file-system\";s:8:\"numParts\";i:4;}}',4),('system.image_toolkit_settings','/admin/config/media/image-toolkit','/admin/config/media/image-toolkit',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/media/image-toolkit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\system\\Form\\ImageToolkitForm\";s:6:\"_title\";s:13:\"Image toolkit\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/media/image\\-toolkit$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/media/image-toolkit\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/config/media/image-toolkit\";s:8:\"numParts\";i:4;}}',4),('system.js_asset','/sites/default/files/js/{file_name}','/sites/default/files/js/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/sites/default/files/js/{file_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"Drupal\\system\\Controller\\JsAssetController::deliver\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"file_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/sites/default/files/js/(?P<file_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"file_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/sites/default/files/js\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"file_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:25:\"/sites/default/files/js/%\";s:8:\"numParts\";i:5;}}',5),('system.linkset_settings','/admin/config/services/linkset','/admin/config/services/linkset',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/config/services/linkset\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:21:\"Menu Linkset Settings\";s:5:\"_form\";s:42:\"Drupal\\system\\Form\\MenuLinksetSettingsForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/admin/config/services/linkset$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/services/linkset\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/admin/config/services/linkset\";s:8:\"numParts\";i:4;}}',4),('system.logging_settings','/admin/config/development/logging','/admin/config/development/logging',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/development/logging\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:31:\"\\Drupal\\system\\Form\\LoggingForm\";s:6:\"_title\";s:18:\"Logging and errors\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/development/logging$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/development/logging\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/config/development/logging\";s:8:\"numParts\";i:4;}}',4),('system.modules_list','/admin/modules','/admin/modules',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/modules\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:6:\"Extend\";s:14:\"_title_context\";s:15:\"With components\";s:5:\"_form\";s:35:\"\\Drupal\\system\\Form\\ModulesListForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_no_big_pipe\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/modules$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/modules\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/modules\";s:8:\"numParts\";i:2;}}',2),('system.modules_list_confirm','/admin/modules/list/confirm','/admin/modules/list/confirm',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/modules/list/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\system\\Form\\ModulesListConfirmForm\";s:6:\"_title\";s:39:\"Some required modules must be installed\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/admin/modules/list/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/modules/list/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:27:\"/admin/modules/list/confirm\";s:8:\"numParts\";i:4;}}',4),('system.modules_list_non_stable_confirm','/admin/modules/list/confirm-non-stable','/admin/modules/list/confirm-non-stable',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/modules/list/confirm-non-stable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\system\\Form\\ModulesListNonStableConfirmForm\";s:6:\"_title\";s:18:\"Non-stable modules\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/modules/list/confirm\\-non\\-stable$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/admin/modules/list/confirm-non-stable\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:38:\"/admin/modules/list/confirm-non-stable\";s:8:\"numParts\";i:4;}}',4),('system.modules_uninstall','/admin/modules/uninstall','/admin/modules/uninstall',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/modules/uninstall\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\system\\Form\\ModulesUninstallForm\";s:6:\"_title\";s:9:\"Uninstall\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/modules/uninstall$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/modules/uninstall\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/modules/uninstall\";s:8:\"numParts\";i:3;}}',3),('system.modules_uninstall_confirm','/admin/modules/uninstall/confirm','/admin/modules/uninstall/confirm',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/modules/uninstall/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"\\Drupal\\system\\Form\\ModulesUninstallConfirmForm\";s:6:\"_title\";s:17:\"Confirm uninstall\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/modules/uninstall/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/modules/uninstall/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/modules/uninstall/confirm\";s:8:\"numParts\";i:4;}}',4),('system.performance_settings','/admin/config/development/performance','/admin/config/development/performance',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/development/performance\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\system\\Controller\\PerformanceController::build\";s:6:\"_title\";s:11:\"Performance\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/development/performance$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/development/performance\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/development/performance\";s:8:\"numParts\";i:4;}}',4),('system.php','/admin/reports/status/php','/admin/reports/status/php',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/reports/status/php\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\system\\Controller\\SystemInfoController::php\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/reports/status/php$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/reports/status/php\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/reports/status/php\";s:8:\"numParts\";i:4;}}',4),('system.prepare_modules_entity_uninstall','/admin/modules/uninstall/entity/{entity_type_id}','/admin/modules/uninstall/entity/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/modules/uninstall/entity/{entity_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:53:\"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm\";s:15:\"_title_callback\";s:64:\"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm::formTitle\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:18:\"administer modules\";s:14:\"_custom_access\";s:66:\"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm::checkAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/modules/uninstall/entity/(?P<entity_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/modules/uninstall/entity\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/modules/uninstall/entity/%\";s:8:\"numParts\";i:5;}}',5),('system.private_file_download','/system/files/{filepath}','/system/files/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/system/files/{filepath}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:47:\"\\Drupal\\system\\FileDownloadController::download\";}s:12:\"requirements\";a:2:{s:8:\"filepath\";s:2:\".+\";s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"filepath\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/system/files/(?P<filepath>.+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:2:\".+\";i:3;s:8:\"filepath\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/system/files\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"filepath\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:15:\"/system/files/%\";s:8:\"numParts\";i:3;}}',3),('system.regional_settings','/admin/config/regional/settings','/admin/config/regional/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/config/regional/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\system\\Form\\RegionalForm\";s:6:\"_title\";s:17:\"Regional settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/config/regional/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/config/regional/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/config/regional/settings\";s:8:\"numParts\";i:4;}}',4),('system.rss_feeds_settings','/admin/config/services/rss-publishing','/admin/config/services/rss-publishing',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/services/rss-publishing\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\system\\Form\\RssFeedsForm\";s:6:\"_title\";s:14:\"RSS publishing\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/services/rss\\-publishing$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/services/rss-publishing\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/services/rss-publishing\";s:8:\"numParts\";i:4;}}',4),('system.run_cron','/admin/reports/status/run-cron','/admin/reports/status/run-cron',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/reports/status/run-cron\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:42:\"\\Drupal\\system\\CronController::runManually\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/status/run\\-cron$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/reports/status/run-cron\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/admin/reports/status/run-cron\";s:8:\"numParts\";i:4;}}',4),('system.site_information_settings','/admin/config/system/site-information','/admin/config/system/site-information',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/system/site-information\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\system\\Form\\SiteInformationForm\";s:6:\"_title\";s:19:\"Basic site settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/system/site\\-information$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/system/site-information\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/system/site-information\";s:8:\"numParts\";i:4;}}',4),('system.site_maintenance_mode','/admin/config/development/maintenance','/admin/config/development/maintenance',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/development/maintenance\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\system\\Form\\SiteMaintenanceModeForm\";s:6:\"_title\";s:16:\"Maintenance mode\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:57:\"administer site configuration+administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/development/maintenance$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/development/maintenance\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/development/maintenance\";s:8:\"numParts\";i:4;}}',4),('system.status','/admin/reports/status','/admin/reports/status',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/reports/status\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\system\\Controller\\SystemInfoController::status\";s:6:\"_title\";s:13:\"Status report\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/reports/status$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/reports/status\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/reports/status\";s:8:\"numParts\";i:3;}}',3),('system.temporary','/system/temporary','/system/temporary',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/system/temporary\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:47:\"\\Drupal\\system\\FileDownloadController::download\";s:6:\"scheme\";s:9:\"temporary\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/system/temporary$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/system/temporary\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:17:\"/system/temporary\";s:8:\"numParts\";i:2;}}',2),('system.themes_page','/admin/appearance','/admin/appearance',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/admin/appearance\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:10:\"Appearance\";s:11:\"_controller\";s:54:\"\\Drupal\\system\\Controller\\SystemController::themesPage\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer themes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/admin/appearance$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/appearance\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:17:\"/admin/appearance\";s:8:\"numParts\";i:2;}}',2),('system.theme_install','/admin/appearance/install','/admin/appearance/install',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/appearance/install\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:50:\"\\Drupal\\system\\Controller\\ThemeController::install\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:17:\"administer themes\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/appearance/install$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/appearance/install\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/appearance/install\";s:8:\"numParts\";i:3;}}',3),('system.theme_settings','/admin/appearance/settings','/admin/appearance/settings',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/appearance/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\system\\Form\\ThemeSettingsForm\";s:6:\"_title\";s:19:\"Appearance settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer themes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/appearance/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/appearance/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:26:\"/admin/appearance/settings\";s:8:\"numParts\";i:3;}}',3),('system.theme_settings_theme','/admin/appearance/settings/{theme}','/admin/appearance/settings/%',14,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/appearance/settings/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\system\\Form\\ThemeSettingsForm\";s:15:\"_title_callback\";s:21:\"theme_handler:getName\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer themes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/appearance/settings/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/appearance/settings\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:28:\"/admin/appearance/settings/%\";s:8:\"numParts\";i:4;}}',4),('system.theme_set_default','/admin/appearance/default','/admin/appearance/default',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/appearance/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:20:\"Set as default theme\";s:11:\"_controller\";s:58:\"\\Drupal\\system\\Controller\\ThemeController::setDefaultTheme\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:17:\"administer themes\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/appearance/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/appearance/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/appearance/default\";s:8:\"numParts\";i:3;}}',3),('system.theme_uninstall','/admin/appearance/uninstall','/admin/appearance/uninstall',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/appearance/uninstall\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\ThemeController::uninstall\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:17:\"administer themes\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/admin/appearance/uninstall$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/appearance/uninstall\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/admin/appearance/uninstall\";s:8:\"numParts\";i:3;}}',3),('system.timezone','/system/timezone/{abbreviation}/{offset}/{is_daylight_saving_time}','/system/timezone',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/system/timezone/{abbreviation}/{offset}/{is_daylight_saving_time}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:57:\"\\Drupal\\system\\Controller\\TimezoneController::getTimezone\";s:12:\"abbreviation\";s:0:\"\";s:6:\"offset\";i:-1;s:23:\"is_daylight_saving_time\";N;}s:12:\"requirements\";a:4:{s:7:\"_access\";s:4:\"TRUE\";s:12:\"abbreviation\";s:14:\"0|([A-Z]{3,5})\";s:6:\"offset\";s:6:\"\\-?\\d+\";s:23:\"is_daylight_saving_time\";s:7:\"\\-1|0|1\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"abbreviation\";i:1;s:6:\"offset\";i:2;s:23:\"is_daylight_saving_time\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:129:\"{^/system/timezone(?:/(?P<abbreviation>0|(?:[A-Z]{3,5}))(?:/(?P<offset>\\-?\\d+)(?:/(?P<is_daylight_saving_time>\\-1|0|1))?)?)?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:7:\"\\-1|0|1\";i:3;s:23:\"is_daylight_saving_time\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"\\-?\\d+\";i:3;s:6:\"offset\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:16:\"0|(?:[A-Z]{3,5})\";i:3;s:12:\"abbreviation\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/system/timezone\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"abbreviation\";i:1;s:6:\"offset\";i:2;s:23:\"is_daylight_saving_time\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:16:\"/system/timezone\";s:8:\"numParts\";i:5;}}',5),('tb_megamenu.admin.save','/admin/structure/tb-megamenu/save/{tb_megamenu}','/admin/structure/tb-megamenu/save/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/structure/tb-megamenu/save/{tb_megamenu}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:34:\"Save configuration of TB Mega Menu\";s:11:\"_controller\";s:75:\"\\Drupal\\tb_megamenu\\Controller\\TBMegaMenuAdminController::saveConfiguration\";}s:12:\"requirements\";a:3:{s:11:\"_csrf_token\";s:4:\"TRUE\";s:11:\"_permission\";s:22:\"administer tb_megamenu\";s:11:\"tb_megamenu\";s:14:\"[a-zA-Z0-9_-]+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:17:\"access_check.csrf\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"tb_megamenu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/admin/structure/tb\\-megamenu/save/(?P<tb_megamenu>[a-zA-Z0-9_-]+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:14:\"[a-zA-Z0-9_-]+\";i:3;s:11:\"tb_megamenu\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/structure/tb-megamenu/save\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"tb_megamenu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:35:\"/admin/structure/tb-megamenu/save/%\";s:8:\"numParts\";i:5;}}',5),('toolbar.subtrees','/toolbar/subtrees/{hash}','/toolbar/subtrees/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/toolbar/subtrees/{hash}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\toolbar\\Controller\\ToolbarController::subtreesAjax\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:64:\"\\Drupal\\toolbar\\Controller\\ToolbarController::checkSubTreeAccess\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"hash\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/toolbar/subtrees/(?P<hash>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"hash\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/toolbar/subtrees\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"hash\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:19:\"/toolbar/subtrees/%\";s:8:\"numParts\";i:3;}}',3),('update.confirmation_page','/admin/update/ready','/admin/update/ready',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/update/ready\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:31:\"\\Drupal\\update\\Form\\UpdateReady\";s:6:\"_title\";s:15:\"Ready to update\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/update/ready$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/update/ready\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/update/ready\";s:8:\"numParts\";i:3;}}',3),('update.manual_status','/admin/reports/updates/check','/admin/reports/updates/check',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/updates/check\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:19:\"Manual update check\";s:11:\"_controller\";s:64:\"\\Drupal\\update\\Controller\\UpdateController::updateStatusManually\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/reports/updates/check$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/updates/check\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/reports/updates/check\";s:8:\"numParts\";i:4;}}',4),('update.module_update','/admin/modules/update','/admin/modules/update',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/modules/update\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\update\\Form\\UpdateManagerUpdate\";s:6:\"_title\";s:6:\"Update\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/modules/update$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/modules/update\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/modules/update\";s:8:\"numParts\";i:3;}}',3),('update.report_update','/admin/reports/updates/update','/admin/reports/updates/update',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/reports/updates/update\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\update\\Form\\UpdateManagerUpdate\";s:6:\"_title\";s:6:\"Update\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/updates/update$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/reports/updates/update\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/reports/updates/update\";s:8:\"numParts\";i:4;}}',4),('update.settings','/admin/reports/updates/settings','/admin/reports/updates/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/reports/updates/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:33:\"\\Drupal\\update\\UpdateSettingsForm\";s:6:\"_title\";s:23:\"Update Manager settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/updates/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/reports/updates/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/reports/updates/settings\";s:8:\"numParts\";i:4;}}',4),('update.status','/admin/reports/updates','/admin/reports/updates',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/reports/updates\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\update\\Controller\\UpdateController::updateStatus\";s:6:\"_title\";s:17:\"Available updates\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/reports/updates$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/reports/updates\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/reports/updates\";s:8:\"numParts\";i:3;}}',3),('update.theme_update','/admin/appearance/update','/admin/appearance/update',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/appearance/update\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\update\\Form\\UpdateManagerUpdate\";s:6:\"_title\";s:6:\"Update\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/appearance/update$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/appearance/update\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/appearance/update\";s:8:\"numParts\";i:3;}}',3),('user.admin_create','/admin/people/create','/admin/people/create',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/people/create\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"user.register\";s:6:\"_title\";s:8:\"Add user\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:4:\"user\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/people/create$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/people/create\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/people/create\";s:8:\"numParts\";i:3;}}',3),('user.admin_index','/admin/config/people','/admin/config/people',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/config/people\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:6:\"People\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/config/people$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/config/people\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/config/people\";s:8:\"numParts\";i:3;}}',3),('user.admin_permissions','/admin/people/permissions','/admin/people/permissions',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/people/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\user\\Form\\UserPermissionsForm\";s:6:\"_title\";s:11:\"Permissions\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/people/permissions$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/people/permissions\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/people/permissions\";s:8:\"numParts\";i:3;}}',3),('user.admin_permissions.module','/admin/people/permissions/module/{modules}','/admin/people/permissions/module/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/people/permissions/module/{modules}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\user\\Form\\UserPermissionsModuleSpecificForm\";s:6:\"_title\";s:18:\"Module Permissions\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:22:\"administer permissions\";s:7:\"modules\";s:16:\"[a-z][a-z0-9_,]*\";s:14:\"_custom_access\";s:59:\"\\Drupal\\user\\Form\\UserPermissionsModuleSpecificForm::access\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"modules\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/admin/people/permissions/module/(?P<modules>[a-z][a-z0-9_,]*)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:16:\"[a-z][a-z0-9_,]*\";i:3;s:7:\"modules\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/people/permissions/module\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"modules\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:34:\"/admin/people/permissions/module/%\";s:8:\"numParts\";i:5;}}',5),('user.cancel_confirm','/user/{user}/cancel/confirm/{timestamp}/{hashed_pass}','/user/%/cancel/confirm',11,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/user/{user}/cancel/confirm/{timestamp}/{hashed_pass}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:28:\"Confirm account cancellation\";s:11:\"_controller\";s:53:\"\\Drupal\\user\\Controller\\UserController::confirmCancel\";s:9:\"timestamp\";i:0;s:11:\"hashed_pass\";s:0:\"\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"user.delete\";s:4:\"user\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"user\";i:1;s:9:\"timestamp\";i:2;s:11:\"hashed_pass\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:97:\"{^/user/(?P<user>\\d+)/cancel/confirm(?:/(?P<timestamp>[^/]++)(?:/(?P<hashed_pass>[^/]++))?)?$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"hashed_pass\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"timestamp\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/cancel/confirm\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"user\";i:1;s:9:\"timestamp\";i:2;s:11:\"hashed_pass\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:11;s:14:\"patternOutline\";s:22:\"/user/%/cancel/confirm\";s:8:\"numParts\";i:6;}}',6),('user.edit','/user/edit','/user/edit',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/user/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:52:\"\\Drupal\\user\\Controller\\UserController::userEditPage\";s:6:\"_title\";s:12:\"Edit account\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/user/edit$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/user/edit\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:10:\"/user/edit\";s:8:\"numParts\";i:2;}}',2),('user.login','/user/login','/user/login',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/user/login\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:31:\"\\Drupal\\user\\Form\\UserLoginForm\";s:6:\"_title\";s:6:\"Log in\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/user/login$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/login\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/user/login\";s:8:\"numParts\";i:2;}}',2),('user.login.http','/user/login','/user/login',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/user/login\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:59:\"\\Drupal\\user\\Controller\\UserAuthenticationController::login\";}s:12:\"requirements\";a:2:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/user/login$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/login\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/user/login\";s:8:\"numParts\";i:2;}}',2),('user.login_status.http','/user/login_status','/user/login_status',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/user/login_status\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:65:\"\\Drupal\\user\\Controller\\UserAuthenticationController::loginStatus\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/user/login_status$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/user/login_status\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:18:\"/user/login_status\";s:8:\"numParts\";i:2;}}',2),('user.logout','/user/logout','/user/logout',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/user/logout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:46:\"\\Drupal\\user\\Controller\\UserController::logout\";}s:12:\"requirements\";a:2:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:24:\"_csrf_confirm_form_route\";s:19:\"user.logout.confirm\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:30:\"access_check.user.login_status\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/user/logout$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/user/logout\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/user/logout\";s:8:\"numParts\";i:2;}}',2),('user.logout.confirm','/user/logout/confirm','/user/logout/confirm',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/user/logout/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:35:\"\\Drupal\\user\\Form\\UserLogoutConfirm\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/user/logout/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/user/logout/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/user/logout/confirm\";s:8:\"numParts\";i:3;}}',3),('user.logout.http','/user/logout','/user/logout',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/user/logout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:60:\"\\Drupal\\user\\Controller\\UserAuthenticationController::logout\";}s:12:\"requirements\";a:3:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:30:\"access_check.user.login_status\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/user/logout$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/user/logout\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/user/logout\";s:8:\"numParts\";i:2;}}',2),('user.multiple_cancel_confirm','/admin/people/cancel','/admin/people/cancel',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/people/cancel\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\user\\Form\\UserMultipleCancelConfirm\";s:6:\"_title\";s:11:\"Cancel user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer users\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/people/cancel$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/people/cancel\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/people/cancel\";s:8:\"numParts\";i:3;}}',3),('user.page','/user','/user',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:5:\"/user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\user\\Controller\\UserController::userPage\";s:6:\"_title\";s:10:\"My account\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:12:\"{^/user$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:5:\"/user\";s:8:\"numParts\";i:1;}}',1),('user.pass','/user/password','/user/password',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/user/password\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\user\\Form\\UserPasswordForm\";s:6:\"_title\";s:19:\"Reset your password\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/user/password$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/user/password\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/user/password\";s:8:\"numParts\";i:2;}}',2),('user.pass.http','/user/password','/user/password',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/user/password\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:67:\"\\Drupal\\user\\Controller\\UserAuthenticationController::resetPassword\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/user/password$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/user/password\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/user/password\";s:8:\"numParts\";i:2;}}',2),('user.register','/user/register','/user/register',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/user/register\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"user.register\";s:6:\"_title\";s:18:\"Create new account\";}s:12:\"requirements\";a:1:{s:21:\"_access_user_register\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.user.register\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/user/register$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/user/register\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/user/register\";s:8:\"numParts\";i:2;}}',2),('user.reset','/user/reset/{uid}/{timestamp}/{hash}','/user/reset/%/%/%',24,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/user/reset/{uid}/{timestamp}/{hash}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\user\\Controller\\UserController::resetPass\";s:6:\"_title\";s:14:\"Reset password\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/user/reset/(?P<uid>[^/]++)/(?P<timestamp>[^/]++)/(?P<hash>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"hash\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"timestamp\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"uid\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/reset\";}}s:9:\"path_vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:24;s:14:\"patternOutline\";s:17:\"/user/reset/%/%/%\";s:8:\"numParts\";i:5;}}',5),('user.reset.form','/user/reset/{uid}','/user/reset/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/user/reset/{uid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\user\\Controller\\UserController::getResetPassForm\";s:6:\"_title\";s:14:\"Reset password\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:3:\"uid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/user/reset/(?P<uid>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"uid\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/reset\";}}s:9:\"path_vars\";a:1:{i:0;s:3:\"uid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:13:\"/user/reset/%\";s:8:\"numParts\";i:3;}}',3),('user.reset.login','/user/reset/{uid}/{timestamp}/{hash}/login','/user/reset/%/%/%/login',49,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/user/reset/{uid}/{timestamp}/{hash}/login\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\user\\Controller\\UserController::resetPassLogin\";s:6:\"_title\";s:14:\"Reset password\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/user/reset/(?P<uid>[^/]++)/(?P<timestamp>[^/]++)/(?P<hash>[^/]++)/login$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/login\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"hash\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"timestamp\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"uid\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/reset\";}}s:9:\"path_vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:49;s:14:\"patternOutline\";s:23:\"/user/reset/%/%/%/login\";s:8:\"numParts\";i:6;}}',6),('user.role.settings','/admin/people/role-settings','/admin/people/role-settings',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/people/role-settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\user\\Form\\RoleSettingsForm\";s:6:\"_title\";s:13:\"Role settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/people/role\\-settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/people/role-settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/admin/people/role-settings\";s:8:\"numParts\";i:3;}}',3),('user.role_add','/admin/people/roles/add','/admin/people/roles/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/admin/people/roles/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"user_role.default\";s:6:\"_title\";s:8:\"Add role\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:30:\"{^/admin/people/roles/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/admin/people/roles/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:23:\"/admin/people/roles/add\";s:8:\"numParts\";i:4;}}',4),('user.well-known.change_password','/.well-known/change-password','/.well-known/change-password',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/.well-known/change-password\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"\\Drupal\\user\\Controller\\UserController::userEditPage\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/\\.well\\-known/change\\-password$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/.well-known/change-password\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:28:\"/.well-known/change-password\";s:8:\"numParts\";i:2;}}',2),('view.block_content.page_1','/admin/content/block','/admin/content/block',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"block_content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:20:\"access block library\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/block\";s:8:\"numParts\";i:3;}}',3),('view.comment.page_published','/admin/content/comment','/admin/content/comment',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/content/comment\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"comment\";s:10:\"display_id\";s:14:\"page_published\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"administer comments\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/content/comment$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/content/comment\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/content/comment\";s:8:\"numParts\";i:3;}}',3),('view.comment.page_unapproved','/admin/content/comment/approval','/admin/content/comment/approval',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/content/comment/approval\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"comment\";s:10:\"display_id\";s:15:\"page_unapproved\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"administer comments\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/content/comment/approval$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/content/comment/approval\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/content/comment/approval\";s:8:\"numParts\";i:4;}}',4),('view.content.page_1','/admin/content','/admin/content',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:23:\"access content overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/content\";s:8:\"numParts\";i:2;}}',2),('view.files.page_1','/admin/content/files','/admin/content/files',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/files\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"files\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access files overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/files$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/files\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/files\";s:8:\"numParts\";i:3;}}',3),('view.files.page_2','/admin/content/files/usage/{arg_0}','/admin/content/files/usage/%',30,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/content/files/usage/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"files\";s:10:\"display_id\";s:6:\"page_2\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access files overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/content/files/usage/(?P<arg_0>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/content/files/usage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/content/files/usage/%\";s:8:\"numParts\";i:5;}}',5),('view.frontpage.feed_1','/rss.xml','/rss.xml',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:8:\"/rss.xml\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:9:\"frontpage\";s:10:\"display_id\";s:6:\"feed_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"feed\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Feed\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:16:\"{^/rss\\.xml$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/rss.xml\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:8:\"/rss.xml\";s:8:\"numParts\";i:1;}}',1),('view.frontpage.page_1','/node','/node',1,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:5:\"/node\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:9:\"frontpage\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:14:\"access content\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:12:\"{^/node$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:5:\"/node\";s:8:\"numParts\";i:1;}}',1),('view.media.media_page_list','/admin/content/media','/admin/content/media',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/media\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"media\";s:10:\"display_id\";s:15:\"media_page_list\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access media overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/media$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/media\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/media\";s:8:\"numParts\";i:3;}}',3),('view.media_library.page','/admin/content/media-grid','/admin/content/media-grid',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/content/media-grid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"media_library\";s:10:\"display_id\";s:4:\"page\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access media overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/content/media\\-grid$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/content/media-grid\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/content/media-grid\";s:8:\"numParts\";i:3;}}',3),('view.media_library.widget','/admin/content/media-widget/{arg_0}','/admin/content/media-widget',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/content/media-widget/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:6:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"media_library\";s:10:\"display_id\";s:6:\"widget\";s:30:\"_view_display_show_admin_links\";b:1;s:5:\"arg_0\";N;}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:10:\"view media\";s:7:\"_format\";s:4:\"html\";s:14:\"_custom_access\";s:36:\"media_library.ui_builder:checkAccess\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/content/media\\-widget(?:/(?P<arg_0>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/content/media-widget\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/admin/content/media-widget\";s:8:\"numParts\";i:4;}}',4),('view.media_library.widget_table','/admin/content/media-widget-table/{arg_0}','/admin/content/media-widget-table',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/content/media-widget-table/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:6:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"media_library\";s:10:\"display_id\";s:12:\"widget_table\";s:30:\"_view_display_show_admin_links\";b:1;s:5:\"arg_0\";N;}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:10:\"view media\";s:7:\"_format\";s:4:\"html\";s:14:\"_custom_access\";s:36:\"media_library.ui_builder:checkAccess\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/content/media\\-widget\\-table(?:/(?P<arg_0>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/content/media-widget-table\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:33:\"/admin/content/media-widget-table\";s:8:\"numParts\";i:4;}}',4),('view.taxonomy_term.feed_1','/taxonomy/term/{arg_0}/feed','/taxonomy/term/%/feed',13,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/taxonomy/term/{arg_0}/feed\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"taxonomy_term\";s:10:\"display_id\";s:6:\"feed_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"feed\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Feed\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/taxonomy/term/(?P<arg_0>[^/]++)/feed$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/feed\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:21:\"/taxonomy/term/%/feed\";s:8:\"numParts\";i:4;}}',4),('view.taxonomy_term.page_1','/taxonomy/term/{arg_0}','/taxonomy/term/%',6,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/taxonomy/term/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"taxonomy_term\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:14:\"access content\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/taxonomy/term/(?P<arg_0>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:16:\"/taxonomy/term/%\";s:8:\"numParts\";i:3;}}',3),('view.user_admin_people.page_1','/admin/people','/admin/people',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/admin/people\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:17:\"user_admin_people\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:16:\"administer users\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/admin/people$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/admin/people\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/admin/people\";s:8:\"numParts\";i:2;}}',2),('view.watchdog.page','/admin/reports/dblog','/admin/reports/dblog',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/reports/dblog\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:8:\"watchdog\";s:10:\"display_id\";s:4:\"page\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"access site reports\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/reports/dblog$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/reports/dblog\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/reports/dblog\";s:8:\"numParts\";i:3;}}',3),('views.ajax','/views/ajax','/views/ajax',3,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/views/ajax\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:53:\"\\Drupal\\views\\Controller\\ViewAjaxController::ajaxView\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/views/ajax$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/views/ajax\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/views/ajax\";s:8:\"numParts\";i:2;}}',2),('views_ui.add','/admin/structure/views/add','/admin/structure/views/add',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/structure/views/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:8:\"view.add\";s:6:\"_title\";s:8:\"Add view\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:4:\"view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/structure/views/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/views/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/structure/views/add\";s:8:\"numParts\";i:4;}}',4),('views_ui.autocomplete','/admin/views/ajax/autocomplete/tag','/admin/views/ajax/autocomplete/tag',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/views/ajax/autocomplete/tag\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::autocompleteTag\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/views/ajax/autocomplete/tag$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/views/ajax/autocomplete/tag\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/views/ajax/autocomplete/tag\";s:8:\"numParts\";i:5;}}',5),('views_ui.form_add_handler','/admin/structure/views/{js}/add-handler/{view}/{display_id}/{type}','/admin/structure/views/%/add-handler/%/%/%',232,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/views/{js}/add-handler/{view}/{display_id}/{type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:46:\"\\Drupal\\views_ui\\Form\\Ajax\\AddHandler::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/views/(?P<js>nojs|ajax)/add\\-handler/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/add-handler\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:232;s:14:\"patternOutline\";s:42:\"/admin/structure/views/%/add-handler/%/%/%\";s:8:\"numParts\";i:8;}}',8),('views_ui.form_analyze','/admin/structure/views/{js}/analyze/{view}/{display_id}','/admin/structure/views/%/analyze/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/views/{js}/analyze/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:43:\"\\Drupal\\views_ui\\Form\\Ajax\\Analyze::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/views/(?P<js>nojs|ajax)/analyze/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/analyze\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:36:\"/admin/structure/views/%/analyze/%/%\";s:8:\"numParts\";i:7;}}',7),('views_ui.form_display','/admin/structure/views/{js}/display/{view}/{display_id}/{type}','/admin/structure/views/%/display/%/%/%',232,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/views/{js}/display/{view}/{display_id}/{type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:43:\"\\Drupal\\views_ui\\Form\\Ajax\\Display::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:112:\"{^/admin/structure/views/(?P<js>nojs|ajax)/display/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:232;s:14:\"patternOutline\";s:38:\"/admin/structure/views/%/display/%/%/%\";s:8:\"numParts\";i:8;}}',8),('views_ui.form_edit_details','/admin/structure/views/{js}/edit-details/{view}/{display_id}','/admin/structure/views/%/edit-details/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/views/{js}/edit-details/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:47:\"\\Drupal\\views_ui\\Form\\Ajax\\EditDetails::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/views/(?P<js>nojs|ajax)/edit\\-details/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/edit-details\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:41:\"/admin/structure/views/%/edit-details/%/%\";s:8:\"numParts\";i:7;}}',7),('views_ui.form_handler','/admin/structure/views/{js}/handler/{view}/{display_id}/{type}/{id}','/admin/structure/views/%/handler/%/%/%/%',464,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/views/{js}/handler/{view}/{display_id}/{type}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:49:\"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandler::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:127:\"{^/admin/structure/views/(?P<js>nojs|ajax)/handler/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/handler\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:464;s:14:\"patternOutline\";s:40:\"/admin/structure/views/%/handler/%/%/%/%\";s:8:\"numParts\";i:9;}}',9),('views_ui.form_handler_extra','/admin/structure/views/{js}/handler-extra/{view}/{display_id}/{type}/{id}','/admin/structure/views/%/handler-extra/%/%/%/%',464,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/views/{js}/handler-extra/{view}/{display_id}/{type}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:54:\"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandlerExtra::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/views/(?P<js>nojs|ajax)/handler\\-extra/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/handler-extra\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:464;s:14:\"patternOutline\";s:46:\"/admin/structure/views/%/handler-extra/%/%/%/%\";s:8:\"numParts\";i:9;}}',9),('views_ui.form_handler_group','/admin/structure/views/{js}/handler-group/{view}/{display_id}/{type}/{id}','/admin/structure/views/%/handler-group/%/%/%/%',464,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/views/{js}/handler-group/{view}/{display_id}/{type}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandlerGroup::getForm\";s:10:\"form_state\";N;}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/views/(?P<js>nojs|ajax)/handler\\-group/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/handler-group\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:464;s:14:\"patternOutline\";s:46:\"/admin/structure/views/%/handler-group/%/%/%/%\";s:8:\"numParts\";i:9;}}',9),('views_ui.form_rearrange','/admin/structure/views/{js}/rearrange/{view}/{display_id}/{type}','/admin/structure/views/%/rearrange/%/%/%',232,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/views/{js}/rearrange/{view}/{display_id}/{type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:45:\"\\Drupal\\views_ui\\Form\\Ajax\\Rearrange::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:114:\"{^/admin/structure/views/(?P<js>nojs|ajax)/rearrange/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/rearrange\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:232;s:14:\"patternOutline\";s:40:\"/admin/structure/views/%/rearrange/%/%/%\";s:8:\"numParts\";i:8;}}',8),('views_ui.form_rearrange_filter','/admin/structure/views/{js}/rearrange-filter/{view}/{display_id}','/admin/structure/views/%/rearrange-filter/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/views/{js}/rearrange-filter/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Form\\Ajax\\RearrangeFilter::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/views/(?P<js>nojs|ajax)/rearrange\\-filter/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/rearrange-filter\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:45:\"/admin/structure/views/%/rearrange-filter/%/%\";s:8:\"numParts\";i:7;}}',7),('views_ui.form_reorder_displays','/admin/structure/views/{js}/reorder-displays/{view}/{display_id}','/admin/structure/views/%/reorder-displays/%/%',116,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/views/{js}/reorder-displays/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Form\\Ajax\\ReorderDisplays::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/views/(?P<js>nojs|ajax)/reorder\\-displays/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/reorder-displays\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:45:\"/admin/structure/views/%/reorder-displays/%/%\";s:8:\"numParts\";i:7;}}',7),('views_ui.reports_fields','/admin/reports/fields/views-fields','/admin/reports/fields/views-fields',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/reports/fields/views-fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::reportFields\";s:6:\"_title\";s:13:\"Used in views\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/admin/reports/fields/views\\-fields$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/reports/fields/views-fields\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/reports/fields/views-fields\";s:8:\"numParts\";i:4;}}',4),('views_ui.reports_plugins','/admin/reports/views-plugins','/admin/reports/views-plugins',7,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/views-plugins\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::reportPlugins\";s:6:\"_title\";s:13:\"Views plugins\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/views\\-plugins$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/views-plugins\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/reports/views-plugins\";s:8:\"numParts\";i:3;}}',3),('views_ui.settings_advanced','/admin/structure/views/settings/advanced','/admin/structure/views/settings/advanced',31,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/views/settings/advanced\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\views_ui\\Form\\AdvancedSettingsForm\";s:6:\"_title\";s:23:\"Advanced Views settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/views/settings/advanced$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/views/settings/advanced\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/views/settings/advanced\";s:8:\"numParts\";i:5;}}',5),('views_ui.settings_basic','/admin/structure/views/settings','/admin/structure/views/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/structure/views/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\views_ui\\Form\\BasicSettingsForm\";s:6:\"_title\";s:14:\"Views settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/views/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/views/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/structure/views/settings\";s:8:\"numParts\";i:4;}}',4),('views_year_filter.settings_form','/admin/config/views-year-filter/settings','/admin/config/views-year-filter/settings',15,_binary 'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/config/views-year-filter/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\views_year_filter\\Form\\SettingsForm\";s:6:\"_title\";s:26:\"Views year filter settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/admin/config/views\\-year\\-filter/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/config/views-year-filter/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:40:\"/admin/config/views-year-filter/settings\";s:8:\"numParts\";i:4;}}',4);
/*!40000 ALTER TABLE `router` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `search_dataset`
--

DROP TABLE IF EXISTS `search_dataset`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `search_dataset` (
  `sid` int unsigned NOT NULL DEFAULT '0' COMMENT 'Search item ID, e.g. node ID for nodes.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "languages".langcode of the item variant.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'Type of item, e.g. node.',
  `data` longtext NOT NULL COMMENT 'List of space-separated words from the item.',
  `reindex` int unsigned NOT NULL DEFAULT '0' COMMENT 'Set to force node reindexing.',
  PRIMARY KEY (`sid`,`langcode`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores items that will be searched.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `search_dataset`
--

LOCK TABLES `search_dataset` WRITE;
/*!40000 ALTER TABLE `search_dataset` DISABLE KEYS */;
INSERT INTO `search_dataset` VALUES (1,'en','help_search',' exporting your complete site configuration goal create and download an archive containing all your site s configuration exported as yaml files see managing and deploying configuration for more information about configuration steps in the manage administrative menu navigate to configuration   development   configuration synchronization   export  click export and save the archive file  ',1729064404),(1,'en','node_search',' getting started ept page buider getting started ept page buider demo page supercharge your drupal site with extra paragraph types ept modules flexible reusable and customizable content layouts for a seamless editing experience ept documentation download paragraphid1 paddingtop 40px important paddingright 20px important marginbottom 40px important paddingbottom 40px important paddingleft 20px important eptwidthdefault eptcontainer maxwidth 960px margin  auto paragraphid1 eptbasicbutton color ffffff backgroundcolor 0d77b5 paragraphid1 eptbasicbutton hover color ffffff backgroundcolor 0a5987 paragraphid1 eptbasicbutton2 color ffffff paragraphid1 eptbasicbutton2 hover media screen and maxwidth 640px paragraphid1 eptherocontainer herocol1 width 100 paragraphid1 eptherocontainer herocol2 width 100 paragraphid1 eptherocontainer flexdirection column gap  media screen and maxwidth 640px paragraphid1 eptherocontainer herocol1 order 1 paragraphid1 eptherocontainer herocol2 order 2 paragraphid1 after background rgba 6 content display block width 100 height 100 position absolute zindex 1 left  top  zindex 5 objectfit cover paragraphid1 position relative paragraphid1 eptcontainer position relative zindex 6  why choose ept  ept modules provide drupal users with an extended range of paragraph types offering you complete control over content presentation whether you re building landing pages blogs or portfolios ept makes it easier to break away from rigid templates and embrace flexibility customize each type to suit your unique needs and create reusable components that reduce development time paragraphid2 paddingright 20px important marginbottom 20px important paddingleft 20px important eptwidthsmall eptcontainer maxwidth 768px margin  auto    install ept modules download and install the extra paragraph types modules via drupal s module directory configure paragraph types enable and configure paragraph types based on your project needs start creating build dynamic content layouts with ease and empower your content team to take control of the website paragraphid6 paddingtop 20px important paddingright 20px important paddingbottom 60px important paddingleft 20px important background url http eptdemolocal sites default files 202410 bgimage1webp center center norepeat backgroundposition bottom left backgroundsize 300px 300px eptedgetoedge overflow hidden width 100vw maxwidth 100vw marginleft calc 50vw 50 important marginright calc 50vw 50 important objectfit cover body overflowx hidden eptwidthdefault eptcontainer maxwidth 960px margin  auto  what are drupal paragraphs  drupal paragraphs is a powerful module that allows you to create reusable content components called paragraph types these flexible content blocks let you design rich dynamic layouts without relying on a fixed template structure with paragraphs content creators can mix and match various elements text images videos and more to build custom layouts 721320 websites use drupal 238556 usage statistics for paragraphs module paragraphid9 paddingtop 40px important paddingright 20px important marginbottom 40px important paddingbottom 40px important paddingleft 20px important backgroundcolor 30e30 eptedgetoedge overflow hidden width 100vw maxwidth 100vw marginleft calc 50vw 50 important marginright calc 50vw 50 important objectfit cover body overflowx hidden eptwidthdefault eptcontainer maxwidth 960px margin  auto  you can download a bunch of ept modules from drupalorg image image image image image image image image image image image paragraphid10 paddingtop 40px important paddingright 20px important paddingbottom 40px important paddingleft 20px important background url http eptdemolocal sites default files 2024108af0c4402152467886c795ee5c055211jpg center center norepeat backgroundposition bottom right backgroundsize 400px 400px eptedgetoedge overflow hidden width 100vw maxwidth 100vw marginleft calc 50vw 50 important marginright calc 50vw 50 important objectfit cover body overflowx hidden eptwidthdefault eptcontainer maxwidth 960px margin  auto  ept modules uses glightbox for image video in popups image ept modules come with seamless integration of the glightbox javascript plugin providing a modern and sleek lightbox experience for media content whether it s images videos or galleries glightbox ensures that your media is displayed beautifully with smooth animations and responsive design this powerful combination enhances the user experience making your content more interactive and visually engaging glightbox module glightbox site paragraphid11 paddingtop 40px important paddingright 20px important marginbottom 40px important paddingbottom 40px important paddingleft 20px important eptedgetoedge overflow hidden width 100vw maxwidth 100vw marginleft calc 50vw 50 important marginright calc 50vw 50 important objectfit cover body overflowx hidden eptwidthdefault eptcontainer maxwidth 960px margin  auto paragraphid11 eptbasicbutton color ffffff backgroundcolor 0d77b5 paragraphid11 eptbasicbutton hover paragraphid11 eptbasicbutton2 color ffffff paragraphid11 eptbasicbutton2 hover color eeeeee media screen and maxwidth 640px paragraphid11 eptparagraphctacontent column1 width 100 paragraphid11 eptparagraphctacontent column2 width 100 paragraphid11 eptparagraphctacontent flexdirection column gap  paragraphid11 eptparagraphctacontent column1 order 2 paragraphid11 eptparagraphctacontent column2 order 1 media screen and maxwidth 640px paragraphid11 eptparagraphctacontent column1 order 1 paragraphid11 eptparagraphctacontent column2 order 2  each ept module has rich settings dom box settings margin padding border for each component you can also set type of border and color background color image or video each component has settings for background color image video image and videos settings allows to adjust options via usual drupal form settings for javascript plugins you can set up options for javascript plugins from the same configuration form for component paragraphid30 paddingtop 20px important paddingright 20px important marginbottom 10px important paddingbottom 40px important paddingleft 20px important eptwidthdefault eptcontainer maxwidth 960px margin  auto  you can start from one module install any number of ebt ept modules for blocks paragraphs you need hockey club paragraphid12 paddingtop 40px important paddingright 20px important marginbottom 40px important paddingbottom 40px important paddingleft 20px important eptwidthdefault eptcontainer maxwidth 960px margin  auto  find and download your extra paragraph type ept counter ept text ept tiles ept slick slider ept call to action ept image gallery ept tabs ept accordion faq ept carousel ept quote paragraphid23 paddingtop 40px important paddingright 20px important marginbottom 40px important paddingbottom 40px important paddingleft 20px important background url http eptdemolocal sites default files 2024104950565daf4845efbe68c27550a02da9webp center center norepeat backgroundsize cover important backgroundposition center left backgroundsize 300px 300px eptwidthdefault eptcontainer maxwidth 960px margin  auto  number of modules passoptionstojavascript 1 titlewrapper h2 striptags 1 styles twocolumns startval  prefix suffix decimalplaces  duration 2 usegrouping 1 separator comma useeasing 1 smarteasingthreshold 999 smarteasingamount 333 enablescrollspy 1 scrollspydelay  scrollspyonce  25 ept modules 25 ebt modules paragraphid26 paddingtop 40px important paddingright 20px important marginbottom 40px important paddingbottom 40px important paddingleft 20px important eptwidthxsmall eptcontainer maxwidth 640px margin  auto  ept and ebt modules  ept modules ept accordion faq ept basic button ept block ept bootstrap button ept call to action ept carousel ept columns container ept countdown ept counter ept image ept image gallery ept micromodal ept quote ept slick slider ept slideshow ept stats ept tabs ept text ept tiles ept timeline ept video ept video and image gallery ept views ept webform ept webform popup ebt modules ebt accordion faq ebt basic button ebt block ebt bootstrap button ebt call to action ebt carousel ebt columns ebt countdown ebt counter ebt image ebt image gallery ebt micromodal ebt quote ebt slick slider ebt slideshow ebt stats ebt tabs ebt text ebt tiles ebt timeline ebt video ebt video and image gallery ebt views ebt webform ebt webform popup paragraphid33 paddingtop 30px important paddingright 20px important marginbottom 30px important paddingbottom 30px important paddingleft 20px important backgroundcolor 30e30 eptwidthxsmall eptcontainer maxwidth 640px margin  auto  faq how to install extra paragraph types ept modules  you can install ept modules as usual drupal module download them with composer for example composer require drupal epttabs and then install ept module as usual download contributed modules using composer that s it all dependencies will be downloaded with composer automatically cool can i create my own ept ebt module  yes sure here is documentation for ept ebt modules  https drupalbookorg ept creatingneweptmodule in short ept module can be generated with drush command drush generate ept module then you can extend your new component as usual drupal paragraph type extending ebt settings form  it s for ebt block type just use ept instead of ebt  send feedback or idea for ept modules you can send me a message using any of the contact forms below or by following the link in the header or footer  linkedin drupalorg slack drupalbook paragraphid36 paddingtop 40px important paddingright 20px important marginbottom 40px important paddingbottom 20px important paddingleft 40px important eptwidthsmall eptcontainer maxwidth 768px margin  auto admin sun 10062024 2123  ',0),(2,'en','help_search',' exporting a single configuration item goal export a single configuration item to a file see managing and deploying configuration for more information about configuration steps in the manage administrative menu navigate to configuration   development   configuration synchronization   export   single item  select the configuration type that you want to export and then select the specific configuration name to export use your browser to copy the text in the box marked here is your configuration to the clipboard paste the copied text into a plaintext editor on your computer or other device and save it using the suggested file name below the text box  ',1729064404),(3,'en','help_search',' importing your complete site configuration goal import the complete configuration of your site from an archive file such as one that was previously exported see exporting your complete site configuration see managing and deploying configuration for more information about configuration steps in the manage administrative menu navigate to configuration   development   configuration synchronization   import  browse to find the configuration archive that you want to import click upload  your configuration archive will be unpacked and placed in the configuration synchronization directory and you will be redirected to the synchronize page review the differences between your uploaded configuration and the active configuration if any and click import all to import the changes  ',1729064404),(4,'en','help_search',' importing a single configuration item goal import a single configuration item in yaml format such as one that was previously exported see exporting a single configuration item see managing and deploying configuration for more information about configuration steps in the manage administrative menu navigate to configuration   development   configuration synchronization   import   single item  select the configuration type that you want to import on your computer or other device copy the yamlformat configuration that you want to import to the clipboard paste the clipboard text into the box labeled paste your configuration here  click import   ',1729064404),(5,'en','help_search',' managing the fields of contact forms goal add remove or rearrange the fields on personal and sitewide contact forms what are the fields on contact forms  both personal and sitewide contact forms will always have subject and message fields you can add additional fields for users to fill out if desired note that if you want to display other content on a form page such as text or images you can use a content block steps in the manage administrative menu navigate to structure   contact forms  click manage fields for the form you want to change the fields of and add or remove one or more fields on the form click manage form display to change the order or configuration of the fields on the form  ',1729064404),(6,'en','help_search',' configuring personal contact forms goal configure personal contact forms for registered users on the website steps in the manage administrative menu navigate to configuration   people   account settings  in the contact settings section check uncheck the box to enable disable the contact form for new user accounts click save configuration  in the manage administrative menu navigate to people   permissions  verify that permissions are correct for your site s roles including the generic anonymous user and authenticated user  in order to use personal contact forms users need both view user information  in the user section which enables them to view user profiles and use users personal contact forms  in the contact section which enables them to use contact forms if they can view user profiles click save permissions  the contact form will always have subject and message fields if you want to add more fields follow the steps in managing the fields of contact forms  ',1729064404),(7,'en','help_search',' creating a new contact form goal create a new sitewide contact form steps in the manage administrative menu navigate to structure   contact forms  click add contact form  fill in the label  title for the form  recipients  and optionally the other settings click save  you should see your new contact form in the table along with a link to view it the contact form will always have subject and message fields if you want to add more fields follow the steps in managing the fields of contact forms  ',1729064404),(8,'en','help_search',' managing contact forms what are contact forms  there are two different types of contact forms provided by the core contact module personal contact forms which allow users to contact other users on the site and sitewide contact forms which allow users to contact site managers or administrators a site can have more than one sitewide contact form each has its own fields to fill out recipients and url you can also change the fields that are shown on personal contact forms using the personal contact form site visitors can email registered users on your site by using the personal contact form without knowing or learning the email address of the recipient when a user with the correct permissions is viewing another user s profile the viewer will see a contact tab or link which leads to the personal contact form if the user whose profile is being viewed has their personal contact form enabled this is a user account setting  contact form management tasks see the related topics below for specific tasks  ',1729064404),(9,'en','help_search',' setting a default contact form goal set a sitewide contact form to be the default contact form  the form displayed on the default contact page  for example   contact   steps in the manage administrative menu navigate to structure   contact forms  click edit for the sitewide form you want to be the default check make this the default form and click save   ',1729064404),(10,'en','help_search',' changing the appearance of your site what is a theme  a theme is a set of files that define the visual look and feel of your site the core software and modules that run on your site determine which content including html text and other data stored in the database uploaded images and any other asset files is displayed on the pages of your site the theme determines the html markup and css styling that wraps the content several basic themes are supplied with the core software additional contributed themes can be downloaded separately from the download extend page on drupalorg  or you can create your own theme what is a base theme  a base theme is a theme that is not meant to be used directly on a site but instead acts as a scaffolding for building other themes the core stable 9 theme is one example other base themes can be downloaded from the download extend page on drupalorg  what is a layout  a layout is a template that defines where blocks and other pieces of content should be displayed the core layout discovery module allows modules and themes to register layouts and the core layout builder module provides a visual interface for placing fields and blocks in layouts for entity subtypes and individual entity items see managing content structure for more on entities and fields  changing site appearance overview the main way to change the overall appearance of your site is to switch the default theme the core layout builder and layout discovery modules allow you to define layouts for your site s content and the core breakpoint module helps themes change appearance for differentsized devices see the related topics listed below for specific tasks additional resources extending and customizing your site drupal user guide  theming drupal ',1729064404),(11,'en','help_search',' managing and deploying configuration what is the configuration system  the configuration system provides the ability for administrators to customize the site and to move and synchronize configuration changes between development sites and the live site it does this in 2 ways providing storage for configuration providing a process in which configuration changes can be imported and exported between instances of the same site for example from dev to staging to live  what is configuration data  configuration data describes settings that define how your site behaves or is displayed for example when a site administrator updates settings using an administrative form these settings are stored as configuration data configuration data describes settings as simple as a site name and as complex as a view or image style what kinds of configuration are there  active configuration active configuration is the current working configuration of a site storage of active configuration is defined by the site and resides in the database by default simple configuration a simple configuration item is a group of settings such as the settings for a module or theme each simple configuration item has its own unique structure configuration entities configuration entities are userdefined configuration items grouped by type such as views image styles and content types each configuration entity within a type has a similar structure default configuration default configuration can be defined by a module theme or installation profile in its config install or config optional directories configuration is provided in yaml files file extension yml yaml is a humanreadable data serialization standard that is used by the core software for several purposes once the default configuration has been imported into the site s active configuration through installing the extension that configuration is owned by the site not the extension this means that future updates of the extension will not override the site s active configuration for that extension what is configuration synchronization  configuration synchronization is the process of exporting and importing configuration to keep configuration synchronized between different versions of a site for example between a development site and the live site each site has unique identifier also called a uuid  which identifies the site to the system in any instance of the site as long as the site instances have been reproduced as clones cloning is when the codebase and database are copied to create a new site instance when site instances are cloned a dev instance of the site has the same uuid as the live instance when site instances share the same uuid configuration can be exported from one instance to another the following list contains terms and concepts related to configuration synchronization exported configuration when configuration is exported the active configuration is exported as a set of files in yaml format when using the configuration synchronization administrative ui configuration can be exported as a fullexport or singleitem archive this archive can then be imported into the destination site instance imported configuration imported configuration is configuration that has been exported from another instance of the site the source and is now being imported into another site instance the destination thereby updating its active configuration to match the imported configuration data set configuration sync directory the configuration sync directory location is set in the site s settingsphp file when configuration is exported the active configuration is exported and described in yaml files which are stored in the configuration sync directory after the first export the system compares the site s active configuration with the configuration data in the sync directory and will only export active configuration items that are different than their counterparts in the sync directory managing configuration overview configuration management tasks such as exporting or importing configuration and synchronizing configuration can be done either through the administrative ui provided by the core configuration manager module or a commandline interface cli tool defining a configuration sync directory path other than the default value requires read write access to the site s settingsphp file most modules and themes also provide settings forms for updating the configuration they provide see the related topics listed below for specific tasks additional resources configuration management workflow using drush concept types of data drupal user guide  concept development sites drupal user guide  making a development site drupal user guide  ',1729064404),(12,'en','help_search',' managing content structure what types of data does a site have  there are four main types of data content is the information text images etc meant to be displayed to website visitors configuration is data that defines how the content is displayed some configuration such as field labels may also be visible to site visitors state is temporary data about the state of your site such as the last time the system cron jobs ran session is a subset of state information related to users interactions with the site such as site cookies and whether or not they are logged in what is a content entity  a content entity  or more commonly  entity  is an item of content data which can consist of text html markup images attached files and other data content entities are grouped into entity types  which have different purposes and are displayed in very different ways on the site most entity types are also divided into entity subtypes  which are divisions within an entity type to allow for smaller variations in how the entities are used and displayed for example the content item entity type that stores pagelevel content is divided into content type subtypes the content block entity type has block types  but the user entity type for user profile information does not have subtypes what is a field  within entity items the data is stored in individual fields  each of which holds one type of data such as formatted or plain text images or other files or dates fields can be added by an administrator on entity subtypes so that all entity items of a given entity subtype have the same collection of fields available and they can be singlevalued or multiplevalued when you create or edit entity items you are specifying the values for the fields on the entity item what is a reference field  a reference field is a field that stores a relationship between an entity and one or more other entities which may belong to the same or different entity type for example a content reference field on a content type stores a relationship between one content item and one or more other content items what field types are available  the following field types are provided by the core system and core modules many more are provided by contributed modules boolean number provided by the core system stores true false values and numbers comment provided by the core comment module allows users to add comments to an entity date timestamp datetime module stores dates and times date range datetime range module stores time date periods with a start and an end email core system stores email addresses link link module stores urls and link text list options module stores values chosen from predefined lists where the values can be numbers or text see section below for more on list fields reference core system stores entity references see section above telephone telephone module stores telephone numbers text text module stores formatted and unformatted text see section below for more on text fields what settings are available for list field types  list fields associate predefined keys  or value codes with labels that the user sees for example you might define a list field that shows the user the names of several locations while behind the scenes a location code is stored in the database each list field type corresponds to one type of stored key for example a list integer  field stores integers while the list text  field stores text strings once you have chosen the field type the main setting for a list field is the allowed values list which associates the keys with the labels what types of text fields are available  there are several types of text fields with different characteristics text fields can be either plain or formatted  plain text fields do not contain html while formatted fields can contain html and are processed through text filters  these are provided by the core filter module if you have that module enabled see the related topic below on filters for more information text fields can also be regularlength with a limit of 255 characters or long  with a very large character limit and long formatted text fields can include a summary attribute all possible combinations of these characteristics exist as text field types for example  text plain  and text formatted long with summary  are two examples of text field types what is a formatter  a formatter is a way to display a field most field types offer several types of formatters and most formatters have settings that further define how the field is displayed it is also possible to completely hide a field from display and you have the option of showing or hiding the field s label when it is displayed what is a widget  a widget is a way to edit a field some field types such as plain text singleline fields have only one widget available in this case a singleline text input field other field types offer choices for the widget for example singlevalued list fields can use a select or radio button widget for editing many widget types have settings that further define how the field can be edited managing content structure overview besides the field modules listed in the previous section there are additional core modules that you can use to manage your content structure the core node comment content block custom menu links user file image media taxonomy and contact modules all provide content entity types the core field ui module provides a user interface for managing fields and their display on entities the core layout builder module provides a more flexible user interface for configuring the display of entities the core filter responsive image and path modules provide settings and display options for entities and fields depending on the core and contributed modules that you currently have installed on your site the related topics below and other topics listed on the main help page see help will help you with tasks related to content structure additional resources concept types of data drupal user guide  planning your site drupal user guide  concept reference fields drupal user guide  ',1729064404),(13,'en','help_search',' running and configuring cron goal configure your system so that cron will run automatically what are cron tasks  to ensure that your site and its modules continue to function well a group of administrative operations should be run periodically these operations are called cron tasks and running the tasks is known as running cron  depending on how often content is updated on your site you might need to run cron on a schedule ranging from hourly to weekly to keep your site running well what options are available for running cron  if the core automated cron module is installed your site will run cron periodically on a schedule you can configure you can set up a task on your web server to visit the cron url  which is unique to your site on a schedule you can also run cron manually but this is not the recommended way to make sure it is run periodically steps in the manage administration menu navigate to configuration   system   cron  note the last run time on the page if you want to run cron right now click run cron and wait for cron to finish if you have a way to configure tasks on your web server copy the link where it says to run cron from outside the site go to  set up a task to visit that url on your desired cron schedule such as once an hour or once a week on linuxlike servers you can use the wget command to visit a url if you configure an outside task you should uninstall the automated cron module if you are not configuring an outside task and you have the core automated cron module installed select a schedule for automated cron runs in cron settings   run cron every  click save configuration  additional resources concept cron drupal user guide  configuring cron maintenance tasks drupal user guide  ',1729064404),(14,'en','help_search',' extending and modifying your site functionality what is a module  a module is a set of php javascript and or css files that extends site features and adds functionality a set of core modules is distributed as part of the core software download additional contributed modules can be downloaded separately from the download extend page on drupalorg  what is an experimental module  an experimental module is a module that is still in development and is not yet stable using experimental modules on production sites is not recommended what are installing and uninstalling  installing a core or downloaded contributed module means turning it on so that you can use its features and functionality uninstalling means turning it off and removing all of its configuration a module cannot be uninstalled if another installed module depends on it or if you have created content on your site using the module you would need to delete the content and uninstall dependent modules first extending overview see the related topics listed below for help performing tasks related to extending the functionality of your site additional resources concept modules drupal user guide  extending and customizing your site drupal user guide  ',1729064404),(15,'en','help_search',' maintaining and troubleshooting your site maintaining and troubleshooting overview here are some tasks and hints related to maintaining your site and troubleshooting problems that may come up on your site see the related topics below for more information when performing maintenance such as installing uninstalling or updating a module put your site in maintenance mode configure your site so that cron runs periodically if your site is not behaving as expected clear the cache before trying to diagnose the problem there are several site reports that can help you diagnose problems with your site there are also two core modules that can be used for error logging database logging and syslog additional resources preventing and fixing problems drupal user guide  security and maintenance drupal user guide  ',1729064404),(16,'en','help_search',' managing media what are media items  core media items include audio images documents and videos you can add other media types such as social media posts through the use of contributed modules media items may be files located in your site s file system or remote items referenced by a url media items are content entities and they are divided into media types which are entity subtypes media types can have fields see managing content structure for more information on content entities and fields what is the media library  the media library is a visual user interface for managing and reusing media items add media items to content using media reference fields and the media library field widget what is an image style  an image style is a set of processing steps known as effects  that can be applied to images examples of effects include scaling and cropping images to different sizes responsive image styles can associate image styles with your theme s size breakpoints this allows serving images sized for the browser width overview of managing media the following modules provide mediarelated functionality media items and media types are managed by the core media module the core media module provides a media reference field to add media to content entities the core file and image modules also provide reference fields it is recommended to use the media reference field because it is more versatile the core media library module provides the media library and the media library field widget with this module installed the media library field widget becomes the default widget for editing media reference fields the core image module provides a user interface for defining image styles the core responsive image module provides responsive image styles using the core breakpoint module and a breakpointenabled theme these responsive styles can serve images sized for the browser see the related topics listed below for specific tasks additional resources media module ',1729064404),(17,'en','help_search',' managing menus what is a menu  a menu is a collection of menu links used to navigate a web site menus and menu links can be provided by modules or site administrators managing menus overview the core menu ui module provides a user interface for managing menus including creating new menus reordering menu links and disabling links provided by modules it also provides the ability for links to content items to be added to menus while editing if configured on the content type the core custom menu links module provides the ability to add custom links to menus each menu can be displayed by placing a block in a theme region some themes also can display a menu outside of the block system see the related topics listed below for specific tasks additional resources concept menu drupal user guide  ',1729064404),(18,'en','help_search',' optimizing site performance what is site performance  site performance in this context refers to speed factors such as the page load time and the response time after a user action on a page what is caching  caching is saving alreadyrendered html output and other calculated data for later use the first time it is needed this saves time because the next time the same data is needed it can be quickly retrieved instead of recalculated automatic caching systems also include mechanisms to delete cached calculations or mark them as no longer valid when the underlying data changes to facilitate that cached data has a lifetime  which is the maximum time before the data will be deleted from the cache forcing recalculation  what is file aggregation  aggregation is when css and javascript files are merged together and compressed into a format that is much smaller than the original this allows for faster transmission and faster rendering on the other end what can i do to improve my site s performance  the following core software modules and mechanisms can improve your site s performance internal page cache module caches pages requested by users who are not logged in anonymous users do not use if your site needs to send different output to different anonymous users internal dynamic page cache module caches data for both authenticated and anonymous users with noncacheable data in the page converted to placeholders and calculated when the page is requested big pipe module changes the way pages are sent to users so that cacheable parts are sent out first with placeholders and the uncacheable or personalized parts of the page are streamed afterwards this allows the browser to render the bulk of the page quickly and fill in the details later performance page settings in the manage administrative menu if you navigate to configuration   development   performance  you will find a setting for the maximum cache lifetime as well as the ability to turn on css and javascript file aggregation additional resources online documentation for the internal page cache module online documentation for the internal dynamic page cache module online documentation for the bigpipe module ',1729064404),(19,'en','help_search',' making your site secure what are security updates  any software occasionally has bugs and sometimes these bugs have security implications when security bugs are fixed in the core software modules or themes that your site uses they are released in a security update  you will need to apply security updates in order to keep your site secure what are security advisories  a security advisory is a public announcement about a reported security problem in the core software contributed projects with a shield icon and stable releases for this project are covered by the security advisory policy on their project page are also covered by drupal s security advisory policy security advisories are managed by the drupal security team  security tasks keeping track of updates updating the core software and updating contributed modules and or themes are all part of keeping your site secure see the related topics listed below for specific tasks additional resources security and maintenance drupal user guide  security advisory process and permissions policy ',1729064404),(20,'en','help_search',' using inline quick settings editing goal edit settings in place what is quick editing  the core settings tray module provides the ability to quickly edit settings inline it requires the core contextual links module in order to expose the links that let you edit in place who can edit settings in place  in order to follow these steps to edit settings in place the core settings tray module must be installed also either the core toolbar module or a contributed replacement must be installed you will need to have use contextual links permission as well as permission to edit the particular content or settings steps find and visit a page on your site that has the settings that you would like to edit click the contextual links edit button on the toolbar in most themes it looks like a pencil contextual edit links with the same icon will appear all over your page find the contextual link for the part of the page you want to edit for example if you want to edit the settings for a block the link should be in the topright corner of the block or topleft for righttoleft languages click the link to open the contextual links menu and click quick edit  an editing form for the settings should appear on the page make your edits and submit the form  ',1729064404),(21,'en','help_search',' tracking the content of your website tracking overview the core history module tracks how recently users have viewed content items and provides a views field and filter that can be used to show users content that they haven t yet seen if you have one or more tracking modules installed on your site see the related topics listed below for specific tasks  ',1729064404),(22,'en','help_search',' working with languages and translations what text can be translated in your site  there are three types of text that can be translated content blocks content items etc can be written in english or another language and can be translated into additional languages see managing content structure to learn more about content many configuration items also include text that can be translated default configuration provided by your site s software is provided in english you can also download communityprovided translations see managing and deploying configuration to learn more about configuration user interface text that is provided by the core software your install profile themes and modules is provided in english but can be translated into other languages you can also download translations that communitymembers have provided working with languages overview the core language module lets you add new languages to your site provides the language switcher block and provides the ability to configure block visibility by language the block and block visibility settings are only available if you have multiple languages configured the core content translation configuration translation and interface translation modules let you translate content configuration and the builtin user interface respectively the core update manager module manages automatic downloads of communityprovided translations of default configuration and userinterface text see the related topics listed below for specific tasks  ',1729064404),(23,'en','help_search',' accessibility of the administrative interface overview of accessibility the core administrative interface has builtin compliance with many accessibility standards so that most pages are accessible to most users in their default state however certain pages become more accessible to some users through the use of a nondefault or improved interface these interfaces include disabling draganddrop functionality the default draganddrop user interface for ordering tables in the administrative interface presents a challenge for some users including keyboardonly users and users of screen readers and other assistive technology the draganddrop interface can be disabled in a table by clicking a link labeled show row weights above the table the replacement interface allows users to order the table by choosing numerical weights with increasing numbers instead of dragging table rows enabling inline form errors errors that occur when you submit a form such as not filling in a required field are sometimes difficult for users to understand and locate in order to make these errors easier to find the best practice is to put a summary of the errors at the top of the form page to make them easier to understand the best practice is to display error messages with the form fields they are related to both of these practices are implemented by the core inline form errors module  ',1729064404),(24,'en','help_search',' using the administrative interface what administrative interface components are available  the following administrative interface components are provided by the core software and its modules some contributed modules offer additional functionality accessibility features to enable all users to perform administrative tasks see accessibility of the administrative interface for more information a menu system which you can navigate to find pages for administrative tasks the core toolbar module displays this menu on the top or left side of the page right side in righttoleft languages there are also contributed module replacements for the core toolbar module with additional features such as the admin toolbar module  the core shortcuts module enhances the toolbar with a configurable list of links to commonlyused tasks if you install the core contextual links module nonadministrative pages will contain links leading to related administrative tasks inplace or quick editing inplace editing of configuration is provided by the core settings tray module see using inline quick settings editing for more information the core help module displays help topics and provides a help block that can be placed on administrative pages to provide an overview of their functionality what are the sections of the administrative menu  the administrative menu which you can navigate by visiting  admin on your site or by using an administrative toolbar has the following sections some may not be available depending on which modules are currently installed on your site and your permissions  content  find manage and create new pages manage comments and files structure  place and edit blocks set up content types and fields configure menus administer taxonomy and configure some contributed modules appearance  switch between themes install themes and update existing themes extend  update install and uninstall modules configuration  configure the settings for various site functionality including some contributed modules people  manage user accounts and permissions reports  display information about site security necessary updates and site activity help  get help on using the administrative interface administrative interface overview install the core modules mentioned above to use the corresponding aspect of the administrative interface see the related topics listed below for more details on some aspects of the administrative interface  ',1729064404),(25,'en','help_search',' enabling web services what is a web service  a web service allows your site to provide its content and data to other web sites and applications typically the data is transported via http in a serialized machinereadable format what is serialization  serialization is the process of converting complex data structures into text strings so that they can be exchanged and stored the reverse process is called deserialization  json and xml are the two mostcommonlyused data serialization formats for web services what is http basic authentication  http basic authentication is a method for authenticating requests by sending a user name and password along with the request what modules provide web services  the following core software modules provide web services json api module exposes entities to other applications using a fully compliant implementation of the json api specification  see managing content structure for more information on content entities and fields restful web services module exposes entities and other resources to other applications using a rest implementation data is exchanged using a serialization format such as json and transferred using an authentication method such as http basic authentication serialization module provides a framework for adding specific serialization formats for other modules to use http basic authentication module provides a way for web services to be authenticated using http basic authentication against site user accounts there are also contributed modules that provide web services additional resources online documentation for the restful web services module online documentation for the json api module comparison of the restful web services and json api modules ',1729064404),(26,'en','help_search',' configuring help search goal set up your site so that users can search for help steps in the manage administrative menu navigate to extend  verify that the search help and block modules are installed or install them if they are not already installed in the manage administrative menu navigate to configuration   search and metadata   search pages  verify that a help search page is listed in the search pages section if not add a new page of type help  check the indexing status of the help search page if it is not fully indexed see running and configuring cron about how to run cron until indexing is complete in the future you can click rebuild search index on this page or clearing the site cache in order to force help topic text to be reindexed for searching this should be done whenever a module theme language or string translation is updated in the manage administrative menu navigate to structure   block layout  click the link for your administrative theme such as the core claro theme near the top of the page and verify that there is already a search block for help located in the help region if not follow the steps in the related topic to place the search form block in the help region when configuring the block choose help as the search page and in the pages tab under visibility  enter  admin help to make the search form only visible on the main help page in the manage administrative menu navigate to help  verify that the search block is visible and try a search  ',1729064404),(27,'en','help_search',' working with help topics what is a help topic  a help topic describes a concept or steps to accomplish a task related to a feature provided by one or more modules or themes if the core search module is enabled these topics are also searchable where are help topics listed  the toplevel help topics are listed at help links to other topics including nontoplevel help topics can be found under the related heading when viewing a topic page how are help topics provided  modules and themes can provide help topics as twigfilebased plugins in a project subdirectory called helptopics  plugin metadata is provided in yaml front matter within each twig file pluginbased help topics provided by modules and themes will automatically be updated when a module or theme is updated use the plugins in core modules help helptopics as a guide when writing and formatting a help topic plugin for your theme or module how are help topics translated  the title and body text of help topics provided by contributed modules and themes are translatable using user interface translation provided by interface translation module topics provided by custom modules and themes are also translatable if they have been viewed at least once in a nonenglish language which triggers putting their translatable text into the translation database how can users search for help topics  to enable users to search help including help topics you will need to install the core search module configure a search page and add a search block to the help page or another administrative page a search page is provided automatically and if you use the core claro administrative theme a help search block is shown on the main help page then users with search permissions and permission to view help will be able to search help see the related topic configuring help search for stepbystep instructions additional resources help topics standards ',1729064404),(28,'en','help_search',' configuring search pages goal configure one or more search pages steps in the manage administrative menu navigate to configuration   search and metadata   search pages  scroll down to the search pages section you will see a list of the alreadyconfigured search pages on your site to configure an existing search page click edit  or to add a new search page select the search page type and click add search page  enter the desired label name and url path for the search page for content search pages select the desired level of influence in ranking search results of the available content ranking factors click save  you will be returned to the search pages page verify that the correct search page is listed as default in the status column if not click set as default in the operations list for the correct search page optionally disable or delete any search pages that you do not want to have available on the site disabling is temporary while deleting is permanent follow the steps in managing the search index to make sure that the search index is updated  ',1729064404),(29,'en','help_search',' managing the search index goal manage the search index and make sure that the site is fully indexed for searching what is the search index  the content and help search types provided by the core software preindex their content and store the results in several database tables that are collectively called the search index  the process of indexing renders the content and breaks it up into words which can then be matched more efficiently with keyword queries when users perform searches search indexing happens during cron runs see running and configuring cron for more information about cron steps in the manage administrative menu navigate to configuration   search and metadata   search pages  under indexing throttle  select the number of items to index per cron run  a smaller number will make cron faster and reduce the possibility of timeout a larger number will make sure more of your site is indexed in fewer cron runs under default indexing settings  enter the desired minimum word length to index  words smaller than this length will be dropped from both keywords when searching and content when indexing if your site uses chinese japanese or korean languages optionally check simple cjk handling under default indexing settings to provide some support for these languages click save configuration  and you should be returned to the search pages page click reindex site if you have changed the indexing configuration or later on if you believe that the search index has been corrupted follow the steps in running and configuring cron to make sure a cron task has been configured after waiting for cron to run several times verify that the content has been fully indexed for searching the overall status is listed under indexing progress  and the status for each search page is shown in the indexing progress column of the search pages section  ',1729064404),(30,'en','help_search',' configuring site search what are search pages  the core search module organizes site search into pages  each page allows users to search a particular type of content with a particular configuration the configuration includes specifying a url that starts with search  a name for the page and additional options for some search page types when users visit the main search page see search  they will see the configured search pages that they have access to each search page has a search form on it and the page will display search results after the user enters keywords into the form and clicks the search button what modules provide site search  the core search module provides the ability to configure search pages search page types are provided by both core and contributed modules the core modules that provide search page types are the node module for searching content pages the user module for searching user profiles the help module for searching help topics as an alternative to the core search module s system of search pages you can use contributed modules to provide site search for example the apache solr and sphinx contributed modules use thirdparty technology to provide site search what are the limitations of the core search module  there are two main limitations of the core search module first it is not appropriate for very large sites if you have a large site look into other search technologies like apache solr second the node search page type only supports exact keyword matching which is not the behavior that most users will expect you can improve this by installing a languagespecific stemming module for your language such as porter stemmer for american english which makes it so that for example a search for the word walk would match pages containing the words walk walking and walked what are the search permissions  users with use search permission can use the search form block and search page this permission is required for any search configured in the core search module in addition to use search   view user information permission is needed for searching users in addition to use search   view published content permission is needed for searching content users with use advanced search permission can use more complex search filtering when performing content searches configuring site search overview in order to configure site search using the core search module you will need to configure one or more search pages you will also need to verify or alter permissions so that the desired user roles can search the site see managing user accounts and site visitors for more information about roles and permissions for content search you will also need to make sure that the search index is configured and that the site is fully indexed finally you may wish to place the search form block on pages of your site or add the search page to a navigation menu to give users easy access to search see the related topics listed below for specific tasks additional resources online documentation for the search module ',1729064404),(31,'en','help_search',' clearing the site cache goal clear the data in the site cache what is the cache  some of the calculations that are done when your site loads a page take a long time to run to save time when these calculations would need to be done again their results can be cached in your site s database there are internal mechanisms to clear cached data when the conditions or assumptions that went into the calculation have changed but you can also clear cached data manually when your site is misbehaving a good first step is to clear the cache and see if the problem goes away steps in the manage administrative menu navigate to configuration   development   performance  click clear all caches  your site s cached data will be cleared additional resources concept cache drupal user guide  ',1729064404),(32,'en','help_search',' changing basic site settings goal configure the basic settings of your site including the site name slogan main email address default time zone default country and the date formats to use steps in the manage administrative menu navigate to configuration   system   basic site settings  enter the site name slogan and main email address for your site click save configuration  you should see a message indicating that the settings were saved in the manage administrative menu navigate to configuration   region and language   regional settings  select the default country and default time zone for your site click save configuration  you should see a message indicating that the settings were saved in the manage administrative menu navigate to configuration   region and language   date and time formats  look at the patterns for the default long medium and short date formats if any of them does not match the date format you want to use on your site click edit in that row to edit the format adjust the format string until the displayed format matches what you want date format strings are composed of php date format codes click save format  you should see a message indicating that the format was saved repeat the previous three steps for any other date formats that need to be changed additional resources php date format codes reference ',1729064404),(33,'en','help_search',' configuring error responses including 403404 pages goal set up your site to respond appropriately to site errors including 403 and 404 page responses what are 403 and 404 responses  when a user visits a web page the web server sends a response code in addition to the page content a normal nonerror response has code 200 if the page does not exist on the site the response code is 404 if the page exists but the user is not authorized to visit the page the response code is 403 the core software provides default responses for both 403 and 404 codes but if you prefer you can create your own pages for each what other errors can occur  under some situations your site can generate error messages these can be due to user errors such as entering invalid values in a form or incorrect configuration php runtime errors or software bugs some errors may result in a white screen of death  a totally blank web page response less drastic errors will generate error messages you can configure what happens when an error message is generated steps if desired create pages to use for 403 and 404 responses note the urls for these pages in the manage administrative menu navigate to configuration   system   basic site settings  in the error pages section enter the url for your 403404 pages starting after the site home page url for example if your site url is https examplecom and your 404 page is https examplecom notfound  you would enter  notfound  click save configuration  you should see a message indicating that the settings were saved in the manage administrative menu navigate to configuration   development   logging and errors  for a production site select none under error messages to display  for a site that is in development select one of the other options so that you are more aware of the errors the site is generating click save configuration  you should see a message indicating that the settings were saved  ',1729064404),(34,'en','help_search',' enabling and disabling maintenance mode goal put your site in maintenance mode to perform maintenance operations and then return to normal mode when finished what is maintenance mode  when your site is in maintenance mode most site visitors will see a simple maintenance mode message page rather than being able to use the full functionality of the site users with use the site in maintenance mode permission who are already logged in will be able to use the full site and the log in page at  user will also be accessible to anyone steps in the manage administrative menu navigate to configuration   development   maintenance mode  check put site into maintenance mode  optionally change the message to display when in maintenance mode  and click save configuration  your site will be in maintenance mode perform your maintenance operations in the manage administrative menu navigate to configuration   development   maintenance mode  uncheck put site into maintenance mode and click save configuration  your site will be back in normal operation mode clear the site cache see clearing the site cache for instructions  ',1729064404),(35,'en','help_search',' installing a module goal install a core module or a contributed module that has already been downloaded steps in the manage administrative menu navigate to extend  enter a word from the module name or description into the filter box to make the list of modules smaller locate the module you want to install check the box next to the name of the module you want to install you can also check more than one box to install multiple modules at the same time if the checkbox is disabled for the module you are trying to install expand the information to see why you may need to download an additional module that your module requires click install at the bottom of the page if you chose to install a module with dependencies that were not already installed or if you chose an experimental module confirm your choice on the next page wait for the module or modules to be installed you should be returned to the extend page with a message saying the module or modules were installed  ',1729064404),(36,'en','help_search',' uninstalling a module goal uninstall a module your site should be in maintenance mode when you uninstall modules see enabling and disabling maintenance mode for details steps in the manage administrative menu navigate to extend   uninstall  enter a word from the module name or description into the filter box to make the list of modules smaller locate the module you want to uninstall in the description column see if there are reasons that this module cannot be uninstalled for example you may have created content using this module which you would need to delete first or there may be another module installed that requires this module to be installed you would need to uninstall the other module first if there are no reasons listed the module can be uninstalled check the box in the uninstall column next to the module s name click uninstall at the bottom of the page verify the list of modules to be uninstalled and configuration to be deleted on the confirmation page and click uninstall  wait for the module to be uninstalled you should be returned to the uninstall page with a message saying the module was uninstalled  ',1729064404),(37,'en','help_search',' running reports on your site goal run reports to learn about the status and health of your site steps in the manage administrative menu navigate to reports   status report to see a report that summarizes the health and status of your site if there are any warnings or errors you will need to fix them take note of any upcoming highly critical security releases that may impact your site if you have the core database logging module installed in the manage administrative menu navigate to reports   recent log messages to see a report of the error and informational messages your site has generated you can filter the report by severity to see only the most critical messages if desired if you have the core update manager module installed in the manage administrative menu navigate to reports   available updates to see a report of the updates that are available for your site software if last checked is far in the past click check manually to update the report scan the report if the core software or any modules or themes have security updates available you should update them as soon as possible additional resources security and maintenance drupal user guide   which includes information on how to update your site s core software modules and themes  ',1729064404),(38,'en','help_search',' installing a theme and setting default themes goal install a core theme or a contributed theme that has already been downloaded choose the default themes to use for the site and for administrative pages steps in the manage administrative menu navigate to appearance  locate the themes that you want to use as the site default theme and for administrative pages for each of these themes if the theme is in the uninstalled themes section click the install link to install the theme wait for the theme to be installed translations might be downloaded you should be returned to the appearance page locate the theme that you want to be your default theme which should now be in the installed themes section if it is not already labeled as the default theme  click the set as default link at the bottom of the page select the administration theme that you want to use on administrative pages click save configuration if you selected a new theme if you changed the default theme for your site visit the site home page or another page on the nonadministration part of your site and verify that the site is using the new theme if you changed the administration theme verify that the new theme is used on administrative pages  ',1729064404),(39,'en','help_search',' uninstalling an unused theme goal uninstall a theme that was previously installed but is no longer being used on the site steps in the manage administrative menu navigate to appearance  locate the theme that you want to uninstall in the installed themes section click the uninstall link to uninstall the theme if there is not an uninstall link the theme cannot be uninstalled because it is either being used as the site default theme being used as the administration theme  or is the base theme for another installed theme  ',1729064404),(40,'en','help_search',' creating a user account goal create a new user account steps in the manage administrative menu navigate to people  click add user  enter the email address   username  and password  twice for the new user verify that the roles checked for the new user are correct if you want the new user to receive an email message notifying them of the new account check notify user of new account  optionally change other settings on the form click create new account  you will be left on the add user page repeat these steps if you have more user accounts to create  ',1729064404),(41,'en','help_search',' adding a new role goal create a new role steps in the manage administrative menu navigate to people   roles  click add role  enter the desired role name  if desired click edit to change the machine name for the role click save  you should be returned to the roles page and your new role should be in the role list  ',1729064404),(42,'en','help_search',' managing user accounts and site visitors what is a user  a user is anyone accessing or viewing your site anonymous users are users who are not logged in and authenticated users are users who are logged in what is a role  roles are used to group and classify users each user can be assigned one or more roles there are also special roles for all anonymous and all authenticated users what is a permission  granting a permission to a role allows users who have been assigned that role to perform an action on the site such as viewing content editing or creating a particular type of content administering settings for a particular module or using a particular function of the site such as search  overview of managing user accounts and visitors the core user module allows users to register log in and log out and administrators to manage user roles and permissions the core ban module allows administrators to ban certain ip addresses from accessing the site depending on which modules you have installed on your site the related topics below will help you with tasks related to managing user accounts and visitors  ',1729064404),(43,'en','help_search',' modifying the permissions for a role goal modify the permissions for an existing role steps in the manage administrative menu navigate to people   permissions  review the permissions for the role paying particular attention to the permissions marked with warning give to trusted roles only this permission has security implications uncheck permissions that this role should not have in the row of the permission and the column of the role check permissions that this role should have click save permissions   ',1729064404),(44,'en','help_search',' configuring how user accounts are created and deleted goal configure settings related to how user accounts are created and deleted what are the settings related to user account creation and deletion  you can make it possible for new users to register themselves for accounts with or without email verification or administrative approval or you can make it so only administrators with administer users permission can register new users you can configure what happens to content that a user created if their account is canceled  deleted you can edit the email messages that are sent to users when their accounts are pending approved created blocked or canceled or when they request a password reset what are variables in email message text  variables are short text strings enclosed in square brackets that you can insert into configured email message text when an individual message is generated data from your site is substituted for the variables some commonlyused variables are site name the name of your website site url the url of your website site loginurl the url where users can log in to your site user displayname the user s displayed name user accountname the user s account name user mail the user s email alias user onetimeloginurl an expiring url that a user can use to log in once if they need to reset their password steps in the manage administrative menu navigate to configuration   people   account settings  select the method you want to use for creating user accounts and check or uncheck the box that requires email verification to match the settings you want for your site select the desired option for what happens to content that a user created if their account is canceled optionally edit the text of email messages related to user accounts verify that the other settings are correct click save configuration  you should see a message indicating that the settings were saved  ',1729064404),(45,'en','help_search',' modifying or deleting a user account goal update or delete an existing user account steps in the manage administrative menu navigate to people  enter all or part of the user name or email address of the user account you want to update or delete and click filter  a short list of user accounts including the account of interest should be shown in the table if not modify the filter text until you can find the account of interest click edit in the operations area of the account of interest to delete the user account scroll to the bottom and click cancel account  select what you want to happen to the user s content on the next screen and click cancel account  to update the user account enter new values in the form and click save   ',1729064404),(46,'en','help_search',' viewing drupal announcements what are drupal announcements  a feed of announcements about the drupal project and drupal association programs the purpose of this feed is to provide a channel for outreach directly to drupal site owners this content must be highly relevant to site owners interests serve the strategic goals of the project and or promote the sustainability of the project and the drupal association the module sources its content from a json feed generated from here  the governance policy for the content is documented here  how can i see the announcements in my site  if you have the toolbar module enabled you will see a direct link to them in the toolbar if the toolbar module is not enabled the content can always be accessed in the announcements page who can see the announcements  users with the view official announcements related to drupal permission can view drupal announcements additional resources announcement module overview ',1729064404),(47,'en','help_search',' configuring a previouslyplaced block goal configure the settings of a block that was previously placed in a region of a theme steps in the manage administrative menu navigate to structure   block layout  click the name of the theme that contains the block optionally click demonstrate block regions to see the regions of the theme if you only want to change the region where a block is located or the ordering of blocks within a region drag blocks to their desired positions and click save blocks  if you want to change additional settings find the region where the block you want to update is currently located and click configure in the line of the block description edit the block s settings the available settings vary depending on the module that provides the block but for all blocks you can change  block title  the heading for the block on your site for some blocks you will need to check the override title checkbox in order to enter a title display title  check the box if you want the title displayed visibility  add conditions for when the block should be displayed region  change the theme region the block is displayed in click save block   ',1729064404),(48,'en','help_search',' managing blocks what are blocks  blocks are boxes of content rendered into an area or region of a web page of your site blocks are placed and configured specifically for each theme what are content blocks  content blocks are blocks whose content you can edit you can define one or more block types  and attach fields to each block type content blocks can be placed just like blocks provided by other modules what is the block description  the block description is an identification name for a block which is shown in the administrative interface it is not displayed on the site what is the block title  the block title is the heading that is optionally shown to site visitors when the block is placed in a region overview for managing blocks the block module allows you to place blocks in regions of your installed themes and configure block settings the block content module allows you to manage block types and content blocks see the related topics listed below for specific tasks additional resources blocks drupal user guide  ',1729064404),(49,'en','help_search',' placing a block goal place a block into a theme s region steps in the manage administrative menu navigate to structure  block layout click the name of the theme that you want to place the block in optionally click demonstrate block regions to see the regions of the theme find the region where you want the block and click place block in that region a modal dialog will pop up find the block you want to place and click place block  a configure block modal dialog will pop up configure the block and click save block  see configuring a previouslyplaced block for configuration details  ',1729064404),(50,'en','help_search',' managing text filters and text formats goal configure text formats on the site what are text filters and text formats  a text filter is a processing step that can be applied to text either to transform it in some way such as converting urls in the text into html links or to defend against potentiallydangerous input from site users a text format is an ordered sequence of text filters text filters are provided by modules text formats are managed by the core filter module text fields that have formatted in the field type name such as text formatted   use text formats users choose the text format when editing the field text when the field text is shown on the site it is processed by the chosen text format administrators can configure text formats and assign permissions for who can use each format if the core text editor module is enabled administrators can also associate visual editors with text formats what text filters are available  some of the more commonly used text filters are limit allowed html tags and correct faulty html limits which html tags can be used useful both for site security and enforcing site design convert line breaks into html line breaks in html source are displayed as horizontal spaces this filter converts line breaks into html paragraph and line break tags convert urls into links takes plain urls in text and turns them into html links restrict images to this site for text formats that allow html image tags restricts images to urls within this site steps in the manage administrative menu navigate to configuration   content authoring   text formats and editors  if you do not have the core text editor module installed the menu link and page title will instead be text formats  click configure to configure an existing text format or  add text format to create a new text format enter the desired name for the text format check the roles that can use this text format some html tags allow users to embed malicious links or scripts in text to ensure security anonymous and untrusted users should only have access to text formats that restrict them to either plain text or a safe set of html tags improper text format configuration is a security risk if the core text editor module is installed see the related topic to connect a text editor to this text format under enabled filters  check the text filters that you want to use under filter processing order  drag the filters to the correct order choose the order carefully for example if you have a filter that results in a particular html tag being added to the text that should run after a filter that restricts html tags to avoid deleting the new tags the first filter added under filter settings  verify and adjust the settings for each active filter that has configuration options click save configuration  which will return you to the text formats and editors page repeat these steps if you have additional text formats to configure  ',1729064404),(51,'en','help_search',' creating a content block goal create a content block which can later be placed on the site steps in the manage administrative menu navigate to content  open the content blocks tab click add content block  if you have more than one block type defined on your site click the name of the type you want to create enter a description of your block to be shown to administrators and the body text for your block click save   ',1729064404),(52,'en','help_search',' defining a block type goal define a block type and its fields steps in the manage administrative menu navigate to structure   block types  click add block type  enter a label for this block type shown in the administrative interface optionally edit the automaticallygenerated machine name or the description click save  you will be returned to the block types page click manage fields in the row of your new block type and add the desired fields to your block type optionally click manage form display or manage display to change the editing form or field display for your block type  ',1729064404),(53,'en','help_search',' managing height width and resolution breakpoints what are breakpoints  breakpoints are the point at which your site s content will respond to provide the user with the best possible layout to consume the information a breakpoint separates the height or width of viewports screens printers and other media output types into steps for instance a width breakpoint of 40em creates two steps one for widths up to 40em and one for widths above 40em breakpoints can be used to define when layouts should shift from one form to another when images should be resized and other changes that need to respond to changes in viewport height or width what are media queries  media queries are a formal way to encode breakpoints for instance a width breakpoint at 40em would be written as the media query minwidth 40em breakpoints are really just media queries with some additional metadata such as a name and multiplier information what are resolution multipliers  resolution multipliers are a measure of the viewport s device resolution defined to be the ratio between the physical pixel size of the active device and the deviceindependent pixel size the breakpoint module defines multipliers of 1 15 and 2 when defining breakpoints modules and themes can define which multipliers apply to each breakpoint what is a breakpoint group  breakpoints can be organized into groups modules and themes should use groups to separate out breakpoints that are meant to be used for different purposes such as breakpoints for layouts or breakpoints for image sizing managing breakpoints and breakpoint groups overview the breakpoint module allows you to define breakpoints and breakpoint groups in yaml files modules and themes can use the api provided by the breakpoint module to define breakpoints and breakpoint groups and to assign resolution multipliers to breakpoints additional resources working with breakpoints in drupal w3c standards for media queries ',1729064404),(54,'en','help_search',' connecting text editors to text formats goal configure a text format so that when a user is editing text and selects this text format a text editor installed on your site is shown configure the text editor such as choosing which buttons and functions are available see managing text filters and text formats for more about text formats what is a text editor  a text editor is software typically a javascript library that provides buttons and other command mechanisms to make editing html text easier some editors are called visual or wysiwyg what you see is what you get  editors these editors hide the details of html from the user and instead show formatted output on the screen the core text editor module provides a framework for deploying text editors on your site the core ckeditor 5 module provides ckeditor 5 which is a widelyused javascript text editor that creates clean and valid html the module also enforces the html tag restrictions in the associated text format various contributed modules provide other editors to install a new editor besides installing the module you may need to download the editor library from a thirdparty site steps in the manage administrative menu navigate to configuration   content authoring   text formats and editors  the text editor column in the table shows the text editor that is currently connected to each text format if any follow the steps on managing text filters and text formats to add a new text format or configure an existing text format when you reach the step about text editors return to this topic select ckeditor 5 as the text editor  or another text editor that you have installed the rest of these steps assume you selected ckeditor 5  under toolbar configuration  drag buttons between available buttons and active toolbar  only buttons in active toolbar will be shown to the user focusing or hovering over a button will display a tooltip explaining what the button does drag buttons within active toolbar to the desired order and group buttons by dragging them between group identifiers drag a new group identifier to the toolbar to add additional groups if you add buttons that require configuration the ckeditor 5 plugin settings section will be visible and provide their respective configuration forms return to managing text filters and text formats to complete the text format configuration and be sure to save the text format  ',1729064404),(55,'en','help_search',' configuring comments goal configure a content entity type subtype to allow commenting using a comment type that you have configured see managing content structure for more about content entities and fields and creating a comment type to configure a comment type who can configure comments  in order to follow these steps the field ui module must be installed you ll need the comment module s administer comments and comment settings permission in order to change comment settings for a comment field you ll also need to have the appropriate permission for adding fields to the entity type or subtype that the comments are attached to for example to add a comment field to content items provided by the node module you would need the node module s administer content types permission steps follow the steps in the related adding a field to an entity subtype topic to add a field of type comments to the desired entity type or subtype on the first field settings page choose the comment type to use for this entity type or subtype you ll also notice that the allowed number of values field cannot be changed for comment fields on the next field settings page enter the desired settings for the comment field  threading  whether or not the comments are collected by threads with people able to reply to particular comments instead of to the content entity itself comments per page  the maximum number of comments displayed on one page a pager will be added if you exceed this limit  anonymous commenting  whether or not anonymous commenters are allowed or required to leave contact information with their comments only applies if anonymous users have permission to post comments  show reply form on the same page as comments  whether the comment reply form is displayed on the same page as the comments if this is not selected clicking reply will open a new page with the reply form preview comments  whether previewing comments before submission is required   optional  or disabled  default value  each individual entity has its own comment settings but here you can set defaults for the comment settings for this entity type or subtype the comment settings values are  open  comments are allowed closed  past comments remain visible but no new comments are allowed hidden  past comments are hidden and no new comments are allowed additional resources online documentation for content comment settings ',1729064404),(56,'en','help_search',' creating a comment type goal create a new comment type see managing comments for information about comments and comment types who can create a comment type  users with the administer comment types and settings permission typically administrators can create comment types steps in the manage administrative menu navigate to structure   comment types  click add comment type  in the label field enter a name for the comment type which is how it will be listed in the administrative interface in the target entity type field select the entity type to be commented on see managing content structure for more about content entities and fields click save  the comment type will be created optionally if you have the core field ui module installed you can follow the steps in the related topics to add fields to the new comment type set up the editing form and configure the display  ',1729064404),(57,'en','help_search',' disabling comments goal turn off commenting for a particular entity see managing content structure for more about content entities and fields note that if you want to turn off commenting for all entities of an entity type or subtype you will need to edit the field settings for the comment field see configuring comments for more about configuring the comment field who can disable comments  you will need the administer comments and comment settings permission in order to disable commenting you will also need permission to edit the entity that the comments are on steps find the entity you want to disable comments for and edit it for example to turn off comments on a content item you could find it by navigating in the manage administrative menu to content  filtering to find the content item and clicking edit  under comment settings  select the desired comment setting  open  comments are allowed closed  past comments remain visible but no new comments are allowed hidden  past comments are hidden and no new comments are allowed save the entity  ',1729064404),(58,'en','help_search',' moderating comments goal decide which comments are shown on the website who can moderate comments  users with the administer comments and comment settings permission typically administrators can moderate comments you will also need the access the content overview page permission from the node module if it is installed to navigate to the comment management page steps in the manage administrative menu navigate to content   comments  a list of all comments is shown to unpublish comments select one or more comments by checking the boxes on the left side right side in righttoleft languages then select unpublish comment from the action select list and click apply to selected items  if you select the delete comment action you can instead delete the unwanted comments to change the content of a comment click edit from the dropdown button for a particular comment to publish comments that are not yet visible on the website navigate to the unapproved comments tab select one or more comments by checking the boxes on the left side right side in righttoleft languages then select publish comment from the action select list and click apply to selected items  additional resources online documentation for moderating comments ',1729064404),(59,'en','help_search',' managing comments what is a comment  a comment is a piece of content typically posted by a website visitor which provides discussion or commentary on other content like blog posts and news articles comments are a type of content entity and can have fields that store text html markup and other data comments are attached to other content entities via comment fields see managing content structure for more about content entities and fields what is a comment type  comments are divided into comment types  which are the entity subtypes for the comment entity type each comment type has its own fields and its own form and display settings each type can be used to comment on a single entity type you can set up different comment types for different commenting purposes on your web site for example you might set up a comment type for recipes that has fields how did it taste and did the instructions work and another comment type for blog entries that has only a generic comment body field what is moderation  moderation is a workflow where comments posted by some users on your site are verified before being published to prevent spam and other bad behavior the core software provides basic moderation functionality you can configure permissions so that new comments posted by some user roles start as unpublished until a user with a different role reviews and publishes them contributed modules provide additional moderation and spamreduction functionality such as requiring untrusted users pass a captcha test before submitting comments and letting community members flag comments as possible spam see managing user accounts and site visitors for more about users permissions and roles overview of managing comments the core comment module provides the following functionality posting comments creating comment types the core field ui module allows you to attach fields to comment types and attach comment reference fields to other entities so that people can comment on them configuring commenting moderating comments as discussed above see the related topics listed below for specific tasks  ',1729064404),(60,'en','help_search',' using contextual links goal use contextual links to access administrative tasks without navigating the administrative menu what are contextual links  contextual links give users with the use contextual links permission quick access to administrative tasks related to areas of nonadministrative pages for example if a page on your site displays a block the block would have a contextual link that would allow users with permission to configure the block if the block contains a menu or a view it would also have a contextual link for editing the menu links or the view clicking a contextual link takes you to the related administrative page directly without needing to navigate through the administrative menu system steps make sure that the core contextual links module is installed and that you have a role with the use contextual links permission optionally make sure that a toolbar module is installed either the core toolbar module or a contributed module replacement visit a nonadministrative page on your site such as the home page locate a block or another area on the page that you want to edit or configure make the contextual links button visible by hovering your mouse over that area in the page in most themes this button looks like a pencil and is placed in the upper right corner of the page area upper left for righttoleft languages and hovering will also temporarily outline the affected area alternatively click the contextual links toggle button on the right end of the toolbar left end for righttoleft languages which will make all contextual link buttons on the page visible until it is clicked again while the contextual links button for the area of interest is visible click the button to display the list of links for that area click a link in the list to visit the corresponding administrative page complete your administrative task and save your settings or cancel the action you should be returned to the page you started from  ',1729064404),(61,'en','help_search',' adding a field to an entity subtype goal add a field to an entity subtype see managing content structure for an overview of entity types and subtypes as well as an overview of field types steps navigate to the page for managing the entity subtype you want to add the field to for example to add a field to a content type in the manage administrative menu navigate to structure   content types  find the particular subtype that you want to add the field to and click manage fields  click add field  in add a new field  select the type of field you want to add see managing content structure for an overview of field types the label field should now be visible enter a label for the field which is used as the field label for both content editing and content display click save and continue  on the next screen enter a value for allowed number of values  you can limit the field to one value per entity item a set number of values or set it to have unlimited values click save field settings  on the next screen optionally edit the settings for the field which vary depending on what field type you are creating for all fields you can edit the label   help text  text to be displayed below the field on the content editing page and required field  to make it so a value must be entered in order to save the content when editing you can also configure a default value for the field click save settings  you should be returned to the manage fields page with your new field in the list  ',1729064404),(62,'en','help_search',' configuring field display for an entity subtype goal configure the formatters used to display the fields of an entity subtype their order in the display and the formatter settings see managing content structure for background information steps navigate to the page for managing the entity type you want to add the field to for example to add a field to a content type in the manage administrative menu navigate to structure   content types  find the particular subtype that you want to configure the display of and click manage display in the operations list use the drag arrows to order the fields in your preferred order drag any fields that you do not wish to see in the display to the disabled section in the label column select the position for each field label in the display or  hidden  to hide a label you can also choose  visually hidden if you want the label s text to appear in the html page so that screen readers and search engines can read it but it will not be visible in the format column select the formatter for displaying each field after selecting the desired formatters click the settings gear in each row to change the settings for the formatter when you are done making changes click save  test the display for your entity subtype by viewing an entity if needed return to these steps to further refine the display  ',1729064404),(63,'en','help_search',' configuring the edit form for an entity subtype goal configure the widgets used to edit the fields of an entity subtype their order on the form and the widget settings see managing content structure for background information steps navigate to the page for managing the entity type you want to add the field to for example to add a field to a content type in the manage administrative menu navigate to structure   content types  find the particular subtype that you want to configure the editing form for and click manage form display in the operations list use the drag arrows to order the fields in your preferred order drag any fields that you do not wish to see on the editing form to the disabled section in the widget column select the widget for editing each field after selecting the desired widgets click the settings gear in each row to change the settings for the widget when you are done making changes click save  test the editing form for your entity subtype by editing or creating an entity if needed return to these steps to further refine the form  ',1729064404),(64,'en','help_search',' adding a reference field to an entity subtype goal add an entity reference field to an entity subtype see managing content structure for more information on entities and reference fields steps navigate to the page for managing the entity subtype you want to add the field to for example to add a field to a content type in the manage administrative menu navigate to structure   content types  find the particular subtype that you want to add the field to and click manage fields  click add field  in add a new field  select the type of reference field you want to add the reference section of the select list shows the most common types of reference field choose other  if the entity type you want to reference is not listed the label field should now be visible enter a label for the field which is used as the field label for both content editing and content display click save and continue  on the next screen verify that the type of entity you want to reference is shown in type of item to reference  or select it if not enter a value for allowed number of values  you can limit the field to one value per entity item a set number of values or set it to have unlimited values click save field settings  on the next screen optionally edit the settings for label   help text  text to be displayed below the field on the content editing page and required field  to make it so a value must be entered in order to save the content when editing in the reference type section you will usually want to limit the entity subtypes that can be referenced for example if you are creating a content reference you can check one or two content type choices the choices will be easier for content editors to scan if you also choose a sort value normally the entity title or label field click save settings  you should be returned to the manage fields page with your new field in the list  ',1729064404),(65,'en','help_search',' creating a content item goal create and publish a content item see managing content for more about content types and content items who can create content  users with the access the content overview page permission can visit the content page as described in this topic each content type has its own create permissions for example to create content of type article a user would need the article create new content permission in addition users with the bypass content access control or administer content permission can create content items of all types some contributed modules change the permission structure for creating content steps in the manage administrative menu navigate to content  click add content  if there is more than one content type defined on your site that you have permission to create click the name of the type of content you want to create on the content edit form enter the title of your content which will show as the page title when the content item is displayed on a page and also as the label for the content item in administration screens fill in the other fields shown on the edit form for this specific content type leave the published field checked to publish the content immediately or uncheck it to make it unpublished unpublished content is generally not shown to nonadministrative site users optionally click preview to preview the content click save  you will see the content displayed on a page additional resources basic page management drupal user guide  creating a content item drupal user guide  ',1729064404),(66,'en','help_search',' creating a content type goal create a new content type see managing content for more about content types who can create a content type  users with the administer content types permission typically administrators can create new content types steps in the manage administrative menu navigate to structure   content types  click add content type in the name field enter a name for the content type which is how it will be listed in the administrative interface optionally enter a description for the content type you may also want to adjust some of the settings in the vertical tabs section of the edit page click save and manage fields  your content type will be created and assuming you have the core field ui module installed you will be taken to the manage fields page for the content type if you do not have the core field ui module installed the button will say save instead if you have the core field ui module installed follow the steps in the related topics to add fields to the new content type set up the editing form and configure the display additional resources adding a content type drupal user guide  setting up content structure drupal user guide  ',1729064404),(67,'en','help_search',' editing a content item goal find a content item and edit it or update a group of content items in bulk see managing content for more about content types and content items who can find and edit content  users with the access the content overview page permission can use the content page to find content each content type has its own edit permissions for example to edit content of type article a user would need the article edit own content permission to edit an article they created or the article edit any content permission to edit an article someone else created in addition users with the bypass content access control or administer content permission can edit content items of all types some contributed modules change the permission structure for editing content steps in the manage administrative menu navigate to content  optionally use filters to reduce the list of content items shown  title  key word s from the title content type published status language if you enter or select filter values click filter to apply the filters optionally sort the list by clicking a column header click again to reverse the order to edit the title or other field values for one content item click edit in the row of the content item update the values and click save  a few types of edits can be done in bulk to multiple content items for example to publish several unpublished content items check the boxes in the left column right column in righttoleft languages to select the desired content items for action  select the publish content action click apply to selected items to make the change the other actions under action work in a similar manner additional resources basic page management drupal user guide  editing a content item drupal user guide  ',1729064404),(68,'en','help_search',' managing content what is a content item  a content item is a type of content entity for pagelevel content which can have fields that store text html markup images attached files and other data see managing content structure for more about content entities and fields what is a content type  content items are divided into content types  which are the entity subtypes for the content item entity type each content type has its own fields and display settings for example you might set up content types for pages articles recipes events and blog entries on your web site overview of managing content the core node module allows you to define content types and add and edit content items the core field ui module allows you to attach fields to each content type and manage the edit form and display for each content type see the related topics listed below for specific tasks many other core and contributed modules and installation profiles provide predefined content types modify the permission structure for content items and provide other functionality  ',1729064404),(69,'en','help_search',' tracking which content a user has visited what content visits are tracked  the core history module tracks when each loggedin user has most recently visited each content item page on the site this allows content to be marked as new or updated for each user meaning that it was newly created or has been updated since the last time they visited its page these records are kept for one month meaning that content older than one month is never marked as new or updated what options are available for using this tracking information  you can display the new updated status of content by creating or editing a view there is a has new content field for content views which displays the new updated marker there is also a has new content filter which limits the view to new and updated content  ',1729064404),(70,'en','help_search',' adding an image style goal add a new image style which can be used to process and display images see managing media for an overview of image styles steps in the manage administrative menu navigate to configuration   media  image styles click add image style  enter a descriptive image style name  and click create new style  under effect  choose an effect to apply and click add  configure the effect on the next page most effects require some additional configuration after they are added for example for the crop effect enter the width and height to crop the image to and choose the anchor point click add effect  repeat the previous two steps until all of the effects have been added drag to change the order of the effects then click save to save the new order the image style can now be used to format a field containing an image in your layouts or traditional field displays it can also be used as part of a responsive image style see related topics below for more information  ',1729064404),(71,'en','help_search',' managing content listings views  what is a view  a view is a listing of items on your site for example a block showing the most recent comments a page listing news items or a list of registered users the listings can be formatted in a table grid list calendar rss feed and other formats some output formats may require you to install additional contributed modules  what are the components of a view  when you first create a view you will specify what type of base data is being displayed in the view which cannot be changed after choosing a base data type you can edit the following components which allow you to specify which data to output in what order and in what format  displays  whether the output goes to a page block feed etc a single view can have multiple displays each with different settings format  the output style for each display such as content item grid table or html list fields  if the format allows the particular fields to display filter criteria  criteria to limit the data to output such as whether the content is published the type of content etc filters can be exposed to let users choose how to filter the data sort criteria  how to order the data sorting can also be exposed to users page settings   block settings  etc settings specific to the display type such as the url for a page display most display types support an access setting where you can choose a permission or role that a user must have in order to see the view header and footer  content to display at the top or bottom of the view display no results behavior  what to do if the filter criteria result in having no data to display pager  how many items to display and how to paginate if there are additional items to display advanced   contextual filters  like regular filters except the criteria come from the context  such as the current date page the view is displayed on etc advanced   relationships  additional data to pull in and display related in some way to the base data of the view such as data about the user who created the content item  advanced   exposed form  if you have exposed filters or sorts how to display the form to the user what are bulk operations  views using a table display format can include a bulk operations form which allows users with sufficient permission to select one or more items from the view and apply an administrative action to them the bulk actions available are specific to the base data type of the view for example a view of content items could support bulk publishing and unpublishing actions if you have the core actions ui module installed see the related topic configuring actions for more about actions managing views overview the core views module handles the display of views and the core views ui module allows you to create edit and delete views in the administrative interface see the related topics listed below for specific tasks if the views ui module is installed  additional resources creating listings with views drupal user guide  ',1729064404),(72,'en','help_search',' configure menu settings for a content type goal for an existing content type configure the available menus that will be shown as options on content editing screens links to content items of this type can be added to these menus during editing steps in the manage administrative menu navigate to structure  content types locate the content type you want to configure and click edit in the operations list under menu settings  check the menus that you want to be available when editing a content item of this type optionally select the default parent item  to put links to content items under a default location in the menu structure click save   ',1729064404),(73,'en','help_search',' adding a link to a menu goal add a link to a menu note that you can also add a link to a menu from the content edit page if menu settings have been configured for the content type steps in the manage administration menu navigate to structure  menus locate the desired menu and click add link in the operations list enter the menu link title to be displayed enter the link  one of the following an internal path such as  node add a full external url start typing the title of a content item and select it when the full title comes up  nolink  to display the menu link title as plain text without a link  front  to link to the front page of your site make sure that enabled is checked if not the menu link will not be displayed optionally enter a description  which will be displayed when a user hovers over the link optionally check show as expanded to automatically show the children of this link if any when this link is shown optionally select the parent link  if this menu link should be a child of another menu link click save  you will be returned to the add link page to add another link in the manage administration menu navigate to structure  menus locate the menu you just added a link to and click edit in the operations list verify that the order of links is correct if it is not drag menu links until the order is correct and click save   ',1729064404),(74,'en','help_search',' creating a menu goal create a new menu steps in the manage administration menu navigate structure  menus click add menu  enter the title for the menu which is used as the default block title if the menu is displayed as a block if desired also edit the machine name of the menu which is by default derived from the title enter an administrative summary which is displayed on the menus page if your site has more than one language choose the language for the menu click save  you will be on the menu editing page ready to add links to the menu if the core custom menu links module is installed see related topics for further tasks  ',1729064404),(75,'en','help_search',' reordering and disabling menu links goal disable menu links or change the order and hierarchy of menu links steps in the manage administration menu navigate to structure  menus click edit menu for the menu that you want to edit drag menu links into a new order or check uncheck enabled to enable or disable menu links click save to save your changes  ',1729064404),(76,'en','help_search',' creating a url alias for a content item goal give a content item page a human or seofriendly url alias you can follow similar steps to create an alias for a taxonomy term page see configuring aliases for urls for more about aliases who can create url aliases  users with the create and edit url aliases permission can create aliases to follow the steps in this topic you will also need permission to edit the content item steps locate and open the content edit form for the content item or create a new content item see related topics on creating and editing content under url alias on the edit form enter the desired alias for example aboutus make sure the alias starts with a character click save  verify that the page can be visited with the new alias for example https examplecom aboutus  additional resources creating a content item drupal user guide  ',1729064404),(77,'en','help_search',' editing a url alias goal change an existing url alias to correct the path or the alias value see configuring aliases for urls for more about aliases who can manage url aliases  users with the administer url aliases permission can edit aliases steps in the manage administration menu navigate to configuration   search and metadata   url aliases  a list of all the site s aliases will appear click edit in the dropdown button for the alias that you would like to change make the required changes and click save  you will be returned to the url alias list page note that you can also add new aliases from this page for any path on your site  ',1729064404),(78,'en','help_search',' configuring aliases for urls what is a url  url is the abbreviation for uniform resource locator which is the page s address on the web it is the name by which a browser identifies a page to display in the example visit us at examplecom   https examplecom would be the url for the home page of your website users use urls to locate content on the web what is a path  a path is the unique last part of the url for a specific function or piece of content for example for a page whose full url is https examplecom node 7  the path is node 7  here are some examples of paths you might find in your site node 7 path to a particular content item taxonomy term 6 path to a taxonomy term page user 3 path to a user profile page what is an alias  the core software allows you to provide more understandable urls for pages on your site which are called aliases  for example if you have an about us page with the path node 7  you can set up an alias of about so that your visitors will see it as https wwwexamplecom about  overview of configuring paths aliases and urls the core path module provides the url aliasing functionality the contributed pathauto module allows you to configure automaticallygenerated url aliases for content items and other pages see the related topics listed below for specific tasks additional resources concept paths aliases and urls drupal user guide  ',1729064404),(79,'en','help_search',' creating and using shortcut administrative links goal create view and use a set of shortcuts to access administrative pages what are shortcuts  shortcuts are quick links to administrative pages they are managed by the core shortcut module a site can have one or more shortcut sets  which can be shared by one or more users by default there is only one set shared by all users each set contains a limited number of shortcuts users need use shortcuts permission to view shortcuts  edit current shortcut set permission to add delete or edit the shortcuts in the set assigned to them and select any shortcut set permission to select a different shortcut set when editing their user profile there is also an administer shortcuts permission which allows an administrator to do any of these actions as well as select shortcut sets for other users steps make sure that the core shortcut module is installed and that you have a role with edit current shortcut set or administer shortcuts permission also make sure that a toolbar module is installed either the core toolbar module or a contributed module replacement navigate to an administrative page that you want in your shortcut list click the shortcut link to add the page to your shortcut list in the core claro administrative theme the link looks like a star and is displayed next to the page title however if the page is already in your shortcut set clicking the shortcut link will remove it from your shortcut set repeat until all the desired links have been added to your shortcut set click shortcuts in the toolbar to display your shortcuts and verify that the list is complete optionally click edit shortcuts at the right end of the shortcut list left end in righttoleft languages to remove links or change their order click any link in the shortcut bar to go directly to the administrative page  ',1729064404),(80,'en','help_search',' configuring taxonomy goal create a taxonomy vocabulary and add a reference field for that vocabulary to a content entity see managing taxonomy for information about taxonomy and managing content structure for more on content entities who can configure a taxonomy vocabulary  users with the administer vocabularies and terms permission can configure a vocabulary to add a field in the administrative interface the core field ui module must be installed and you will also need the administer fields permission for the entity you are adding the field to steps in the manage administrative menu navigate to structure   taxonomy  click add vocabulary  in the name field enter a name for the vocabulary for example ingredients which is how it will be shown in the administrative interface optionally add a description click save  your vocabulary will be created and you will see the page that lists all the terms in this vocabulary optionally click add term to add a term to the new vocabulary in the name field enter the term name for example butter click save  you will receive a confirmation about the term you created you may optionally continue to add more terms if you have the field ui module installed follow the instructions on the related adding a reference field to an entity subtype topic to add a taxonomy reference field to the entity type of your choice the settings page will allow you to choose the vocabulary that you created as the vocabulary to reference you may also want to configure the display and form display of the new field see related topics  additional resources setting up a taxonomy drupal user guide  ',1729064404),(81,'en','help_search',' managing taxonomy what is taxonomy  taxonomy is used to classify website content one common example of taxonomy is the tags used to classify or categorize posts in a blog website a cooking website could use an ingredients taxonomy to classify recipes individual taxonomy items are known as terms  the blog tags or recipe ingredients in these examples and a set of terms is known as a vocabulary  the set of all blog post tags or the set of all recipe ingredients in these examples technically taxonomy terms are an entity type and the entity subtypes are the vocabularies see managing content structure for more on content entities like other entities taxonomy terms can have fields attached for instance you could set up an image field to contain an icon for each term an individual vocabulary can organize its terms in a hierarchy or it could be flat for example blog tags normally have a flat structure while a recipe ingredients vocabulary could be hierarchical for example tomatoes could be a subterm of vegetables and under tomatoes you could have green and red tomatoes taxonomy terms are normally attached as reference fields to other content entities which is how you can use them to classify content when you set up a taxonomy reference field you can let users enter terms in two ways free tagging new terms can be created right on the content editing form fixed list of terms the list of terms is curated and managed outside the content editing form and users can only select from the existing list when editing content taxonomy reference fields can be added to any entity such as user accounts content blocks or regular content items if you use them to classify regular content items your site will automatically be set up with taxonomy listing pages for each term each of these pages lists all of the content items that are classified with that term overview of managing taxonomy the core taxonomy module allows you to create and edit taxonomy vocabularies and taxonomy terms the core field ui module provides a user interface for adding fields to entities including the taxonomy reference field and configuring field editing and display see the related topics listed below for specific tasks additional resources concept taxonomy drupal user guide  ',1729064404),(82,'en','help_search',' adding a new display to an existing view goal add a new display to an existing view this will allow you to display similar data to an existing view using similar settings in a new block page feed etc steps if you are not already editing your view in the manage administrative menu navigate to structure   views  find the view you want to edit and click its edit link under displays  click add  in the popup list click the link for the type of display you want to add the most common types are page and block  the new display will be added to your view and you will be editing that display optionally click the link next to display name and enter a new name to be shown for this display in the administrative interface follow the steps in editing an existing view display to edit the other settings for the display  ',1729064404),(83,'en','help_search',' adding a bulk operations form to a view goal add one or more existing actions as bulk operations to an existing tablestyle view if you have the core actions ui module installed see the related topic configuring actions for more information about actions who can edit views  the core views ui module will need to be installed and you will need administer views permission in order to edit a view steps in the manage administrative menu navigate to structure   views  a list of all views is shown find the view that you would like to edit and click edit from the dropdown button note that bulk operations work best in a view with a page display and a table format if there is not already an operations bulk form in the fields list for the view click add in the fields section to add it the exact name of the bulk form field will vary and may contain keywords like bulk update form element or operations not to be confused with operations links  which are applied to each item in a row if the bulk operations field already exists click the field name to edit its settings check the action s you want to make available in the selected actions list and click apply all displays   verify that the access settings for the view are at least as restrictive as the permissions necessary to perform the bulk operations people with permission to see the view but who don t have permission to do the bulk operations will experience problems click save  the action s will be available as bulk operations in the view  ',1729064404),(84,'en','help_search',' creating a new view goal create a new view to list content or other items on your site steps in the manage administrative menu navigate to structure   views  click add view  in the view name field enter a name for the view which is how it will be listed in the administrative interface in view settings   show  select the base data type to display in your view this cannot be changed later optionally select or enter filtering sorting and page block display settings these can be added or changed later click save and edit  your view will be created edit it following the steps in the related topics below  ',1729064404),(85,'en','help_search',' editing an existing view display goal edit an existing view display to modify what data is displayed or how it is displayed steps if you are not already editing your view in the manage administrative menu navigate to structure   views  find the view you want to edit and click its edit link under displays  click the display you want to edit find the section whose settings you want to change such as format or filter criteria  see managing content listings views for more information for sections containing lists such as fields and filter criteria  to modify or delete an existing item click the name of the item to add a new item click add in the dropdown list to change the order of items click rearrange in the dropdown list for sections containing individual settings such as title and format  there are often two links for each setting the first link shows the current value click that link to change the value if there is a second link called settings  click that link to change the settings details for example if your format is currently shown as unformatted list  click unformatted list to switch to using a grid or table format click settings next to your format type to change the settings for your chosen format when you have finished changing all the settings verify that the display is correct by clicking update preview  return to editing settings if necessary when you have verified the display click save  alternatively if you have made mistakes and want to discard your changes click cancel  additional resources creating listings with views drupal user guide  ',1729064404),(86,'en','help_search',' adding a new media type goal add a new media type that can be referenced in media reference fields media types are a content entity type see managing media for an overview of media items and media types and managing content structure for more information on content entities and fields steps in the manage administrative menu navigate to structure  media types if there is not already a media type for the type of media you want to use on your site click add media type  enter a name and description for your media type and select the media source  for most media sources there is additional information that will need to be stored with your media item in a field on your media type under media source configuration  select an existing field to reuse to store this information or select  create  to create a new field note the types of metadata in the field mapping section that can be mapped to fields on your media type click save  optionally add additional fields for the metadata noted above or for other information that you want to store to your media type by clicking on manage fields  see related topic below if you have added metadata fields click edit  under field mapping  select the fields you added for each piece of metadata information click save  you can now use this media type by adding a media reference field to any content entity subtype see related topic below  ',1729064404);
/*!40000 ALTER TABLE `search_dataset` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `search_index`
--

DROP TABLE IF EXISTS `search_index`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `search_index` (
  `word` varchar(50) NOT NULL DEFAULT '' COMMENT 'The "search_total".word that is associated with the search item.',
  `sid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "search_dataset".sid of the searchable item to which the word belongs.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "languages".langcode of the item variant.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The "search_dataset".type of the searchable item to which the word belongs.',
  `score` float DEFAULT NULL COMMENT 'The numeric score of the word, higher being more important.',
  PRIMARY KEY (`word`,`sid`,`langcode`,`type`),
  KEY `sid_type` (`sid`,`langcode`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores the search index, associating words, items and…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `search_index`
--

LOCK TABLES `search_index` WRITE;
/*!40000 ALTER TABLE `search_index` DISABLE KEYS */;
INSERT INTO `search_index` VALUES ('0a5987',1,'en','node_search',1),('0d77b5',1,'en','node_search',1.64006),('1',1,'en','node_search',6.06288),('1',53,'en','help_search',1),('100',1,'en','node_search',5.26833),('10062024',1,'en','node_search',0.473576),('100vw',1,'en','node_search',5.6886),('10px',1,'en','node_search',0.606252),('15',53,'en','help_search',1),('2',1,'en','node_search',2.82525),('2',11,'en','help_search',1),('2',53,'en','help_search',1),('200',33,'en','help_search',1),('202410',1,'en','node_search',0.839384),('2024104950565daf4845efbe68c27550a02da9webp',1,'en','node_search',0.573154),('2024108af0c4402152467886c795ee5c055211jpg',1,'en','node_search',0.697623),('20px',1,'en','node_search',18.6948),('2123',1,'en','node_search',0.472657),('238556',1,'en','node_search',0.716357),('25',1,'en','node_search',1.0883),('255',12,'en','help_search',0.7017),('3',78,'en','help_search',1),('300px',1,'en','node_search',2.7793),('30e30',1,'en','node_search',1.23148),('30px',1,'en','node_search',1.57185),('333',1,'en','node_search',0.549707),('400px',1,'en','node_search',1.38519),('403',33,'en','help_search',23),('403404',33,'en','help_search',27),('404',33,'en','help_search',23.9769),('40em',53,'en','help_search',5),('40px',1,'en','node_search',15.5951),('5',1,'en','node_search',1),('5',54,'en','help_search',13.1162),('50',1,'en','node_search',5.66449),('50vw',1,'en','node_search',5.66716),('6',1,'en','node_search',2),('6',78,'en','help_search',1),('60px',1,'en','node_search',0.860547),('640px',1,'en','node_search',4.33638),('7',78,'en','help_search',13),('721320',1,'en','node_search',0.722831),('768px',1,'en','node_search',1.40286),('9',10,'en','help_search',1),('960px',1,'en','node_search',5.59378),('999',1,'en','node_search',0.552215),('abbreviation',78,'en','help_search',1),('ability',11,'en','help_search',1),('ability',17,'en','help_search',2),('ability',18,'en','help_search',0.857458),('ability',20,'en','help_search',1),('ability',22,'en','help_search',1),('ability',30,'en','help_search',1),('able',27,'en','help_search',0.961087),('able',34,'en','help_search',2),('able',55,'en','help_search',1),('about',1,'en','help_search',1),('about',2,'en','help_search',1),('about',3,'en','help_search',1),('about',4,'en','help_search',1),('about',12,'en','help_search',1),('about',19,'en','help_search',1),('about',22,'en','help_search',2),('about',24,'en','help_search',0.902857),('about',26,'en','help_search',1),('about',29,'en','help_search',1),('about',30,'en','help_search',0.839384),('about',37,'en','help_search',1),('about',46,'en','help_search',1),('about',54,'en','help_search',1.98087),('about',55,'en','help_search',1),('about',56,'en','help_search',2),('about',57,'en','help_search',2),('about',59,'en','help_search',1.90974),('about',65,'en','help_search',1),('about',66,'en','help_search',1),('about',67,'en','help_search',1),('about',68,'en','help_search',1),('about',71,'en','help_search',1.68557),('about',76,'en','help_search',1),('about',77,'en','help_search',1),('about',78,'en','help_search',9),('about',80,'en','help_search',2),('about',83,'en','help_search',1),('aboutus',76,'en','help_search',5),('above',12,'en','help_search',0.800068),('above',23,'en','help_search',1),('above',24,'en','help_search',0.879565),('above',53,'en','help_search',1),('above',59,'en','help_search',0.869951),('above',86,'en','help_search',1),('absolute',1,'en','node_search',1),('access',11,'en','help_search',0.705825),('access',30,'en','help_search',1.7974),('access',50,'en','help_search',0.873132),('access',58,'en','help_search',4),('access',60,'en','help_search',2),('access',65,'en','help_search',8),('access',67,'en','help_search',8),('access',71,'en','help_search',4),('access',79,'en','help_search',1),('access',83,'en','help_search',4),('accessed',46,'en','help_search',1),('accessibility',23,'en','help_search',46),('accessibility',24,'en','help_search',2),('accessible',23,'en','help_search',2),('accessible',34,'en','help_search',1),('accessing',42,'en','help_search',2),('accomplish',27,'en','help_search',1),('accordion',1,'en','node_search',12.3165),('account',6,'en','help_search',4),('account',8,'en','help_search',1),('account',40,'en','help_search',36),('account',44,'en','help_search',25.989),('account',45,'en','help_search',41),('accountname',44,'en','help_search',1),('accounts',6,'en','help_search',1),('accounts',24,'en','help_search',0.913226),('accounts',25,'en','help_search',1),('accounts',30,'en','help_search',0.845322),('accounts',40,'en','help_search',1),('accounts',42,'en','help_search',46),('accounts',44,'en','help_search',30.9849),('accounts',45,'en','help_search',1),('accounts',59,'en','help_search',0.916736),('accounts',81,'en','help_search',1),('action',1,'en','node_search',12.2811),('action',18,'en','help_search',1),('action',42,'en','help_search',1),('action',58,'en','help_search',9),('action',60,'en','help_search',0.96498),('action',67,'en','help_search',8.88977),('action',71,'en','help_search',0.836446),('action',83,'en','help_search',1.98493),('actions',67,'en','help_search',0.98493),('actions',71,'en','help_search',4.06626),('actions',79,'en','help_search',1),('actions',83,'en','help_search',8),('active',3,'en','help_search',1),('active',11,'en','help_search',8.73661),('active',50,'en','help_search',0.792123),('active',53,'en','help_search',1),('active',54,'en','help_search',11.0194),('activity',24,'en','help_search',0.889397),('acts',10,'en','help_search',1),('add',5,'en','help_search',3),('add',6,'en','help_search',1),('add',7,'en','help_search',5),('add',12,'en','help_search',0.873132),('add',16,'en','help_search',3),('add',17,'en','help_search',1),('add',22,'en','help_search',1),('add',26,'en','help_search',1),('add',27,'en','help_search',1),('add',28,'en','help_search',5),('add',30,'en','help_search',0.810915),('add',40,'en','help_search',8),('add',41,'en','help_search',4),('add',47,'en','help_search',1),('add',50,'en','help_search',3.69535),('add',51,'en','help_search',4),('add',52,'en','help_search',5),('add',54,'en','help_search',2.73092),('add',55,'en','help_search',2),('add',56,'en','help_search',5),('add',61,'en','help_search',13),('add',62,'en','help_search',2),('add',63,'en','help_search',2),('add',64,'en','help_search',13),('add',65,'en','help_search',4),('add',66,'en','help_search',5),('add',68,'en','help_search',1),('add',70,'en','help_search',13),('add',73,'en','help_search',15),('add',74,'en','help_search',5),('add',77,'en','help_search',1),('add',79,'en','help_search',2),('add',80,'en','help_search',14),('add',82,'en','help_search',6),('add',83,'en','help_search',6),('add',84,'en','help_search',4),('add',85,'en','help_search',5),('add',86,'en','help_search',6),('added',12,'en','help_search',0.997306),('added',17,'en','help_search',1),('added',50,'en','help_search',1.61652),('added',55,'en','help_search',1),('added',70,'en','help_search',2),('added',72,'en','help_search',1),('added',73,'en','help_search',1),('added',79,'en','help_search',1),('added',81,'en','help_search',1),('added',82,'en','help_search',1),('added',84,'en','help_search',1),('added',86,'en','help_search',2),('adding',25,'en','help_search',1),('adding',41,'en','help_search',26),('adding',55,'en','help_search',5),('adding',61,'en','help_search',26),('adding',64,'en','help_search',26),('adding',66,'en','help_search',11),('adding',70,'en','help_search',26),('adding',73,'en','help_search',26),('adding',80,'en','help_search',5),('adding',81,'en','help_search',0.927431),('adding',82,'en','help_search',26),('adding',83,'en','help_search',26),('adding',86,'en','help_search',27),('addition',30,'en','help_search',1.81959),('addition',33,'en','help_search',1),('addition',65,'en','help_search',1),('addition',67,'en','help_search',1),('additional',5,'en','help_search',1),('additional',10,'en','help_search',18.8293),('additional',11,'en','help_search',12.9539),('additional',12,'en','help_search',11.6723),('additional',13,'en','help_search',18.5602),('additional',14,'en','help_search',20),('additional',15,'en','help_search',19),('additional',16,'en','help_search',18.1873),('additional',17,'en','help_search',19),('additional',18,'en','help_search',16.1756),('additional',19,'en','help_search',19),('additional',22,'en','help_search',1),('additional',24,'en','help_search',2),('additional',25,'en','help_search',19),('additional',27,'en','help_search',17.8997),('additional',30,'en','help_search',15.9024),('additional',31,'en','help_search',19),('additional',32,'en','help_search',19),('additional',35,'en','help_search',1),('additional',37,'en','help_search',19),('additional',46,'en','help_search',19),('additional',47,'en','help_search',1),('additional',48,'en','help_search',19),('additional',50,'en','help_search',0.774192),('additional',53,'en','help_search',19.0423),('additional',54,'en','help_search',0.869951),('additional',55,'en','help_search',16.9618),('additional',58,'en','help_search',19),('additional',59,'en','help_search',0.968904),('additional',65,'en','help_search',19),('additional',66,'en','help_search',19),('additional',67,'en','help_search',18.3346),('additional',70,'en','help_search',1),('additional',71,'en','help_search',17.6775),('additional',76,'en','help_search',19),('additional',78,'en','help_search',19),('additional',80,'en','help_search',19),('additional',81,'en','help_search',16.9618),('additional',85,'en','help_search',18.5602),('additional',86,'en','help_search',2),('address',8,'en','help_search',1),('address',32,'en','help_search',2),('address',40,'en','help_search',4),('address',45,'en','help_search',1),('address',78,'en','help_search',1),('addresses',12,'en','help_search',0.839384),('addresses',42,'en','help_search',1),('adds',14,'en','help_search',1),('adjust',1,'en','node_search',0.618696),('adjust',32,'en','help_search',1),('adjust',50,'en','help_search',0.794753),('adjust',66,'en','help_search',1),('admin',1,'en','node_search',0.475426),('admin',24,'en','help_search',15),('admin',26,'en','help_search',4),('administer',24,'en','help_search',0.96498),('administer',44,'en','help_search',4),('administer',55,'en','help_search',8),('administer',56,'en','help_search',4),('administer',57,'en','help_search',4),('administer',58,'en','help_search',4),('administer',65,'en','help_search',4),('administer',66,'en','help_search',4),('administer',67,'en','help_search',4),('administer',77,'en','help_search',4),('administer',79,'en','help_search',8),('administer',80,'en','help_search',8),('administer',83,'en','help_search',4),('administering',42,'en','help_search',1),('administration',13,'en','help_search',1),('administration',38,'en','help_search',5),('administration',39,'en','help_search',4),('administration',65,'en','help_search',1),('administration',73,'en','help_search',2),('administration',74,'en','help_search',1),('administration',75,'en','help_search',1),('administration',77,'en','help_search',1),('administrative',1,'en','help_search',1),('administrative',2,'en','help_search',1),('administrative',3,'en','help_search',1),('administrative',4,'en','help_search',1),('administrative',5,'en','help_search',1),('administrative',6,'en','help_search',2),('administrative',7,'en','help_search',1),('administrative',9,'en','help_search',1),('administrative',11,'en','help_search',2.53983),('administrative',13,'en','help_search',1),('administrative',18,'en','help_search',0.886095),('administrative',23,'en','help_search',28),('administrative',24,'en','help_search',91.3775),('administrative',26,'en','help_search',5),('administrative',27,'en','help_search',1.97808),('administrative',28,'en','help_search',1),('administrative',29,'en','help_search',1),('administrative',31,'en','help_search',1),('administrative',32,'en','help_search',3),('administrative',33,'en','help_search',1.93838),('administrative',34,'en','help_search',2),('administrative',35,'en','help_search',1),('administrative',36,'en','help_search',1),('administrative',37,'en','help_search',3),('administrative',38,'en','help_search',5),('administrative',39,'en','help_search',1),('administrative',40,'en','help_search',1),('administrative',41,'en','help_search',1),('administrative',43,'en','help_search',1),('administrative',44,'en','help_search',2),('administrative',45,'en','help_search',1),('administrative',47,'en','help_search',1),('administrative',48,'en','help_search',1),('administrative',49,'en','help_search',1),('administrative',50,'en','help_search',0.98493),('administrative',51,'en','help_search',1),('administrative',52,'en','help_search',2),('administrative',54,'en','help_search',1),('administrative',56,'en','help_search',2),('administrative',57,'en','help_search',1),('administrative',58,'en','help_search',1),('administrative',60,'en','help_search',6.9658),('administrative',61,'en','help_search',1),('administrative',62,'en','help_search',1),('administrative',63,'en','help_search',1),('administrative',64,'en','help_search',1),('administrative',65,'en','help_search',1),('administrative',66,'en','help_search',2),('administrative',67,'en','help_search',1),('administrative',70,'en','help_search',1),('administrative',71,'en','help_search',1.63414),('administrative',72,'en','help_search',1),('administrative',74,'en','help_search',1),('administrative',79,'en','help_search',30.9496),('administrative',80,'en','help_search',3),('administrative',82,'en','help_search',2),('administrative',83,'en','help_search',1),('administrative',84,'en','help_search',2),('administrative',85,'en','help_search',1),('administrative',86,'en','help_search',1),('administrator',11,'en','help_search',1),('administrator',12,'en','help_search',0.993146),('administrator',79,'en','help_search',1),('administrators',8,'en','help_search',1),('administrators',11,'en','help_search',1),('administrators',17,'en','help_search',1),('administrators',42,'en','help_search',2),('administrators',44,'en','help_search',1),('administrators',50,'en','help_search',2),('administrators',51,'en','help_search',1),('administrators',56,'en','help_search',1),('administrators',58,'en','help_search',1),('administrators',66,'en','help_search',1),('advanced',30,'en','help_search',3.59781),('advanced',71,'en','help_search',10.801),('advisories',19,'en','help_search',20),('advisory',19,'en','help_search',14),('affected',60,'en','help_search',1),('after',1,'en','node_search',1),('after',11,'en','help_search',0.766757),('after',18,'en','help_search',1),('after',29,'en','help_search',0.906287),('after',30,'en','help_search',1),('after',33,'en','help_search',0.997306),('after',50,'en','help_search',0.810915),('after',62,'en','help_search',1),('after',63,'en','help_search',1),('after',70,'en','help_search',1),('after',71,'en','help_search',1),('afterwards',18,'en','help_search',0.913226),('again',31,'en','help_search',1),('again',60,'en','help_search',1),('again',67,'en','help_search',1),('against',25,'en','help_search',1),('against',50,'en','help_search',1),('aggregation',18,'en','help_search',20.8513),('alias',44,'en','help_search',1),('alias',76,'en','help_search',35),('alias',77,'en','help_search',30),('alias',78,'en','help_search',20),('aliases',76,'en','help_search',26),('aliases',77,'en','help_search',32),('aliases',78,'en','help_search',61),('aliasing',78,'en','help_search',1),('all',1,'en','help_search',1),('all',1,'en','node_search',0.513597),('all',3,'en','help_search',4),('all',12,'en','help_search',2.28248),('all',14,'en','help_search',1),('all',19,'en','help_search',1),('all',20,'en','help_search',1),('all',24,'en','help_search',1),('all',31,'en','help_search',4),('all',42,'en','help_search',2),('all',45,'en','help_search',1),('all',47,'en','help_search',1),('all',57,'en','help_search',1),('all',58,'en','help_search',1),('all',60,'en','help_search',1),('all',61,'en','help_search',1),('all',65,'en','help_search',1),('all',67,'en','help_search',1),('all',70,'en','help_search',1),('all',77,'en','help_search',1),('all',79,'en','help_search',2),('all',80,'en','help_search',1),('all',81,'en','help_search',2.96498),('all',83,'en','help_search',5),('all',85,'en','help_search',1),('allow',8,'en','help_search',2),('allow',10,'en','help_search',0.980874),('allow',12,'en','help_search',1),('allow',50,'en','help_search',1.89945),('allow',55,'en','help_search',1),('allow',60,'en','help_search',1),('allow',71,'en','help_search',1),('allow',80,'en','help_search',1),('allow',82,'en','help_search',1),('allowed',12,'en','help_search',2.9266),('allowed',50,'en','help_search',1),('allowed',55,'en','help_search',7.69854),('allowed',57,'en','help_search',3),('allowed',61,'en','help_search',4),('allowed',64,'en','help_search',4),('allows',1,'en','node_search',1.3954),('allows',10,'en','help_search',1),('allows',12,'en','help_search',0.876337),('allows',16,'en','help_search',1),('allows',18,'en','help_search',1.90974),('allows',23,'en','help_search',1),('allows',25,'en','help_search',1),('allows',30,'en','help_search',1),('allows',42,'en','help_search',3),('allows',48,'en','help_search',2),('allows',53,'en','help_search',0.976851),('allows',59,'en','help_search',0.892724),('allows',68,'en','help_search',2),('allows',69,'en','help_search',1),('allows',71,'en','help_search',2.65179),('allows',78,'en','help_search',2),('allows',79,'en','help_search',1),('allows',81,'en','help_search',0.945829),('along',7,'en','help_search',1),('along',25,'en','help_search',1),('already',26,'en','help_search',2),('already',34,'en','help_search',1),('already',35,'en','help_search',2),('already',38,'en','help_search',2),('already',79,'en','help_search',1),('already',82,'en','help_search',1),('already',83,'en','help_search',2),('already',85,'en','help_search',1),('already',86,'en','help_search',1),('alreadyconfigured',28,'en','help_search',1),('alreadyrendered',18,'en','help_search',1),('also',1,'en','node_search',0.621888),('also',8,'en','help_search',1),('also',11,'en','help_search',1.58702),('also',12,'en','help_search',3.37064),('also',13,'en','help_search',1),('also',15,'en','help_search',1),('also',16,'en','help_search',1),('also',17,'en','help_search',2),('also',18,'en','help_search',1),('also',19,'en','help_search',1),('also',20,'en','help_search',1),('also',22,'en','help_search',3),('also',24,'en','help_search',1),('also',25,'en','help_search',1),('also',27,'en','help_search',2),('also',30,'en','help_search',1.7001),('also',31,'en','help_search',1),('also',34,'en','help_search',1),('also',35,'en','help_search',1),('also',42,'en','help_search',1),('also',50,'en','help_search',1),('also',54,'en','help_search',1),('also',55,'en','help_search',2),('also',57,'en','help_search',1),('also',58,'en','help_search',1),('also',60,'en','help_search',2),('also',61,'en','help_search',1),('also',62,'en','help_search',1),('also',64,'en','help_search',1),('also',65,'en','help_search',1),('also',66,'en','help_search',1),('also',69,'en','help_search',1),('also',70,'en','help_search',1),('also',71,'en','help_search',1),('also',73,'en','help_search',1),('also',74,'en','help_search',1),('also',76,'en','help_search',1),('also',77,'en','help_search',1),('also',79,'en','help_search',2),('also',80,'en','help_search',2),('alter',30,'en','help_search',0.857458),('alternative',30,'en','help_search',1),('alternatively',60,'en','help_search',1),('alternatively',85,'en','help_search',1),('always',5,'en','help_search',1),('always',6,'en','help_search',1),('always',7,'en','help_search',1),('always',46,'en','help_search',1),('american',30,'en','help_search',0.976851),('anchor',70,'en','help_search',4),('and',1,'en','help_search',3),('and',1,'en','node_search',65.2013),('and',2,'en','help_search',3),('and',3,'en','help_search',5),('and',4,'en','help_search',1),('and',5,'en','help_search',4),('and',6,'en','help_search',3),('and',7,'en','help_search',2),('and',8,'en','help_search',2),('and',9,'en','help_search',1),('and',10,'en','help_search',23.1993),('and',11,'en','help_search',40.2271),('and',12,'en','help_search',19.524),('and',13,'en','help_search',29.9973),('and',14,'en','help_search',62),('and',15,'en','help_search',70),('and',16,'en','help_search',9.99315),('and',17,'en','help_search',2),('and',18,'en','help_search',10.5892),('and',19,'en','help_search',26),('and',20,'en','help_search',3),('and',21,'en','help_search',2),('and',22,'en','help_search',34),('and',23,'en','help_search',3),('and',24,'en','help_search',11.5995),('and',25,'en','help_search',19),('and',26,'en','help_search',9),('and',27,'en','help_search',8.95792),('and',28,'en','help_search',6),('and',29,'en','help_search',13.7539),('and',30,'en','help_search',9.36877),('and',31,'en','help_search',1),('and',32,'en','help_search',16),('and',33,'en','help_search',26.7011),('and',34,'en','help_search',30),('and',36,'en','help_search',3),('and',37,'en','help_search',15),('and',38,'en','help_search',29),('and',40,'en','help_search',1),('and',41,'en','help_search',1),('and',42,'en','help_search',52),('and',43,'en','help_search',1),('and',44,'en','help_search',47),('and',45,'en','help_search',4),('and',46,'en','help_search',3),('and',47,'en','help_search',2),('and',48,'en','help_search',4),('and',49,'en','help_search',3),('and',50,'en','help_search',59.5847),('and',51,'en','help_search',1),('and',52,'en','help_search',2),('and',53,'en','help_search',56.4734),('and',54,'en','help_search',15.3423),('and',55,'en','help_search',6.89272),('and',56,'en','help_search',7),('and',57,'en','help_search',8),('and',58,'en','help_search',6),('and',59,'en','help_search',14.5978),('and',60,'en','help_search',3.97685),('and',61,'en','help_search',8),('and',62,'en','help_search',3),('and',63,'en','help_search',2),('and',64,'en','help_search',8),('and',65,'en','help_search',3),('and',66,'en','help_search',6),('and',67,'en','help_search',22),('and',68,'en','help_search',11),('and',69,'en','help_search',1),('and',70,'en','help_search',5),('and',71,'en','help_search',8.05703),('and',72,'en','help_search',1),('and',73,'en','help_search',4),('and',75,'en','help_search',27),('and',76,'en','help_search',6),('and',77,'en','help_search',5),('and',78,'en','help_search',31),('and',79,'en','help_search',30.9973),('and',80,'en','help_search',9),('and',81,'en','help_search',9.71009),('and',82,'en','help_search',4),('and',83,'en','help_search',5),('and',84,'en','help_search',5),('and',85,'en','help_search',3.98902),('and',86,'en','help_search',5),('animations',1,'en','node_search',0.659351),('announcement',19,'en','help_search',1),('announcement',46,'en','help_search',11),('announcements',46,'en','help_search',93),('anonymous',6,'en','help_search',4),('anonymous',18,'en','help_search',2.93498),('anonymous',42,'en','help_search',5),('anonymous',50,'en','help_search',0.886095),('anonymous',55,'en','help_search',6),('another',8,'en','help_search',1),('another',11,'en','help_search',2.4152),('another',14,'en','help_search',1),('another',22,'en','help_search',1),('another',27,'en','help_search',0.997306),('another',36,'en','help_search',1),('another',38,'en','help_search',1),('another',39,'en','help_search',1),('another',53,'en','help_search',1),('another',54,'en','help_search',0.968904),('another',59,'en','help_search',1),('another',60,'en','help_search',1),('another',73,'en','help_search',2),('any',1,'en','node_search',1.08909),('any',3,'en','help_search',1),('any',10,'en','help_search',1),('any',11,'en','help_search',0.876337),('any',19,'en','help_search',1),('any',28,'en','help_search',1),('any',30,'en','help_search',0.920273),('any',32,'en','help_search',2),('any',37,'en','help_search',3),('any',54,'en','help_search',1),('any',62,'en','help_search',1),('any',63,'en','help_search',1),('any',67,'en','help_search',4),('any',73,'en','help_search',1),('any',77,'en','help_search',1),('any',79,'en','help_search',5.95723),('any',81,'en','help_search',1),('any',86,'en','help_search',1),('anyone',34,'en','help_search',1),('anyone',42,'en','help_search',1),('apache',30,'en','help_search',12),('api',25,'en','help_search',34),('api',53,'en','help_search',0.961087),('appear',20,'en','help_search',2),('appear',62,'en','help_search',1),('appear',77,'en','help_search',1),('appearance',10,'en','help_search',46.9579),('appearance',24,'en','help_search',3.8289),('appearance',38,'en','help_search',8),('appearance',39,'en','help_search',4),('applications',25,'en','help_search',3),('applied',16,'en','help_search',1),('applied',50,'en','help_search',1),('applied',83,'en','help_search',1),('applies',55,'en','help_search',1),('apply',19,'en','help_search',1),('apply',53,'en','help_search',1),('apply',58,'en','help_search',8),('apply',67,'en','help_search',4.97258),('apply',70,'en','help_search',1),('apply',71,'en','help_search',0.842342),('apply',83,'en','help_search',4),('appropriate',30,'en','help_search',1),('appropriate',55,'en','help_search',1),('appropriately',33,'en','help_search',1),('approval',44,'en','help_search',1),('approved',44,'en','help_search',1),('archive',1,'en','help_search',2),('archive',3,'en','help_search',6),('archive',11,'en','help_search',1.60282),('are',1,'en','node_search',14.9024),('are',5,'en','help_search',19),('are',6,'en','help_search',1),('are',8,'en','help_search',21),('are',10,'en','help_search',1),('are',11,'en','help_search',24.2128),('are',12,'en','help_search',59.5296),('are',13,'en','help_search',39.9973),('are',14,'en','help_search',19),('are',15,'en','help_search',3),('are',16,'en','help_search',23),('are',18,'en','help_search',4.78255),('are',19,'en','help_search',44),('are',22,'en','help_search',2),('are',23,'en','help_search',3.98902),('are',24,'en','help_search',41),('are',25,'en','help_search',2),('are',26,'en','help_search',2),('are',27,'en','help_search',61),('are',29,'en','help_search',1),('are',30,'en','help_search',58.7594),('are',31,'en','help_search',2),('are',32,'en','help_search',1),('are',33,'en','help_search',19.9097),('are',34,'en','help_search',1),('are',35,'en','help_search',1),('are',36,'en','help_search',2),('are',37,'en','help_search',2),('are',40,'en','help_search',1),('are',42,'en','help_search',6),('are',44,'en','help_search',69.9769),('are',46,'en','help_search',19),('are',48,'en','help_search',41),('are',50,'en','help_search',42),('are',53,'en','help_search',62),('are',54,'en','help_search',2),('are',55,'en','help_search',7.50101),('are',57,'en','help_search',5),('are',58,'en','help_search',2),('are',59,'en','help_search',5),('are',60,'en','help_search',19),('are',61,'en','help_search',1),('are',62,'en','help_search',1),('are',63,'en','help_search',1),('are',64,'en','help_search',1),('are',68,'en','help_search',2),('are',69,'en','help_search',39),('are',70,'en','help_search',1),('are',71,'en','help_search',37.225),('are',78,'en','help_search',2),('are',79,'en','help_search',21),('are',80,'en','help_search',1),('are',81,'en','help_search',4.96109),('are',82,'en','help_search',2),('are',83,'en','help_search',2),('are',85,'en','help_search',2),('are',86,'en','help_search',1),('area',45,'en','help_search',1),('area',48,'en','help_search',1),('area',60,'en','help_search',5.98902),('areas',60,'en','help_search',1),('arrows',62,'en','help_search',1),('arrows',63,'en','help_search',1),('article',65,'en','help_search',2),('article',67,'en','help_search',11),('articles',59,'en','help_search',1),('articles',68,'en','help_search',1),('aspect',24,'en','help_search',0.869951),('aspects',24,'en','help_search',0.857458),('asset',10,'en','help_search',1),('assign',50,'en','help_search',1),('assign',53,'en','help_search',0.953396),('assigned',42,'en','help_search',2),('assigned',79,'en','help_search',1),('assistive',23,'en','help_search',1),('associate',12,'en','help_search',0.78951),('associate',16,'en','help_search',1),('associate',50,'en','help_search',1),('associated',54,'en','help_search',1),('associates',12,'en','help_search',0.729424),('association',46,'en','help_search',2),('assume',54,'en','help_search',0.957226),('assuming',66,'en','help_search',1),('assumptions',31,'en','help_search',1),('attach',48,'en','help_search',1),('attach',59,'en','help_search',1.77549),('attach',68,'en','help_search',1),('attached',12,'en','help_search',1),('attached',55,'en','help_search',1),('attached',59,'en','help_search',1),('attached',68,'en','help_search',1),('attached',81,'en','help_search',2),('attention',43,'en','help_search',1),('attribute',12,'en','help_search',0.687638),('audio',16,'en','help_search',1),('authenticated',6,'en','help_search',4),('authenticated',18,'en','help_search',0.968904),('authenticated',25,'en','help_search',1),('authenticated',42,'en','help_search',5),('authenticating',25,'en','help_search',1),('authentication',25,'en','help_search',34),('authoring',50,'en','help_search',3.85992),('authoring',54,'en','help_search',4),('authorized',33,'en','help_search',1),('auto',1,'en','node_search',8.05772),('automated',13,'en','help_search',3.98776),('automatic',18,'en','help_search',1),('automatic',22,'en','help_search',1),('automatically',1,'en','node_search',0.509287),('automatically',13,'en','help_search',1),('automatically',27,'en','help_search',1.98902),('automatically',73,'en','help_search',1),('automatically',81,'en','help_search',0.98493),('automaticallygenerated',52,'en','help_search',1),('automaticallygenerated',78,'en','help_search',1),('available',12,'en','help_search',47.9205),('available',13,'en','help_search',19),('available',22,'en','help_search',1),('available',24,'en','help_search',20),('available',28,'en','help_search',2),('available',37,'en','help_search',6),('available',47,'en','help_search',1),('available',50,'en','help_search',19),('available',54,'en','help_search',4.73881),('available',69,'en','help_search',19),('available',71,'en','help_search',0.827757),('available',72,'en','help_search',2),('available',83,'en','help_search',1.98493),('avoid',50,'en','help_search',0.808176),('aware',33,'en','help_search',0.906287),('away',1,'en','node_search',1),('away',31,'en','help_search',1),('back',34,'en','help_search',1),('background',1,'en','node_search',4.36563),('background',62,'en','help_search',1),('background',63,'en','help_search',1),('backgroundcolor',1,'en','node_search',3.87154),('backgroundposition',1,'en','node_search',2.09516),('backgroundsize',1,'en','node_search',2.65925),('bad',59,'en','help_search',1),('ban',42,'en','help_search',2),('bar',79,'en','help_search',0.957226),('base',10,'en','help_search',21),('base',39,'en','help_search',1),('base',71,'en','help_search',6.70772),('base',84,'en','help_search',1),('based',1,'en','node_search',0.899454),('basic',1,'en','node_search',11.7365),('basic',10,'en','help_search',1),('basic',25,'en','help_search',33),('basic',32,'en','help_search',31),('basic',33,'en','help_search',4),('basic',59,'en','help_search',1),('basic',65,'en','help_search',11),('basic',67,'en','help_search',10.5295),('beautifully',1,'en','node_search',0.662985),('because',16,'en','help_search',1),('because',18,'en','help_search',1),('because',39,'en','help_search',1),('become',23,'en','help_search',1),('becomes',16,'en','help_search',1),('been',11,'en','help_search',2.61181),('been',27,'en','help_search',1),('been',29,'en','help_search',2.7263),('been',35,'en','help_search',1),('been',38,'en','help_search',1),('been',42,'en','help_search',1),('been',69,'en','help_search',1),('been',70,'en','help_search',1),('been',73,'en','help_search',1),('been',79,'en','help_search',1),('before',15,'en','help_search',1),('before',18,'en','help_search',1),('before',55,'en','help_search',0.96498),('before',59,'en','help_search',1.93838),('behaves',11,'en','help_search',1),('behaving',15,'en','help_search',1),('behavior',30,'en','help_search',1),('behavior',59,'en','help_search',1),('behavior',71,'en','help_search',3.8289),('behind',12,'en','help_search',0.759465),('being',8,'en','help_search',1),('being',11,'en','help_search',0.78951),('being',34,'en','help_search',1),('being',39,'en','help_search',3),('being',50,'en','help_search',0.819249),('being',59,'en','help_search',1),('being',71,'en','help_search',1),('believe',29,'en','help_search',0.931053),('belong',12,'en','help_search',0.923838),('below',1,'en','node_search',0.483934),('below',2,'en','help_search',1),('below',8,'en','help_search',1),('below',10,'en','help_search',0.949597),('below',11,'en','help_search',0.685676),('below',12,'en','help_search',2.89048),('below',14,'en','help_search',1),('below',15,'en','help_search',1),('below',16,'en','help_search',0.968904),('below',17,'en','help_search',1),('below',19,'en','help_search',1),('below',21,'en','help_search',1),('below',22,'en','help_search',1),('below',24,'en','help_search',0.863659),('below',30,'en','help_search',0.792123),('below',42,'en','help_search',1),('below',48,'en','help_search',1),('below',59,'en','help_search',0.857458),('below',61,'en','help_search',1),('below',64,'en','help_search',1),('below',68,'en','help_search',1),('below',70,'en','help_search',1),('below',71,'en','help_search',0.786915),('below',78,'en','help_search',1),('below',81,'en','help_search',0.902857),('below',84,'en','help_search',1),('below',86,'en','help_search',2),('besides',12,'en','help_search',0.630018),('besides',54,'en','help_search',1),('best',23,'en','help_search',2),('best',53,'en','help_search',1),('best',83,'en','help_search',1),('between',3,'en','help_search',1),('between',11,'en','help_search',3.79218),('between',12,'en','help_search',1.8477),('between',24,'en','help_search',0.949597),('between',53,'en','help_search',1),('between',54,'en','help_search',1.81472),('bgimage1webp',1,'en','node_search',0.836446),('big',18,'en','help_search',0.949597),('bigpipe',18,'en','help_search',9.23322),('blank',33,'en','help_search',1),('block',1,'en','node_search',13.2018),('block',5,'en','help_search',1),('block',12,'en','help_search',8.62029),('block',17,'en','help_search',2),('block',20,'en','help_search',2),('block',22,'en','help_search',4),('block',24,'en','help_search',1),('block',26,'en','help_search',9),('block',27,'en','help_search',1.98493),('block',30,'en','help_search',1.73835),('block',47,'en','help_search',52),('block',48,'en','help_search',57),('block',49,'en','help_search',53),('block',51,'en','help_search',34),('block',52,'en','help_search',43),('block',60,'en','help_search',5),('block',71,'en','help_search',6),('block',74,'en','help_search',2),('block',82,'en','help_search',5),('block',84,'en','help_search',1),('blocked',44,'en','help_search',1),('blocks',1,'en','node_search',1.36795),('blocks',10,'en','help_search',2),('blocks',22,'en','help_search',1),('blocks',24,'en','help_search',0.989021),('blocks',47,'en','help_search',8),('blocks',48,'en','help_search',102),('blocks',51,'en','help_search',1),('blocks',81,'en','help_search',1),('blog',59,'en','help_search',2),('blog',68,'en','help_search',1),('blog',81,'en','help_search',4),('blogs',1,'en','node_search',1),('body',1,'en','node_search',2.82961),('body',27,'en','help_search',1),('body',51,'en','help_search',1),('body',59,'en','help_search',1),('boolean',12,'en','help_search',0.899454),('bootstrap',1,'en','node_search',11.71),('border',1,'en','node_search',1.24381),('both',5,'en','help_search',1),('both',6,'en','help_search',1),('both',18,'en','help_search',0.972861),('both',23,'en','help_search',0.997306),('both',29,'en','help_search',1),('both',30,'en','help_search',1),('both',33,'en','help_search',1),('both',50,'en','help_search',1),('both',61,'en','help_search',1),('both',64,'en','help_search',1),('bottom',1,'en','node_search',1.5205),('bottom',35,'en','help_search',1),('bottom',36,'en','help_search',1),('bottom',38,'en','help_search',1),('bottom',45,'en','help_search',1),('bottom',71,'en','help_search',0.96498),('box',1,'en','node_search',0.628375),('box',2,'en','help_search',2),('box',4,'en','help_search',1),('box',6,'en','help_search',1),('box',35,'en','help_search',3),('box',36,'en','help_search',2),('box',44,'en','help_search',1),('box',47,'en','help_search',1),('boxes',48,'en','help_search',1),('boxes',58,'en','help_search',2),('boxes',67,'en','help_search',1),('brackets',44,'en','help_search',1),('break',1,'en','node_search',1),('break',50,'en','help_search',1),('breakpoint',10,'en','help_search',0.976851),('breakpoint',16,'en','help_search',0.997306),('breakpoint',53,'en','help_search',52.2799),('breakpointenabled',16,'en','help_search',0.993146),('breakpoints',16,'en','help_search',1),('breakpoints',53,'en','help_search',85.8495),('breaks',29,'en','help_search',1),('breaks',50,'en','help_search',3),('browse',3,'en','help_search',1),('browser',2,'en','help_search',1),('browser',16,'en','help_search',1.98087),('browser',18,'en','help_search',0.909743),('browser',78,'en','help_search',1),('bugs',19,'en','help_search',3),('bugs',33,'en','help_search',1),('buider',1,'en','node_search',27),('build',1,'en','node_search',10.4721),('builder',10,'en','help_search',1.98087),('builder',12,'en','help_search',0.600219),('building',1,'en','node_search',1),('building',10,'en','help_search',1),('builtin',22,'en','help_search',1),('builtin',23,'en','help_search',1),('bulk',18,'en','help_search',0.902857),('bulk',67,'en','help_search',2),('bulk',71,'en','help_search',18.9762),('bulk',83,'en','help_search',37.9822),('bunch',1,'en','node_search',13.4107),('but',10,'en','help_search',1),('but',12,'en','help_search',1),('but',13,'en','help_search',1),('but',22,'en','help_search',1),('but',31,'en','help_search',1),('but',33,'en','help_search',2),('but',39,'en','help_search',1),('but',47,'en','help_search',1),('but',55,'en','help_search',1.81991),('but',57,'en','help_search',1),('but',62,'en','help_search',1),('but',83,'en','help_search',1),('butter',80,'en','help_search',1),('button',1,'en','node_search',23.42),('button',12,'en','help_search',2.54671),('button',20,'en','help_search',1),('button',30,'en','help_search',1),('button',54,'en','help_search',1.81268),('button',58,'en','help_search',1),('button',60,'en','help_search',4.99731),('button',66,'en','help_search',1),('button',77,'en','help_search',1),('button',83,'en','help_search',1),('buttons',54,'en','help_search',10.2472),('buttons',60,'en','help_search',1),('bypass',65,'en','help_search',4),('bypass',67,'en','help_search',4),('cache',15,'en','help_search',1),('cache',18,'en','help_search',22.2999),('cache',26,'en','help_search',1),('cache',31,'en','help_search',58),('cache',34,'en','help_search',2),('cacheable',18,'en','help_search',0.934703),('cached',18,'en','help_search',2),('cached',31,'en','help_search',7),('caches',18,'en','help_search',1.97286),('caches',31,'en','help_search',4),('caching',18,'en','help_search',21),('calc',1,'en','node_search',5.66984),('calculated',18,'en','help_search',1.9496),('calculation',31,'en','help_search',1),('calculations',18,'en','help_search',1),('calculations',31,'en','help_search',2),('calendar',71,'en','help_search',1),('call',1,'en','node_search',12.2825),('called',1,'en','node_search',0.774192),('called',11,'en','help_search',0.886095),('called',13,'en','help_search',1),('called',25,'en','help_search',1),('called',27,'en','help_search',1),('called',29,'en','help_search',1),('called',54,'en','help_search',1),('called',78,'en','help_search',1),('called',85,'en','help_search',1),('can',1,'en','node_search',36.9961),('can',5,'en','help_search',2),('can',6,'en','help_search',1),('can',8,'en','help_search',3),('can',10,'en','help_search',3),('can',11,'en','help_search',5.18083),('can',12,'en','help_search',8.51489),('can',13,'en','help_search',4),('can',14,'en','help_search',2),('can',15,'en','help_search',2),('can',16,'en','help_search',4.98493),('can',17,'en','help_search',3),('can',18,'en','help_search',21),('can',20,'en','help_search',19),('can',21,'en','help_search',1),('can',22,'en','help_search',26),('can',23,'en','help_search',1),('can',24,'en','help_search',3),('can',25,'en','help_search',1),('can',26,'en','help_search',2),('can',27,'en','help_search',21),('can',29,'en','help_search',1),('can',30,'en','help_search',4.67183),('can',31,'en','help_search',2),('can',33,'en','help_search',23),('can',35,'en','help_search',1),('can',36,'en','help_search',1),('can',37,'en','help_search',1),('can',42,'en','help_search',1),('can',44,'en','help_search',8),('can',45,'en','help_search',1),('can',46,'en','help_search',40),('can',47,'en','help_search',1),('can',48,'en','help_search',3),('can',50,'en','help_search',5.89945),('can',51,'en','help_search',1),('can',53,'en','help_search',3.96109),('can',55,'en','help_search',19.9167),('can',56,'en','help_search',21),('can',57,'en','help_search',19),('can',58,'en','help_search',21),('can',59,'en','help_search',4.87957),('can',61,'en','help_search',3),('can',62,'en','help_search',2),('can',64,'en','help_search',3),('can',65,'en','help_search',21),('can',66,'en','help_search',20),('can',67,'en','help_search',22),('can',68,'en','help_search',1),('can',69,'en','help_search',1),('can',70,'en','help_search',3),('can',71,'en','help_search',6.85746),('can',72,'en','help_search',1),('can',73,'en','help_search',1),('can',76,'en','help_search',22),('can',77,'en','help_search',21),('can',78,'en','help_search',1),('can',79,'en','help_search',2),('can',80,'en','help_search',20),('can',81,'en','help_search',7),('can',83,'en','help_search',19),('can',84,'en','help_search',1),('can',86,'en','help_search',3),('cancel',45,'en','help_search',8),('cancel',60,'en','help_search',0.968904),('cancel',85,'en','help_search',3.9235),('canceled',44,'en','help_search',5.98902),('cannot',14,'en','help_search',1),('cannot',36,'en','help_search',1),('cannot',39,'en','help_search',1),('cannot',55,'en','help_search',1),('cannot',71,'en','help_search',1),('cannot',84,'en','help_search',1),('captcha',59,'en','help_search',0.945829),('carefully',50,'en','help_search',0.833529),('carousel',1,'en','node_search',12.2741),('case',12,'en','help_search',0.646943),('categorize',81,'en','help_search',1),('center',1,'en','node_search',4.77076),('certain',23,'en','help_search',1),('certain',42,'en','help_search',1),('challenge',23,'en','help_search',1),('change',5,'en','help_search',2),('change',8,'en','help_search',1),('change',10,'en','help_search',1.96621),('change',34,'en','help_search',1),('change',40,'en','help_search',1),('change',41,'en','help_search',1),('change',47,'en','help_search',4),('change',52,'en','help_search',1),('change',55,'en','help_search',1),('change',58,'en','help_search',1),('change',62,'en','help_search',1),('change',63,'en','help_search',1),('change',65,'en','help_search',1),('change',67,'en','help_search',1.98493),('change',70,'en','help_search',1),('change',75,'en','help_search',1),('change',77,'en','help_search',2),('change',79,'en','help_search',0.96498),('change',85,'en','help_search',5),('changed',29,'en','help_search',0.938382),('changed',31,'en','help_search',1),('changed',32,'en','help_search',1),('changed',38,'en','help_search',2),('changed',55,'en','help_search',1),('changed',71,'en','help_search',1),('changed',84,'en','help_search',2),('changes',3,'en','help_search',1),('changes',11,'en','help_search',2),('changes',18,'en','help_search',1.94209),('changes',53,'en','help_search',2),('changes',62,'en','help_search',1),('changes',63,'en','help_search',1),('changes',75,'en','help_search',1),('changes',77,'en','help_search',1),('changes',85,'en','help_search',0.98493),('changing',10,'en','help_search',45),('changing',32,'en','help_search',26),('changing',85,'en','help_search',1),('channel',46,'en','help_search',1),('character',12,'en','help_search',0.693594),('character',76,'en','help_search',1),('characteristics',12,'en','help_search',1.409),('characters',12,'en','help_search',0.699655),('check',6,'en','help_search',1),('check',9,'en','help_search',1),('check',26,'en','help_search',1),('check',29,'en','help_search',1),('check',34,'en','help_search',1),('check',35,'en','help_search',2),('check',36,'en','help_search',1),('check',37,'en','help_search',4),('check',40,'en','help_search',1),('check',43,'en','help_search',1),('check',44,'en','help_search',1),('check',47,'en','help_search',2),('check',50,'en','help_search',1.74863),('check',64,'en','help_search',1),('check',67,'en','help_search',1),('check',72,'en','help_search',1),('check',73,'en','help_search',1),('check',75,'en','help_search',1),('check',83,'en','help_search',1),('checkbox',35,'en','help_search',1),('checkbox',47,'en','help_search',1),('checked',37,'en','help_search',4),('checked',40,'en','help_search',1),('checked',65,'en','help_search',1),('checked',73,'en','help_search',1),('checking',58,'en','help_search',2),('child',73,'en','help_search',1),('children',73,'en','help_search',1),('chinese',29,'en','help_search',1),('choice',35,'en','help_search',1),('choice',80,'en','help_search',1),('choices',12,'en','help_search',0.643484),('choices',64,'en','help_search',2),('choose',1,'en','node_search',19),('choose',26,'en','help_search',1),('choose',38,'en','help_search',1),('choose',50,'en','help_search',1.83353),('choose',55,'en','help_search',1),('choose',62,'en','help_search',1),('choose',64,'en','help_search',2),('choose',70,'en','help_search',2),('choose',71,'en','help_search',2),('choose',74,'en','help_search',1),('choose',80,'en','help_search',1),('choosing',23,'en','help_search',1),('choosing',54,'en','help_search',1),('choosing',71,'en','help_search',1),('chose',35,'en','help_search',2),('chosen',12,'en','help_search',1.55879),('chosen',50,'en','help_search',1),('chosen',85,'en','help_search',1),('cjk',29,'en','help_search',3.97258),('ckeditor',54,'en','help_search',13.1162),('claro',26,'en','help_search',1),('claro',27,'en','help_search',0.989021),('claro',79,'en','help_search',1),('classified',81,'en','help_search',0.961087),('classify',42,'en','help_search',1),('classify',81,'en','help_search',4.99731),('clean',54,'en','help_search',1),('clear',15,'en','help_search',1),('clear',31,'en','help_search',11),('clear',34,'en','help_search',1),('cleared',31,'en','help_search',1),('clearing',26,'en','help_search',1),('clearing',31,'en','help_search',26),('clearing',34,'en','help_search',1),('cli',11,'en','help_search',0.725015),('click',1,'en','help_search',1),('click',3,'en','help_search',2),('click',4,'en','help_search',1),('click',5,'en','help_search',2),('click',6,'en','help_search',2),('click',7,'en','help_search',2),('click',9,'en','help_search',2),('click',13,'en','help_search',1.98087),('click',20,'en','help_search',3),('click',26,'en','help_search',2),('click',28,'en','help_search',4),('click',29,'en','help_search',1.91473),('click',31,'en','help_search',1),('click',32,'en','help_search',4),('click',33,'en','help_search',1.86836),('click',34,'en','help_search',2),('click',35,'en','help_search',1),('click',36,'en','help_search',2),('click',37,'en','help_search',1),('click',38,'en','help_search',3),('click',39,'en','help_search',1),('click',40,'en','help_search',2),('click',41,'en','help_search',3),('click',43,'en','help_search',1),('click',44,'en','help_search',0.972861),('click',45,'en','help_search',5),('click',47,'en','help_search',5),('click',49,'en','help_search',5),('click',50,'en','help_search',1.71539),('click',51,'en','help_search',3),('click',52,'en','help_search',4),('click',56,'en','help_search',2),('click',58,'en','help_search',3),('click',60,'en','help_search',2.98633),('click',61,'en','help_search',5),('click',62,'en','help_search',3),('click',63,'en','help_search',3),('click',64,'en','help_search',5),('click',65,'en','help_search',4),('click',66,'en','help_search',2),('click',67,'en','help_search',4.99315),('click',70,'en','help_search',5),('click',72,'en','help_search',2),('click',73,'en','help_search',4),('click',74,'en','help_search',2),('click',75,'en','help_search',2),('click',76,'en','help_search',1),('click',77,'en','help_search',2),('click',79,'en','help_search',3.94216),('click',80,'en','help_search',4),('click',82,'en','help_search',4),('click',83,'en','help_search',4.98902),('click',84,'en','help_search',2),('click',85,'en','help_search',10.9809),('click',86,'en','help_search',4),('clicked',60,'en','help_search',1),('clicking',23,'en','help_search',1),('clicking',55,'en','help_search',0.98493),('clicking',57,'en','help_search',1),('clicking',60,'en','help_search',1),('clicking',67,'en','help_search',1),('clicking',79,'en','help_search',1),('clicking',85,'en','help_search',1),('clicking',86,'en','help_search',1),('clicks',30,'en','help_search',1),('clipboard',2,'en','help_search',1),('clipboard',4,'en','help_search',2),('cloned',11,'en','help_search',0.842342),('clones',11,'en','help_search',0.860547),('cloning',11,'en','help_search',0.857458),('closed',55,'en','help_search',3.63897),('closed',57,'en','help_search',4),('club',1,'en','node_search',0.595774),('code',12,'en','help_search',0.752312),('code',33,'en','help_search',4),('codebase',11,'en','help_search',0.854391),('codes',12,'en','help_search',0.781775),('codes',32,'en','help_search',12),('codes',33,'en','help_search',1),('collected',55,'en','help_search',1),('collection',12,'en','help_search',0.972861),('collection',17,'en','help_search',1),('collectively',29,'en','help_search',1),('color',1,'en','node_search',6.77628),('column',1,'en','node_search',1.63333),('column',28,'en','help_search',1),('column',29,'en','help_search',0.873132),('column',36,'en','help_search',2),('column',43,'en','help_search',1),('column',54,'en','help_search',1),('column',62,'en','help_search',2),('column',63,'en','help_search',1),('column',67,'en','help_search',3),('column1',1,'en','node_search',1.90334),('column2',1,'en','node_search',1.90166),('columns',1,'en','node_search',11.6968),('combination',1,'en','node_search',0.653974),('combinations',12,'en','help_search',0.683725),('come',1,'en','node_search',0.683725),('come',15,'en','help_search',1),('come',71,'en','help_search',0.913226),('comes',73,'en','help_search',1),('comma',1,'en','node_search',0.556022),('command',1,'en','node_search',0.496787),('command',13,'en','help_search',1),('command',54,'en','help_search',1),('commandline',11,'en','help_search',0.729424),('comment',12,'en','help_search',2.38267),('comment',55,'en','help_search',30.4076),('comment',56,'en','help_search',63),('comment',57,'en','help_search',11),('comment',58,'en','help_search',19),('comment',59,'en','help_search',55.4508),('commentary',59,'en','help_search',1),('commented',56,'en','help_search',1),('commenters',55,'en','help_search',1),('commenting',55,'en','help_search',5),('commenting',57,'en','help_search',3),('commenting',59,'en','help_search',1.87634),('comments',12,'en','help_search',0.869951),('comments',24,'en','help_search',1),('comments',55,'en','help_search',77.2798),('comments',56,'en','help_search',2),('comments',57,'en','help_search',58),('comments',58,'en','help_search',76),('comments',59,'en','help_search',51.8436),('comments',71,'en','help_search',1),('common',64,'en','help_search',1),('common',81,'en','help_search',1),('common',82,'en','help_search',1),('commonly',12,'en','help_search',1),('commonly',50,'en','help_search',1),('commonlyused',24,'en','help_search',1),('commonlyused',44,'en','help_search',1),('community',59,'en','help_search',0.931053),('communitymembers',22,'en','help_search',1),('communityprovided',22,'en','help_search',2),('compares',11,'en','help_search',0.759465),('comparison',25,'en','help_search',11),('complete',1,'en','help_search',26),('complete',1,'en','node_search',1),('complete',3,'en','help_search',28),('complete',26,'en','help_search',1),('complete',54,'en','help_search',0.839384),('complete',60,'en','help_search',0.98493),('complete',79,'en','help_search',0.993146),('completely',12,'en','help_search',0.664818),('complex',11,'en','help_search',1),('complex',25,'en','help_search',1),('complex',30,'en','help_search',0.892724),('compliance',23,'en','help_search',1),('compliant',25,'en','help_search',1),('component',1,'en','node_search',2.34273),('components',1,'en','node_search',1.72759),('components',24,'en','help_search',20),('components',71,'en','help_search',20),('composed',32,'en','help_search',1),('composer',1,'en','node_search',7.19927),('compressed',18,'en','help_search',1),('computer',2,'en','help_search',1),('computer',4,'en','help_search',1),('concept',11,'en','help_search',14.7488),('concept',12,'en','help_search',12.7),('concept',13,'en','help_search',10.6579),('concept',14,'en','help_search',11),('concept',17,'en','help_search',11),('concept',27,'en','help_search',1),('concept',31,'en','help_search',11),('concept',78,'en','help_search',11),('concept',81,'en','help_search',9.74705),('concepts',11,'en','help_search',0.819249),('conditions',31,'en','help_search',1),('conditions',47,'en','help_search',1),('config',11,'en','help_search',8),('configurable',24,'en','help_search',1),('configuration',1,'en','help_search',37),('configuration',1,'en','node_search',0.609315),('configuration',2,'en','help_search',49),('configuration',3,'en','help_search',46),('configuration',4,'en','help_search',47),('configuration',5,'en','help_search',1),('configuration',6,'en','help_search',8),('configuration',11,'en','help_search',172.074),('configuration',12,'en','help_search',5),('configuration',13,'en','help_search',7.9074),('configuration',14,'en','help_search',1),('configuration',18,'en','help_search',3.49253),('configuration',22,'en','help_search',7),('configuration',24,'en','help_search',4.70972),('configuration',26,'en','help_search',4),('configuration',28,'en','help_search',4),('configuration',29,'en','help_search',8.77905),('configuration',30,'en','help_search',2),('configuration',31,'en','help_search',4),('configuration',32,'en','help_search',20),('configuration',33,'en','help_search',16.1957),('configuration',34,'en','help_search',16),('configuration',36,'en','help_search',1),('configuration',38,'en','help_search',4),('configuration',44,'en','help_search',7.85992),('configuration',49,'en','help_search',1),('configuration',50,'en','help_search',11.2476),('configuration',54,'en','help_search',10.3077),('configuration',70,'en','help_search',5),('configuration',77,'en','help_search',4),('configuration',86,'en','help_search',4),('configure',1,'en','node_search',1.80574),('configure',6,'en','help_search',1),('configure',13,'en','help_search',4),('configure',15,'en','help_search',1),('configure',22,'en','help_search',1),('configure',24,'en','help_search',2.85752),('configure',27,'en','help_search',1),('configure',28,'en','help_search',2),('configure',30,'en','help_search',2.73993),('configure',32,'en','help_search',1),('configure',33,'en','help_search',1),('configure',44,'en','help_search',2),('configure',47,'en','help_search',5),('configure',48,'en','help_search',1),('configure',49,'en','help_search',5),('configure',50,'en','help_search',7.40885),('configure',54,'en','help_search',2.99315),('configure',55,'en','help_search',21),('configure',56,'en','help_search',1),('configure',59,'en','help_search',1),('configure',60,'en','help_search',2),('configure',61,'en','help_search',1),('configure',62,'en','help_search',2),('configure',63,'en','help_search',2),('configure',66,'en','help_search',1),('configure',70,'en','help_search',1),('configure',72,'en','help_search',28),('configure',78,'en','help_search',1),('configure',80,'en','help_search',21),('configured',17,'en','help_search',1),('configured',22,'en','help_search',1),('configured',29,'en','help_search',0.909743),('configured',30,'en','help_search',2.74449),('configured',44,'en','help_search',1),('configured',48,'en','help_search',1),('configured',55,'en','help_search',1),('configured',73,'en','help_search',1),('configuring',6,'en','help_search',26),('configuring',12,'en','help_search',0.597248),('configuring',13,'en','help_search',37.4847),('configuring',26,'en','help_search',28),('configuring',27,'en','help_search',0.953396),('configuring',28,'en','help_search',26),('configuring',29,'en','help_search',1.91323),('configuring',30,'en','help_search',42.7117),('configuring',33,'en','help_search',26),('configuring',44,'en','help_search',26),('configuring',47,'en','help_search',26),('configuring',49,'en','help_search',1),('configuring',55,'en','help_search',26),('configuring',57,'en','help_search',2),('configuring',59,'en','help_search',0.879565),('configuring',62,'en','help_search',26),('configuring',63,'en','help_search',26),('configuring',71,'en','help_search',0.805455),('configuring',76,'en','help_search',1),('configuring',77,'en','help_search',1),('configuring',78,'en','help_search',45),('configuring',80,'en','help_search',26),('configuring',81,'en','help_search',0.920273),('configuring',83,'en','help_search',1),('confirm',35,'en','help_search',1),('confirmation',36,'en','help_search',1),('confirmation',80,'en','help_search',1),('confused',83,'en','help_search',1),('connect',50,'en','help_search',0.848323),('connected',54,'en','help_search',1),('connecting',54,'en','help_search',26),('consist',12,'en','help_search',1),('consume',53,'en','help_search',1),('contact',1,'en','node_search',0.485867),('contact',5,'en','help_search',51),('contact',6,'en','help_search',44),('contact',7,'en','help_search',38),('contact',8,'en','help_search',98),('contact',9,'en','help_search',47),('contact',12,'en','help_search',0.609315),('contact',55,'en','help_search',1),('contain',12,'en','help_search',1.44349),('contain',24,'en','help_search',1),('contain',81,'en','help_search',1),('contain',83,'en','help_search',1),('container',1,'en','node_search',5.89947),('containing',1,'en','help_search',1),('containing',30,'en','help_search',0.949597),('containing',70,'en','help_search',1),('containing',85,'en','help_search',2),('contains',11,'en','help_search',0.824901),('contains',47,'en','help_search',1),('contains',60,'en','help_search',1),('contains',79,'en','help_search',1),('content',1,'en','node_search',25.8862),('content',5,'en','help_search',2),('content',10,'en','help_search',4.97685),('content',11,'en','help_search',1),('content',12,'en','help_search',89.8735),('content',13,'en','help_search',1),('content',14,'en','help_search',2),('content',16,'en','help_search',5),('content',17,'en','help_search',2),('content',20,'en','help_search',1),('content',21,'en','help_search',28),('content',22,'en','help_search',6),('content',24,'en','help_search',4.98087),('content',25,'en','help_search',3),('content',28,'en','help_search',8),('content',29,'en','help_search',7.89272),('content',30,'en','help_search',8.21653),('content',33,'en','help_search',1),('content',36,'en','help_search',1),('content',42,'en','help_search',2),('content',44,'en','help_search',1.98902),('content',45,'en','help_search',1),('content',46,'en','help_search',4),('content',48,'en','help_search',28),('content',50,'en','help_search',3.87562),('content',51,'en','help_search',36),('content',53,'en','help_search',1),('content',54,'en','help_search',4),('content',55,'en','help_search',18.6752),('content',56,'en','help_search',2),('content',57,'en','help_search',8),('content',58,'en','help_search',9),('content',59,'en','help_search',6),('content',61,'en','help_search',11),('content',62,'en','help_search',6),('content',63,'en','help_search',6),('content',64,'en','help_search',19),('content',65,'en','help_search',99.8792),('content',66,'en','help_search',88),('content',67,'en','help_search',107.333),('content',68,'en','help_search',105),('content',69,'en','help_search',62),('content',71,'en','help_search',31.6669),('content',72,'en','help_search',33),('content',73,'en','help_search',3),('content',76,'en','help_search',43),('content',78,'en','help_search',4),('content',80,'en','help_search',3),('content',81,'en','help_search',11.9596),('content',84,'en','help_search',1),('content',85,'en','help_search',1),('content',86,'en','help_search',4),('context',18,'en','help_search',1),('context',71,'en','help_search',3.62515),('contextual',20,'en','help_search',9),('contextual',24,'en','help_search',1),('contextual',60,'en','help_search',66),('contextual',71,'en','help_search',3.70972),('continue',13,'en','help_search',1),('continue',61,'en','help_search',4),('continue',64,'en','help_search',4),('continue',80,'en','help_search',1),('contributed',1,'en','node_search',5.67358),('contributed',10,'en','help_search',4),('contributed',12,'en','help_search',1.49425),('contributed',14,'en','help_search',5),('contributed',16,'en','help_search',1),('contributed',19,'en','help_search',2),('contributed',20,'en','help_search',1),('contributed',24,'en','help_search',3.8775),('contributed',25,'en','help_search',1),('contributed',27,'en','help_search',1),('contributed',30,'en','help_search',3),('contributed',35,'en','help_search',1),('contributed',38,'en','help_search',1),('contributed',54,'en','help_search',1),('contributed',59,'en','help_search',0.980874),('contributed',60,'en','help_search',1),('contributed',65,'en','help_search',1),('contributed',67,'en','help_search',1),('contributed',68,'en','help_search',1),('contributed',71,'en','help_search',1),('contributed',78,'en','help_search',1),('contributed',79,'en','help_search',1),('control',1,'en','node_search',1.86679),('control',65,'en','help_search',4),('control',67,'en','help_search',4),('convert',50,'en','help_search',2),('converted',18,'en','help_search',0.957226),('converting',25,'en','help_search',1),('converting',50,'en','help_search',1),('converts',50,'en','help_search',1),('cookies',12,'en','help_search',1),('cooking',81,'en','help_search',1),('cool',1,'en','node_search',8.13153),('copied',2,'en','help_search',1),('copied',11,'en','help_search',0.851346),('copy',2,'en','help_search',1),('copy',4,'en','help_search',1),('copy',13,'en','help_search',1),('core',8,'en','help_search',1),('core',10,'en','help_search',6.95772),('core',11,'en','help_search',1.70451),('core',12,'en','help_search',9.59002),('core',13,'en','help_search',1.99731),('core',14,'en','help_search',6),('core',15,'en','help_search',1),('core',16,'en','help_search',7.99461),('core',17,'en','help_search',2),('core',18,'en','help_search',1),('core',19,'en','help_search',3),('core',20,'en','help_search',4),('core',21,'en','help_search',1),('core',22,'en','help_search',4),('core',23,'en','help_search',1.98493),('core',24,'en','help_search',7.88282),('core',25,'en','help_search',1),('core',26,'en','help_search',1),('core',27,'en','help_search',6.98902),('core',29,'en','help_search',1),('core',30,'en','help_search',26.7867),('core',33,'en','help_search',1),('core',35,'en','help_search',1),('core',37,'en','help_search',4),('core',38,'en','help_search',1),('core',42,'en','help_search',2),('core',50,'en','help_search',3.81085),('core',54,'en','help_search',2),('core',56,'en','help_search',1),('core',59,'en','help_search',2.79901),('core',60,'en','help_search',2),('core',66,'en','help_search',3),('core',68,'en','help_search',3),('core',69,'en','help_search',1),('core',71,'en','help_search',2.41392),('core',74,'en','help_search',1),('core',78,'en','help_search',2),('core',79,'en','help_search',4),('core',80,'en','help_search',1),('core',81,'en','help_search',1.8881),('core',83,'en','help_search',2),('corner',20,'en','help_search',1),('corner',60,'en','help_search',1),('correct',6,'en','help_search',1),('correct',8,'en','help_search',1),('correct',28,'en','help_search',2),('correct',40,'en','help_search',1),('correct',44,'en','help_search',0.976851),('correct',50,'en','help_search',1.83353),('correct',73,'en','help_search',2),('correct',77,'en','help_search',1),('correct',85,'en','help_search',1),('corresponding',24,'en','help_search',0.873132),('corresponding',60,'en','help_search',0.989021),('corresponds',12,'en','help_search',0.747619),('corrupted',29,'en','help_search',0.920273),('could',57,'en','help_search',1),('could',71,'en','help_search',0.824901),('could',81,'en','help_search',6),('countdown',1,'en','node_search',11.6707),('counter',1,'en','node_search',12.2492),('counterparts',11,'en','help_search',0.747619),('country',32,'en','help_search',2),('cover',1,'en','node_search',4.40141),('covered',19,'en','help_search',2),('create',1,'en','help_search',1),('create',1,'en','node_search',9.84596),('create',7,'en','help_search',1),('create',10,'en','help_search',1),('create',11,'en','help_search',0.848323),('create',12,'en','help_search',0.949597),('create',24,'en','help_search',1),('create',33,'en','help_search',2),('create',40,'en','help_search',6),('create',41,'en','help_search',1),('create',50,'en','help_search',0.920273),('create',51,'en','help_search',2),('create',56,'en','help_search',21),('create',65,'en','help_search',26),('create',66,'en','help_search',21),('create',70,'en','help_search',4),('create',71,'en','help_search',1.7974),('create',74,'en','help_search',1),('create',76,'en','help_search',26),('create',79,'en','help_search',1),('create',80,'en','help_search',1),('create',81,'en','help_search',0.942091),('create',84,'en','help_search',1),('create',86,'en','help_search',5),('created',14,'en','help_search',1),('created',36,'en','help_search',1),('created',44,'en','help_search',29.989),('created',56,'en','help_search',1),('created',66,'en','help_search',1),('created',67,'en','help_search',2),('created',69,'en','help_search',1),('created',71,'en','help_search',0.876337),('created',80,'en','help_search',3),('created',81,'en','help_search',1),('created',84,'en','help_search',1),('creates',53,'en','help_search',1),('creates',54,'en','help_search',1),('creating',1,'en','node_search',9.78337),('creating',7,'en','help_search',26),('creating',17,'en','help_search',1),('creating',40,'en','help_search',26),('creating',42,'en','help_search',1),('creating',44,'en','help_search',1),('creating',51,'en','help_search',26),('creating',55,'en','help_search',1),('creating',56,'en','help_search',26),('creating',59,'en','help_search',0.896076),('creating',61,'en','help_search',1),('creating',63,'en','help_search',1),('creating',64,'en','help_search',1),('creating',65,'en','help_search',37.8792),('creating',66,'en','help_search',26),('creating',69,'en','help_search',1),('creating',71,'en','help_search',8.57154),('creating',74,'en','help_search',26),('creating',76,'en','help_search',38),('creating',79,'en','help_search',26),('creating',84,'en','help_search',26),('creating',85,'en','help_search',10.6579),('creatingneweptmodule',1,'en','node_search',5.50972),('creation',44,'en','help_search',19),('creators',1,'en','node_search',0.747619),('criteria',71,'en','help_search',10.8666),('criteria',85,'en','help_search',8),('critical',37,'en','help_search',2),('cron',12,'en','help_search',4),('cron',13,'en','help_search',127.986),('cron',15,'en','help_search',1),('cron',26,'en','help_search',2),('cron',29,'en','help_search',11.7259),('crop',70,'en','help_search',5),('cropping',16,'en','help_search',1),('css',10,'en','help_search',1),('css',14,'en','help_search',1),('css',18,'en','help_search',1.85135),('curated',81,'en','help_search',1),('current',11,'en','help_search',1),('current',71,'en','help_search',0.902857),('current',79,'en','help_search',8),('current',85,'en','help_search',1),('currently',12,'en','help_search',0.591395),('currently',24,'en','help_search',1),('currently',47,'en','help_search',1),('currently',54,'en','help_search',1),('currently',85,'en','help_search',1),('custom',1,'en','node_search',0.725015),('custom',12,'en','help_search',0.620288),('custom',17,'en','help_search',2),('custom',27,'en','help_search',1),('custom',74,'en','help_search',1),('customizable',1,'en','node_search',1),('customize',1,'en','node_search',0.980874),('customize',11,'en','help_search',1),('customizing',10,'en','help_search',10.2416),('customizing',14,'en','help_search',11),('data',10,'en','help_search',1),('data',11,'en','help_search',31.9136),('data',12,'en','help_search',32.3651),('data',18,'en','help_search',6.93009),('data',25,'en','help_search',5),('data',31,'en','help_search',4),('data',44,'en','help_search',1),('data',59,'en','help_search',1),('data',68,'en','help_search',1),('data',71,'en','help_search',13.4291),('data',82,'en','help_search',1),('data',84,'en','help_search',1),('data',85,'en','help_search',1),('database',10,'en','help_search',1),('database',11,'en','help_search',1.85135),('database',12,'en','help_search',0.749958),('database',15,'en','help_search',1),('database',27,'en','help_search',1),('database',29,'en','help_search',1),('database',31,'en','help_search',1),('database',37,'en','help_search',1),('date',12,'en','help_search',2.57253),('date',32,'en','help_search',21),('date',71,'en','help_search',0.899454),('dates',12,'en','help_search',1.85746),('datetime',12,'en','help_search',1.71189),('death',33,'en','help_search',4),('decide',58,'en','help_search',1),('decimalplaces',1,'en','node_search',0.561181),('default',1,'en','node_search',2.1161),('default',9,'en','help_search',43),('default',10,'en','help_search',0.98493),('default',11,'en','help_search',4.66762),('default',16,'en','help_search',1),('default',22,'en','help_search',2),('default',23,'en','help_search',2),('default',28,'en','help_search',8),('default',29,'en','help_search',7.93972),('default',32,'en','help_search',5),('default',33,'en','help_search',1),('default',38,'en','help_search',38),('default',39,'en','help_search',1),('default',55,'en','help_search',3.79839),('default',61,'en','help_search',1),('default',72,'en','help_search',5),('default',74,'en','help_search',2),('default',79,'en','help_search',1),('defaults',55,'en','help_search',0.913226),('defend',50,'en','help_search',1),('define',10,'en','help_search',1.97685),('define',11,'en','help_search',1),('define',12,'en','help_search',2.07234),('define',48,'en','help_search',1),('define',52,'en','help_search',1),('define',53,'en','help_search',3.9223),('define',68,'en','help_search',1),('defined',11,'en','help_search',2),('defined',51,'en','help_search',1),('defined',53,'en','help_search',1),('defined',65,'en','help_search',1),('defines',10,'en','help_search',1),('defines',12,'en','help_search',1),('defines',53,'en','help_search',1),('defining',11,'en','help_search',0.72066),('defining',16,'en','help_search',1),('defining',52,'en','help_search',26),('defining',53,'en','help_search',1),('delete',14,'en','help_search',1),('delete',18,'en','help_search',1),('delete',28,'en','help_search',1),('delete',36,'en','help_search',1),('delete',45,'en','help_search',3),('delete',58,'en','help_search',5),('delete',71,'en','help_search',0.797402),('delete',79,'en','help_search',1),('delete',85,'en','help_search',1),('deleted',18,'en','help_search',1),('deleted',36,'en','help_search',1),('deleted',44,'en','help_search',28),('deleting',28,'en','help_search',1),('deleting',45,'en','help_search',26),('deleting',50,'en','help_search',0.805455),('deletion',44,'en','help_search',19),('demo',1,'en','node_search',1),('demonstrate',47,'en','help_search',4),('demonstrate',49,'en','help_search',4),('dependencies',1,'en','node_search',0.512513),('dependencies',35,'en','help_search',1),('dependent',14,'en','help_search',1),('depending',12,'en','help_search',0.592848),('depending',13,'en','help_search',1),('depending',24,'en','help_search',1),('depending',42,'en','help_search',1),('depending',47,'en','help_search',1),('depending',61,'en','help_search',1),('depends',14,'en','help_search',1),('deploying',1,'en','help_search',1),('deploying',2,'en','help_search',1),('deploying',3,'en','help_search',1),('deploying',4,'en','help_search',1),('deploying',11,'en','help_search',26),('deploying',22,'en','help_search',1),('deploying',54,'en','help_search',1),('derived',74,'en','help_search',1),('described',11,'en','help_search',0.769219),('described',65,'en','help_search',1),('describes',11,'en','help_search',2),('describes',27,'en','help_search',1),('description',35,'en','help_search',1),('description',36,'en','help_search',5),('description',47,'en','help_search',1),('description',48,'en','help_search',20),('description',51,'en','help_search',1),('description',52,'en','help_search',1),('description',66,'en','help_search',4),('description',73,'en','help_search',4),('description',80,'en','help_search',1),('description',86,'en','help_search',4),('descriptive',70,'en','help_search',1),('deserialization',25,'en','help_search',4),('design',1,'en','node_search',1.42007),('design',50,'en','help_search',1),('desired',5,'en','help_search',1),('desired',13,'en','help_search',1),('desired',28,'en','help_search',2),('desired',29,'en','help_search',1),('desired',30,'en','help_search',0.854391),('desired',33,'en','help_search',1),('desired',37,'en','help_search',1),('desired',41,'en','help_search',2),('desired',44,'en','help_search',0.997306),('desired',47,'en','help_search',1),('desired',50,'en','help_search',0.909743),('desired',52,'en','help_search',1),('desired',54,'en','help_search',0.892724),('desired',55,'en','help_search',2),('desired',57,'en','help_search',1),('desired',62,'en','help_search',1),('desired',63,'en','help_search',1),('desired',67,'en','help_search',1),('desired',73,'en','help_search',1),('desired',74,'en','help_search',1),('desired',76,'en','help_search',1),('desired',79,'en','help_search',1),('destination',11,'en','help_search',1.58432),('details',18,'en','help_search',0.896076),('details',24,'en','help_search',0.860547),('details',36,'en','help_search',1),('details',49,'en','help_search',1),('details',54,'en','help_search',1),('details',85,'en','help_search',1),('determine',10,'en','help_search',1),('determines',10,'en','help_search',1),('dev',11,'en','help_search',1.83938),('development',1,'en','help_search',4),('development',1,'en','node_search',0.942091),('development',2,'en','help_search',4),('development',3,'en','help_search',4),('development',4,'en','help_search',4),('development',11,'en','help_search',16.539),('development',14,'en','help_search',1),('development',18,'en','help_search',3.4798),('development',31,'en','help_search',4),('development',33,'en','help_search',4.67026),('development',34,'en','help_search',8),('device',2,'en','help_search',1),('device',4,'en','help_search',1),('device',53,'en','help_search',2),('deviceindependent',53,'en','help_search',11),('devices',10,'en','help_search',0.96498),('diagnose',15,'en','help_search',2),('dialog',49,'en','help_search',2),('did',59,'en','help_search',2),('differences',3,'en','help_search',1),('different',8,'en','help_search',1),('different',11,'en','help_search',1.65177),('different',12,'en','help_search',3.64749),('different',16,'en','help_search',1),('different',18,'en','help_search',1.95772),('different',53,'en','help_search',0.997306),('different',59,'en','help_search',2.99731),('different',71,'en','help_search',1),('different',79,'en','help_search',1),('differentsized',10,'en','help_search',0.968904),('difficult',23,'en','help_search',1),('direct',46,'en','help_search',1),('directly',10,'en','help_search',1),('directly',46,'en','help_search',1),('directly',60,'en','help_search',1),('directly',79,'en','help_search',0.953396),('directories',11,'en','help_search',1),('directory',1,'en','node_search',0.909743),('directory',3,'en','help_search',1),('directory',11,'en','help_search',4.53613),('disable',6,'en','help_search',1),('disable',28,'en','help_search',1),('disable',57,'en','help_search',21),('disable',75,'en','help_search',2),('disabled',23,'en','help_search',1),('disabled',35,'en','help_search',1),('disabled',55,'en','help_search',3.81358),('disabled',62,'en','help_search',4),('disabled',63,'en','help_search',4),('disabling',17,'en','help_search',1),('disabling',23,'en','help_search',1),('disabling',28,'en','help_search',1),('disabling',34,'en','help_search',26),('disabling',36,'en','help_search',1),('disabling',57,'en','help_search',26),('disabling',75,'en','help_search',26),('discard',85,'en','help_search',0.989021),('discovery',10,'en','help_search',1.98087),('discussed',59,'en','help_search',0.873132),('discussion',59,'en','help_search',1),('display',1,'en','node_search',1),('display',5,'en','help_search',5),('display',12,'en','help_search',3.12375),('display',17,'en','help_search',1),('display',23,'en','help_search',1),('display',24,'en','help_search',0.906287),('display',30,'en','help_search',1),('display',33,'en','help_search',3.68109),('display',34,'en','help_search',4),('display',47,'en','help_search',4),('display',52,'en','help_search',9),('display',54,'en','help_search',0.909743),('display',56,'en','help_search',1),('display',59,'en','help_search',1),('display',60,'en','help_search',0.997306),('display',61,'en','help_search',1),('display',62,'en','help_search',37),('display',63,'en','help_search',4),('display',64,'en','help_search',1),('display',66,'en','help_search',1),('display',68,'en','help_search',2),('display',69,'en','help_search',1),('display',70,'en','help_search',1),('display',71,'en','help_search',13.1563),('display',73,'en','help_search',1),('display',78,'en','help_search',1),('display',79,'en','help_search',1),('display',80,'en','help_search',2),('display',81,'en','help_search',0.916736),('display',82,'en','help_search',38),('display',83,'en','help_search',1),('display',84,'en','help_search',2),('display',85,'en','help_search',30),('displayed',1,'en','node_search',0.664818),('displayed',9,'en','help_search',11),('displayed',10,'en','help_search',2),('displayed',11,'en','help_search',1),('displayed',12,'en','help_search',5.31879),('displayed',17,'en','help_search',1),('displayed',32,'en','help_search',4),('displayed',44,'en','help_search',1),('displayed',47,'en','help_search',3),('displayed',48,'en','help_search',1),('displayed',50,'en','help_search',1),('displayed',55,'en','help_search',1.98902),('displayed',61,'en','help_search',1),('displayed',64,'en','help_search',1),('displayed',65,'en','help_search',2),('displayed',71,'en','help_search',1.89608),('displayed',73,'en','help_search',3),('displayed',74,'en','help_search',2),('displayed',79,'en','help_search',1),('displayed',85,'en','help_search',2),('displaying',62,'en','help_search',1),('displayname',44,'en','help_search',1),('displays',24,'en','help_search',2),('displays',60,'en','help_search',1),('displays',69,'en','help_search',1),('displays',70,'en','help_search',1),('displays',71,'en','help_search',5),('displays',82,'en','help_search',4),('displays',83,'en','help_search',4),('displays',85,'en','help_search',4),('distributed',14,'en','help_search',1),('divided',12,'en','help_search',2),('divided',16,'en','help_search',1),('divided',59,'en','help_search',1),('divided',68,'en','help_search',1),('divisions',12,'en','help_search',1),('documentation',1,'en','node_search',11.503),('documentation',18,'en','help_search',27.7322),('documentation',25,'en','help_search',22),('documentation',30,'en','help_search',8.57154),('documentation',55,'en','help_search',9.711),('documentation',58,'en','help_search',11),('documented',46,'en','help_search',1),('documents',16,'en','help_search',1),('does',11,'en','help_search',1),('does',12,'en','help_search',20),('does',32,'en','help_search',1),('does',33,'en','help_search',1),('does',54,'en','help_search',0.899454),('dom',1,'en','node_search',0.630018),('don',83,'en','help_search',1),('done',11,'en','help_search',0.736141),('done',26,'en','help_search',1),('done',31,'en','help_search',2),('done',62,'en','help_search',1),('done',63,'en','help_search',1),('done',67,'en','help_search',1),('down',28,'en','help_search',1),('download',1,'en','help_search',1),('download',1,'en','node_search',51.9662),('download',10,'en','help_search',22),('download',14,'en','help_search',12),('download',22,'en','help_search',2),('download',35,'en','help_search',1),('download',54,'en','help_search',1),('downloaded',1,'en','node_search',0.510357),('downloaded',10,'en','help_search',2),('downloaded',14,'en','help_search',2),('downloaded',35,'en','help_search',1),('downloaded',38,'en','help_search',2),('downloads',22,'en','help_search',1),('drag',47,'en','help_search',1),('drag',50,'en','help_search',0.836446),('drag',54,'en','help_search',2.7113),('drag',62,'en','help_search',2),('drag',63,'en','help_search',2),('drag',70,'en','help_search',1),('drag',73,'en','help_search',1),('drag',75,'en','help_search',1),('draganddrop',23,'en','help_search',3),('dragging',23,'en','help_search',1),('dragging',54,'en','help_search',0.882818),('drastic',33,'en','help_search',1),('dropdown',58,'en','help_search',1),('dropdown',77,'en','help_search',1),('dropdown',83,'en','help_search',1),('dropdown',85,'en','help_search',2),('dropped',29,'en','help_search',1),('drupal',1,'en','node_search',55.542),('drupal',10,'en','help_search',20.2472),('drupal',11,'en','help_search',22.041),('drupal',12,'en','help_search',19.0044),('drupal',13,'en','help_search',21.0603),('drupal',14,'en','help_search',22),('drupal',15,'en','help_search',22),('drupal',17,'en','help_search',11),('drupal',19,'en','help_search',23),('drupal',31,'en','help_search',11),('drupal',37,'en','help_search',11),('drupal',46,'en','help_search',54),('drupal',48,'en','help_search',11),('drupal',53,'en','help_search',10.363),('drupal',65,'en','help_search',21.8496),('drupal',66,'en','help_search',22),('drupal',67,'en','help_search',20.8086),('drupal',71,'en','help_search',8.54373),('drupal',76,'en','help_search',11),('drupal',78,'en','help_search',11),('drupal',80,'en','help_search',11),('drupal',81,'en','help_search',9.711),('drupal',85,'en','help_search',10.572),('drupalbook',1,'en','node_search',5.25019),('drupalbookorg',1,'en','node_search',5.5211),('drupalorg',1,'en','node_search',18.6319),('drupalorg',10,'en','help_search',22),('drupalorg',14,'en','help_search',11),('drush',1,'en','node_search',0.993579),('drush',11,'en','help_search',7.43636),('due',33,'en','help_search',1),('duration',1,'en','node_search',0.559882),('during',29,'en','help_search',1),('during',72,'en','help_search',1),('dynamic',1,'en','node_search',10.4705),('dynamic',18,'en','help_search',10.2101),('each',1,'en','node_search',14.2523),('each',8,'en','help_search',1),('each',11,'en','help_search',2.89272),('each',12,'en','help_search',1.74762),('each',17,'en','help_search',1),('each',27,'en','help_search',1),('each',29,'en','help_search',0.879565),('each',30,'en','help_search',2),('each',33,'en','help_search',1),('each',38,'en','help_search',1),('each',42,'en','help_search',1),('each',48,'en','help_search',2),('each',50,'en','help_search',1.79212),('each',53,'en','help_search',1),('each',54,'en','help_search',1),('each',55,'en','help_search',0.942091),('each',59,'en','help_search',2),('each',62,'en','help_search',3),('each',63,'en','help_search',2),('each',65,'en','help_search',1),('each',67,'en','help_search',1),('each',68,'en','help_search',3),('each',69,'en','help_search',3),('each',71,'en','help_search',2),('each',79,'en','help_search',1),('each',81,'en','help_search',2.93781),('each',83,'en','help_search',1),('each',85,'en','help_search',1),('each',86,'en','help_search',1),('ease',1,'en','node_search',9.67522),('easier',1,'en','node_search',1),('easier',23,'en','help_search',2),('easier',54,'en','help_search',1),('easier',64,'en','help_search',1),('easy',30,'en','help_search',0.800068),('ebt',1,'en','node_search',171.549),('edit',9,'en','help_search',4),('edit',12,'en','help_search',1.59803),('edit',20,'en','help_search',39),('edit',24,'en','help_search',0.993146),('edit',28,'en','help_search',4),('edit',32,'en','help_search',5),('edit',41,'en','help_search',4),('edit',44,'en','help_search',1.98493),('edit',45,'en','help_search',4),('edit',47,'en','help_search',1),('edit',48,'en','help_search',1),('edit',52,'en','help_search',1),('edit',57,'en','help_search',7),('edit',58,'en','help_search',4),('edit',60,'en','help_search',1),('edit',61,'en','help_search',2),('edit',63,'en','help_search',27),('edit',64,'en','help_search',1),('edit',65,'en','help_search',2),('edit',66,'en','help_search',1),('edit',67,'en','help_search',38),('edit',68,'en','help_search',2),('edit',71,'en','help_search',1.7974),('edit',72,'en','help_search',4),('edit',73,'en','help_search',5),('edit',74,'en','help_search',1),('edit',75,'en','help_search',5),('edit',76,'en','help_search',7),('edit',77,'en','help_search',5),('edit',79,'en','help_search',12.9397),('edit',81,'en','help_search',0.938382),('edit',82,'en','help_search',6),('edit',83,'en','help_search',26),('edit',84,'en','help_search',5),('edit',85,'en','help_search',7),('edit',86,'en','help_search',4),('edited',12,'en','help_search',0.63333),('editing',1,'en','node_search',1),('editing',12,'en','help_search',0.635),('editing',16,'en','help_search',1),('editing',17,'en','help_search',1),('editing',20,'en','help_search',46),('editing',24,'en','help_search',3),('editing',42,'en','help_search',1),('editing',50,'en','help_search',1),('editing',52,'en','help_search',1),('editing',54,'en','help_search',2),('editing',56,'en','help_search',1),('editing',60,'en','help_search',1),('editing',61,'en','help_search',3),('editing',63,'en','help_search',5),('editing',64,'en','help_search',3),('editing',66,'en','help_search',1),('editing',67,'en','help_search',37.363),('editing',69,'en','help_search',1),('editing',72,'en','help_search',3),('editing',74,'en','help_search',1),('editing',76,'en','help_search',1),('editing',77,'en','help_search',26),('editing',79,'en','help_search',1),('editing',81,'en','help_search',3.91674),('editing',82,'en','help_search',3),('editing',85,'en','help_search',28),('editor',2,'en','help_search',1),('editor',50,'en','help_search',3.65618),('editor',54,'en','help_search',35.8406),('editors',50,'en','help_search',7.96127),('editors',54,'en','help_search',35.9809),('editors',64,'en','help_search',1),('edits',20,'en','help_search',1),('edits',67,'en','help_search',1),('eeeeee',1,'en','node_search',0.640063),('effect',70,'en','help_search',11),('effects',16,'en','help_search',5),('effects',70,'en','help_search',3),('efficiently',29,'en','help_search',1),('either',11,'en','help_search',0.733888),('either',12,'en','help_search',0.725015),('either',20,'en','help_search',1),('either',39,'en','help_search',1),('either',50,'en','help_search',1.86995),('either',60,'en','help_search',1),('either',79,'en','help_search',1),('element',83,'en','help_search',1),('elements',1,'en','node_search',0.736141),('else',67,'en','help_search',1),('email',8,'en','help_search',2),('email',12,'en','help_search',1.68173),('email',32,'en','help_search',2),('email',40,'en','help_search',5),('email',44,'en','help_search',24.9849),('email',45,'en','help_search',1),('embed',50,'en','help_search',0.899454),('embrace',1,'en','node_search',0.989021),('empower',1,'en','node_search',9.6397),('enable',1,'en','node_search',0.902857),('enable',6,'en','help_search',1),('enable',24,'en','help_search',1),('enable',27,'en','help_search',1),('enable',75,'en','help_search',1),('enabled',8,'en','help_search',1),('enabled',12,'en','help_search',0.71),('enabled',27,'en','help_search',1),('enabled',46,'en','help_search',2),('enabled',50,'en','help_search',4.36937),('enabled',73,'en','help_search',4),('enabled',75,'en','help_search',4),('enables',6,'en','help_search',2),('enablescrollspy',1,'en','node_search',0.548462),('enabling',23,'en','help_search',1),('enabling',25,'en','help_search',26),('enabling',34,'en','help_search',26),('enabling',36,'en','help_search',1),('enclosed',44,'en','help_search',1),('encode',53,'en','help_search',1),('end',12,'en','help_search',0.845322),('end',18,'en','help_search',1),('end',60,'en','help_search',2),('end',79,'en','help_search',1.95373),('enforces',54,'en','help_search',1),('enforcing',50,'en','help_search',1),('engaging',1,'en','node_search',0.643484),('engines',62,'en','help_search',1),('english',22,'en','help_search',3),('english',30,'en','help_search',0.972861),('enhances',1,'en','node_search',0.652202),('enhances',24,'en','help_search',1),('ensure',13,'en','help_search',1),('ensure',50,'en','help_search',0.889397),('ensures',1,'en','node_search',0.66666),('enter',26,'en','help_search',1),('enter',28,'en','help_search',1),('enter',29,'en','help_search',1),('enter',32,'en','help_search',1),('enter',33,'en','help_search',1.9689),('enter',35,'en','help_search',1),('enter',36,'en','help_search',1),('enter',40,'en','help_search',1),('enter',41,'en','help_search',1),('enter',45,'en','help_search',2),('enter',47,'en','help_search',1),('enter',50,'en','help_search',0.913226),('enter',51,'en','help_search',1),('enter',52,'en','help_search',1),('enter',55,'en','help_search',1),('enter',56,'en','help_search',1),('enter',61,'en','help_search',2),('enter',64,'en','help_search',2),('enter',65,'en','help_search',1),('enter',66,'en','help_search',2),('enter',67,'en','help_search',1),('enter',70,'en','help_search',2),('enter',73,'en','help_search',3),('enter',74,'en','help_search',2),('enter',76,'en','help_search',1),('enter',80,'en','help_search',2),('enter',81,'en','help_search',1),('enter',82,'en','help_search',1),('enter',84,'en','help_search',2),('enter',86,'en','help_search',1),('entered',61,'en','help_search',1),('entered',64,'en','help_search',1),('entering',33,'en','help_search',1),('enters',30,'en','help_search',1),('entities',10,'en','help_search',1),('entities',11,'en','help_search',2),('entities',12,'en','help_search',4.71418),('entities',16,'en','help_search',3),('entities',25,'en','help_search',6),('entities',55,'en','help_search',1),('entities',56,'en','help_search',1),('entities',57,'en','help_search',2),('entities',59,'en','help_search',2.88282),('entities',64,'en','help_search',1),('entities',68,'en','help_search',1),('entities',80,'en','help_search',1),('entities',81,'en','help_search',3.92384),('entities',86,'en','help_search',1),('entity',10,'en','help_search',2),('entity',11,'en','help_search',1),('entity',12,'en','help_search',49.9515),('entity',16,'en','help_search',1),('entity',55,'en','help_search',10.8444),('entity',56,'en','help_search',5),('entity',57,'en','help_search',5),('entity',59,'en','help_search',4),('entity',61,'en','help_search',30),('entity',62,'en','help_search',30),('entity',63,'en','help_search',30),('entity',64,'en','help_search',34),('entity',68,'en','help_search',3),('entity',80,'en','help_search',7),('entity',81,'en','help_search',3),('entity',86,'en','help_search',2),('entries',59,'en','help_search',1),('entries',68,'en','help_search',1),('ept',1,'en','node_search',331.656),('eptbasicbutton',1,'en','node_search',3.28013),('eptbasicbutton2',1,'en','node_search',3.28013),('eptcontainer',1,'en','node_search',9.06131),('eptdemolocal',1,'en','node_search',2.12212),('eptedgetoedge',1,'en','node_search',2.85394),('eptherocontainer',1,'en','node_search',5),('eptparagraphctacontent',1,'en','node_search',4.44002),('epttabs',1,'en','node_search',0.517983),('eptwidthdefault',1,'en','node_search',5.59378),('eptwidthsmall',1,'en','node_search',1.40648),('eptwidthxsmall',1,'en','node_search',1.06589),('error',15,'en','help_search',1),('error',23,'en','help_search',1),('error',33,'en','help_search',36.6811),('error',37,'en','help_search',1),('errors',23,'en','help_search',4.98493),('errors',33,'en','help_search',28.6271),('errors',37,'en','help_search',1),('etc',12,'en','help_search',1),('etc',22,'en','help_search',1),('etc',71,'en','help_search',3.89608),('etc',82,'en','help_search',1),('events',68,'en','help_search',1),('every',13,'en','help_search',3.93972),('exact',30,'en','help_search',1),('exact',83,'en','help_search',1),('example',1,'en','node_search',0.520204),('example',9,'en','help_search',1),('example',10,'en','help_search',1),('example',11,'en','help_search',2.89272),('example',12,'en','help_search',4.76159),('example',20,'en','help_search',1),('example',30,'en','help_search',1.96498),('example',33,'en','help_search',0.989021),('example',36,'en','help_search',1),('example',50,'en','help_search',0.830633),('example',55,'en','help_search',1),('example',57,'en','help_search',1),('example',59,'en','help_search',1),('example',60,'en','help_search',1),('example',61,'en','help_search',1),('example',62,'en','help_search',1),('example',63,'en','help_search',1),('example',64,'en','help_search',2),('example',65,'en','help_search',1),('example',67,'en','help_search',2),('example',68,'en','help_search',1),('example',70,'en','help_search',1),('example',71,'en','help_search',1.8249),('example',76,'en','help_search',2),('example',78,'en','help_search',3),('example',80,'en','help_search',2),('example',81,'en','help_search',3),('example',85,'en','help_search',1),('examplecom',33,'en','help_search',7.8309),('examplecom',76,'en','help_search',4),('examplecom',78,'en','help_search',12),('examples',12,'en','help_search',0.677939),('examples',16,'en','help_search',1),('examples',78,'en','help_search',1),('examples',81,'en','help_search',2),('exceed',55,'en','help_search',1),('except',71,'en','help_search',0.916736),('exchanged',25,'en','help_search',2),('exist',12,'en','help_search',0.681785),('exist',33,'en','help_search',1),('existing',24,'en','help_search',0.938382),('existing',28,'en','help_search',1),('existing',43,'en','help_search',1),('existing',45,'en','help_search',1),('existing',50,'en','help_search',0.927431),('existing',54,'en','help_search',0.993146),('existing',72,'en','help_search',1),('existing',77,'en','help_search',1),('existing',81,'en','help_search',1),('existing',82,'en','help_search',29),('existing',83,'en','help_search',2),('existing',85,'en','help_search',28),('existing',86,'en','help_search',1),('exists',33,'en','help_search',1),('exists',83,'en','help_search',1),('expand',35,'en','help_search',1),('expanded',73,'en','help_search',4),('expect',30,'en','help_search',1),('expected',15,'en','help_search',1),('experience',1,'en','node_search',2.3172),('experience',83,'en','help_search',0.997306),('experimental',14,'en','help_search',24),('experimental',35,'en','help_search',1),('expiring',44,'en','help_search',1),('explaining',54,'en','help_search',0.902857),('export',1,'en','help_search',8),('export',2,'en','help_search',7),('export',11,'en','help_search',1.51419),('exported',1,'en','help_search',1),('exported',3,'en','help_search',1),('exported',4,'en','help_search',1),('exported',11,'en','help_search',7.41884),('exporting',1,'en','help_search',26),('exporting',2,'en','help_search',26),('exporting',3,'en','help_search',1),('exporting',4,'en','help_search',1),('exporting',11,'en','help_search',1.65163),('expose',20,'en','help_search',1),('exposed',71,'en','help_search',9.36248),('exposes',25,'en','help_search',2),('extend',1,'en','node_search',0.494765),('extend',10,'en','help_search',22),('extend',14,'en','help_search',11),('extend',24,'en','help_search',3.73881),('extend',26,'en','help_search',4),('extend',35,'en','help_search',8),('extend',36,'en','help_search',4),('extended',1,'en','node_search',1),('extending',1,'en','node_search',5.42034),('extending',10,'en','help_search',10.2817),('extending',14,'en','help_search',57),('extends',14,'en','help_search',1),('extension',11,'en','help_search',4.70731),('external',73,'en','help_search',1),('extra',1,'en','node_search',55.6797),('facilitate',18,'en','help_search',1),('factors',18,'en','help_search',1),('factors',28,'en','help_search',1),('false',12,'en','help_search',0.889397),('faq',1,'en','node_search',22.263),('far',37,'en','help_search',1),('faster',18,'en','help_search',2),('faster',29,'en','help_search',1),('faulty',50,'en','help_search',1),('feature',27,'en','help_search',1),('features',14,'en','help_search',2),('features',24,'en','help_search',2),('feed',46,'en','help_search',3),('feed',71,'en','help_search',2),('feed',82,'en','help_search',1),('feedback',1,'en','node_search',7.82074),('feel',10,'en','help_search',1),('few',67,'en','help_search',1),('fewer',29,'en','help_search',1),('ffffff',1,'en','node_search',4.28013),('field',12,'en','help_search',90.2698),('field',16,'en','help_search',5),('field',21,'en','help_search',1),('field',23,'en','help_search',1),('field',50,'en','help_search',3),('field',52,'en','help_search',1),('field',55,'en','help_search',12),('field',56,'en','help_search',3),('field',57,'en','help_search',3),('field',59,'en','help_search',1.89272),('field',61,'en','help_search',58),('field',62,'en','help_search',30),('field',63,'en','help_search',3),('field',64,'en','help_search',54.9931),('field',65,'en','help_search',1),('field',66,'en','help_search',4),('field',67,'en','help_search',1),('field',68,'en','help_search',1),('field',69,'en','help_search',1),('field',70,'en','help_search',2),('field',80,'en','help_search',13),('field',81,'en','help_search',4.77171),('field',83,'en','help_search',3),('field',84,'en','help_search',1),('field',86,'en','help_search',12),('fields',5,'en','help_search',55),('fields',6,'en','help_search',3),('fields',7,'en','help_search',3),('fields',8,'en','help_search',2),('fields',10,'en','help_search',2),('fields',12,'en','help_search',36.2034),('fields',16,'en','help_search',5),('fields',23,'en','help_search',1),('fields',24,'en','help_search',0.976851),('fields',25,'en','help_search',1),('fields',48,'en','help_search',1),('fields',50,'en','help_search',1),('fields',52,'en','help_search',6),('fields',55,'en','help_search',3),('fields',56,'en','help_search',2),('fields',57,'en','help_search',1),('fields',59,'en','help_search',6.76891),('fields',61,'en','help_search',9),('fields',62,'en','help_search',3),('fields',63,'en','help_search',3),('fields',64,'en','help_search',9),('fields',65,'en','help_search',1),('fields',66,'en','help_search',9),('fields',68,'en','help_search',4),('fields',71,'en','help_search',5),('fields',80,'en','help_search',4),('fields',81,'en','help_search',3.92384),('fields',83,'en','help_search',8),('fields',85,'en','help_search',4),('fields',86,'en','help_search',10),('file',1,'en','help_search',1),('file',2,'en','help_search',2),('file',3,'en','help_search',1),('file',11,'en','help_search',2.47298),('file',12,'en','help_search',0.615536),('file',16,'en','help_search',2),('file',18,'en','help_search',19.8513),('file',27,'en','help_search',1),('files',1,'en','help_search',1),('files',1,'en','node_search',2.11312),('files',10,'en','help_search',2),('files',11,'en','help_search',2.57767),('files',12,'en','help_search',2),('files',14,'en','help_search',1),('files',16,'en','help_search',1),('files',18,'en','help_search',1),('files',24,'en','help_search',1),('files',53,'en','help_search',0.96498),('files',68,'en','help_search',1),('fill',5,'en','help_search',1),('fill',7,'en','help_search',1),('fill',8,'en','help_search',1),('fill',18,'en','help_search',0.899454),('fill',65,'en','help_search',1),('filling',23,'en','help_search',1),('filter',12,'en','help_search',1.30788),('filter',21,'en','help_search',1),('filter',35,'en','help_search',1),('filter',36,'en','help_search',1),('filter',37,'en','help_search',1),('filter',45,'en','help_search',5),('filter',50,'en','help_search',12.7833),('filter',67,'en','help_search',5),('filter',69,'en','help_search',1),('filter',71,'en','help_search',5.9534),('filter',85,'en','help_search',8),('filtering',30,'en','help_search',0.889397),('filtering',57,'en','help_search',1),('filtering',84,'en','help_search',1),('filters',12,'en','help_search',3.57125),('filters',50,'en','help_search',72.0452),('filters',54,'en','help_search',2.83669),('filters',67,'en','help_search',2),('filters',71,'en','help_search',6.48204),('finally',30,'en','help_search',0.822065),('find',1,'en','node_search',11.2641),('find',3,'en','help_search',1),('find',18,'en','help_search',0.866793),('find',20,'en','help_search',2),('find',23,'en','help_search',1),('find',24,'en','help_search',2),('find',45,'en','help_search',1),('find',47,'en','help_search',1),('find',49,'en','help_search',2),('find',57,'en','help_search',3),('find',61,'en','help_search',1),('find',62,'en','help_search',1),('find',63,'en','help_search',1),('find',64,'en','help_search',1),('find',67,'en','help_search',21),('find',78,'en','help_search',1),('find',82,'en','help_search',1),('find',83,'en','help_search',1),('find',85,'en','help_search',2),('finish',13,'en','help_search',1),('finished',34,'en','help_search',1),('finished',85,'en','help_search',1),('first',11,'en','help_search',0.76431),('first',14,'en','help_search',1),('first',18,'en','help_search',1.92384),('first',30,'en','help_search',1),('first',31,'en','help_search',1),('first',36,'en','help_search',2),('first',50,'en','help_search',0.802752),('first',55,'en','help_search',1),('first',71,'en','help_search',1),('first',85,'en','help_search',1),('fix',37,'en','help_search',1),('fixed',1,'en','node_search',0.754681),('fixed',19,'en','help_search',1),('fixed',81,'en','help_search',1),('fixing',15,'en','help_search',11),('flag',59,'en','help_search',0.923838),('flat',81,'en','help_search',2),('flexdirection',1,'en','node_search',1.63333),('flexibility',1,'en','node_search',0.98493),('flexible',1,'en','node_search',1.76922),('flexible',12,'en','help_search',0.59873),('focusing',54,'en','help_search',0.923838),('follow',6,'en','help_search',1),('follow',7,'en','help_search',1),('follow',20,'en','help_search',1),('follow',26,'en','help_search',1),('follow',28,'en','help_search',1),('follow',29,'en','help_search',0.916736),('follow',54,'en','help_search',1),('follow',55,'en','help_search',2),('follow',56,'en','help_search',1),('follow',66,'en','help_search',1),('follow',76,'en','help_search',2),('follow',80,'en','help_search',1),('follow',82,'en','help_search',1),('following',1,'en','node_search',0.482973),('following',11,'en','help_search',0.830633),('following',12,'en','help_search',0.920273),('following',16,'en','help_search',1),('following',18,'en','help_search',1),('following',24,'en','help_search',2),('following',25,'en','help_search',1),('following',59,'en','help_search',0.902857),('following',71,'en','help_search',1),('following',73,'en','help_search',1),('following',84,'en','help_search',1),('footer',1,'en','node_search',0.480114),('footer',71,'en','help_search',3.89144),('for',1,'en','help_search',1),('for',1,'en','node_search',28.42),('for',2,'en','help_search',1),('for',3,'en','help_search',1),('for',4,'en','help_search',1),('for',5,'en','help_search',2),('for',6,'en','help_search',3),('for',7,'en','help_search',1),('for',8,'en','help_search',1),('for',9,'en','help_search',2),('for',10,'en','help_search',6.89158),('for',11,'en','help_search',9.15176),('for',12,'en','help_search',28.7994),('for',13,'en','help_search',20.9931),('for',14,'en','help_search',1),('for',15,'en','help_search',2),('for',16,'en','help_search',6.94585),('for',17,'en','help_search',3),('for',18,'en','help_search',31.5331),('for',19,'en','help_search',2),('for',20,'en','help_search',5),('for',21,'en','help_search',1),('for',22,'en','help_search',1),('for',23,'en','help_search',3),('for',24,'en','help_search',5.78798),('for',25,'en','help_search',28),('for',26,'en','help_search',4),('for',27,'en','help_search',20.9496),('for',28,'en','help_search',3),('for',29,'en','help_search',5.6446),('for',30,'en','help_search',24.6358),('for',32,'en','help_search',4),('for',33,'en','help_search',7.83681),('for',34,'en','help_search',1),('for',35,'en','help_search',2),('for',36,'en','help_search',3),('for',37,'en','help_search',1),('for',38,'en','help_search',6),('for',39,'en','help_search',1),('for',40,'en','help_search',2),('for',41,'en','help_search',1),('for',42,'en','help_search',2),('for',43,'en','help_search',28),('for',44,'en','help_search',5.98633),('for',46,'en','help_search',2),('for',47,'en','help_search',4),('for',48,'en','help_search',22),('for',49,'en','help_search',1),('for',50,'en','help_search',5.52904),('for',51,'en','help_search',1),('for',52,'en','help_search',2),('for',53,'en','help_search',17.2169),('for',54,'en','help_search',2),('for',55,'en','help_search',18.4947),('for',56,'en','help_search',3),('for',57,'en','help_search',7),('for',58,'en','help_search',12),('for',59,'en','help_search',7.76413),('for',60,'en','help_search',5.98902),('for',61,'en','help_search',10),('for',62,'en','help_search',33),('for',63,'en','help_search',33),('for',64,'en','help_search',9),('for',65,'en','help_search',5),('for',66,'en','help_search',4),('for',67,'en','help_search',5.99731),('for',68,'en','help_search',8),('for',69,'en','help_search',22),('for',70,'en','help_search',4),('for',71,'en','help_search',5.41199),('for',72,'en','help_search',27),('for',73,'en','help_search',1),('for',74,'en','help_search',3),('for',75,'en','help_search',1),('for',76,'en','help_search',32),('for',77,'en','help_search',4),('for',78,'en','help_search',35),('for',79,'en','help_search',1),('for',80,'en','help_search',7),('for',81,'en','help_search',7.79579),('for',82,'en','help_search',3),('for',83,'en','help_search',3),('for',84,'en','help_search',1),('for',85,'en','help_search',6),('for',86,'en','help_search',8),('force',26,'en','help_search',1),('forcing',18,'en','help_search',1),('form',1,'en','node_search',6.63113),('form',5,'en','help_search',8),('form',6,'en','help_search',2),('form',7,'en','help_search',34),('form',8,'en','help_search',42),('form',9,'en','help_search',44),('form',11,'en','help_search',1),('form',20,'en','help_search',2),('form',23,'en','help_search',4.98493),('form',26,'en','help_search',5),('form',30,'en','help_search',8.95339),('form',33,'en','help_search',1),('form',40,'en','help_search',1),('form',45,'en','help_search',1),('form',52,'en','help_search',5),('form',53,'en','help_search',1),('form',55,'en','help_search',5.95111),('form',56,'en','help_search',1),('form',59,'en','help_search',1),('form',63,'en','help_search',35),('form',65,'en','help_search',2),('form',66,'en','help_search',1),('form',68,'en','help_search',1),('form',71,'en','help_search',5.21371),('form',76,'en','help_search',2),('form',80,'en','help_search',1),('form',81,'en','help_search',2),('form',83,'en','help_search',32),('formal',53,'en','help_search',1),('format',4,'en','help_search',1),('format',11,'en','help_search',0.810915),('format',18,'en','help_search',1),('format',25,'en','help_search',2),('format',32,'en','help_search',25),('format',50,'en','help_search',15.6114),('format',54,'en','help_search',7.64925),('format',62,'en','help_search',4),('format',70,'en','help_search',1),('format',71,'en','help_search',6.85746),('format',83,'en','help_search',1),('format',85,'en','help_search',15),('formats',25,'en','help_search',2),('formats',32,'en','help_search',7),('formats',50,'en','help_search',63.3271),('formats',54,'en','help_search',33.8367),('formats',71,'en','help_search',2),('formatted',12,'en','help_search',8.81776),('formatted',50,'en','help_search',5),('formatted',54,'en','help_search',1),('formatted',71,'en','help_search',1),('formatter',12,'en','help_search',15.5412),('formatter',62,'en','help_search',3),('formatters',12,'en','help_search',1.33517),('formatters',62,'en','help_search',5),('formatting',27,'en','help_search',1),('forms',1,'en','node_search',0.484898),('forms',5,'en','help_search',51),('forms',6,'en','help_search',34),('forms',7,'en','help_search',5),('forms',8,'en','help_search',49),('forms',9,'en','help_search',4),('forms',11,'en','help_search',0.695602),('forms',54,'en','help_search',0.842342),('found',27,'en','help_search',1),('four',12,'en','help_search',1),('framework',25,'en','help_search',1),('framework',54,'en','help_search',1),('free',81,'en','help_search',1),('from',1,'en','node_search',26.4721),('from',3,'en','help_search',1),('from',10,'en','help_search',2),('from',11,'en','help_search',2.6312),('from',12,'en','help_search',1.48323),('from',13,'en','help_search',5),('from',14,'en','help_search',1),('from',18,'en','help_search',1),('from',29,'en','help_search',1),('from',35,'en','help_search',1),('from',36,'en','help_search',1),('from',42,'en','help_search',1),('from',44,'en','help_search',1),('from',46,'en','help_search',2),('from',50,'en','help_search',1),('from',53,'en','help_search',1),('from',54,'en','help_search',2),('from',58,'en','help_search',4),('from',60,'en','help_search',0.949597),('from',67,'en','help_search',1),('from',71,'en','help_search',1.75209),('from',73,'en','help_search',1),('from',74,'en','help_search',1),('from',77,'en','help_search',1),('from',79,'en','help_search',1),('from',81,'en','help_search',1),('from',83,'en','help_search',1),('front',27,'en','help_search',1),('front',73,'en','help_search',5),('full',34,'en','help_search',2),('full',73,'en','help_search',2),('full',78,'en','help_search',1),('fullexport',11,'en','help_search',0.808176),('fully',25,'en','help_search',1),('fully',26,'en','help_search',1),('fully',29,'en','help_search',1.89272),('fully',30,'en','help_search',0.827757),('function',13,'en','help_search',1),('function',42,'en','help_search',1),('function',78,'en','help_search',1),('functionality',14,'en','help_search',29),('functionality',16,'en','help_search',1),('functionality',23,'en','help_search',1),('functionality',24,'en','help_search',2.92384),('functionality',34,'en','help_search',1),('functionality',59,'en','help_search',2.86054),('functionality',68,'en','help_search',1),('functionality',78,'en','help_search',1),('functions',54,'en','help_search',1),('further',12,'en','help_search',1.29999),('further',62,'en','help_search',1),('further',63,'en','help_search',1),('further',74,'en','help_search',1),('future',11,'en','help_search',0.927431),('future',26,'en','help_search',1),('galleries',1,'en','node_search',0.668514),('gallery',1,'en','node_search',23.847),('gap',1,'en','node_search',1.63333),('gear',62,'en','help_search',1),('gear',63,'en','help_search',1),('generally',65,'en','help_search',1),('generate',1,'en','node_search',0.495774),('generate',33,'en','help_search',2),('generated',1,'en','node_search',0.498827),('generated',33,'en','help_search',1),('generated',37,'en','help_search',1),('generated',44,'en','help_search',1),('generated',46,'en','help_search',1),('generating',33,'en','help_search',0.902857),('generic',6,'en','help_search',1),('generic',59,'en','help_search',1),('get',24,'en','help_search',0.886095),('get',54,'en','help_search',4),('getting',1,'en','node_search',27),('give',30,'en','help_search',0.802752),('give',43,'en','help_search',4),('give',60,'en','help_search',1),('give',76,'en','help_search',1),('given',12,'en','help_search',0.98493),('glightbox',1,'en','node_search',28.5681),('goal',1,'en','help_search',19),('goal',2,'en','help_search',19),('goal',3,'en','help_search',19),('goal',4,'en','help_search',19),('goal',5,'en','help_search',19),('goal',6,'en','help_search',19),('goal',7,'en','help_search',19),('goal',9,'en','help_search',19),('goal',13,'en','help_search',19),('goal',20,'en','help_search',19),('goal',26,'en','help_search',19),('goal',28,'en','help_search',19),('goal',29,'en','help_search',19),('goal',31,'en','help_search',19),('goal',32,'en','help_search',19),('goal',33,'en','help_search',19),('goal',34,'en','help_search',19),('goal',35,'en','help_search',19),('goal',36,'en','help_search',19),('goal',37,'en','help_search',19),('goal',38,'en','help_search',19),('goal',39,'en','help_search',19),('goal',40,'en','help_search',19),('goal',41,'en','help_search',19),('goal',43,'en','help_search',19),('goal',44,'en','help_search',19),('goal',45,'en','help_search',19),('goal',47,'en','help_search',19),('goal',49,'en','help_search',19),('goal',50,'en','help_search',19),('goal',51,'en','help_search',19),('goal',52,'en','help_search',19),('goal',54,'en','help_search',19),('goal',55,'en','help_search',19),('goal',56,'en','help_search',19),('goal',57,'en','help_search',19),('goal',58,'en','help_search',19),('goal',60,'en','help_search',19),('goal',61,'en','help_search',19),('goal',62,'en','help_search',19),('goal',63,'en','help_search',19),('goal',64,'en','help_search',19),('goal',65,'en','help_search',19),('goal',66,'en','help_search',19),('goal',67,'en','help_search',19),('goal',70,'en','help_search',19),('goal',72,'en','help_search',19),('goal',73,'en','help_search',19),('goal',74,'en','help_search',19),('goal',75,'en','help_search',19),('goal',76,'en','help_search',19),('goal',77,'en','help_search',19),('goal',79,'en','help_search',19),('goal',80,'en','help_search',19),('goal',82,'en','help_search',19),('goal',83,'en','help_search',19),('goal',84,'en','help_search',19),('goal',85,'en','help_search',19),('goal',86,'en','help_search',19),('goals',46,'en','help_search',1),('goes',31,'en','help_search',1),('goes',71,'en','help_search',1),('good',31,'en','help_search',1),('governance',46,'en','help_search',1),('granting',42,'en','help_search',1),('green',81,'en','help_search',1),('grid',71,'en','help_search',2),('grid',85,'en','help_search',4),('group',11,'en','help_search',1),('group',13,'en','help_search',1),('group',42,'en','help_search',1),('group',53,'en','help_search',19),('group',54,'en','help_search',5.25496),('group',67,'en','help_search',1),('grouped',11,'en','help_search',1),('grouped',12,'en','help_search',1),('groups',53,'en','help_search',22.5589),('groups',54,'en','help_search',0.866793),('guide',10,'en','help_search',10.123),('guide',11,'en','help_search',21.9999),('guide',12,'en','help_search',18.9892),('guide',13,'en','help_search',20.9751),('guide',14,'en','help_search',22),('guide',15,'en','help_search',22),('guide',17,'en','help_search',11),('guide',19,'en','help_search',11),('guide',27,'en','help_search',1),('guide',31,'en','help_search',11),('guide',37,'en','help_search',11),('guide',48,'en','help_search',11),('guide',65,'en','help_search',21.8038),('guide',66,'en','help_search',22),('guide',67,'en','help_search',20.7671),('guide',71,'en','help_search',8.51611),('guide',76,'en','help_search',11),('guide',78,'en','help_search',11),('guide',80,'en','help_search',11),('guide',81,'en','help_search',9.67522),('guide',85,'en','help_search',10.4874),('handles',71,'en','help_search',0.800068),('handling',29,'en','help_search',3.95608),('happen',45,'en','help_search',1),('happens',29,'en','help_search',1),('happens',33,'en','help_search',1),('happens',44,'en','help_search',1.98902),('has',1,'en','node_search',12.652),('has',8,'en','help_search',2),('has',11,'en','help_search',5.48026),('has',12,'en','help_search',1),('has',18,'en','help_search',1),('has',19,'en','help_search',1),('has',20,'en','help_search',1),('has',23,'en','help_search',1),('has',24,'en','help_search',1),('has',29,'en','help_search',2.7299),('has',30,'en','help_search',1),('has',33,'en','help_search',1),('has',35,'en','help_search',1),('has',37,'en','help_search',1),('has',38,'en','help_search',1),('has',43,'en','help_search',4),('has',50,'en','help_search',0.78951),('has',55,'en','help_search',0.934703),('has',59,'en','help_search',3),('has',65,'en','help_search',1),('has',67,'en','help_search',1),('has',68,'en','help_search',1),('has',69,'en','help_search',36),('has',74,'en','help_search',1),('have',5,'en','help_search',1),('have',6,'en','help_search',1),('have',7,'en','help_search',1),('have',8,'en','help_search',1),('have',11,'en','help_search',0.866793),('have',12,'en','help_search',26.6223),('have',13,'en','help_search',1.99731),('have',14,'en','help_search',1),('have',16,'en','help_search',1),('have',19,'en','help_search',1),('have',20,'en','help_search',1),('have',21,'en','help_search',2),('have',22,'en','help_search',2),('have',27,'en','help_search',1),('have',28,'en','help_search',1),('have',29,'en','help_search',0.942091),('have',30,'en','help_search',2),('have',31,'en','help_search',1),('have',36,'en','help_search',1),('have',37,'en','help_search',3),('have',40,'en','help_search',1),('have',42,'en','help_search',2),('have',43,'en','help_search',2),('have',46,'en','help_search',1),('have',50,'en','help_search',4.42848),('have',51,'en','help_search',1),('have',54,'en','help_search',0.96498),('have',55,'en','help_search',3),('have',56,'en','help_search',1),('have',59,'en','help_search',1),('have',60,'en','help_search',3),('have',61,'en','help_search',1),('have',64,'en','help_search',1),('have',65,'en','help_search',1),('have',66,'en','help_search',3),('have',68,'en','help_search',1),('have',70,'en','help_search',1),('have',71,'en','help_search',3.66728),('have',73,'en','help_search',1),('have',78,'en','help_search',1),('have',79,'en','help_search',3),('have',80,'en','help_search',1),('have',81,'en','help_search',3),('have',83,'en','help_search',1.99731),('have',85,'en','help_search',2.99731),('have',86,'en','help_search',1),('haven',21,'en','help_search',1),('having',71,'en','help_search',0.949597),('header',1,'en','node_search',0.481063),('header',67,'en','help_search',1),('header',71,'en','help_search',3.9074),('heading',27,'en','help_search',1),('heading',47,'en','help_search',1),('heading',48,'en','help_search',1),('health',37,'en','help_search',2),('height',1,'en','node_search',1),('height',53,'en','help_search',28),('height',70,'en','help_search',4),('help',12,'en','help_search',1.75415),('help',14,'en','help_search',1),('help',15,'en','help_search',1),('help',24,'en','help_search',7.4272),('help',26,'en','help_search',54),('help',27,'en','help_search',151.109),('help',29,'en','help_search',4),('help',30,'en','help_search',2),('help',42,'en','help_search',1),('help',61,'en','help_search',4),('help',64,'en','help_search',4),('helps',10,'en','help_search',0.972861),('helptopics',27,'en','help_search',8),('here',1,'en','node_search',0.504001),('here',2,'en','help_search',4),('here',4,'en','help_search',4),('here',15,'en','help_search',1),('here',46,'en','help_search',22),('here',55,'en','help_search',0.920273),('here',78,'en','help_search',1),('herocol1',1,'en','node_search',2),('herocol2',1,'en','node_search',2),('hidden',1,'en','node_search',5.6728),('hidden',55,'en','help_search',4.47703),('hidden',57,'en','help_search',5),('hidden',62,'en','help_search',8),('hide',12,'en','help_search',0.662985),('hide',54,'en','help_search',1),('hide',62,'en','help_search',1),('hiding',12,'en','help_search',0.657549),('hierarchical',81,'en','help_search',1),('hierarchy',75,'en','help_search',1),('hierarchy',81,'en','help_search',1),('highly',37,'en','help_search',1),('highly',46,'en','help_search',1),('hints',15,'en','help_search',1),('history',21,'en','help_search',1),('history',69,'en','help_search',1),('hockey',1,'en','node_search',0.597248),('holds',12,'en','help_search',1),('home',33,'en','help_search',0.993146),('home',38,'en','help_search',1),('home',60,'en','help_search',1),('home',78,'en','help_search',1),('horizontal',50,'en','help_search',1),('hour',13,'en','help_search',1),('hourly',13,'en','help_search',1),('hover',1,'en','node_search',3.28013),('hovering',54,'en','help_search',0.920273),('hovering',60,'en','help_search',2),('hovers',73,'en','help_search',1),('how',1,'en','node_search',8.37717),('how',11,'en','help_search',1),('how',12,'en','help_search',3.29815),('how',13,'en','help_search',1),('how',21,'en','help_search',1),('how',26,'en','help_search',1),('how',27,'en','help_search',57),('how',37,'en','help_search',1),('how',44,'en','help_search',27),('how',46,'en','help_search',19),('how',56,'en','help_search',1),('how',59,'en','help_search',1),('how',66,'en','help_search',1),('how',71,'en','help_search',4.74727),('how',80,'en','help_search',1),('how',81,'en','help_search',1),('how',84,'en','help_search',1),('how',85,'en','help_search',1),('however',23,'en','help_search',1),('however',79,'en','help_search',1),('html',10,'en','help_search',2),('html',12,'en','help_search',2.44132),('html',18,'en','help_search',1),('html',50,'en','help_search',12.3934),('html',54,'en','help_search',4),('html',59,'en','help_search',1),('html',62,'en','help_search',1),('html',68,'en','help_search',1),('html',71,'en','help_search',1),('http',1,'en','node_search',2.12517),('http',25,'en','help_search',44),('https',1,'en','node_search',5.53254),('https',33,'en','help_search',7.84712),('https',76,'en','help_search',4),('https',78,'en','help_search',12),('human',76,'en','help_search',1),('humanreadable',11,'en','help_search',0.989021),('icon',19,'en','help_search',1),('icon',20,'en','help_search',1),('icon',81,'en','help_search',1),('idea',1,'en','node_search',7.80505),('identification',48,'en','help_search',1),('identifier',11,'en','help_search',0.892724),('identifier',54,'en','help_search',3.49253),('identifiers',54,'en','help_search',0.876337),('identifies',11,'en','help_search',0.879565),('identifies',78,'en','help_search',1),('image',1,'en','node_search',58.808),('image',11,'en','help_search',2),('image',12,'en','help_search',1.20828),('image',16,'en','help_search',26.9919),('image',50,'en','help_search',1),('image',53,'en','help_search',0.989021),('image',70,'en','help_search',41),('image',81,'en','help_search',1),('images',1,'en','node_search',1.40016),('images',5,'en','help_search',1),('images',10,'en','help_search',1),('images',12,'en','help_search',3),('images',16,'en','help_search',4.98087),('images',50,'en','help_search',1.99731),('images',53,'en','help_search',1),('images',68,'en','help_search',1),('images',70,'en','help_search',1),('immediately',65,'en','help_search',1),('impact',37,'en','help_search',1),('implementation',25,'en','help_search',2),('implemented',23,'en','help_search',0.989021),('implications',19,'en','help_search',1),('implications',43,'en','help_search',4),('import',3,'en','help_search',11),('import',4,'en','help_search',11),('important',1,'en','node_search',43.5564),('imported',11,'en','help_search',5.90265),('importing',3,'en','help_search',26),('importing',4,'en','help_search',26),('importing',11,'en','help_search',1.64815),('improper',50,'en','help_search',3.45463),('improve',18,'en','help_search',20),('improve',30,'en','help_search',1),('improved',23,'en','help_search',1),('include',12,'en','help_search',0.691597),('include',16,'en','help_search',2),('include',18,'en','help_search',1),('include',22,'en','help_search',1),('include',23,'en','help_search',1),('include',71,'en','help_search',0.857458),('includes',30,'en','help_search',1),('includes',37,'en','help_search',1),('including',6,'en','help_search',1),('including',10,'en','help_search',1),('including',17,'en','help_search',1),('including',23,'en','help_search',1),('including',24,'en','help_search',0.923838),('including',27,'en','help_search',2),('including',32,'en','help_search',1),('including',33,'en','help_search',27),('including',45,'en','help_search',1),('including',81,'en','help_search',0.923838),('incorrect',33,'en','help_search',1),('increasing',23,'en','help_search',1),('index',26,'en','help_search',4),('index',28,'en','help_search',2),('index',29,'en','help_search',58.9274),('index',30,'en','help_search',0.830633),('indexed',26,'en','help_search',1),('indexed',29,'en','help_search',2.89272),('indexed',30,'en','help_search',0.824901),('indexing',26,'en','help_search',2),('indexing',29,'en','help_search',22.8982),('indicating',32,'en','help_search',3),('indicating',33,'en','help_search',1.85285),('indicating',44,'en','help_search',0.957226),('individual',10,'en','help_search',1),('individual',12,'en','help_search',1),('individual',44,'en','help_search',1),('individual',55,'en','help_search',0.938382),('individual',81,'en','help_search',2),('individual',85,'en','help_search',1),('influence',28,'en','help_search',1),('information',1,'en','help_search',1),('information',2,'en','help_search',1),('information',3,'en','help_search',1),('information',4,'en','help_search',1),('information',6,'en','help_search',4),('information',12,'en','help_search',3.70583),('information',15,'en','help_search',1),('information',16,'en','help_search',1),('information',24,'en','help_search',2.90286),('information',25,'en','help_search',1),('information',29,'en','help_search',1),('information',30,'en','help_search',4.47836),('information',35,'en','help_search',1),('information',37,'en','help_search',1),('information',53,'en','help_search',2),('information',55,'en','help_search',1),('information',56,'en','help_search',1),('information',62,'en','help_search',1),('information',63,'en','help_search',1),('information',64,'en','help_search',1),('information',69,'en','help_search',19),('information',70,'en','help_search',1),('information',80,'en','help_search',1),('information',83,'en','help_search',1),('information',85,'en','help_search',1),('information',86,'en','help_search',5),('informational',37,'en','help_search',1),('ingredients',80,'en','help_search',1),('ingredients',81,'en','help_search',4),('inline',20,'en','help_search',27),('inline',23,'en','help_search',1.98493),('inline',24,'en','help_search',1),('inplace',24,'en','help_search',2),('input',12,'en','help_search',0.645209),('input',50,'en','help_search',1),('insert',44,'en','help_search',1),('install',1,'en','node_search',30.2858),('install',11,'en','help_search',4),('install',22,'en','help_search',1),('install',24,'en','help_search',3.75596),('install',26,'en','help_search',1),('install',27,'en','help_search',1),('install',35,'en','help_search',10),('install',38,'en','help_search',6),('install',54,'en','help_search',1),('install',71,'en','help_search',1),('installation',11,'en','help_search',1),('installation',68,'en','help_search',1),('installed',12,'en','help_search',0.58995),('installed',13,'en','help_search',1.99731),('installed',14,'en','help_search',1),('installed',16,'en','help_search',1),('installed',20,'en','help_search',2),('installed',21,'en','help_search',1),('installed',24,'en','help_search',1),('installed',26,'en','help_search',2),('installed',35,'en','help_search',3),('installed',36,'en','help_search',2),('installed',37,'en','help_search',2),('installed',38,'en','help_search',5),('installed',39,'en','help_search',6),('installed',42,'en','help_search',1),('installed',48,'en','help_search',1),('installed',50,'en','help_search',1.81085),('installed',54,'en','help_search',1.96109),('installed',55,'en','help_search',1),('installed',56,'en','help_search',1),('installed',58,'en','help_search',1),('installed',60,'en','help_search',2),('installed',66,'en','help_search',3),('installed',71,'en','help_search',1.59269),('installed',74,'en','help_search',1),('installed',79,'en','help_search',2),('installed',80,'en','help_search',2),('installed',83,'en','help_search',2),('installing',11,'en','help_search',0.942091),('installing',14,'en','help_search',20),('installing',15,'en','help_search',1),('installing',30,'en','help_search',1),('installing',35,'en','help_search',26),('installing',38,'en','help_search',26),('installing',54,'en','help_search',1),('instance',11,'en','help_search',6.60419),('instance',53,'en','help_search',2),('instance',81,'en','help_search',1),('instances',11,'en','help_search',3.54852),('instead',1,'en','node_search',0.490769),('instead',10,'en','help_search',1),('instead',18,'en','help_search',1),('instead',23,'en','help_search',1),('instead',50,'en','help_search',0.934703),('instead',54,'en','help_search',1),('instead',55,'en','help_search',1),('instead',58,'en','help_search',1),('instead',66,'en','help_search',1),('instructions',27,'en','help_search',0.945829),('instructions',34,'en','help_search',1),('instructions',59,'en','help_search',1),('instructions',80,'en','help_search',1),('integer',12,'en','help_search',2.97194),('integers',12,'en','help_search',0.740689),('integration',1,'en','node_search',0.681785),('interactions',12,'en','help_search',1),('interactive',1,'en','node_search',0.646943),('interest',45,'en','help_search',3),('interest',60,'en','help_search',1),('interests',46,'en','help_search',1),('interface',10,'en','help_search',1),('interface',11,'en','help_search',0.727213),('interface',12,'en','help_search',1.20198),('interface',16,'en','help_search',2),('interface',17,'en','help_search',1),('interface',22,'en','help_search',3),('interface',23,'en','help_search',32),('interface',24,'en','help_search',66.3775),('interface',27,'en','help_search',2),('interface',48,'en','help_search',1),('interface',52,'en','help_search',1),('interface',56,'en','help_search',1),('interface',66,'en','help_search',1),('interface',71,'en','help_search',0.794753),('interface',80,'en','help_search',2),('interface',81,'en','help_search',0.931053),('interface',82,'en','help_search',1),('interface',84,'en','help_search',1),('interfaces',23,'en','help_search',1),('internal',18,'en','help_search',20.4433),('internal',31,'en','help_search',1),('internal',73,'en','help_search',1),('into',2,'en','help_search',1),('into',4,'en','help_search',1),('into',11,'en','help_search',2.53391),('into',12,'en','help_search',3),('into',16,'en','help_search',1),('into',18,'en','help_search',1),('into',22,'en','help_search',2),('into',25,'en','help_search',1),('into',27,'en','help_search',1),('into',29,'en','help_search',1),('into',30,'en','help_search',3),('into',31,'en','help_search',1),('into',34,'en','help_search',8),('into',35,'en','help_search',1),('into',36,'en','help_search',1),('into',44,'en','help_search',1),('into',48,'en','help_search',1),('into',49,'en','help_search',1),('into',50,'en','help_search',5),('into',53,'en','help_search',2),('into',59,'en','help_search',1),('into',68,'en','help_search',1),('into',75,'en','help_search',1),('invalid',33,'en','help_search',1),('item',2,'en','help_search',31),('item',4,'en','help_search',32),('item',11,'en','help_search',2),('item',12,'en','help_search',6.85498),('item',57,'en','help_search',2),('item',61,'en','help_search',1),('item',64,'en','help_search',5),('item',65,'en','help_search',39.8792),('item',67,'en','help_search',39.363),('item',68,'en','help_search',24),('item',69,'en','help_search',1),('item',71,'en','help_search',1.87313),('item',72,'en','help_search',5),('item',73,'en','help_search',1),('item',76,'en','help_search',41),('item',78,'en','help_search',1),('item',83,'en','help_search',1),('item',85,'en','help_search',3),('item',86,'en','help_search',1),('items',10,'en','help_search',1),('items',11,'en','help_search',1.75231),('items',12,'en','help_search',3.84729),('items',16,'en','help_search',26),('items',17,'en','help_search',1),('items',21,'en','help_search',1),('items',22,'en','help_search',2),('items',29,'en','help_search',4),('items',55,'en','help_search',1),('items',58,'en','help_search',8),('items',65,'en','help_search',2),('items',67,'en','help_search',10.9534),('items',68,'en','help_search',3),('items',71,'en','help_search',5.53668),('items',72,'en','help_search',2),('items',78,'en','help_search',1),('items',81,'en','help_search',3.95959),('items',84,'en','help_search',1),('items',85,'en','help_search',1),('items',86,'en','help_search',1),('its',8,'en','help_search',1),('its',11,'en','help_search',2.78177),('its',13,'en','help_search',1),('its',14,'en','help_search',2),('its',24,'en','help_search',1),('its',25,'en','help_search',1),('its',46,'en','help_search',1),('its',52,'en','help_search',1),('its',55,'en','help_search',0.931053),('its',59,'en','help_search',2),('its',65,'en','help_search',1),('its',67,'en','help_search',1),('its',68,'en','help_search',1),('its',69,'en','help_search',1),('its',81,'en','help_search',1),('its',82,'en','help_search',1),('its',83,'en','help_search',1),('its',85,'en','help_search',1),('itself',55,'en','help_search',1),('japanese',29,'en','help_search',1),('javascript',1,'en','node_search',1.90312),('javascript',14,'en','help_search',1),('javascript',18,'en','help_search',1.85135),('javascript',54,'en','help_search',2),('jobs',12,'en','help_search',1),('json',25,'en','help_search',36),('json',46,'en','help_search',1),('just',1,'en','node_search',0.491762),('just',48,'en','help_search',1),('just',53,'en','help_search',1),('just',73,'en','help_search',1),('keep',11,'en','help_search',0.906287),('keep',13,'en','help_search',1),('keep',19,'en','help_search',1),('keeping',19,'en','help_search',2),('kept',69,'en','help_search',1),('key',12,'en','help_search',0.745294),('key',67,'en','help_search',1),('keyboardonly',23,'en','help_search',1),('keys',12,'en','help_search',3.87487),('keyword',29,'en','help_search',1),('keyword',30,'en','help_search',1),('keywords',29,'en','help_search',1),('keywords',30,'en','help_search',1),('keywords',83,'en','help_search',1),('kinds',11,'en','help_search',19),('knowing',8,'en','help_search',1),('known',13,'en','help_search',1),('known',16,'en','help_search',1),('known',81,'en','help_search',2),('korean',29,'en','help_search',1),('label',7,'en','help_search',4),('label',12,'en','help_search',0.655756),('label',28,'en','help_search',4),('label',52,'en','help_search',1),('label',56,'en','help_search',4),('label',61,'en','help_search',10),('label',62,'en','help_search',7),('label',64,'en','help_search',11),('label',65,'en','help_search',1),('labeled',4,'en','help_search',1),('labeled',23,'en','help_search',1),('labeled',38,'en','help_search',1),('labels',12,'en','help_search',4.84414),('landing',1,'en','node_search',1),('language',22,'en','help_search',7),('language',26,'en','help_search',1),('language',27,'en','help_search',1),('language',30,'en','help_search',0.993146),('language',32,'en','help_search',8),('language',67,'en','help_search',4),('language',74,'en','help_search',2),('languages',20,'en','help_search',1),('languages',22,'en','help_search',49),('languages',24,'en','help_search',1),('languages',29,'en','help_search',1.9689),('languages',58,'en','help_search',2),('languages',60,'en','help_search',2),('languages',67,'en','help_search',1),('languages',79,'en','help_search',0.968904),('languagespecific',30,'en','help_search',1),('large',12,'en','help_search',0.695602),('large',30,'en','help_search',2),('larger',29,'en','help_search',1),('last',12,'en','help_search',1),('last',13,'en','help_search',4),('last',37,'en','help_search',4),('last',69,'en','help_search',1),('last',78,'en','help_search',1),('later',18,'en','help_search',1.89272),('later',29,'en','help_search',0.934703),('later',51,'en','help_search',1),('later',84,'en','help_search',2),('layout',10,'en','help_search',26.9617),('layout',12,'en','help_search',0.601716),('layout',26,'en','help_search',4),('layout',47,'en','help_search',4),('layout',49,'en','help_search',1),('layout',53,'en','help_search',1),('layouts',1,'en','node_search',12.1575),('layouts',10,'en','help_search',2.97685),('layouts',53,'en','help_search',1.98902),('layouts',70,'en','help_search',1),('leading',24,'en','help_search',1),('leads',8,'en','help_search',1),('learn',22,'en','help_search',2),('learn',37,'en','help_search',1),('learning',8,'en','help_search',1),('least',27,'en','help_search',1),('least',83,'en','help_search',1),('leave',55,'en','help_search',1),('leave',65,'en','help_search',1),('left',1,'en','node_search',2.39386),('left',24,'en','help_search',1),('left',40,'en','help_search',1),('left',58,'en','help_search',2),('left',60,'en','help_search',2),('left',67,'en','help_search',1),('left',79,'en','help_search',0.976851),('length',29,'en','help_search',5),('less',33,'en','help_search',1),('let',1,'en','node_search',0.766757),('let',20,'en','help_search',1),('let',22,'en','help_search',1),('let',71,'en','help_search',1),('let',81,'en','help_search',1),('lets',22,'en','help_search',1),('letting',59,'en','help_search',0.934703),('level',28,'en','help_search',1),('library',16,'en','help_search',25),('library',54,'en','help_search',2),('lifetime',18,'en','help_search',4.86055),('lightbox',1,'en','node_search',0.670377),('like',20,'en','help_search',2),('like',30,'en','help_search',1),('like',48,'en','help_search',1),('like',59,'en','help_search',1),('like',60,'en','help_search',1),('like',71,'en','help_search',0.923838),('like',77,'en','help_search',1),('like',79,'en','help_search',1),('like',81,'en','help_search',1),('like',83,'en','help_search',2),('limit',12,'en','help_search',1.39535),('limit',50,'en','help_search',1),('limit',55,'en','help_search',1),('limit',61,'en','help_search',1),('limit',64,'en','help_search',2),('limit',71,'en','help_search',1),('limitations',30,'en','help_search',20),('limited',79,'en','help_search',1),('limits',50,'en','help_search',1),('limits',69,'en','help_search',1),('line',47,'en','help_search',1),('line',50,'en','help_search',4),('link',1,'en','node_search',0.482016),('link',7,'en','help_search',1),('link',8,'en','help_search',1),('link',12,'en','help_search',2.50061),('link',13,'en','help_search',1),('link',20,'en','help_search',3),('link',23,'en','help_search',1),('link',26,'en','help_search',1),('link',38,'en','help_search',2),('link',39,'en','help_search',2),('link',46,'en','help_search',1),('link',50,'en','help_search',0.949597),('link',60,'en','help_search',4.98902),('link',73,'en','help_search',62),('link',79,'en','help_search',3.95723),('link',82,'en','help_search',3),('link',85,'en','help_search',5),('linkedin',1,'en','node_search',5.27086),('links',12,'en','help_search',0.617112),('links',17,'en','help_search',10),('links',20,'en','help_search',9),('links',24,'en','help_search',3),('links',27,'en','help_search',1),('links',50,'en','help_search',3.89272),('links',60,'en','help_search',63.989),('links',72,'en','help_search',2),('links',73,'en','help_search',2),('links',74,'en','help_search',2),('links',75,'en','help_search',30),('links',79,'en','help_search',28.965),('links',83,'en','help_search',4),('links',85,'en','help_search',1),('linuxlike',13,'en','help_search',1),('list',11,'en','help_search',0.827757),('list',12,'en','help_search',28.8966),('list',24,'en','help_search',1),('list',28,'en','help_search',2),('list',35,'en','help_search',1),('list',36,'en','help_search',2),('list',41,'en','help_search',1),('list',45,'en','help_search',1),('list',58,'en','help_search',3),('list',60,'en','help_search',1.98217),('list',61,'en','help_search',1),('list',62,'en','help_search',1),('list',63,'en','help_search',1),('list',64,'en','help_search',1.99315),('list',67,'en','help_search',2),('list',71,'en','help_search',3),('list',72,'en','help_search',1),('list',73,'en','help_search',2),('list',77,'en','help_search',2),('list',79,'en','help_search',3.97),('list',81,'en','help_search',3),('list',82,'en','help_search',1),('list',83,'en','help_search',3),('list',84,'en','help_search',1),('list',85,'en','help_search',10),('listed',10,'en','help_search',0.953396),('listed',11,'en','help_search',0.687638),('listed',12,'en','help_search',1.21546),('listed',14,'en','help_search',1),('listed',16,'en','help_search',0.972861),('listed',17,'en','help_search',1),('listed',19,'en','help_search',1),('listed',21,'en','help_search',1),('listed',22,'en','help_search',1),('listed',24,'en','help_search',0.866793),('listed',26,'en','help_search',1),('listed',27,'en','help_search',20),('listed',28,'en','help_search',1),('listed',29,'en','help_search',0.886095),('listed',30,'en','help_search',0.794753),('listed',36,'en','help_search',1),('listed',48,'en','help_search',1),('listed',56,'en','help_search',1),('listed',59,'en','help_search',0.860547),('listed',64,'en','help_search',1),('listed',66,'en','help_search',1),('listed',68,'en','help_search',1),('listed',71,'en','help_search',0.78951),('listed',78,'en','help_search',1),('listed',81,'en','help_search',0.906287),('listed',84,'en','help_search',1),('listing',71,'en','help_search',2),('listing',81,'en','help_search',0.976851),('listings',71,'en','help_search',35.5437),('listings',85,'en','help_search',11.6148),('lists',12,'en','help_search',0.816452),('lists',80,'en','help_search',1),('lists',81,'en','help_search',0.968904),('lists',85,'en','help_search',1),('live',11,'en','help_search',3.73211),('load',18,'en','help_search',1),('loads',31,'en','help_search',1),('locate',23,'en','help_search',1),('locate',35,'en','help_search',1),('locate',36,'en','help_search',1),('locate',38,'en','help_search',2),('locate',39,'en','help_search',1),('locate',60,'en','help_search',1),('locate',72,'en','help_search',1),('locate',73,'en','help_search',2),('locate',76,'en','help_search',1),('locate',78,'en','help_search',1),('located',16,'en','help_search',1),('located',26,'en','help_search',1),('located',47,'en','help_search',2),('location',11,'en','help_search',0.774192),('location',12,'en','help_search',0.754681),('location',72,'en','help_search',1),('locations',12,'en','help_search',0.76431),('locator',78,'en','help_search',1),('log',34,'en','help_search',1),('log',37,'en','help_search',4),('log',42,'en','help_search',2),('log',44,'en','help_search',2),('logged',12,'en','help_search',1),('logged',18,'en','help_search',0.997306),('logged',34,'en','help_search',1),('logged',42,'en','help_search',2),('loggedin',69,'en','help_search',1),('logging',15,'en','help_search',2),('logging',33,'en','help_search',3.73881),('logging',37,'en','help_search',1),('loginurl',44,'en','help_search',1),('long',11,'en','help_search',0.869951),('long',12,'en','help_search',6.20151),('long',31,'en','help_search',1),('long',32,'en','help_search',1),('longer',18,'en','help_search',1),('longer',39,'en','help_search',1),('look',10,'en','help_search',1),('look',30,'en','help_search',1),('look',32,'en','help_search',1),('looks',20,'en','help_search',1),('looks',60,'en','help_search',1),('looks',79,'en','help_search',1),('machine',41,'en','help_search',4),('machine',52,'en','help_search',1),('machine',74,'en','help_search',1),('machinereadable',25,'en','help_search',1),('made',85,'en','help_search',0.997306),('mail',44,'en','help_search',1),('main',10,'en','help_search',1),('main',12,'en','help_search',2.32097),('main',26,'en','help_search',1),('main',27,'en','help_search',0.980874),('main',30,'en','help_search',2),('main',32,'en','help_search',2),('maintaining',15,'en','help_search',46),('maintenance',13,'en','help_search',10.4874),('maintenance',15,'en','help_search',13),('maintenance',19,'en','help_search',11),('maintenance',34,'en','help_search',75),('maintenance',36,'en','help_search',5),('maintenance',37,'en','help_search',11),('make',9,'en','help_search',4),('make',13,'en','help_search',1),('make',20,'en','help_search',1),('make',23,'en','help_search',2),('make',26,'en','help_search',1),('make',28,'en','help_search',1),('make',29,'en','help_search',3.91323),('make',30,'en','help_search',0.836446),('make',35,'en','help_search',1),('make',36,'en','help_search',1),('make',44,'en','help_search',2),('make',54,'en','help_search',1),('make',60,'en','help_search',4),('make',61,'en','help_search',1),('make',64,'en','help_search',1),('make',65,'en','help_search',1),('make',67,'en','help_search',0.989021),('make',73,'en','help_search',1),('make',76,'en','help_search',1),('make',77,'en','help_search',1),('make',79,'en','help_search',2),('make',83,'en','help_search',1),('makes',1,'en','node_search',1),('makes',30,'en','help_search',0.968904),('making',1,'en','node_search',0.648686),('making',11,'en','help_search',7.33326),('making',19,'en','help_search',26),('making',62,'en','help_search',1),('making',63,'en','help_search',1),('malicious',50,'en','help_search',0.896076),('manage',1,'en','help_search',4),('manage',2,'en','help_search',4),('manage',3,'en','help_search',4),('manage',4,'en','help_search',4),('manage',5,'en','help_search',12),('manage',6,'en','help_search',8),('manage',7,'en','help_search',4),('manage',9,'en','help_search',4),('manage',12,'en','help_search',0.623497),('manage',13,'en','help_search',4),('manage',18,'en','help_search',3.55759),('manage',24,'en','help_search',2.91674),('manage',26,'en','help_search',16),('manage',28,'en','help_search',4),('manage',29,'en','help_search',5),('manage',31,'en','help_search',4),('manage',32,'en','help_search',12),('manage',33,'en','help_search',7.75353),('manage',34,'en','help_search',8),('manage',35,'en','help_search',4),('manage',36,'en','help_search',4),('manage',37,'en','help_search',12),('manage',38,'en','help_search',4),('manage',39,'en','help_search',4),('manage',40,'en','help_search',4),('manage',41,'en','help_search',4),('manage',42,'en','help_search',1),('manage',43,'en','help_search',4),('manage',44,'en','help_search',4),('manage',45,'en','help_search',4),('manage',47,'en','help_search',4),('manage',48,'en','help_search',1),('manage',49,'en','help_search',4),('manage',50,'en','help_search',3.95608),('manage',51,'en','help_search',4),('manage',52,'en','help_search',16),('manage',54,'en','help_search',4),('manage',56,'en','help_search',4),('manage',57,'en','help_search',4),('manage',58,'en','help_search',4),('manage',61,'en','help_search',12),('manage',62,'en','help_search',8),('manage',63,'en','help_search',8),('manage',64,'en','help_search',12),('manage',65,'en','help_search',4),('manage',66,'en','help_search',12),('manage',67,'en','help_search',4),('manage',68,'en','help_search',1),('manage',70,'en','help_search',4),('manage',72,'en','help_search',4),('manage',73,'en','help_search',8),('manage',74,'en','help_search',4),('manage',75,'en','help_search',4),('manage',77,'en','help_search',23),('manage',80,'en','help_search',4),('manage',82,'en','help_search',4),('manage',83,'en','help_search',4),('manage',84,'en','help_search',4),('manage',85,'en','help_search',4),('manage',86,'en','help_search',8),('managed',16,'en','help_search',1),('managed',19,'en','help_search',1),('managed',50,'en','help_search',1),('managed',79,'en','help_search',1),('managed',81,'en','help_search',1),('management',8,'en','help_search',19),('management',11,'en','help_search',8.20031),('management',58,'en','help_search',1),('management',65,'en','help_search',11),('management',67,'en','help_search',10.4874),('manager',11,'en','help_search',0.731649),('manager',22,'en','help_search',1),('manager',37,'en','help_search',1),('managers',8,'en','help_search',1),('manages',22,'en','help_search',1),('managing',1,'en','help_search',1),('managing',2,'en','help_search',1),('managing',3,'en','help_search',1),('managing',4,'en','help_search',1),('managing',5,'en','help_search',26),('managing',6,'en','help_search',1),('managing',7,'en','help_search',1),('managing',8,'en','help_search',26),('managing',10,'en','help_search',1),('managing',11,'en','help_search',40.1606),('managing',12,'en','help_search',38.6049),('managing',16,'en','help_search',47),('managing',17,'en','help_search',46),('managing',22,'en','help_search',2),('managing',25,'en','help_search',1),('managing',28,'en','help_search',1),('managing',29,'en','help_search',26),('managing',30,'en','help_search',0.848323),('managing',42,'en','help_search',46),('managing',48,'en','help_search',45),('managing',50,'en','help_search',26),('managing',53,'en','help_search',44.6366),('managing',54,'en','help_search',2.83669),('managing',55,'en','help_search',1),('managing',56,'en','help_search',2),('managing',57,'en','help_search',1),('managing',59,'en','help_search',45.1362),('managing',61,'en','help_search',3),('managing',62,'en','help_search',2),('managing',63,'en','help_search',2),('managing',64,'en','help_search',2),('managing',65,'en','help_search',1),('managing',66,'en','help_search',1),('managing',67,'en','help_search',1),('managing',68,'en','help_search',46),('managing',70,'en','help_search',1),('managing',71,'en','help_search',41.2523),('managing',80,'en','help_search',2),('managing',81,'en','help_search',45.1145),('managing',85,'en','help_search',1),('managing',86,'en','help_search',2),('manner',67,'en','help_search',0.968904),('manually',13,'en','help_search',1),('manually',31,'en','help_search',1),('manually',37,'en','help_search',4),('many',12,'en','help_search',1.53962),('many',22,'en','help_search',1),('many',23,'en','help_search',1),('many',68,'en','help_search',1),('many',71,'en','help_search',0.942091),('mapped',86,'en','help_search',1),('mapping',86,'en','help_search',8),('margin',1,'en','node_search',8.68446),('marginbottom',1,'en','node_search',6.59259),('marginleft',1,'en','node_search',2.84294),('marginright',1,'en','node_search',2.83224),('mark',18,'en','help_search',1),('marked',2,'en','help_search',1),('marked',43,'en','help_search',1),('marked',69,'en','help_search',2),('marker',69,'en','help_search',1),('markup',10,'en','help_search',1),('markup',12,'en','help_search',1),('markup',59,'en','help_search',1),('markup',68,'en','help_search',1),('match',1,'en','node_search',0.740689),('match',11,'en','help_search',0.781775),('match',30,'en','help_search',0.953396),('match',32,'en','help_search',1),('match',44,'en','help_search',1),('matched',29,'en','help_search',1),('matches',32,'en','help_search',1),('matching',30,'en','help_search',1),('matter',27,'en','help_search',1),('maximum',18,'en','help_search',1.86055),('maximum',55,'en','help_search',1),('maxwidth',1,'en','node_search',14.176),('may',12,'en','help_search',1.92384),('may',15,'en','help_search',1),('may',16,'en','help_search',1),('may',24,'en','help_search',1),('may',30,'en','help_search',0.819249),('may',33,'en','help_search',1),('may',35,'en','help_search',1),('may',36,'en','help_search',2),('may',37,'en','help_search',1),('may',54,'en','help_search',1),('may',66,'en','help_search',1),('may',71,'en','help_search',1),('may',80,'en','help_search',2),('may',83,'en','help_search',1),('meaning',69,'en','help_search',2),('means',11,'en','help_search',0.931053),('means',14,'en','help_search',2),('meant',10,'en','help_search',1),('meant',12,'en','help_search',1),('meant',53,'en','help_search',1),('measure',53,'en','help_search',1),('mechanisms',18,'en','help_search',2),('mechanisms',31,'en','help_search',1),('mechanisms',54,'en','help_search',1),('media',1,'en','node_search',4.60503),('media',12,'en','help_search',0.61241),('media',16,'en','help_search',117.446),('media',53,'en','help_search',33.2416),('media',70,'en','help_search',5),('media',86,'en','help_search',55),('mediarelated',16,'en','help_search',1),('medium',32,'en','help_search',1),('members',59,'en','help_search',0.927431),('mentioned',24,'en','help_search',0.882818),('menu',1,'en','help_search',1),('menu',2,'en','help_search',1),('menu',3,'en','help_search',1),('menu',4,'en','help_search',1),('menu',5,'en','help_search',1),('menu',6,'en','help_search',2),('menu',7,'en','help_search',1),('menu',9,'en','help_search',1),('menu',12,'en','help_search',0.618696),('menu',13,'en','help_search',1),('menu',17,'en','help_search',41),('menu',18,'en','help_search',0.882818),('menu',20,'en','help_search',1),('menu',24,'en','help_search',22),('menu',26,'en','help_search',4),('menu',28,'en','help_search',1),('menu',29,'en','help_search',1),('menu',30,'en','help_search',0.805455),('menu',31,'en','help_search',1),('menu',32,'en','help_search',3),('menu',33,'en','help_search',1.93838),('menu',34,'en','help_search',2),('menu',35,'en','help_search',1),('menu',36,'en','help_search',1),('menu',37,'en','help_search',3),('menu',38,'en','help_search',1),('menu',39,'en','help_search',1),('menu',40,'en','help_search',1),('menu',41,'en','help_search',1),('menu',43,'en','help_search',1),('menu',44,'en','help_search',1),('menu',45,'en','help_search',1),('menu',47,'en','help_search',1),('menu',49,'en','help_search',1),('menu',50,'en','help_search',1.93047),('menu',51,'en','help_search',1),('menu',52,'en','help_search',1),('menu',54,'en','help_search',1),('menu',56,'en','help_search',1),('menu',57,'en','help_search',1),('menu',58,'en','help_search',1),('menu',60,'en','help_search',4),('menu',61,'en','help_search',1),('menu',62,'en','help_search',1),('menu',63,'en','help_search',1),('menu',64,'en','help_search',1),('menu',65,'en','help_search',1),('menu',66,'en','help_search',1),('menu',67,'en','help_search',1),('menu',70,'en','help_search',1),('menu',72,'en','help_search',32),('menu',73,'en','help_search',45),('menu',74,'en','help_search',39),('menu',75,'en','help_search',36),('menu',77,'en','help_search',1),('menu',80,'en','help_search',1),('menu',82,'en','help_search',1),('menu',83,'en','help_search',1),('menu',84,'en','help_search',1),('menu',85,'en','help_search',1),('menu',86,'en','help_search',1),('menus',17,'en','help_search',50),('menus',24,'en','help_search',0.968904),('menus',72,'en','help_search',3),('menus',73,'en','help_search',2),('menus',74,'en','help_search',5),('menus',75,'en','help_search',1),('merged',18,'en','help_search',1),('message',1,'en','node_search',0.486839),('message',5,'en','help_search',4),('message',6,'en','help_search',4),('message',7,'en','help_search',4),('message',32,'en','help_search',3),('message',33,'en','help_search',2.85285),('message',34,'en','help_search',5),('message',35,'en','help_search',1),('message',36,'en','help_search',1),('message',40,'en','help_search',1),('message',44,'en','help_search',21.9572),('messages',23,'en','help_search',1),('messages',33,'en','help_search',5.68109),('messages',37,'en','help_search',6),('messages',44,'en','help_search',1.98493),('metadata',26,'en','help_search',4),('metadata',27,'en','help_search',1),('metadata',28,'en','help_search',4),('metadata',29,'en','help_search',4),('metadata',53,'en','help_search',1),('metadata',77,'en','help_search',4),('metadata',86,'en','help_search',4),('method',25,'en','help_search',2),('method',44,'en','help_search',1),('micromodal',1,'en','node_search',11.6578),('might',12,'en','help_search',0.776703),('might',13,'en','help_search',1),('might',38,'en','help_search',1),('might',59,'en','help_search',1),('might',68,'en','help_search',1),('might',78,'en','help_search',1),('minimum',29,'en','help_search',4),('minwidth',53,'en','help_search',1),('misbehaving',31,'en','help_search',1),('mistakes',85,'en','help_search',0.993146),('mix',1,'en','node_search',0.742984),('modal',49,'en','help_search',2),('mode',15,'en','help_search',1),('mode',34,'en','help_search',75),('mode',36,'en','help_search',5),('moderate',58,'en','help_search',20),('moderating',58,'en','help_search',37),('moderating',59,'en','help_search',0.876337),('moderation',59,'en','help_search',24.965),('modern',1,'en','node_search',0.674137),('modify',43,'en','help_search',1),('modify',45,'en','help_search',1),('modify',68,'en','help_search',1),('modify',85,'en','help_search',2),('modifying',14,'en','help_search',26),('modifying',43,'en','help_search',26),('modifying',45,'en','help_search',26),('module',1,'en','node_search',52.2156),('module',8,'en','help_search',1),('module',10,'en','help_search',2.97286),('module',11,'en','help_search',2.72942),('module',12,'en','help_search',8.46129),('module',13,'en','help_search',2.99461),('module',14,'en','help_search',48),('module',15,'en','help_search',1),('module',16,'en','help_search',17.436),('module',17,'en','help_search',2),('module',18,'en','help_search',30.5823),('module',20,'en','help_search',4),('module',21,'en','help_search',1),('module',22,'en','help_search',2),('module',23,'en','help_search',0.98493),('module',24,'en','help_search',18),('module',25,'en','help_search',26),('module',26,'en','help_search',1),('module',27,'en','help_search',5),('module',30,'en','help_search',37.3277),('module',35,'en','help_search',38),('module',36,'en','help_search',38),('module',37,'en','help_search',2),('module',42,'en','help_search',3),('module',46,'en','help_search',14),('module',47,'en','help_search',1),('module',48,'en','help_search',2),('module',50,'en','help_search',3.81085),('module',53,'en','help_search',2.93025),('module',54,'en','help_search',4),('module',55,'en','help_search',4),('module',56,'en','help_search',1),('module',58,'en','help_search',1),('module',59,'en','help_search',1.79901),('module',60,'en','help_search',4),('module',66,'en','help_search',3),('module',68,'en','help_search',2),('module',69,'en','help_search',1),('module',71,'en','help_search',3.19292),('module',74,'en','help_search',1),('module',78,'en','help_search',2),('module',79,'en','help_search',5),('module',80,'en','help_search',2),('module',81,'en','help_search',1.8843),('module',83,'en','help_search',2),('modules',1,'en','node_search',121.136),('modules',10,'en','help_search',2.98087),('modules',11,'en','help_search',0.7017),('modules',12,'en','help_search',4.85309),('modules',13,'en','help_search',1),('modules',14,'en','help_search',21),('modules',15,'en','help_search',1),('modules',16,'en','help_search',3),('modules',17,'en','help_search',2),('modules',18,'en','help_search',1),('modules',19,'en','help_search',2),('modules',21,'en','help_search',1),('modules',22,'en','help_search',2),('modules',24,'en','help_search',6.68775),('modules',25,'en','help_search',33),('modules',26,'en','help_search',1),('modules',27,'en','help_search',9),('modules',30,'en','help_search',23),('modules',35,'en','help_search',4),('modules',36,'en','help_search',3),('modules',37,'en','help_search',2),('modules',42,'en','help_search',1),('modules',48,'en','help_search',1),('modules',50,'en','help_search',1),('modules',53,'en','help_search',2.96109),('modules',54,'en','help_search',1),('modules',59,'en','help_search',0.976851),('modules',65,'en','help_search',1),('modules',67,'en','help_search',1),('modules',68,'en','help_search',1),('modules',71,'en','help_search',1),('month',69,'en','help_search',2),('more',1,'en','help_search',1),('more',1,'en','node_search',1.37416),('more',2,'en','help_search',1),('more',3,'en','help_search',1),('more',4,'en','help_search',1),('more',5,'en','help_search',1),('more',6,'en','help_search',1),('more',7,'en','help_search',1),('more',8,'en','help_search',1),('more',10,'en','help_search',1),('more',12,'en','help_search',6.6464),('more',15,'en','help_search',1),('more',16,'en','help_search',2),('more',21,'en','help_search',1),('more',22,'en','help_search',2),('more',23,'en','help_search',1),('more',24,'en','help_search',2.86055),('more',25,'en','help_search',1),('more',27,'en','help_search',1),('more',28,'en','help_search',1),('more',29,'en','help_search',3),('more',30,'en','help_search',2.59912),('more',33,'en','help_search',0.909743),('more',35,'en','help_search',1),('more',40,'en','help_search',1),('more',42,'en','help_search',1),('more',48,'en','help_search',1),('more',50,'en','help_search',1),('more',51,'en','help_search',1),('more',54,'en','help_search',1),('more',55,'en','help_search',1),('more',56,'en','help_search',1),('more',57,'en','help_search',2),('more',58,'en','help_search',2),('more',59,'en','help_search',1.90974),('more',64,'en','help_search',1),('more',65,'en','help_search',2),('more',66,'en','help_search',1),('more',67,'en','help_search',1),('more',68,'en','help_search',1),('more',70,'en','help_search',1),('more',71,'en','help_search',1.64807),('more',74,'en','help_search',1),('more',76,'en','help_search',1),('more',77,'en','help_search',1),('more',78,'en','help_search',1),('more',79,'en','help_search',2),('more',80,'en','help_search',2),('more',81,'en','help_search',1),('more',83,'en','help_search',2),('more',85,'en','help_search',1),('more',86,'en','help_search',1),('most',11,'en','help_search',0.703756),('most',12,'en','help_search',2.33704),('most',20,'en','help_search',1),('most',23,'en','help_search',2),('most',30,'en','help_search',1),('most',34,'en','help_search',1),('most',37,'en','help_search',1),('most',60,'en','help_search',1),('most',64,'en','help_search',1),('most',69,'en','help_search',1),('most',70,'en','help_search',1),('most',71,'en','help_search',2),('most',82,'en','help_search',1),('most',86,'en','help_search',1),('mostcommonlyused',25,'en','help_search',1),('mouse',60,'en','help_search',1),('move',11,'en','help_search',1),('much',18,'en','help_search',1),('multiple',22,'en','help_search',1),('multiple',35,'en','help_search',1),('multiple',67,'en','help_search',1),('multiple',71,'en','help_search',1),('multiplevalued',12,'en','help_search',0.961087),('multiplier',53,'en','help_search',1),('multipliers',53,'en','help_search',22.9496),('must',20,'en','help_search',2),('must',46,'en','help_search',1),('must',55,'en','help_search',1),('must',61,'en','help_search',1),('must',64,'en','help_search',1),('must',71,'en','help_search',0.98493),('must',80,'en','help_search',1),('name',2,'en','help_search',5),('name',11,'en','help_search',1),('name',25,'en','help_search',1),('name',28,'en','help_search',1),('name',30,'en','help_search',1),('name',32,'en','help_search',2),('name',35,'en','help_search',2),('name',36,'en','help_search',2),('name',41,'en','help_search',8),('name',44,'en','help_search',4),('name',45,'en','help_search',1),('name',47,'en','help_search',1),('name',48,'en','help_search',1),('name',49,'en','help_search',1),('name',50,'en','help_search',4.62515),('name',51,'en','help_search',1),('name',52,'en','help_search',1),('name',53,'en','help_search',1),('name',56,'en','help_search',1),('name',65,'en','help_search',1),('name',66,'en','help_search',5),('name',70,'en','help_search',4),('name',74,'en','help_search',1),('name',78,'en','help_search',1),('name',80,'en','help_search',10),('name',82,'en','help_search',5),('name',83,'en','help_search',2),('name',84,'en','help_search',5),('name',85,'en','help_search',1),('name',86,'en','help_search',4),('names',12,'en','help_search',0.769219),('navigate',1,'en','help_search',1),('navigate',2,'en','help_search',1),('navigate',3,'en','help_search',1),('navigate',4,'en','help_search',1),('navigate',5,'en','help_search',1),('navigate',6,'en','help_search',2),('navigate',7,'en','help_search',1),('navigate',9,'en','help_search',1),('navigate',13,'en','help_search',1),('navigate',17,'en','help_search',1),('navigate',18,'en','help_search',0.876337),('navigate',24,'en','help_search',2),('navigate',26,'en','help_search',4),('navigate',28,'en','help_search',1),('navigate',29,'en','help_search',1),('navigate',31,'en','help_search',1),('navigate',32,'en','help_search',3),('navigate',33,'en','help_search',1.93838),('navigate',34,'en','help_search',2),('navigate',35,'en','help_search',1),('navigate',36,'en','help_search',1),('navigate',37,'en','help_search',3),('navigate',38,'en','help_search',1),('navigate',39,'en','help_search',1),('navigate',40,'en','help_search',1),('navigate',41,'en','help_search',1),('navigate',43,'en','help_search',1),('navigate',44,'en','help_search',1),('navigate',45,'en','help_search',1),('navigate',47,'en','help_search',1),('navigate',49,'en','help_search',1),('navigate',50,'en','help_search',0.976851),('navigate',51,'en','help_search',1),('navigate',52,'en','help_search',1),('navigate',54,'en','help_search',1),('navigate',56,'en','help_search',1),('navigate',58,'en','help_search',3),('navigate',60,'en','help_search',1),('navigate',61,'en','help_search',2),('navigate',62,'en','help_search',2),('navigate',63,'en','help_search',2),('navigate',64,'en','help_search',2),('navigate',65,'en','help_search',1),('navigate',66,'en','help_search',1),('navigate',67,'en','help_search',1),('navigate',70,'en','help_search',1),('navigate',72,'en','help_search',1),('navigate',73,'en','help_search',2),('navigate',74,'en','help_search',1),('navigate',75,'en','help_search',1),('navigate',77,'en','help_search',1),('navigate',79,'en','help_search',1),('navigate',80,'en','help_search',1),('navigate',82,'en','help_search',1),('navigate',83,'en','help_search',1),('navigate',84,'en','help_search',1),('navigate',85,'en','help_search',1),('navigate',86,'en','help_search',1),('navigating',57,'en','help_search',1),('navigating',60,'en','help_search',1),('navigation',30,'en','help_search',0.808176),('near',26,'en','help_search',1),('necessary',24,'en','help_search',0.896076),('necessary',83,'en','help_search',1),('necessary',85,'en','help_search',1),('need',1,'en','node_search',0.59873),('need',6,'en','help_search',1),('need',13,'en','help_search',1),('need',14,'en','help_search',1),('need',19,'en','help_search',1),('need',20,'en','help_search',1),('need',27,'en','help_search',1),('need',30,'en','help_search',2.56694),('need',31,'en','help_search',1),('need',32,'en','help_search',1),('need',35,'en','help_search',1),('need',36,'en','help_search',2),('need',37,'en','help_search',1),('need',44,'en','help_search',1),('need',47,'en','help_search',1),('need',53,'en','help_search',1),('need',54,'en','help_search',1),('need',55,'en','help_search',3),('need',57,'en','help_search',3),('need',58,'en','help_search',1),('need',65,'en','help_search',1),('need',67,'en','help_search',1),('need',76,'en','help_search',1),('need',79,'en','help_search',1),('need',80,'en','help_search',1),('need',83,'en','help_search',2),('need',86,'en','help_search',1),('needed',18,'en','help_search',2),('needed',30,'en','help_search',1.80574),('needed',62,'en','help_search',1),('needed',63,'en','help_search',1),('needing',60,'en','help_search',1),('needs',1,'en','node_search',1.85381),('needs',18,'en','help_search',0.989021),('never',69,'en','help_search',1),('new',1,'en','node_search',0.49376),('new',6,'en','help_search',1),('new',7,'en','help_search',28),('new',11,'en','help_search',0.845322),('new',17,'en','help_search',1),('new',22,'en','help_search',1),('new',24,'en','help_search',1),('new',26,'en','help_search',1),('new',28,'en','help_search',1),('new',38,'en','help_search',3),('new',40,'en','help_search',13),('new',41,'en','help_search',28),('new',44,'en','help_search',2),('new',45,'en','help_search',1),('new',50,'en','help_search',1.71949),('new',52,'en','help_search',1),('new',54,'en','help_search',5.48567),('new',55,'en','help_search',2.76565),('new',56,'en','help_search',2),('new',57,'en','help_search',2),('new',59,'en','help_search',1),('new',61,'en','help_search',5),('new',64,'en','help_search',4.99315),('new',65,'en','help_search',1),('new',66,'en','help_search',3),('new',69,'en','help_search',16),('new',70,'en','help_search',6),('new',74,'en','help_search',1),('new',75,'en','help_search',1),('new',76,'en','help_search',2),('new',77,'en','help_search',1),('new',80,'en','help_search',2),('new',81,'en','help_search',1),('new',82,'en','help_search',30),('new',84,'en','help_search',27),('new',85,'en','help_search',1),('new',86,'en','help_search',28),('newly',69,'en','help_search',1),('news',59,'en','help_search',1),('news',71,'en','help_search',1),('next',18,'en','help_search',1),('next',35,'en','help_search',2),('next',36,'en','help_search',1),('next',45,'en','help_search',1),('next',55,'en','help_search',1),('next',61,'en','help_search',2),('next',64,'en','help_search',2),('next',70,'en','help_search',1),('next',79,'en','help_search',1),('next',82,'en','help_search',1),('next',85,'en','help_search',1),('node',12,'en','help_search',0.621888),('node',30,'en','help_search',2),('node',55,'en','help_search',2),('node',58,'en','help_search',1),('node',68,'en','help_search',1),('node',73,'en','help_search',4),('node',78,'en','help_search',13),('nolink',73,'en','help_search',4),('nonadministration',38,'en','help_search',1),('nonadministrative',24,'en','help_search',1),('nonadministrative',60,'en','help_search',2),('nonadministrative',65,'en','help_search',1),('noncacheable',18,'en','help_search',0.961087),('nondefault',23,'en','help_search',1),('none',33,'en','help_search',3.69535),('nonenglish',27,'en','help_search',1),('nonerror',33,'en','help_search',1),('nontoplevel',27,'en','help_search',1),('norepeat',1,'en','node_search',2.09803),('normal',33,'en','help_search',1),('normal',34,'en','help_search',2),('normally',64,'en','help_search',1),('normally',81,'en','help_search',2),('not',10,'en','help_search',1),('not',11,'en','help_search',1.85498),('not',12,'en','help_search',2.72283),('not',13,'en','help_search',1.99731),('not',14,'en','help_search',2),('not',15,'en','help_search',1),('not',18,'en','help_search',1.98902),('not',23,'en','help_search',1),('not',24,'en','help_search',1),('not',26,'en','help_search',4),('not',28,'en','help_search',2),('not',30,'en','help_search',2),('not',32,'en','help_search',1),('not',33,'en','help_search',2),('not',35,'en','help_search',1),('not',38,'en','help_search',1),('not',39,'en','help_search',1),('not',42,'en','help_search',1),('not',43,'en','help_search',1),('not',45,'en','help_search',1),('not',46,'en','help_search',1),('not',48,'en','help_search',1),('not',50,'en','help_search',0.957226),('not',55,'en','help_search',2.98902),('not',58,'en','help_search',1),('not',62,'en','help_search',2),('not',63,'en','help_search',1),('not',64,'en','help_search',2),('not',65,'en','help_search',1),('not',66,'en','help_search',1),('not',73,'en','help_search',3),('not',82,'en','help_search',1),('not',83,'en','help_search',2),('not',85,'en','help_search',1),('not',86,'en','help_search',1),('note',5,'en','help_search',1),('note',13,'en','help_search',1),('note',33,'en','help_search',1),('note',37,'en','help_search',1),('note',57,'en','help_search',1),('note',73,'en','help_search',1),('note',77,'en','help_search',1),('note',83,'en','help_search',1),('note',86,'en','help_search',1),('noted',86,'en','help_search',1),('notfound',33,'en','help_search',7.78302),('notice',55,'en','help_search',1),('notify',40,'en','help_search',4),('notifying',40,'en','help_search',1),('now',11,'en','help_search',0.792123),('now',13,'en','help_search',1),('now',38,'en','help_search',1),('now',61,'en','help_search',1),('now',64,'en','help_search',1),('now',70,'en','help_search',1),('now',86,'en','help_search',1),('number',1,'en','node_search',11.4659),('number',12,'en','help_search',0.896076),('number',29,'en','help_search',6),('number',55,'en','help_search',5),('number',61,'en','help_search',5),('number',64,'en','help_search',5),('number',79,'en','help_search',1),('numbers',12,'en','help_search',2.49176),('numbers',23,'en','help_search',1),('numerical',23,'en','help_search',1),('objectfit',1,'en','node_search',3.82961),('occasionally',19,'en','help_search',1),('occur',23,'en','help_search',1),('occur',33,'en','help_search',19),('off',14,'en','help_search',1),('off',57,'en','help_search',3),('offer',12,'en','help_search',1.31386),('offer',24,'en','help_search',1),('offering',1,'en','node_search',1),('official',46,'en','help_search',4),('often',13,'en','help_search',1),('often',85,'en','help_search',1),('older',69,'en','help_search',1),('once',11,'en','help_search',0.957226),('once',12,'en','help_search',0.736141),('once',13,'en','help_search',2),('once',27,'en','help_search',1),('once',44,'en','help_search',1),('one',1,'en','node_search',11.4899),('one',3,'en','help_search',1),('one',4,'en','help_search',1),('one',5,'en','help_search',1),('one',8,'en','help_search',1),('one',10,'en','help_search',1),('one',11,'en','help_search',0.836446),('one',12,'en','help_search',5.15836),('one',21,'en','help_search',1),('one',27,'en','help_search',1),('one',28,'en','help_search',1),('one',30,'en','help_search',0.866793),('one',33,'en','help_search',0.916736),('one',35,'en','help_search',1),('one',42,'en','help_search',1),('one',48,'en','help_search',1),('one',51,'en','help_search',1),('one',53,'en','help_search',3),('one',55,'en','help_search',1),('one',58,'en','help_search',2),('one',61,'en','help_search',1),('one',64,'en','help_search',2),('one',65,'en','help_search',1),('one',67,'en','help_search',1),('one',69,'en','help_search',2),('one',71,'en','help_search',0.848323),('one',73,'en','help_search',1),('one',74,'en','help_search',1),('one',79,'en','help_search',3),('one',81,'en','help_search',1),('one',83,'en','help_search',1),('onetimeloginurl',44,'en','help_search',1),('online',18,'en','help_search',27.765),('online',25,'en','help_search',22),('online',30,'en','help_search',8.59953),('online',55,'en','help_search',9.74705),('online',58,'en','help_search',11),('only',11,'en','help_search',0.754681),('only',12,'en','help_search',0.650439),('only',22,'en','help_search',1),('only',26,'en','help_search',1),('only',30,'en','help_search',1),('only',37,'en','help_search',1),('only',43,'en','help_search',4),('only',44,'en','help_search',1),('only',47,'en','help_search',1),('only',50,'en','help_search',0.876337),('only',54,'en','help_search',0.931053),('only',55,'en','help_search',1),('only',59,'en','help_search',1),('only',79,'en','help_search',1),('only',81,'en','help_search',1),('open',20,'en','help_search',1),('open',51,'en','help_search',1),('open',55,'en','help_search',4.61985),('open',57,'en','help_search',4),('open',76,'en','help_search',1),('operation',34,'en','help_search',1),('operations',13,'en','help_search',2),('operations',28,'en','help_search',4),('operations',34,'en','help_search',2),('operations',45,'en','help_search',4),('operations',62,'en','help_search',4),('operations',63,'en','help_search',4),('operations',71,'en','help_search',17.2639),('operations',72,'en','help_search',4),('operations',73,'en','help_search',8),('operations',83,'en','help_search',40.9822),('optimizing',18,'en','help_search',26),('option',12,'en','help_search',0.661163),('option',44,'en','help_search',0.993146),('optional',11,'en','help_search',4),('optional',55,'en','help_search',3.8289),('optionally',7,'en','help_search',1),('optionally',28,'en','help_search',1),('optionally',29,'en','help_search',1),('optionally',34,'en','help_search',1),('optionally',40,'en','help_search',1),('optionally',44,'en','help_search',0.989021),('optionally',47,'en','help_search',1),('optionally',48,'en','help_search',1),('optionally',49,'en','help_search',1),('optionally',52,'en','help_search',2),('optionally',56,'en','help_search',1),('optionally',60,'en','help_search',1),('optionally',61,'en','help_search',1),('optionally',64,'en','help_search',1),('optionally',65,'en','help_search',1),('optionally',66,'en','help_search',1),('optionally',67,'en','help_search',2),('optionally',72,'en','help_search',1),('optionally',73,'en','help_search',3),('optionally',79,'en','help_search',0.989021),('optionally',80,'en','help_search',3),('optionally',82,'en','help_search',1),('optionally',84,'en','help_search',1),('optionally',86,'en','help_search',1),('options',1,'en','node_search',1.22797),('options',12,'en','help_search',1.4206),('options',13,'en','help_search',19),('options',30,'en','help_search',1),('options',33,'en','help_search',0.913226),('options',50,'en','help_search',0.786915),('options',69,'en','help_search',19),('options',72,'en','help_search',1),('order',1,'en','node_search',4.53332),('order',5,'en','help_search',1),('order',6,'en','help_search',1),('order',19,'en','help_search',1),('order',20,'en','help_search',2),('order',23,'en','help_search',2),('order',26,'en','help_search',1),('order',30,'en','help_search',0.876337),('order',47,'en','help_search',1),('order',50,'en','help_search',5.02459),('order',54,'en','help_search',0.889397),('order',55,'en','help_search',2),('order',57,'en','help_search',1),('order',61,'en','help_search',1),('order',62,'en','help_search',3),('order',63,'en','help_search',3),('order',64,'en','help_search',1),('order',67,'en','help_search',1),('order',70,'en','help_search',2),('order',71,'en','help_search',2.98087),('order',73,'en','help_search',2),('order',75,'en','help_search',2),('order',79,'en','help_search',0.961087),('order',83,'en','help_search',1),('order',85,'en','help_search',1),('ordered',50,'en','help_search',1),('ordering',23,'en','help_search',1),('ordering',47,'en','help_search',1),('organize',81,'en','help_search',1),('organized',53,'en','help_search',1),('organizes',30,'en','help_search',1),('original',18,'en','help_search',1),('other',2,'en','help_search',1),('other',4,'en','help_search',1),('other',5,'en','help_search',1),('other',7,'en','help_search',1),('other',8,'en','help_search',1),('other',10,'en','help_search',5),('other',11,'en','help_search',0.716357),('other',12,'en','help_search',5.07468),('other',16,'en','help_search',1),('other',18,'en','help_search',2),('other',22,'en','help_search',1),('other',23,'en','help_search',1),('other',25,'en','help_search',5),('other',27,'en','help_search',1),('other',30,'en','help_search',1),('other',32,'en','help_search',1),('other',33,'en','help_search',19.9132),('other',36,'en','help_search',1),('other',40,'en','help_search',1),('other',44,'en','help_search',0.980874),('other',48,'en','help_search',1),('other',53,'en','help_search',2),('other',54,'en','help_search',2),('other',59,'en','help_search',4.88282),('other',64,'en','help_search',4),('other',65,'en','help_search',1),('other',67,'en','help_search',1.98493),('other',68,'en','help_search',3),('other',71,'en','help_search',1),('other',78,'en','help_search',1),('other',79,'en','help_search',1),('other',81,'en','help_search',2),('other',82,'en','help_search',1),('other',84,'en','help_search',1),('other',86,'en','help_search',1),('out',5,'en','help_search',1),('out',8,'en','help_search',1),('out',18,'en','help_search',0.927431),('out',42,'en','help_search',1),('out',53,'en','help_search',1),('outline',60,'en','help_search',1),('output',18,'en','help_search',1.97685),('output',53,'en','help_search',1),('output',54,'en','help_search',1),('output',71,'en','help_search',5),('outreach',46,'en','help_search',1),('outside',13,'en','help_search',5.99731),('outside',17,'en','help_search',1),('outside',81,'en','help_search',1),('over',1,'en','node_search',1),('over',20,'en','help_search',1),('over',54,'en','help_search',0.916736),('over',60,'en','help_search',1),('over',73,'en','help_search',1),('overall',10,'en','help_search',0.993146),('overall',29,'en','help_search',0.892724),('overflow',1,'en','node_search',2.85116),('overflowx',1,'en','node_search',2.82699),('override',11,'en','help_search',0.920273),('override',47,'en','help_search',4),('overview',10,'en','help_search',19),('overview',11,'en','help_search',14.1606),('overview',12,'en','help_search',12.0017),('overview',14,'en','help_search',19),('overview',15,'en','help_search',19),('overview',16,'en','help_search',19),('overview',17,'en','help_search',19),('overview',21,'en','help_search',19),('overview',22,'en','help_search',19),('overview',23,'en','help_search',19),('overview',24,'en','help_search',17.7735),('overview',30,'en','help_search',16.7117),('overview',42,'en','help_search',19),('overview',46,'en','help_search',11),('overview',48,'en','help_search',19),('overview',53,'en','help_search',18.6366),('overview',58,'en','help_search',4),('overview',59,'en','help_search',17.2851),('overview',61,'en','help_search',3),('overview',65,'en','help_search',4),('overview',67,'en','help_search',4),('overview',68,'en','help_search',19),('overview',70,'en','help_search',1),('overview',71,'en','help_search',15.2523),('overview',78,'en','help_search',19),('overview',81,'en','help_search',18.1873),('overview',86,'en','help_search',1),('own',1,'en','node_search',8.11455),('own',8,'en','help_search',1),('own',10,'en','help_search',1),('own',11,'en','help_search',1),('own',33,'en','help_search',1),('own',55,'en','help_search',0.927431),('own',59,'en','help_search',2),('own',65,'en','help_search',1),('own',67,'en','help_search',5),('own',68,'en','help_search',1),('owned',11,'en','help_search',0.938382),('owners',46,'en','help_search',2),('padding',1,'en','node_search',0.62674),('paddingbottom',1,'en','node_search',7.21819),('paddingleft',1,'en','node_search',8.14615),('paddingright',1,'en','node_search',8.15076),('paddingtop',1,'en','node_search',7.22084),('page',1,'en','node_search',28),('page',3,'en','help_search',1),('page',5,'en','help_search',1),('page',9,'en','help_search',11),('page',10,'en','help_search',22),('page',12,'en','help_search',0.585658),('page',13,'en','help_search',1),('page',14,'en','help_search',11),('page',18,'en','help_search',27.055),('page',19,'en','help_search',1),('page',20,'en','help_search',4),('page',23,'en','help_search',1),('page',24,'en','help_search',1),('page',26,'en','help_search',7),('page',27,'en','help_search',5.9522),('page',28,'en','help_search',14),('page',29,'en','help_search',1.82593),('page',30,'en','help_search',10.732),('page',31,'en','help_search',1),('page',33,'en','help_search',8.96587),('page',34,'en','help_search',2),('page',35,'en','help_search',3),('page',36,'en','help_search',3),('page',38,'en','help_search',4),('page',40,'en','help_search',1),('page',41,'en','help_search',1),('page',46,'en','help_search',1),('page',48,'en','help_search',1),('page',50,'en','help_search',1.72506),('page',52,'en','help_search',1),('page',55,'en','help_search',12.918),('page',58,'en','help_search',5),('page',60,'en','help_search',9.93833),('page',61,'en','help_search',3),('page',62,'en','help_search',2),('page',63,'en','help_search',1),('page',64,'en','help_search',3),('page',65,'en','help_search',19),('page',66,'en','help_search',2),('page',67,'en','help_search',15.4874),('page',69,'en','help_search',2),('page',70,'en','help_search',1),('page',71,'en','help_search',7.89608),('page',73,'en','help_search',3),('page',74,'en','help_search',2),('page',76,'en','help_search',3),('page',77,'en','help_search',2),('page',78,'en','help_search',7),('page',79,'en','help_search',4.9496),('page',80,'en','help_search',2),('page',82,'en','help_search',5),('page',83,'en','help_search',1),('page',84,'en','help_search',1),('pagelevel',12,'en','help_search',1),('pagelevel',68,'en','help_search',1),('pager',55,'en','help_search',1),('pager',71,'en','help_search',3.78332),('pages',1,'en','node_search',1),('pages',10,'en','help_search',1),('pages',18,'en','help_search',1.93838),('pages',23,'en','help_search',2),('pages',24,'en','help_search',4),('pages',26,'en','help_search',12),('pages',28,'en','help_search',42),('pages',29,'en','help_search',11.2782),('pages',30,'en','help_search',29.6242),('pages',33,'en','help_search',34),('pages',38,'en','help_search',4),('pages',60,'en','help_search',1),('pages',68,'en','help_search',1),('pages',78,'en','help_search',2),('pages',79,'en','help_search',2),('pages',81,'en','help_search',1.94177),('paginate',71,'en','help_search',0.938382),('paragraph',1,'en','node_search',59.7465),('paragraph',50,'en','help_search',1),('paragraphid1',1,'en','node_search',13),('paragraphid10',1,'en','node_search',0.699655),('paragraphid11',1,'en','node_search',7.64204),('paragraphid12',1,'en','node_search',0.594307),('paragraphid2',1,'en','node_search',0.934703),('paragraphid23',1,'en','node_search',0.574516),('paragraphid26',1,'en','node_search',0.543537),('paragraphid30',1,'en','node_search',0.60778),('paragraphid33',1,'en','node_search',0.525844),('paragraphid36',1,'en','node_search',0.476356),('paragraphid6',1,'en','node_search',0.863659),('paragraphid9',1,'en','node_search',0.71),('paragraphs',1,'en','node_search',17.6893),('parent',72,'en','help_search',4),('parent',73,'en','help_search',4),('part',14,'en','help_search',1),('part',19,'en','help_search',1),('part',20,'en','help_search',1),('part',38,'en','help_search',1),('part',45,'en','help_search',1),('part',70,'en','help_search',1),('part',78,'en','help_search',1),('particular',20,'en','help_search',1),('particular',30,'en','help_search',2),('particular',42,'en','help_search',3),('particular',43,'en','help_search',1),('particular',50,'en','help_search',0.824901),('particular',55,'en','help_search',1),('particular',57,'en','help_search',1),('particular',58,'en','help_search',1),('particular',61,'en','help_search',1),('particular',62,'en','help_search',1),('particular',63,'en','help_search',1),('particular',64,'en','help_search',1),('particular',71,'en','help_search',1),('particular',78,'en','help_search',1),('parts',18,'en','help_search',1.84779),('pass',59,'en','help_search',0.949597),('passoptionstojavascript',1,'en','node_search',0.571798),('password',25,'en','help_search',1),('password',40,'en','help_search',4),('password',44,'en','help_search',2),('past',37,'en','help_search',1),('past',55,'en','help_search',1.79901),('past',57,'en','help_search',2),('paste',2,'en','help_search',1),('paste',4,'en','help_search',5),('path',11,'en','help_search',0.718502),('path',12,'en','help_search',0.594307),('path',28,'en','help_search',4),('path',73,'en','help_search',1),('path',77,'en','help_search',2),('path',78,'en','help_search',26),('pathauto',78,'en','help_search',11),('paths',78,'en','help_search',31),('patterns',32,'en','help_search',4),('paying',43,'en','help_search',1),('pencil',20,'en','help_search',1),('pencil',60,'en','help_search',1),('pending',44,'en','help_search',1),('people',6,'en','help_search',8),('people',24,'en','help_search',3.68109),('people',40,'en','help_search',4),('people',41,'en','help_search',4),('people',43,'en','help_search',4),('people',44,'en','help_search',4),('people',45,'en','help_search',4),('people',55,'en','help_search',1),('people',59,'en','help_search',0.882818),('people',83,'en','help_search',1),('per',29,'en','help_search',4),('per',55,'en','help_search',4),('per',61,'en','help_search',1),('per',64,'en','help_search',1),('perform',24,'en','help_search',1),('perform',29,'en','help_search',1),('perform',34,'en','help_search',2),('perform',42,'en','help_search',1),('perform',83,'en','help_search',1),('performance',18,'en','help_search',70.3599),('performance',31,'en','help_search',4),('performing',14,'en','help_search',1),('performing',15,'en','help_search',1),('performing',30,'en','help_search',0.886095),('periodically',13,'en','help_search',3),('periodically',15,'en','help_search',1),('periods',12,'en','help_search',0.851346),('permanent',28,'en','help_search',1),('permission',20,'en','help_search',2),('permission',27,'en','help_search',0.968904),('permission',30,'en','help_search',4.55671),('permission',34,'en','help_search',1),('permission',42,'en','help_search',23),('permission',43,'en','help_search',5),('permission',44,'en','help_search',1),('permission',46,'en','help_search',1),('permission',55,'en','help_search',4),('permission',56,'en','help_search',1),('permission',57,'en','help_search',2),('permission',58,'en','help_search',2),('permission',60,'en','help_search',3),('permission',65,'en','help_search',5),('permission',66,'en','help_search',1),('permission',67,'en','help_search',5),('permission',68,'en','help_search',1),('permission',71,'en','help_search',1.85135),('permission',76,'en','help_search',2),('permission',77,'en','help_search',1),('permission',79,'en','help_search',5),('permission',80,'en','help_search',2),('permission',83,'en','help_search',2.99731),('permissions',6,'en','help_search',9),('permissions',8,'en','help_search',1),('permissions',19,'en','help_search',11),('permissions',24,'en','help_search',1.90974),('permissions',27,'en','help_search',0.972861),('permissions',30,'en','help_search',19.4502),('permissions',42,'en','help_search',1),('permissions',43,'en','help_search',39),('permissions',50,'en','help_search',1),('permissions',59,'en','help_search',1.90974),('permissions',65,'en','help_search',1),('permissions',67,'en','help_search',1),('permissions',83,'en','help_search',1),('personal',5,'en','help_search',2),('personal',6,'en','help_search',32),('personal',8,'en','help_search',24),('personalized',18,'en','help_search',0.920273),('php',14,'en','help_search',1),('php',32,'en','help_search',12),('php',33,'en','help_search',1),('physical',53,'en','help_search',1),('piece',59,'en','help_search',1),('piece',78,'en','help_search',1),('piece',86,'en','help_search',1),('pieces',10,'en','help_search',1),('pipe',18,'en','help_search',0.945829),('pixel',53,'en','help_search',12),('place',20,'en','help_search',22),('place',24,'en','help_search',0.997306),('place',26,'en','help_search',1),('place',30,'en','help_search',0.813674),('place',48,'en','help_search',1),('place',49,'en','help_search',11),('placed',3,'en','help_search',1),('placed',24,'en','help_search',1),('placed',47,'en','help_search',1),('placed',48,'en','help_search',3),('placed',51,'en','help_search',1),('placed',60,'en','help_search',1),('placeholders',18,'en','help_search',1.87723),('placing',10,'en','help_search',1),('placing',17,'en','help_search',1),('placing',49,'en','help_search',26),('plain',12,'en','help_search',7.98578),('plain',50,'en','help_search',1.86995),('plain',73,'en','help_search',1),('plaintext',2,'en','help_search',1),('planning',12,'en','help_search',6.33474),('plugin',1,'en','node_search',0.677939),('plugin',27,'en','help_search',2),('plugin',54,'en','help_search',3.44219),('pluginbased',27,'en','help_search',1),('plugins',1,'en','node_search',1.22327),('plugins',27,'en','help_search',2),('point',53,'en','help_search',1),('point',70,'en','help_search',1),('policy',19,'en','help_search',13),('policy',46,'en','help_search',1),('pop',49,'en','help_search',2),('popup',1,'en','node_search',11.5811),('popup',82,'en','help_search',1),('popups',1,'en','node_search',13.0278),('porter',30,'en','help_search',10.8342),('portfolios',1,'en','node_search',1),('position',1,'en','node_search',3),('position',62,'en','help_search',1),('positions',47,'en','help_search',1),('possibility',29,'en','help_search',1),('possible',12,'en','help_search',1.35049),('possible',37,'en','help_search',1),('possible',44,'en','help_search',1),('possible',53,'en','help_search',1),('possible',59,'en','help_search',0.920273),('post',55,'en','help_search',1),('post',81,'en','help_search',1),('posted',59,'en','help_search',3),('posting',59,'en','help_search',0.899454),('posts',16,'en','help_search',1),('posts',59,'en','help_search',1),('posts',81,'en','help_search',1),('potentiallydangerous',50,'en','help_search',1),('powerful',1,'en','node_search',1.43321),('practice',23,'en','help_search',2),('practices',23,'en','help_search',0.993146),('predefined',12,'en','help_search',1.60616),('predefined',68,'en','help_search',1),('prefer',33,'en','help_search',1),('preferred',62,'en','help_search',1),('preferred',63,'en','help_search',1),('prefix',1,'en','node_search',0.563797),('preindex',29,'en','help_search',1),('presentation',1,'en','node_search',1),('presents',23,'en','help_search',1),('prevent',59,'en','help_search',1),('preventing',15,'en','help_search',11),('preview',55,'en','help_search',3.89144),('preview',65,'en','help_search',5),('preview',85,'en','help_search',4),('previewing',55,'en','help_search',0.968904),('previous',12,'en','help_search',0.62674),('previous',32,'en','help_search',1),('previous',70,'en','help_search',1),('previously',3,'en','help_search',1),('previously',4,'en','help_search',1),('previously',39,'en','help_search',1),('previously',47,'en','help_search',1),('previouslyplaced',47,'en','help_search',26),('previouslyplaced',49,'en','help_search',1),('printers',53,'en','help_search',1),('problem',15,'en','help_search',1),('problem',19,'en','help_search',1),('problem',31,'en','help_search',1),('problems',15,'en','help_search',13),('problems',83,'en','help_search',0.993146),('process',11,'en','help_search',1.91323),('process',19,'en','help_search',11),('process',25,'en','help_search',2),('process',29,'en','help_search',1),('process',70,'en','help_search',1),('processed',12,'en','help_search',0.72066),('processed',50,'en','help_search',1),('processing',16,'en','help_search',1),('processing',50,'en','help_search',4.35754),('production',14,'en','help_search',1),('production',33,'en','help_search',0.931053),('profile',8,'en','help_search',2),('profile',11,'en','help_search',1),('profile',12,'en','help_search',1),('profile',22,'en','help_search',1),('profile',78,'en','help_search',1),('profile',79,'en','help_search',1),('profiles',6,'en','help_search',2),('profiles',30,'en','help_search',1),('profiles',68,'en','help_search',1),('programs',46,'en','help_search',1),('progress',29,'en','help_search',7.0238),('project',1,'en','node_search',0.896076),('project',19,'en','help_search',2),('project',27,'en','help_search',1),('project',46,'en','help_search',3),('projects',19,'en','help_search',1),('promote',46,'en','help_search',1),('provide',1,'en','node_search',1),('provide',11,'en','help_search',1.38922),('provide',12,'en','help_search',1.20063),('provide',16,'en','help_search',2),('provide',24,'en','help_search',1),('provide',25,'en','help_search',22),('provide',27,'en','help_search',1),('provide',29,'en','help_search',0.98493),('provide',30,'en','help_search',22),('provide',46,'en','help_search',1),('provide',53,'en','help_search',1),('provide',54,'en','help_search',1.84832),('provide',59,'en','help_search',0.972861),('provide',68,'en','help_search',2),('provide',78,'en','help_search',1),('provided',8,'en','help_search',1),('provided',11,'en','help_search',1.73165),('provided',12,'en','help_search',4.30399),('provided',17,'en','help_search',2),('provided',22,'en','help_search',5),('provided',24,'en','help_search',2),('provided',27,'en','help_search',25.989),('provided',29,'en','help_search',1),('provided',30,'en','help_search',1),('provided',48,'en','help_search',1),('provided',50,'en','help_search',1),('provided',53,'en','help_search',0.957226),('provided',55,'en','help_search',1),('provides',10,'en','help_search',1),('provides',11,'en','help_search',1),('provides',12,'en','help_search',1.20498),('provides',16,'en','help_search',3.99731),('provides',17,'en','help_search',3),('provides',20,'en','help_search',1),('provides',21,'en','help_search',1),('provides',22,'en','help_search',2),('provides',24,'en','help_search',1),('provides',25,'en','help_search',2),('provides',30,'en','help_search',1),('provides',33,'en','help_search',1),('provides',47,'en','help_search',1),('provides',54,'en','help_search',3),('provides',59,'en','help_search',2.90286),('provides',78,'en','help_search',1),('provides',81,'en','help_search',0.934703),('providing',1,'en','node_search',0.676032),('providing',11,'en','help_search',2),('public',19,'en','help_search',1),('publish',58,'en','help_search',5),('publish',65,'en','help_search',2),('publish',67,'en','help_search',4.97258),('published',30,'en','help_search',3.61143),('published',59,'en','help_search',1),('published',65,'en','help_search',4),('published',67,'en','help_search',4),('published',71,'en','help_search',1),('publishes',59,'en','help_search',0.989021),('publishing',71,'en','help_search',0.822065),('pull',71,'en','help_search',0.892724),('purpose',46,'en','help_search',1),('purposes',11,'en','help_search',0.961087),('purposes',12,'en','help_search',1),('purposes',53,'en','help_search',0.993146),('purposes',59,'en','help_search',1),('put',15,'en','help_search',1),('put',23,'en','help_search',1),('put',34,'en','help_search',9),('put',72,'en','help_search',1),('putting',27,'en','help_search',1),('queries',29,'en','help_search',1),('queries',53,'en','help_search',31.2416),('query',53,'en','help_search',1),('quick',20,'en','help_search',49),('quick',24,'en','help_search',5),('quick',60,'en','help_search',1),('quick',79,'en','help_search',1),('quickly',18,'en','help_search',1.89945),('quickly',20,'en','help_search',1),('quote',1,'en','node_search',12.2207),('radio',12,'en','help_search',2.55346),('ran',12,'en','help_search',1),('range',1,'en','node_search',1),('range',12,'en','help_search',1.70574),('ranging',13,'en','help_search',1),('ranking',28,'en','help_search',5),('rather',34,'en','help_search',1),('ratio',53,'en','help_search',1),('reach',54,'en','help_search',0.989021),('read',11,'en','help_search',0.71),('read',62,'en','help_search',1),('readers',23,'en','help_search',1),('readers',62,'en','help_search',1),('ready',74,'en','help_search',1),('really',53,'en','help_search',1),('rearrange',5,'en','help_search',1),('rearrange',85,'en','help_search',4),('reasons',36,'en','help_search',2),('rebuild',26,'en','help_search',4),('recalculated',18,'en','help_search',1),('recalculation',18,'en','help_search',1),('receive',40,'en','help_search',1),('receive',80,'en','help_search',1),('recent',37,'en','help_search',4),('recent',71,'en','help_search',1),('recently',21,'en','help_search',1),('recently',69,'en','help_search',1),('recipe',81,'en','help_search',3),('recipes',59,'en','help_search',1),('recipes',68,'en','help_search',1),('recipes',81,'en','help_search',1),('recipient',8,'en','help_search',1),('recipients',7,'en','help_search',4),('recipients',8,'en','help_search',1),('recommended',13,'en','help_search',1),('recommended',14,'en','help_search',1),('recommended',16,'en','help_search',1),('records',69,'en','help_search',1),('red',81,'en','help_search',1),('redirected',3,'en','help_search',1),('reduce',1,'en','node_search',0.945829),('reduce',29,'en','help_search',1),('reduce',67,'en','help_search',1),('reference',12,'en','help_search',32.2871),('reference',16,'en','help_search',5),('reference',32,'en','help_search',11),('reference',59,'en','help_search',0.886095),('reference',64,'en','help_search',45),('reference',80,'en','help_search',7),('reference',81,'en','help_search',3.92027),('reference',86,'en','help_search',2),('referenced',16,'en','help_search',1),('referenced',64,'en','help_search',1),('referenced',86,'en','help_search',1),('references',12,'en','help_search',0.802752),('refers',18,'en','help_search',1),('refine',62,'en','help_search',1),('refine',63,'en','help_search',1),('region',17,'en','help_search',1),('region',26,'en','help_search',2),('region',32,'en','help_search',8),('region',47,'en','help_search',9),('region',48,'en','help_search',2),('region',49,'en','help_search',3),('regional',32,'en','help_search',4),('regions',47,'en','help_search',5),('regions',48,'en','help_search',1),('regions',49,'en','help_search',5),('register',10,'en','help_search',1),('register',42,'en','help_search',1),('register',44,'en','help_search',2),('registered',6,'en','help_search',1),('registered',8,'en','help_search',1),('registered',71,'en','help_search',1),('regular',71,'en','help_search',0.920273),('regular',81,'en','help_search',1.99731),('regularlength',12,'en','help_search',0.705825),('reindex',29,'en','help_search',3.78332),('reindexed',26,'en','help_search',1),('related',8,'en','help_search',1),('related',10,'en','help_search',0.961087),('related',11,'en','help_search',1.50606),('related',12,'en','help_search',2.87785),('related',14,'en','help_search',2),('related',15,'en','help_search',2),('related',16,'en','help_search',0.980874),('related',17,'en','help_search',1),('related',19,'en','help_search',1),('related',21,'en','help_search',1),('related',22,'en','help_search',1),('related',23,'en','help_search',1),('related',24,'en','help_search',1.86679),('related',26,'en','help_search',1),('related',27,'en','help_search',2.9534),('related',30,'en','help_search',0.797402),('related',42,'en','help_search',2),('related',44,'en','help_search',20.9849),('related',46,'en','help_search',4),('related',48,'en','help_search',1),('related',50,'en','help_search',0.854391),('related',55,'en','help_search',1),('related',56,'en','help_search',1),('related',59,'en','help_search',0.866793),('related',60,'en','help_search',2),('related',66,'en','help_search',1),('related',68,'en','help_search',1),('related',70,'en','help_search',1),('related',71,'en','help_search',2.4897),('related',74,'en','help_search',1),('related',76,'en','help_search',1),('related',78,'en','help_search',1),('related',80,'en','help_search',2),('related',81,'en','help_search',0.913226),('related',83,'en','help_search',1),('related',84,'en','help_search',1),('related',86,'en','help_search',2),('relationship',12,'en','help_search',1.85133),('relationships',71,'en','help_search',3.5843),('relative',1,'en','node_search',2),('released',19,'en','help_search',1),('releases',19,'en','help_search',1),('releases',37,'en','help_search',1),('relevant',46,'en','help_search',1),('relying',1,'en','node_search',0.757065),('remain',55,'en','help_search',0.902857),('remain',57,'en','help_search',1),('remote',16,'en','help_search',1),('remove',5,'en','help_search',2),('remove',79,'en','help_search',1.96498),('removing',14,'en','help_search',1),('render',18,'en','help_search',0.906287),('rendered',48,'en','help_search',1),('rendering',18,'en','help_search',1),('renders',29,'en','help_search',1),('reordering',17,'en','help_search',1),('reordering',75,'en','help_search',26),('repeat',32,'en','help_search',1),('repeat',40,'en','help_search',1),('repeat',50,'en','help_search',0.779231),('repeat',70,'en','help_search',1),('repeat',79,'en','help_search',1),('replacement',20,'en','help_search',1),('replacement',23,'en','help_search',1),('replacement',60,'en','help_search',1),('replacement',79,'en','help_search',1),('replacements',24,'en','help_search',1),('reply',55,'en','help_search',10.8746),('report',37,'en','help_search',10),('reported',19,'en','help_search',1),('reports',15,'en','help_search',1),('reports',24,'en','help_search',3.63897),('reports',37,'en','help_search',39),('reproduced',11,'en','help_search',0.863659),('request',25,'en','help_search',1),('request',44,'en','help_search',1),('requested',18,'en','help_search',1.9496),('requests',25,'en','help_search',1),('require',1,'en','node_search',0.519091),('require',54,'en','help_search',0.863659),('require',70,'en','help_search',1),('require',71,'en','help_search',1),('required',23,'en','help_search',1),('required',30,'en','help_search',0.923838),('required',55,'en','help_search',4.8289),('required',61,'en','help_search',4),('required',64,'en','help_search',4),('required',77,'en','help_search',1),('requires',11,'en','help_search',0.712106),('requires',20,'en','help_search',1),('requires',35,'en','help_search',1),('requires',36,'en','help_search',1),('requires',44,'en','help_search',1),('requiring',59,'en','help_search',0.957226),('reset',44,'en','help_search',2),('resides',11,'en','help_search',1),('resized',53,'en','help_search',1),('resolution',53,'en','help_search',47.9496),('resource',78,'en','help_search',1),('resources',10,'en','help_search',17.8293),('resources',11,'en','help_search',12.9173),('resources',12,'en','help_search',11.0471),('resources',13,'en','help_search',18.4844),('resources',14,'en','help_search',19),('resources',15,'en','help_search',19),('resources',16,'en','help_search',18.1145),('resources',17,'en','help_search',19),('resources',18,'en','help_search',16.1181),('resources',19,'en','help_search',19),('resources',25,'en','help_search',20),('resources',27,'en','help_search',17.8293),('resources',30,'en','help_search',14.9024),('resources',31,'en','help_search',19),('resources',32,'en','help_search',19),('resources',37,'en','help_search',19),('resources',46,'en','help_search',19),('resources',48,'en','help_search',19),('resources',53,'en','help_search',18.0423),('resources',55,'en','help_search',16.8985),('resources',58,'en','help_search',19),('resources',65,'en','help_search',19),('resources',66,'en','help_search',19),('resources',67,'en','help_search',18.2607),('resources',71,'en','help_search',14.8537),('resources',76,'en','help_search',19),('resources',78,'en','help_search',19),('resources',80,'en','help_search',19),('resources',81,'en','help_search',16.8985),('resources',85,'en','help_search',18.4844),('respective',54,'en','help_search',0.845322),('respectively',22,'en','help_search',1),('respond',33,'en','help_search',1),('respond',53,'en','help_search',2),('response',18,'en','help_search',1),('response',33,'en','help_search',5),('responses',33,'en','help_search',48),('responsive',1,'en','node_search',0.657549),('responsive',12,'en','help_search',0.595774),('responsive',16,'en','help_search',3.97954),('responsive',70,'en','help_search',1),('rest',25,'en','help_search',11),('rest',54,'en','help_search',0.961087),('restful',25,'en','help_search',23),('restrict',50,'en','help_search',1.86995),('restrictions',54,'en','help_search',1),('restrictive',83,'en','help_search',1),('restricts',50,'en','help_search',1.80818),('result',33,'en','help_search',1),('result',71,'en','help_search',0.953396),('results',28,'en','help_search',1),('results',29,'en','help_search',1),('results',30,'en','help_search',1),('results',31,'en','help_search',1),('results',50,'en','help_search',0.827757),('results',71,'en','help_search',3.84435),('retrieved',18,'en','help_search',1),('return',34,'en','help_search',1),('return',50,'en','help_search',0.781775),('return',54,'en','help_search',1.82026),('return',62,'en','help_search',1),('return',63,'en','help_search',1),('return',85,'en','help_search',1),('returned',28,'en','help_search',1),('returned',29,'en','help_search',0.953396),('returned',35,'en','help_search',1),('returned',36,'en','help_search',1),('returned',38,'en','help_search',1),('returned',41,'en','help_search',1),('returned',52,'en','help_search',1),('returned',60,'en','help_search',0.957226),('returned',61,'en','help_search',1),('returned',64,'en','help_search',1),('returned',73,'en','help_search',1),('returned',77,'en','help_search',1),('reusable',1,'en','node_search',2.72759),('reuse',86,'en','help_search',1),('reusing',16,'en','help_search',1),('reverse',25,'en','help_search',1),('reverse',67,'en','help_search',1),('review',3,'en','help_search',1),('review',43,'en','help_search',1),('reviews',59,'en','help_search',0.993146),('rgba',1,'en','node_search',1),('rich',1,'en','node_search',12.7636),('right',1,'en','node_search',0.695602),('right',13,'en','help_search',1),('right',24,'en','help_search',1),('right',58,'en','help_search',2),('right',60,'en','help_search',2),('right',67,'en','help_search',1),('right',79,'en','help_search',0.98493),('right',81,'en','help_search',1),('righttoleft',20,'en','help_search',1),('righttoleft',24,'en','help_search',1),('righttoleft',58,'en','help_search',2),('righttoleft',60,'en','help_search',2),('righttoleft',67,'en','help_search',1),('righttoleft',79,'en','help_search',0.972861),('rigid',1,'en','node_search',0.997306),('risk',50,'en','help_search',3.44219),('role',41,'en','help_search',38),('role',42,'en','help_search',21),('role',43,'en','help_search',31),('role',59,'en','help_search',0.997306),('role',60,'en','help_search',1),('role',71,'en','help_search',0.997306),('role',79,'en','help_search',1),('roles',6,'en','help_search',1),('roles',30,'en','help_search',1.68779),('roles',40,'en','help_search',4),('roles',41,'en','help_search',8),('roles',42,'en','help_search',7),('roles',43,'en','help_search',4),('roles',50,'en','help_search',3.61143),('roles',59,'en','help_search',1.90974),('row',23,'en','help_search',4),('row',32,'en','help_search',1),('row',43,'en','help_search',1),('row',52,'en','help_search',1),('row',62,'en','help_search',1),('row',63,'en','help_search',1),('row',67,'en','help_search',1),('row',83,'en','help_search',1),('rows',23,'en','help_search',1),('rss',71,'en','help_search',1),('run',10,'en','help_search',1),('run',13,'en','help_search',22.9397),('run',26,'en','help_search',1),('run',29,'en','help_search',4.89945),('run',31,'en','help_search',1),('run',37,'en','help_search',1),('run',50,'en','help_search',0.813674),('running',13,'en','help_search',51),('running',26,'en','help_search',1),('running',29,'en','help_search',1.91323),('running',37,'en','help_search',26),('runs',13,'en','help_search',0.993146),('runs',15,'en','help_search',1),('runs',29,'en','help_search',2),('runtime',33,'en','help_search',1),('safe',50,'en','help_search',0.869951),('same',1,'en','node_search',0.610858),('same',11,'en','help_search',2.67583),('same',12,'en','help_search',1.89712),('same',18,'en','help_search',1),('same',20,'en','help_search',1),('same',35,'en','help_search',1),('same',55,'en','help_search',4.96161),('save',1,'en','help_search',1),('save',2,'en','help_search',1),('save',6,'en','help_search',8),('save',7,'en','help_search',4),('save',9,'en','help_search',4),('save',13,'en','help_search',3.9235),('save',28,'en','help_search',4),('save',29,'en','help_search',3.85992),('save',31,'en','help_search',1),('save',32,'en','help_search',12),('save',33,'en','help_search',7.45773),('save',34,'en','help_search',8),('save',38,'en','help_search',4),('save',41,'en','help_search',4),('save',43,'en','help_search',4),('save',44,'en','help_search',3.87562),('save',45,'en','help_search',4),('save',47,'en','help_search',8),('save',49,'en','help_search',4),('save',50,'en','help_search',3.13735),('save',51,'en','help_search',4),('save',52,'en','help_search',4),('save',54,'en','help_search',0.833529),('save',56,'en','help_search',4),('save',57,'en','help_search',1),('save',60,'en','help_search',0.976851),('save',61,'en','help_search',13),('save',62,'en','help_search',4),('save',63,'en','help_search',4),('save',64,'en','help_search',13),('save',65,'en','help_search',4),('save',66,'en','help_search',8),('save',67,'en','help_search',4),('save',70,'en','help_search',5),('save',72,'en','help_search',4),('save',73,'en','help_search',8),('save',74,'en','help_search',4),('save',75,'en','help_search',5),('save',76,'en','help_search',4),('save',77,'en','help_search',4),('save',80,'en','help_search',8),('save',83,'en','help_search',3.95608),('save',84,'en','help_search',4),('save',85,'en','help_search',4),('save',86,'en','help_search',8),('saved',32,'en','help_search',3),('saved',33,'en','help_search',1.84154),('saved',44,'en','help_search',0.949597),('saves',18,'en','help_search',1),('saving',18,'en','help_search',1),('say',66,'en','help_search',1),('saying',35,'en','help_search',1),('saying',36,'en','help_search',1),('says',13,'en','help_search',1),('scaffolding',10,'en','help_search',1),('scaling',16,'en','help_search',1),('scan',37,'en','help_search',1),('scan',64,'en','help_search',1),('scenes',12,'en','help_search',0.757065),('schedule',13,'en','help_search',4.99315),('screen',1,'en','node_search',3.2717),('screen',23,'en','help_search',1),('screen',33,'en','help_search',4),('screen',45,'en','help_search',1),('screen',54,'en','help_search',1),('screen',61,'en','help_search',2),('screen',62,'en','help_search',1),('screen',64,'en','help_search',2),('screens',53,'en','help_search',1),('screens',65,'en','help_search',1),('screens',72,'en','help_search',1),('scripts',50,'en','help_search',0.892724),('scroll',28,'en','help_search',1),('scroll',45,'en','help_search',1),('scrollspydelay',1,'en','node_search',0.547222),('scrollspyonce',1,'en','node_search',0.545988),('seamless',1,'en','node_search',1.68178),('search',26,'en','help_search',55),('search',27,'en','help_search',28.8536),('search',28,'en','help_search',62),('search',29,'en','help_search',69.082),('search',30,'en','help_search',197.652),('search',42,'en','help_search',1),('search',62,'en','help_search',1),('search',77,'en','help_search',4),('searchable',27,'en','help_search',1),('searches',29,'en','help_search',1),('searches',30,'en','help_search',0.882818),('searching',26,'en','help_search',1),('searching',29,'en','help_search',2.89272),('searching',30,'en','help_search',4.80231),('second',30,'en','help_search',1),('second',85,'en','help_search',1),('section',6,'en','help_search',3),('section',12,'en','help_search',3.02548),('section',26,'en','help_search',1),('section',28,'en','help_search',1),('section',29,'en','help_search',0.869951),('section',33,'en','help_search',1),('section',38,'en','help_search',2),('section',39,'en','help_search',1),('section',54,'en','help_search',0.854391),('section',62,'en','help_search',1),('section',63,'en','help_search',1),('section',64,'en','help_search',2),('section',66,'en','help_search',1),('section',83,'en','help_search',1),('section',85,'en','help_search',1),('section',86,'en','help_search',1),('sections',24,'en','help_search',20),('sections',85,'en','help_search',2),('secure',19,'en','help_search',28),('security',15,'en','help_search',11),('security',19,'en','help_search',102),('security',24,'en','help_search',0.899454),('security',37,'en','help_search',13),('security',43,'en','help_search',4),('security',50,'en','help_search',5.32828),('see',1,'en','help_search',1),('see',2,'en','help_search',1),('see',3,'en','help_search',2),('see',4,'en','help_search',2),('see',7,'en','help_search',1),('see',8,'en','help_search',2),('see',10,'en','help_search',1.96109),('see',11,'en','help_search',0.691597),('see',12,'en','help_search',3.69525),('see',14,'en','help_search',1),('see',15,'en','help_search',1),('see',16,'en','help_search',1.98087),('see',17,'en','help_search',1),('see',19,'en','help_search',1),('see',21,'en','help_search',1),('see',22,'en','help_search',3),('see',24,'en','help_search',2.86679),('see',25,'en','help_search',1),('see',26,'en','help_search',1),('see',27,'en','help_search',0.957226),('see',28,'en','help_search',1),('see',29,'en','help_search',1),('see',30,'en','help_search',3.64573),('see',31,'en','help_search',1),('see',32,'en','help_search',3),('see',33,'en','help_search',1.85668),('see',34,'en','help_search',2),('see',35,'en','help_search',1),('see',36,'en','help_search',2),('see',37,'en','help_search',4),('see',44,'en','help_search',0.961087),('see',46,'en','help_search',39),('see',47,'en','help_search',1),('see',48,'en','help_search',1),('see',49,'en','help_search',2),('see',50,'en','help_search',0.857458),('see',54,'en','help_search',5),('see',55,'en','help_search',1),('see',56,'en','help_search',2),('see',57,'en','help_search',2),('see',59,'en','help_search',2.78353),('see',61,'en','help_search',2),('see',62,'en','help_search',2),('see',63,'en','help_search',2),('see',64,'en','help_search',1),('see',65,'en','help_search',2),('see',66,'en','help_search',1),('see',67,'en','help_search',1),('see',68,'en','help_search',2),('see',70,'en','help_search',2),('see',71,'en','help_search',2.58117),('see',74,'en','help_search',1),('see',76,'en','help_search',2),('see',77,'en','help_search',1),('see',78,'en','help_search',2),('see',80,'en','help_search',3),('see',81,'en','help_search',1.91323),('see',83,'en','help_search',2),('see',85,'en','help_search',1),('see',86,'en','help_search',3),('seen',21,'en','help_search',1),('sees',12,'en','help_search',0.779231),('select',2,'en','help_search',2),('select',4,'en','help_search',1),('select',12,'en','help_search',2.56025),('select',13,'en','help_search',0.997306),('select',28,'en','help_search',2),('select',29,'en','help_search',1),('select',32,'en','help_search',1),('select',33,'en','help_search',1.84417),('select',38,'en','help_search',1),('select',44,'en','help_search',1.99731),('select',45,'en','help_search',1),('select',54,'en','help_search',0.972861),('select',56,'en','help_search',1),('select',57,'en','help_search',1),('select',58,'en','help_search',7),('select',61,'en','help_search',1),('select',62,'en','help_search',2),('select',63,'en','help_search',1),('select',64,'en','help_search',3),('select',67,'en','help_search',2.99315),('select',71,'en','help_search',0.851346),('select',72,'en','help_search',1),('select',73,'en','help_search',2),('select',79,'en','help_search',6),('select',81,'en','help_search',1),('select',84,'en','help_search',2),('select',86,'en','help_search',4),('selected',38,'en','help_search',1),('selected',54,'en','help_search',0.953396),('selected',55,'en','help_search',0.989021),('selected',58,'en','help_search',8),('selected',67,'en','help_search',3.97258),('selected',83,'en','help_search',4),('selecting',62,'en','help_search',1),('selecting',63,'en','help_search',1),('selects',54,'en','help_search',1),('send',1,'en','node_search',8.32333),('send',18,'en','help_search',0.98493),('sending',25,'en','help_search',1),('sends',33,'en','help_search',1),('sent',18,'en','help_search',1.86581),('sent',44,'en','help_search',1),('seofriendly',76,'en','help_search',1),('separate',53,'en','help_search',1),('separately',10,'en','help_search',1),('separately',14,'en','help_search',1),('separates',53,'en','help_search',1),('separator',1,'en','node_search',0.557303),('sequence',50,'en','help_search',1),('serialization',11,'en','help_search',0.98493),('serialization',25,'en','help_search',24),('serialized',25,'en','help_search',1),('serve',16,'en','help_search',0.98493),('serve',46,'en','help_search',1),('server',13,'en','help_search',2),('server',33,'en','help_search',1),('servers',13,'en','help_search',1),('service',25,'en','help_search',20),('services',25,'en','help_search',72),('serving',16,'en','help_search',1),('session',12,'en','help_search',4),('set',1,'en','node_search',1.23115),('set',9,'en','help_search',1),('set',10,'en','help_search',1),('set',11,'en','help_search',2.3646),('set',13,'en','help_search',2),('set',14,'en','help_search',2),('set',16,'en','help_search',1),('set',24,'en','help_search',0.98493),('set',26,'en','help_search',1),('set',28,'en','help_search',4),('set',33,'en','help_search',1),('set',38,'en','help_search',4),('set',50,'en','help_search',0.866793),('set',55,'en','help_search',0.916736),('set',56,'en','help_search',1),('set',59,'en','help_search',2),('set',61,'en','help_search',2),('set',64,'en','help_search',2),('set',66,'en','help_search',1),('set',68,'en','help_search',1),('set',78,'en','help_search',1),('set',79,'en','help_search',20),('set',81,'en','help_search',5.98087),('sets',79,'en','help_search',5),('setting',8,'en','help_search',1),('setting',9,'en','help_search',26),('setting',12,'en','help_search',0.733888),('setting',18,'en','help_search',0.863659),('setting',38,'en','help_search',26),('setting',57,'en','help_search',1),('setting',66,'en','help_search',11),('setting',71,'en','help_search',1),('setting',80,'en','help_search',11),('setting',85,'en','help_search',1),('settings',1,'en','node_search',19.8876),('settings',6,'en','help_search',8),('settings',7,'en','help_search',1),('settings',11,'en','help_search',6.6956),('settings',12,'en','help_search',16.9432),('settings',13,'en','help_search',3.95608),('settings',18,'en','help_search',0.892724),('settings',20,'en','help_search',54),('settings',22,'en','help_search',1),('settings',24,'en','help_search',2.92743),('settings',29,'en','help_search',7.93972),('settings',32,'en','help_search',37),('settings',33,'en','help_search',5.84528),('settings',40,'en','help_search',1),('settings',42,'en','help_search',1),('settings',44,'en','help_search',26.9276),('settings',47,'en','help_search',4),('settings',48,'en','help_search',1),('settings',50,'en','help_search',3.99239),('settings',54,'en','help_search',3.42983),('settings',55,'en','help_search',20.4185),('settings',56,'en','help_search',4),('settings',57,'en','help_search',9),('settings',58,'en','help_search',4),('settings',59,'en','help_search',1),('settings',60,'en','help_search',0.972861),('settings',61,'en','help_search',9),('settings',62,'en','help_search',3),('settings',63,'en','help_search',3),('settings',64,'en','help_search',9),('settings',66,'en','help_search',1),('settings',68,'en','help_search',1),('settings',71,'en','help_search',10),('settings',72,'en','help_search',30),('settings',73,'en','help_search',1),('settings',80,'en','help_search',1),('settings',82,'en','help_search',2),('settings',83,'en','help_search',2),('settings',84,'en','help_search',5),('settings',85,'en','help_search',14),('settingsphp',11,'en','help_search',5.90181),('several',10,'en','help_search',1),('several',11,'en','help_search',0.96498),('several',12,'en','help_search',2.16248),('several',15,'en','help_search',1),('several',29,'en','help_search',1.89945),('several',67,'en','help_search',1),('severity',37,'en','help_search',4),('share',11,'en','help_search',0.839384),('shared',79,'en','help_search',2),('shield',19,'en','help_search',1),('shift',53,'en','help_search',1),('short',1,'en','node_search',0.499853),('short',32,'en','help_search',1),('short',44,'en','help_search',1),('short',45,'en','help_search',1),('shortcut',79,'en','help_search',54.9341),('shortcuts',24,'en','help_search',1),('shortcuts',79,'en','help_search',47.937),('should',7,'en','help_search',1),('should',10,'en','help_search',1),('should',13,'en','help_search',2),('should',20,'en','help_search',2),('should',26,'en','help_search',1),('should',29,'en','help_search',0.957226),('should',32,'en','help_search',3),('should',33,'en','help_search',1.86054),('should',35,'en','help_search',1),('should',36,'en','help_search',2),('should',37,'en','help_search',1),('should',38,'en','help_search',2),('should',41,'en','help_search',2),('should',43,'en','help_search',2),('should',44,'en','help_search',0.96498),('should',45,'en','help_search',1),('should',47,'en','help_search',1),('should',50,'en','help_search',1.69324),('should',53,'en','help_search',3),('should',60,'en','help_search',0.961087),('should',61,'en','help_search',2),('should',64,'en','help_search',2),('should',73,'en','help_search',1),('show',21,'en','help_search',1),('show',23,'en','help_search',4),('show',54,'en','help_search',1),('show',55,'en','help_search',4),('show',65,'en','help_search',1),('show',73,'en','help_search',5),('show',84,'en','help_search',4),('showing',12,'en','help_search',0.659351),('showing',71,'en','help_search',1),('shown',8,'en','help_search',1),('shown',27,'en','help_search',0.98493),('shown',29,'en','help_search',0.876337),('shown',45,'en','help_search',1),('shown',48,'en','help_search',2),('shown',50,'en','help_search',1),('shown',51,'en','help_search',1),('shown',52,'en','help_search',1),('shown',54,'en','help_search',1.92384),('shown',58,'en','help_search',2),('shown',64,'en','help_search',1),('shown',65,'en','help_search',2),('shown',67,'en','help_search',1),('shown',72,'en','help_search',1),('shown',73,'en','help_search',1),('shown',80,'en','help_search',1),('shown',82,'en','help_search',1),('shown',83,'en','help_search',1),('shown',85,'en','help_search',1),('shows',12,'en','help_search',0.771698),('shows',54,'en','help_search',1),('shows',64,'en','help_search',1),('shows',85,'en','help_search',1),('side',24,'en','help_search',2),('side',58,'en','help_search',4),('similar',11,'en','help_search',1),('similar',67,'en','help_search',0.972861),('similar',76,'en','help_search',1),('similar',82,'en','help_search',2),('simple',11,'en','help_search',4),('simple',29,'en','help_search',3.98922),('simple',34,'en','help_search',1),('since',69,'en','help_search',1),('single',2,'en','help_search',31),('single',4,'en','help_search',32),('single',59,'en','help_search',1),('single',71,'en','help_search',1),('singleitem',11,'en','help_search',0.805455),('singleline',12,'en','help_search',1.29741),('singlevalued',12,'en','help_search',1.60675),('site',1,'en','help_search',27),('site',1,'en','node_search',33.0595),('site',3,'en','help_search',28),('site',6,'en','help_search',1),('site',8,'en','help_search',5),('site',10,'en','help_search',61.1676),('site',11,'en','help_search',32.2666),('site',12,'en','help_search',30.9082),('site',13,'en','help_search',9),('site',14,'en','help_search',40),('site',15,'en','help_search',33),('site',16,'en','help_search',1),('site',17,'en','help_search',2),('site',18,'en','help_search',66.989),('site',19,'en','help_search',29),('site',20,'en','help_search',1),('site',21,'en','help_search',1),('site',22,'en','help_search',21),('site',24,'en','help_search',4.71269),('site',25,'en','help_search',2),('site',26,'en','help_search',2),('site',28,'en','help_search',2),('site',29,'en','help_search',6.76836),('site',30,'en','help_search',69.9142),('site',31,'en','help_search',31),('site',32,'en','help_search',36),('site',33,'en','help_search',12.7251),('site',34,'en','help_search',21),('site',36,'en','help_search',1),('site',37,'en','help_search',32),('site',38,'en','help_search',6),('site',39,'en','help_search',2),('site',42,'en','help_search',31),('site',44,'en','help_search',5.99731),('site',46,'en','help_search',21),('site',47,'en','help_search',1),('site',48,'en','help_search',3),('site',50,'en','help_search',6.99315),('site',51,'en','help_search',2),('site',53,'en','help_search',1),('site',54,'en','help_search',3),('site',59,'en','help_search',2.91323),('site',60,'en','help_search',2),('site',65,'en','help_search',2),('site',68,'en','help_search',1),('site',69,'en','help_search',1),('site',71,'en','help_search',1),('site',73,'en','help_search',1),('site',74,'en','help_search',1),('site',77,'en','help_search',2),('site',78,'en','help_search',2),('site',79,'en','help_search',1),('site',81,'en','help_search',0.993146),('site',84,'en','help_search',1),('site',86,'en','help_search',1),('sites',1,'en','node_search',2.1191),('sites',11,'en','help_search',8.33326),('sites',14,'en','help_search',1),('sites',25,'en','help_search',1),('sites',30,'en','help_search',1),('sitewide',5,'en','help_search',2),('sitewide',7,'en','help_search',1),('sitewide',8,'en','help_search',2),('sitewide',9,'en','help_search',2),('situations',33,'en','help_search',1),('size',16,'en','help_search',1),('size',53,'en','help_search',2),('sized',16,'en','help_search',1.98087),('sizes',16,'en','help_search',1),('sizing',53,'en','help_search',0.98493),('slack',1,'en','node_search',5.2605),('sleek',1,'en','node_search',0.672252),('slick',1,'en','node_search',12.2334),('slider',1,'en','node_search',12.2319),('slideshow',1,'en','node_search',11.6448),('slogan',32,'en','help_search',2),('smaller',12,'en','help_search',1),('smaller',18,'en','help_search',1),('smaller',29,'en','help_search',2),('smaller',35,'en','help_search',1),('smaller',36,'en','help_search',1),('smarteasingamount',1,'en','node_search',0.550958),('smarteasingthreshold',1,'en','node_search',0.553478),('smooth',1,'en','node_search',0.661163),('social',16,'en','help_search',1),('software',10,'en','help_search',2),('software',11,'en','help_search',0.968904),('software',14,'en','help_search',1),('software',18,'en','help_search',1),('software',19,'en','help_search',4),('software',22,'en','help_search',2),('software',24,'en','help_search',1),('software',25,'en','help_search',1),('software',29,'en','help_search',1),('software',33,'en','help_search',2),('software',37,'en','help_search',3),('software',54,'en','help_search',1),('software',59,'en','help_search',1),('software',78,'en','help_search',1),('solr',30,'en','help_search',12),('some',12,'en','help_search',1.6522),('some',15,'en','help_search',1),('some',17,'en','help_search',1),('some',23,'en','help_search',2),('some',24,'en','help_search',4.73496),('some',29,'en','help_search',0.980874),('some',30,'en','help_search',1),('some',31,'en','help_search',1),('some',33,'en','help_search',2),('some',44,'en','help_search',1),('some',47,'en','help_search',1),('some',50,'en','help_search',2.89945),('some',53,'en','help_search',1),('some',54,'en','help_search',1),('some',59,'en','help_search',2),('some',65,'en','help_search',1),('some',66,'en','help_search',1),('some',67,'en','help_search',1),('some',70,'en','help_search',1),('some',71,'en','help_search',1.8861),('some',78,'en','help_search',1),('someone',67,'en','help_search',1),('sometimes',19,'en','help_search',1),('sometimes',23,'en','help_search',1),('soon',37,'en','help_search',1),('sort',64,'en','help_search',1),('sort',67,'en','help_search',1),('sort',71,'en','help_search',4),('sorting',71,'en','help_search',1),('sorting',84,'en','help_search',1),('sorts',71,'en','help_search',0.869951),('source',11,'en','help_search',0.794753),('source',50,'en','help_search',1),('source',86,'en','help_search',8),('sources',46,'en','help_search',1),('sources',86,'en','help_search',1),('spaces',50,'en','help_search',1),('spam',59,'en','help_search',1.91674),('spamreduction',59,'en','help_search',0.96498),('special',42,'en','help_search',1),('specific',2,'en','help_search',1),('specific',8,'en','help_search',1),('specific',10,'en','help_search',0.945829),('specific',11,'en','help_search',0.683725),('specific',16,'en','help_search',0.96498),('specific',17,'en','help_search',1),('specific',19,'en','help_search',1),('specific',21,'en','help_search',1),('specific',22,'en','help_search',1),('specific',25,'en','help_search',1),('specific',30,'en','help_search',0.78951),('specific',48,'en','help_search',1),('specific',59,'en','help_search',0.854391),('specific',65,'en','help_search',1),('specific',68,'en','help_search',1),('specific',71,'en','help_search',2.60924),('specific',78,'en','help_search',2),('specific',81,'en','help_search',0.899454),('specifically',48,'en','help_search',1),('specification',25,'en','help_search',11),('specify',71,'en','help_search',2),('specifying',12,'en','help_search',0.942091),('specifying',30,'en','help_search',1),('speed',18,'en','help_search',1),('sphinx',30,'en','help_search',11),('square',44,'en','help_search',1),('stable',10,'en','help_search',1),('stable',14,'en','help_search',1),('stable',19,'en','help_search',1),('staging',11,'en','help_search',1),('standard',11,'en','help_search',0.980874),('standards',23,'en','help_search',1),('standards',27,'en','help_search',10.2817),('standards',53,'en','help_search',10.2817),('star',79,'en','help_search',1),('start',1,'en','node_search',21.3099),('start',12,'en','help_search',0.848323),('start',59,'en','help_search',1),('start',73,'en','help_search',1),('started',1,'en','node_search',27),('started',60,'en','help_search',0.953396),('starting',33,'en','help_search',1),('starts',30,'en','help_search',1),('starts',76,'en','help_search',1),('startval',1,'en','node_search',0.565115),('state',12,'en','help_search',6),('state',23,'en','help_search',1),('statistics',1,'en','node_search',0.712106),('stats',1,'en','node_search',11.632),('status',26,'en','help_search',1),('status',28,'en','help_search',4),('status',29,'en','help_search',1.76896),('status',37,'en','help_search',6),('status',67,'en','help_search',4),('status',69,'en','help_search',1),('stemmer',30,'en','help_search',10.7896),('stemming',30,'en','help_search',1),('step',31,'en','help_search',1),('step',50,'en','help_search',1),('step',54,'en','help_search',0.98493),('stepbystep',27,'en','help_search',0.949597),('steps',1,'en','help_search',19),('steps',2,'en','help_search',19),('steps',3,'en','help_search',19),('steps',4,'en','help_search',19),('steps',5,'en','help_search',19),('steps',6,'en','help_search',20),('steps',7,'en','help_search',20),('steps',9,'en','help_search',19),('steps',13,'en','help_search',19),('steps',16,'en','help_search',1),('steps',20,'en','help_search',20),('steps',26,'en','help_search',20),('steps',27,'en','help_search',1),('steps',28,'en','help_search',20),('steps',29,'en','help_search',19.9132),('steps',31,'en','help_search',19),('steps',32,'en','help_search',20),('steps',33,'en','help_search',19),('steps',34,'en','help_search',19),('steps',35,'en','help_search',19),('steps',36,'en','help_search',19),('steps',37,'en','help_search',19),('steps',38,'en','help_search',19),('steps',39,'en','help_search',19),('steps',40,'en','help_search',20),('steps',41,'en','help_search',19),('steps',43,'en','help_search',19),('steps',44,'en','help_search',19),('steps',45,'en','help_search',19),('steps',47,'en','help_search',19),('steps',49,'en','help_search',19),('steps',50,'en','help_search',19.644),('steps',51,'en','help_search',19),('steps',52,'en','help_search',19),('steps',53,'en','help_search',2),('steps',54,'en','help_search',20.9545),('steps',55,'en','help_search',21),('steps',56,'en','help_search',20),('steps',57,'en','help_search',19),('steps',58,'en','help_search',19),('steps',60,'en','help_search',19),('steps',61,'en','help_search',19),('steps',62,'en','help_search',20),('steps',63,'en','help_search',20),('steps',64,'en','help_search',19),('steps',65,'en','help_search',19),('steps',66,'en','help_search',20),('steps',67,'en','help_search',19),('steps',70,'en','help_search',20),('steps',72,'en','help_search',19),('steps',73,'en','help_search',19),('steps',74,'en','help_search',19),('steps',75,'en','help_search',19),('steps',76,'en','help_search',21),('steps',77,'en','help_search',19),('steps',79,'en','help_search',19),('steps',80,'en','help_search',19),('steps',82,'en','help_search',20),('steps',83,'en','help_search',19),('steps',84,'en','help_search',20),('steps',85,'en','help_search',19),('steps',86,'en','help_search',19),('still',14,'en','help_search',1),('storage',11,'en','help_search',2),('store',29,'en','help_search',1),('store',59,'en','help_search',1),('store',68,'en','help_search',1),('store',86,'en','help_search',2),('stored',10,'en','help_search',1),('stored',11,'en','help_search',1.76676),('stored',12,'en','help_search',2.49525),('stored',25,'en','help_search',1),('stored',86,'en','help_search',1),('stores',12,'en','help_search',11.822),('strategic',46,'en','help_search',1),('streamed',18,'en','help_search',0.916736),('string',26,'en','help_search',1),('string',32,'en','help_search',4),('strings',12,'en','help_search',0.738408),('strings',25,'en','help_search',1),('strings',32,'en','help_search',1),('strings',44,'en','help_search',1),('striptags',1,'en','node_search',0.569105),('structure',1,'en','node_search',0.749958),('structure',5,'en','help_search',4),('structure',7,'en','help_search',4),('structure',9,'en','help_search',4),('structure',10,'en','help_search',1),('structure',11,'en','help_search',2),('structure',12,'en','help_search',39.205),('structure',16,'en','help_search',1),('structure',22,'en','help_search',1),('structure',24,'en','help_search',4),('structure',25,'en','help_search',1),('structure',26,'en','help_search',4),('structure',47,'en','help_search',4),('structure',49,'en','help_search',4),('structure',52,'en','help_search',4),('structure',55,'en','help_search',1),('structure',56,'en','help_search',5),('structure',57,'en','help_search',1),('structure',59,'en','help_search',1),('structure',61,'en','help_search',6),('structure',62,'en','help_search',5),('structure',63,'en','help_search',5),('structure',64,'en','help_search',5),('structure',65,'en','help_search',1),('structure',66,'en','help_search',15),('structure',67,'en','help_search',1),('structure',68,'en','help_search',2),('structure',72,'en','help_search',5),('structure',73,'en','help_search',8),('structure',74,'en','help_search',4),('structure',75,'en','help_search',4),('structure',80,'en','help_search',5),('structure',81,'en','help_search',2),('structure',82,'en','help_search',4),('structure',83,'en','help_search',4),('structure',84,'en','help_search',4),('structure',85,'en','help_search',4),('structure',86,'en','help_search',5),('structures',25,'en','help_search',1),('style',11,'en','help_search',1),('style',16,'en','help_search',20),('style',70,'en','help_search',41),('style',71,'en','help_search',1),('styles',1,'en','node_search',0.567769),('styles',11,'en','help_search',1),('styles',16,'en','help_search',4.97954),('styles',70,'en','help_search',2),('styling',10,'en','help_search',1),('subdirectory',27,'en','help_search',1),('subject',5,'en','help_search',4),('subject',6,'en','help_search',4),('subject',7,'en','help_search',4),('submission',55,'en','help_search',0.961087),('submit',20,'en','help_search',1),('submit',23,'en','help_search',1),('submitting',59,'en','help_search',0.938382),('subset',12,'en','help_search',1),('substituted',44,'en','help_search',1),('subterm',81,'en','help_search',1),('subtype',12,'en','help_search',0.980874),('subtype',55,'en','help_search',8.90974),('subtype',57,'en','help_search',1),('subtype',61,'en','help_search',29),('subtype',62,'en','help_search',29),('subtype',63,'en','help_search',29),('subtype',64,'en','help_search',29),('subtype',80,'en','help_search',4),('subtype',86,'en','help_search',1),('subtypes',10,'en','help_search',1),('subtypes',12,'en','help_search',6.98902),('subtypes',16,'en','help_search',1),('subtypes',59,'en','help_search',1),('subtypes',61,'en','help_search',1),('subtypes',64,'en','help_search',1),('subtypes',68,'en','help_search',1),('subtypes',81,'en','help_search',1),('such',3,'en','help_search',1),('such',4,'en','help_search',1),('such',5,'en','help_search',1),('such',11,'en','help_search',2.73841),('such',12,'en','help_search',4.6522),('such',13,'en','help_search',1),('such',15,'en','help_search',1),('such',16,'en','help_search',1),('such',18,'en','help_search',1),('such',23,'en','help_search',1),('such',24,'en','help_search',1),('such',25,'en','help_search',2),('such',26,'en','help_search',1),('such',30,'en','help_search',0.989021),('such',33,'en','help_search',1),('such',42,'en','help_search',2),('such',50,'en','help_search',2),('such',53,'en','help_search',1.98902),('such',54,'en','help_search',1),('such',59,'en','help_search',0.961087),('such',60,'en','help_search',1),('such',71,'en','help_search',4.78568),('such',73,'en','help_search',1),('such',81,'en','help_search',1),('such',85,'en','help_search',3),('sufficient',71,'en','help_search',0.854391),('suffix',1,'en','node_search',0.562486),('suggested',2,'en','help_search',1),('suit',1,'en','node_search',0.968904),('summarizes',37,'en','help_search',1),('summary',12,'en','help_search',5.47787),('summary',23,'en','help_search',1),('summary',74,'en','help_search',1),('sun',1,'en','node_search',0.474499),('supercharge',1,'en','node_search',26),('supplied',10,'en','help_search',1),('support',29,'en','help_search',0.976851),('support',71,'en','help_search',1.82206),('supports',30,'en','help_search',1),('sure',1,'en','node_search',0.50505),('sure',13,'en','help_search',1),('sure',28,'en','help_search',1),('sure',29,'en','help_search',2.91323),('sure',30,'en','help_search',0.833529),('sure',54,'en','help_search',0.836446),('sure',60,'en','help_search',2),('sure',73,'en','help_search',1),('sure',76,'en','help_search',1),('sure',79,'en','help_search',2),('sustainability',46,'en','help_search',1),('switch',10,'en','help_search',0.989021),('switch',24,'en','help_search',0.953396),('switch',85,'en','help_search',1),('switcher',22,'en','help_search',4),('sync',11,'en','help_search',4.53866),('synchronization',1,'en','help_search',4),('synchronization',2,'en','help_search',4),('synchronization',3,'en','help_search',5),('synchronization',4,'en','help_search',4),('synchronization',11,'en','help_search',22.3776),('synchronize',3,'en','help_search',4),('synchronize',11,'en','help_search',1),('synchronized',11,'en','help_search',0.902857),('synchronizing',11,'en','help_search',0.738408),('syslog',15,'en','help_search',1),('system',11,'en','help_search',21.6358),('system',12,'en','help_search',4.4446),('system',13,'en','help_search',5),('system',16,'en','help_search',1),('system',17,'en','help_search',1),('system',24,'en','help_search',1),('system',30,'en','help_search',1),('system',32,'en','help_search',4),('system',33,'en','help_search',4),('system',60,'en','help_search',1),('systems',18,'en','help_search',1),('tab',8,'en','help_search',1),('tab',26,'en','help_search',1),('tab',51,'en','help_search',1),('tab',58,'en','help_search',1),('table',7,'en','help_search',1),('table',23,'en','help_search',4),('table',45,'en','help_search',1),('table',54,'en','help_search',1),('table',71,'en','help_search',2.85746),('table',83,'en','help_search',1),('table',85,'en','help_search',4),('tables',23,'en','help_search',1),('tables',29,'en','help_search',1),('tablestyle',83,'en','help_search',1),('tabs',1,'en','node_search',12.2006),('tabs',66,'en','help_search',1),('tag',50,'en','help_search',0.822065),('tag',54,'en','help_search',1),('tagging',81,'en','help_search',1),('tags',50,'en','help_search',7.37404),('tags',81,'en','help_search',4),('take',1,'en','node_search',9.56946),('take',31,'en','help_search',1),('take',37,'en','help_search',1),('taken',66,'en','help_search',1),('takes',50,'en','help_search',1),('takes',60,'en','help_search',1),('target',56,'en','help_search',4),('task',13,'en','help_search',3.99731),('task',27,'en','help_search',1),('task',29,'en','help_search',0.913226),('task',60,'en','help_search',0.980874),('tasks',8,'en','help_search',20),('tasks',10,'en','help_search',0.942091),('tasks',11,'en','help_search',1.42247),('tasks',12,'en','help_search',0.582831),('tasks',13,'en','help_search',32.4456),('tasks',14,'en','help_search',1),('tasks',15,'en','help_search',1),('tasks',16,'en','help_search',0.961087),('tasks',17,'en','help_search',1),('tasks',19,'en','help_search',20),('tasks',21,'en','help_search',1),('tasks',22,'en','help_search',1),('tasks',24,'en','help_search',4),('tasks',30,'en','help_search',0.786915),('tasks',42,'en','help_search',1),('tasks',48,'en','help_search',1),('tasks',59,'en','help_search',0.851346),('tasks',60,'en','help_search',2),('tasks',68,'en','help_search',1),('tasks',71,'en','help_search',0.784336),('tasks',74,'en','help_search',1),('tasks',78,'en','help_search',1),('tasks',81,'en','help_search',0.896076),('taste',59,'en','help_search',1),('taxonomy',12,'en','help_search',0.610858),('taxonomy',24,'en','help_search',0.961087),('taxonomy',76,'en','help_search',1),('taxonomy',78,'en','help_search',2),('taxonomy',80,'en','help_search',64),('taxonomy',81,'en','help_search',89.5416),('team',1,'en','node_search',9.60445),('team',19,'en','help_search',11),('technically',81,'en','help_search',1),('technologies',30,'en','help_search',1),('technology',23,'en','help_search',1),('technology',30,'en','help_search',1),('telephone',12,'en','help_search',2.38691),('template',1,'en','node_search',0.752312),('template',10,'en','help_search',1),('templates',1,'en','node_search',0.993146),('temporarily',60,'en','help_search',1),('temporary',12,'en','help_search',1),('temporary',28,'en','help_search',1),('term',76,'en','help_search',1),('term',78,'en','help_search',2),('term',80,'en','help_search',7),('term',81,'en','help_search',2.92613),('terms',11,'en','help_search',0.822065),('terms',80,'en','help_search',6),('terms',81,'en','help_search',13.9347),('test',59,'en','help_search',0.942091),('test',62,'en','help_search',1),('test',63,'en','help_search',1),('text',1,'en','node_search',12.943),('text',2,'en','help_search',3),('text',4,'en','help_search',1),('text',5,'en','help_search',1),('text',10,'en','help_search',1),('text',12,'en','help_search',39.8545),('text',22,'en','help_search',23),('text',25,'en','help_search',1),('text',26,'en','help_search',1),('text',27,'en','help_search',2),('text',44,'en','help_search',21.9849),('text',45,'en','help_search',1),('text',50,'en','help_search',163.01),('text',51,'en','help_search',1),('text',54,'en','help_search',108.144),('text',59,'en','help_search',1),('text',61,'en','help_search',5),('text',62,'en','help_search',1),('text',64,'en','help_search',5),('text',68,'en','help_search',1),('text',73,'en','help_search',1),('than',8,'en','help_search',1),('than',11,'en','help_search',1.46654),('than',18,'en','help_search',1),('than',29,'en','help_search',1),('than',34,'en','help_search',1),('than',35,'en','help_search',1),('than',51,'en','help_search',1),('than',65,'en','help_search',1),('than',69,'en','help_search',1),('than',74,'en','help_search',1),('that',1,'en','node_search',2.90472),('that',2,'en','help_search',1),('that',3,'en','help_search',2),('that',4,'en','help_search',3),('that',5,'en','help_search',1),('that',6,'en','help_search',1),('that',8,'en','help_search',1),('that',10,'en','help_search',5),('that',11,'en','help_search',6.30646),('that',12,'en','help_search',8.69588),('that',13,'en','help_search',3),('that',14,'en','help_search',3),('that',15,'en','help_search',4),('that',16,'en','help_search',1),('that',18,'en','help_search',2.9347),('that',19,'en','help_search',1),('that',20,'en','help_search',3),('that',21,'en','help_search',2),('that',22,'en','help_search',4),('that',23,'en','help_search',2),('that',24,'en','help_search',1),('that',25,'en','help_search',2),('that',26,'en','help_search',5),('that',28,'en','help_search',3),('that',29,'en','help_search',3.82016),('that',30,'en','help_search',7.47776),('that',31,'en','help_search',2),('that',32,'en','help_search',5),('that',33,'en','help_search',3.67553),('that',35,'en','help_search',3),('that',36,'en','help_search',2),('that',37,'en','help_search',3),('that',38,'en','help_search',6),('that',39,'en','help_search',2),('that',40,'en','help_search',1),('that',42,'en','help_search',1),('that',43,'en','help_search',2),('that',44,'en','help_search',7.92329),('that',47,'en','help_search',3),('that',48,'en','help_search',1),('that',49,'en','help_search',2),('that',50,'en','help_search',8.85086),('that',53,'en','help_search',2),('that',54,'en','help_search',5.82864),('that',55,'en','help_search',3),('that',57,'en','help_search',2),('that',58,'en','help_search',1),('that',59,'en','help_search',4.88282),('that',60,'en','help_search',6.98902),('that',61,'en','help_search',1),('that',62,'en','help_search',3),('that',63,'en','help_search',2),('that',64,'en','help_search',3),('that',65,'en','help_search',1),('that',68,'en','help_search',1),('that',69,'en','help_search',2),('that',71,'en','help_search',0.993146),('that',72,'en','help_search',2),('that',73,'en','help_search',3),('that',75,'en','help_search',1),('that',76,'en','help_search',1),('that',77,'en','help_search',2),('that',78,'en','help_search',1),('that',79,'en','help_search',4.99315),('that',80,'en','help_search',3),('that',81,'en','help_search',1.92221),('that',82,'en','help_search',1),('that',83,'en','help_search',3),('that',85,'en','help_search',3),('that',86,'en','help_search',4),('the',1,'en','help_search',2),('the',1,'en','node_search',14.3799),('the',2,'en','help_search',9),('the',3,'en','help_search',8),('the',4,'en','help_search',6),('the',5,'en','help_search',53),('the',6,'en','help_search',12),('the',7,'en','help_search',8),('the',8,'en','help_search',30),('the',9,'en','help_search',30),('the',10,'en','help_search',44.8969),('the',11,'en','help_search',63.3085),('the',12,'en','help_search',40.0589),('the',13,'en','help_search',14.9946),('the',14,'en','help_search',6),('the',15,'en','help_search',3),('the',16,'en','help_search',37.9564),('the',17,'en','help_search',7),('the',18,'en','help_search',50.6047),('the',19,'en','help_search',6),('the',20,'en','help_search',23),('the',21,'en','help_search',28),('the',22,'en','help_search',9),('the',23,'en','help_search',40.9849),('the',24,'en','help_search',85.1542),('the',25,'en','help_search',40),('the',26,'en','help_search',25),('the',27,'en','help_search',10.9206),('the',28,'en','help_search',17),('the',29,'en','help_search',65.133),('the',30,'en','help_search',94.7056),('the',31,'en','help_search',53),('the',32,'en','help_search',18),('the',33,'en','help_search',20.4958),('the',34,'en','help_search',13),('the',35,'en','help_search',18),('the',36,'en','help_search',18),('the',37,'en','help_search',15),('the',38,'en','help_search',25),('the',39,'en','help_search',10),('the',40,'en','help_search',9),('the',41,'en','help_search',6),('the',42,'en','help_search',6),('the',43,'en','help_search',35),('the',44,'en','help_search',34.9138),('the',45,'en','help_search',15),('the',46,'en','help_search',54),('the',47,'en','help_search',25),('the',48,'en','help_search',47),('the',49,'en','help_search',10),('the',50,'en','help_search',25.6562),('the',51,'en','help_search',6),('the',52,'en','help_search',8),('the',53,'en','help_search',14.8913),('the',54,'en','help_search',25.0258),('the',55,'en','help_search',28.732),('the',56,'en','help_search',14),('the',57,'en','help_search',11),('the',58,'en','help_search',22),('the',59,'en','help_search',7.56866),('the',60,'en','help_search',30.8869),('the',61,'en','help_search',22),('the',62,'en','help_search',28),('the',63,'en','help_search',49),('the',64,'en','help_search',27.9931),('the',65,'en','help_search',24),('the',66,'en','help_search',20),('the',67,'en','help_search',25.963),('the',68,'en','help_search',7),('the',69,'en','help_search',6),('the',70,'en','help_search',13),('the',71,'en','help_search',56.4415),('the',72,'en','help_search',7),('the',73,'en','help_search',22),('the',74,'en','help_search',14),('the',75,'en','help_search',3),('the',76,'en','help_search',10),('the',77,'en','help_search',9),('the',78,'en','help_search',17),('the',79,'en','help_search',18.8617),('the',80,'en','help_search',25),('the',81,'en','help_search',14.6866),('the',82,'en','help_search',12),('the',83,'en','help_search',22.9672),('the',84,'en','help_search',7),('the',85,'en','help_search',17),('the',86,'en','help_search',7),('their',8,'en','help_search',1),('their',11,'en','help_search',0.749958),('their',12,'en','help_search',0.60322),('their',19,'en','help_search',1),('their',23,'en','help_search',1),('their',24,'en','help_search',1),('their',27,'en','help_search',1),('their',29,'en','help_search',1),('their',31,'en','help_search',1),('their',44,'en','help_search',3.98902),('their',47,'en','help_search',1),('their',54,'en','help_search',0.848323),('their',55,'en','help_search',1),('their',62,'en','help_search',1),('their',63,'en','help_search',1),('their',79,'en','help_search',1.96109),('them',1,'en','node_search',0.522445),('them',6,'en','help_search',2),('them',18,'en','help_search',1),('them',23,'en','help_search',1),('them',26,'en','help_search',1),('them',32,'en','help_search',1),('them',37,'en','help_search',2),('them',40,'en','help_search',1),('them',46,'en','help_search',1),('them',50,'en','help_search',1.86995),('them',54,'en','help_search',0.879565),('them',59,'en','help_search',1.8645),('them',71,'en','help_search',0.833529),('them',79,'en','help_search',1),('them',81,'en','help_search',1.99731),('theme',10,'en','help_search',47.9809),('theme',11,'en','help_search',2),('theme',16,'en','help_search',1.98902),('theme',17,'en','help_search',1),('theme',26,'en','help_search',3),('theme',27,'en','help_search',2.98493),('theme',38,'en','help_search',47),('theme',39,'en','help_search',37),('theme',47,'en','help_search',4),('theme',48,'en','help_search',1),('theme',49,'en','help_search',3),('theme',79,'en','help_search',1),('themes',10,'en','help_search',8.9689),('themes',11,'en','help_search',0.699655),('themes',17,'en','help_search',1),('themes',19,'en','help_search',2),('themes',20,'en','help_search',1),('themes',22,'en','help_search',1),('themes',24,'en','help_search',2.82262),('themes',27,'en','help_search',5),('themes',37,'en','help_search',2),('themes',38,'en','help_search',37),('themes',39,'en','help_search',4),('themes',48,'en','help_search',1),('themes',53,'en','help_search',2.96109),('themes',60,'en','help_search',1),('theming',10,'en','help_search',10.0841),('themselves',44,'en','help_search',1),('then',1,'en','node_search',1.01164),('then',2,'en','help_search',1),('then',11,'en','help_search',0.800068),('then',27,'en','help_search',0.976851),('then',29,'en','help_search',1),('then',34,'en','help_search',1),('then',58,'en','help_search',2),('then',70,'en','help_search',1),('there',8,'en','help_search',1),('there',11,'en','help_search',19),('there',12,'en','help_search',2.35233),('there',15,'en','help_search',2),('there',22,'en','help_search',1),('there',24,'en','help_search',1),('there',25,'en','help_search',1),('there',26,'en','help_search',1),('there',30,'en','help_search',1),('there',31,'en','help_search',1),('there',36,'en','help_search',3),('there',37,'en','help_search',1),('there',39,'en','help_search',1),('there',42,'en','help_search',1),('there',65,'en','help_search',1),('there',69,'en','help_search',2),('there',71,'en','help_search',0.934703),('there',79,'en','help_search',2),('there',83,'en','help_search',1),('there',85,'en','help_search',2),('there',86,'en','help_search',2),('thereby',11,'en','help_search',0.786915),('these',1,'en','node_search',0.771698),('these',11,'en','help_search',1),('these',12,'en','help_search',1.39601),('these',13,'en','help_search',1),('these',16,'en','help_search',0.989021),('these',19,'en','help_search',1),('these',20,'en','help_search',1),('these',23,'en','help_search',2.99315),('these',27,'en','help_search',1),('these',29,'en','help_search',0.972861),('these',31,'en','help_search',1),('these',33,'en','help_search',2),('these',38,'en','help_search',1),('these',40,'en','help_search',1),('these',50,'en','help_search',0.776703),('these',54,'en','help_search',1.95723),('these',55,'en','help_search',1),('these',62,'en','help_search',1),('these',63,'en','help_search',1),('these',69,'en','help_search',1),('these',72,'en','help_search',1),('these',79,'en','help_search',1),('these',81,'en','help_search',2.9689),('these',84,'en','help_search',1),('they',6,'en','help_search',1),('they',11,'en','help_search',0.693594),('they',12,'en','help_search',1.96498),('they',16,'en','help_search',1),('they',19,'en','help_search',1),('they',21,'en','help_search',1),('they',23,'en','help_search',1),('they',25,'en','help_search',1),('they',26,'en','help_search',1),('they',27,'en','help_search',1),('they',30,'en','help_search',2),('they',44,'en','help_search',2),('they',67,'en','help_search',1),('they',69,'en','help_search',1),('they',70,'en','help_search',1),('they',79,'en','help_search',1),('thirdparty',30,'en','help_search',1),('thirdparty',54,'en','help_search',1),('this',1,'en','node_search',0.655756),('this',8,'en','help_search',1),('this',9,'en','help_search',4),('this',11,'en','help_search',2.73112),('this',12,'en','help_search',0.648686),('this',13,'en','help_search',1),('this',16,'en','help_search',2),('this',18,'en','help_search',3.90974),('this',19,'en','help_search',1),('this',24,'en','help_search',1),('this',26,'en','help_search',2),('this',29,'en','help_search',1),('this',30,'en','help_search',1.92384),('this',36,'en','help_search',3),('this',43,'en','help_search',6),('this',46,'en','help_search',2),('this',50,'en','help_search',4.73792),('this',52,'en','help_search',1),('this',54,'en','help_search',1.97685),('this',55,'en','help_search',3.89876),('this',60,'en','help_search',1),('this',65,'en','help_search',2),('this',69,'en','help_search',20),('this',72,'en','help_search',2),('this',73,'en','help_search',3),('this',76,'en','help_search',1),('this',77,'en','help_search',1),('this',80,'en','help_search',1),('this',82,'en','help_search',2),('this',84,'en','help_search',1),('this',86,'en','help_search',2),('threading',55,'en','help_search',4),('threads',55,'en','help_search',1),('three',22,'en','help_search',1),('three',32,'en','help_search',1),('throttle',29,'en','help_search',4),('through',11,'en','help_search',1.67748),('through',12,'en','help_search',0.718502),('through',16,'en','help_search',1),('through',23,'en','help_search',1),('through',60,'en','help_search',1),('tiles',1,'en','node_search',12.2091),('time',1,'en','node_search',0.938382),('time',12,'en','help_search',1.85135),('time',13,'en','help_search',1),('time',18,'en','help_search',6),('time',31,'en','help_search',2),('time',32,'en','help_search',6),('time',35,'en','help_search',1),('time',69,'en','help_search',1),('timeline',1,'en','node_search',11.6192),('timeout',29,'en','help_search',1),('times',12,'en','help_search',0.857458),('times',29,'en','help_search',0.899454),('timestamp',12,'en','help_search',0.863659),('title',7,'en','help_search',1),('title',27,'en','help_search',1),('title',47,'en','help_search',14),('title',48,'en','help_search',20),('title',50,'en','help_search',0.942091),('title',64,'en','help_search',1),('title',65,'en','help_search',5),('title',67,'en','help_search',6),('title',73,'en','help_search',10),('title',74,'en','help_search',3),('title',79,'en','help_search',1),('title',85,'en','help_search',4),('titlewrapper',1,'en','node_search',0.570448),('together',18,'en','help_search',1),('toggle',60,'en','help_search',1),('tomatoes',81,'en','help_search',3),('tool',11,'en','help_search',0.722831),('toolbar',20,'en','help_search',2),('toolbar',24,'en','help_search',15),('toolbar',46,'en','help_search',3),('toolbar',54,'en','help_search',15.6581),('toolbar',60,'en','help_search',3),('toolbar',79,'en','help_search',3),('tooltip',54,'en','help_search',0.906287),('top',1,'en','node_search',1),('top',23,'en','help_search',1),('top',24,'en','help_search',1),('top',26,'en','help_search',1),('top',71,'en','help_search',0.968904),('topic',12,'en','help_search',0.707906),('topic',26,'en','help_search',2),('topic',27,'en','help_search',22.9534),('topic',50,'en','help_search',0.851346),('topic',54,'en','help_search',0.976851),('topic',55,'en','help_search',1),('topic',65,'en','help_search',1),('topic',71,'en','help_search',0.808176),('topic',76,'en','help_search',1),('topic',80,'en','help_search',1),('topic',83,'en','help_search',1),('topic',86,'en','help_search',2),('topics',8,'en','help_search',1),('topics',10,'en','help_search',0.957226),('topics',11,'en','help_search',0.689612),('topics',12,'en','help_search',1.17559),('topics',14,'en','help_search',1),('topics',15,'en','help_search',1),('topics',16,'en','help_search',0.976851),('topics',17,'en','help_search',1),('topics',19,'en','help_search',1),('topics',21,'en','help_search',1),('topics',22,'en','help_search',1),('topics',24,'en','help_search',1.86679),('topics',27,'en','help_search',121.282),('topics',30,'en','help_search',1.79475),('topics',42,'en','help_search',1),('topics',48,'en','help_search',1),('topics',56,'en','help_search',1),('topics',59,'en','help_search',0.863659),('topics',66,'en','help_search',1),('topics',68,'en','help_search',1),('topics',70,'en','help_search',1),('topics',71,'en','help_search',0.792123),('topics',74,'en','help_search',1),('topics',76,'en','help_search',1),('topics',78,'en','help_search',1),('topics',80,'en','help_search',1),('topics',81,'en','help_search',0.909743),('topics',84,'en','help_search',1),('topleft',20,'en','help_search',1),('toplevel',27,'en','help_search',1),('topright',20,'en','help_search',1),('totally',33,'en','help_search',1),('track',19,'en','help_search',1),('tracked',69,'en','help_search',19),('tracking',21,'en','help_search',46),('tracking',69,'en','help_search',45),('tracks',21,'en','help_search',1),('tracks',69,'en','help_search',1),('traditional',70,'en','help_search',1),('transferred',25,'en','help_search',1),('transform',50,'en','help_search',1),('translatable',27,'en','help_search',3),('translate',22,'en','help_search',1),('translated',22,'en','help_search',23),('translated',27,'en','help_search',19),('translation',22,'en','help_search',3),('translation',26,'en','help_search',1),('translation',27,'en','help_search',3),('translations',22,'en','help_search',29),('translations',38,'en','help_search',1),('transmission',18,'en','help_search',1),('transported',25,'en','help_search',1),('tray',20,'en','help_search',2),('tray',24,'en','help_search',1),('triggers',27,'en','help_search',1),('troubleshooting',15,'en','help_search',46),('true',12,'en','help_search',0.892724),('trusted',43,'en','help_search',4),('try',26,'en','help_search',1),('trying',15,'en','help_search',1),('trying',35,'en','help_search',1),('turn',18,'en','help_search',0.854391),('turn',57,'en','help_search',3),('turning',14,'en','help_search',2),('turns',50,'en','help_search',1),('twice',40,'en','help_search',1),('twig',27,'en','help_search',1),('twigfilebased',27,'en','help_search',1),('two',8,'en','help_search',1),('two',12,'en','help_search',0.679856),('two',15,'en','help_search',1),('two',25,'en','help_search',1),('two',30,'en','help_search',1),('two',53,'en','help_search',1),('two',64,'en','help_search',1),('two',70,'en','help_search',1),('two',81,'en','help_search',1),('two',85,'en','help_search',1),('twocolumns',1,'en','node_search',0.566439),('type',1,'en','node_search',13.8126),('type',2,'en','help_search',4),('type',4,'en','help_search',4),('type',11,'en','help_search',2),('type',12,'en','help_search',13.0673),('type',17,'en','help_search',1),('type',26,'en','help_search',1),('type',28,'en','help_search',4),('type',30,'en','help_search',2),('type',42,'en','help_search',1),('type',48,'en','help_search',1),('type',50,'en','help_search',1),('type',51,'en','help_search',2),('type',52,'en','help_search',35),('type',55,'en','help_search',12.9097),('type',56,'en','help_search',58),('type',57,'en','help_search',1),('type',59,'en','help_search',26),('type',61,'en','help_search',3),('type',62,'en','help_search',2),('type',63,'en','help_search',2),('type',64,'en','help_search',16),('type',65,'en','help_search',5),('type',66,'en','help_search',66),('type',67,'en','help_search',6),('type',68,'en','help_search',24),('type',71,'en','help_search',4.8249),('type',72,'en','help_search',30),('type',73,'en','help_search',1),('type',80,'en','help_search',1),('type',81,'en','help_search',1),('type',82,'en','help_search',1),('type',84,'en','help_search',1),('type',85,'en','help_search',1),('type',86,'en','help_search',39),('types',1,'en','node_search',48.0172),('types',8,'en','help_search',1),('types',11,'en','help_search',8.39477),('types',12,'en','help_search',88.542),('types',16,'en','help_search',4),('types',22,'en','help_search',1),('types',24,'en','help_search',0.980874),('types',29,'en','help_search',1),('types',30,'en','help_search',3),('types',48,'en','help_search',5),('types',52,'en','help_search',8),('types',53,'en','help_search',1),('types',55,'en','help_search',4),('types',56,'en','help_search',10),('types',59,'en','help_search',6.77882),('types',61,'en','help_search',7),('types',62,'en','help_search',4),('types',63,'en','help_search',4),('types',64,'en','help_search',5),('types',65,'en','help_search',2),('types',66,'en','help_search',10),('types',67,'en','help_search',3),('types',68,'en','help_search',7),('types',71,'en','help_search',1),('types',72,'en','help_search',1),('types',82,'en','help_search',1),('types',86,'en','help_search',4),('typically',25,'en','help_search',1),('typically',54,'en','help_search',1),('typically',56,'en','help_search',1),('typically',58,'en','help_search',1),('typically',59,'en','help_search',1),('typically',66,'en','help_search',1),('typing',73,'en','help_search',1),('unapproved',58,'en','help_search',4),('uncacheable',18,'en','help_search',0.923838),('uncheck',6,'en','help_search',1),('uncheck',34,'en','help_search',1),('uncheck',43,'en','help_search',1),('uncheck',44,'en','help_search',1),('uncheck',65,'en','help_search',1),('uncheck',75,'en','help_search',1),('under',26,'en','help_search',1),('under',27,'en','help_search',1),('under',29,'en','help_search',3.86775),('under',33,'en','help_search',1.92027),('under',50,'en','help_search',2.48477),('under',54,'en','help_search',0.949597),('under',57,'en','help_search',1),('under',67,'en','help_search',0.980874),('under',70,'en','help_search',1),('under',72,'en','help_search',2),('under',76,'en','help_search',1),('under',81,'en','help_search',1),('under',82,'en','help_search',1),('under',85,'en','help_search',1),('under',86,'en','help_search',2),('underlying',18,'en','help_search',1),('understand',23,'en','help_search',2),('understandable',78,'en','help_search',1),('unformatted',12,'en','help_search',0.794753),('unformatted',85,'en','help_search',8),('uniform',78,'en','help_search',1),('uninstall',13,'en','help_search',1),('uninstall',14,'en','help_search',1),('uninstall',24,'en','help_search',0.931053),('uninstall',36,'en','help_search',24),('uninstall',39,'en','help_search',11),('uninstalled',14,'en','help_search',1),('uninstalled',36,'en','help_search',5),('uninstalled',38,'en','help_search',4),('uninstalled',39,'en','help_search',1),('uninstalling',14,'en','help_search',20),('uninstalling',15,'en','help_search',1),('uninstalling',36,'en','help_search',26),('uninstalling',39,'en','help_search',26),('unique',1,'en','node_search',0.96498),('unique',11,'en','help_search',1.89272),('unique',13,'en','help_search',1),('unique',78,'en','help_search',1),('unlimited',61,'en','help_search',1),('unlimited',64,'en','help_search',1),('unpacked',3,'en','help_search',1),('unpublish',58,'en','help_search',5),('unpublished',59,'en','help_search',1),('unpublished',65,'en','help_search',2),('unpublished',67,'en','help_search',1),('unpublishing',71,'en','help_search',0.819249),('until',26,'en','help_search',1),('until',32,'en','help_search',1),('until',45,'en','help_search',1),('until',59,'en','help_search',1),('until',60,'en','help_search',1),('until',70,'en','help_search',1),('until',73,'en','help_search',1),('until',79,'en','help_search',1),('untrusted',50,'en','help_search',0.882818),('untrusted',59,'en','help_search',0.953396),('unused',39,'en','help_search',26),('unwanted',58,'en','help_search',1),('upcoming',37,'en','help_search',1),('update',19,'en','help_search',4),('update',22,'en','help_search',1),('update',24,'en','help_search',1.87314),('update',37,'en','help_search',4),('update',45,'en','help_search',3),('update',47,'en','help_search',1),('update',67,'en','help_search',2),('update',83,'en','help_search',1),('update',85,'en','help_search',4),('updated',13,'en','help_search',1),('updated',26,'en','help_search',1),('updated',27,'en','help_search',2),('updated',28,'en','help_search',1),('updated',69,'en','help_search',9),('updates',11,'en','help_search',1.92384),('updates',19,'en','help_search',21),('updates',24,'en','help_search',0.892724),('updates',37,'en','help_search',6),('updating',11,'en','help_search',1.47793),('updating',15,'en','help_search',1),('updating',19,'en','help_search',2),('upload',3,'en','help_search',4),('uploaded',3,'en','help_search',1),('uploaded',10,'en','help_search',1),('upper',60,'en','help_search',2),('url',1,'en','node_search',2.12823),('url',8,'en','help_search',1),('url',13,'en','help_search',6),('url',16,'en','help_search',1),('url',28,'en','help_search',1),('url',30,'en','help_search',1),('url',33,'en','help_search',2.97395),('url',44,'en','help_search',4),('url',71,'en','help_search',1),('url',73,'en','help_search',1),('url',76,'en','help_search',54),('url',77,'en','help_search',55),('url',78,'en','help_search',25),('urls',12,'en','help_search',0.833529),('urls',33,'en','help_search',1),('urls',50,'en','help_search',3.99731),('urls',76,'en','help_search',1),('urls',77,'en','help_search',1),('urls',78,'en','help_search',58),('usage',1,'en','node_search',0.714225),('use',1,'en','node_search',1.20927),('use',2,'en','help_search',1),('use',5,'en','help_search',1),('use',6,'en','help_search',6),('use',12,'en','help_search',1.26527),('use',13,'en','help_search',1),('use',14,'en','help_search',1),('use',16,'en','help_search',2),('use',18,'en','help_search',1.98902),('use',20,'en','help_search',4),('use',23,'en','help_search',1),('use',24,'en','help_search',0.876337),('use',25,'en','help_search',1),('use',27,'en','help_search',1.98902),('use',30,'en','help_search',18.4099),('use',32,'en','help_search',2),('use',33,'en','help_search',1),('use',34,'en','help_search',6),('use',38,'en','help_search',3),('use',44,'en','help_search',2),('use',50,'en','help_search',3.73884),('use',53,'en','help_search',1.96109),('use',55,'en','help_search',1),('use',60,'en','help_search',9),('use',62,'en','help_search',1),('use',63,'en','help_search',1),('use',67,'en','help_search',2),('use',78,'en','help_search',1),('use',79,'en','help_search',5),('use',81,'en','help_search',2.99731),('use',86,'en','help_search',2),('used',10,'en','help_search',1),('used',11,'en','help_search',0.976851),('used',12,'en','help_search',1),('used',15,'en','help_search',1),('used',17,'en','help_search',1),('used',21,'en','help_search',1),('used',38,'en','help_search',1),('used',39,'en','help_search',3),('used',42,'en','help_search',1),('used',50,'en','help_search',2),('used',53,'en','help_search',1.99731),('used',59,'en','help_search',1),('used',61,'en','help_search',1),('used',62,'en','help_search',1),('used',63,'en','help_search',1),('used',64,'en','help_search',1),('used',70,'en','help_search',3),('used',74,'en','help_search',1),('used',81,'en','help_search',2),('useeasing',1,'en','node_search',0.554747),('useful',50,'en','help_search',1),('usegrouping',1,'en','node_search',0.558589),('user',1,'en','node_search',0.650439),('user',6,'en','help_search',19),('user',8,'en','help_search',4),('user',10,'en','help_search',10.1622),('user',11,'en','help_search',22.0204),('user',12,'en','help_search',27.3552),('user',13,'en','help_search',21.0175),('user',14,'en','help_search',22),('user',15,'en','help_search',22),('user',16,'en','help_search',2),('user',17,'en','help_search',12),('user',18,'en','help_search',1),('user',19,'en','help_search',11),('user',22,'en','help_search',2),('user',23,'en','help_search',1),('user',24,'en','help_search',0.916736),('user',25,'en','help_search',2),('user',27,'en','help_search',1),('user',30,'en','help_search',8.33564),('user',31,'en','help_search',11),('user',33,'en','help_search',3),('user',34,'en','help_search',4),('user',37,'en','help_search',11),('user',40,'en','help_search',43),('user',42,'en','help_search',69),('user',44,'en','help_search',57.974),('user',45,'en','help_search',33),('user',48,'en','help_search',11),('user',53,'en','help_search',1),('user',54,'en','help_search',2.92384),('user',59,'en','help_search',2.91674),('user',65,'en','help_search',22.8038),('user',66,'en','help_search',22),('user',67,'en','help_search',21.7671),('user',69,'en','help_search',28),('user',71,'en','help_search',11.2515),('user',73,'en','help_search',1),('user',76,'en','help_search',11),('user',78,'en','help_search',13),('user',79,'en','help_search',1),('user',80,'en','help_search',11),('user',81,'en','help_search',11.6063),('user',85,'en','help_search',10.5295),('userdefined',11,'en','help_search',1),('userinterface',22,'en','help_search',1),('username',40,'en','help_search',4),('users',1,'en','node_search',1),('users',5,'en','help_search',1),('users',6,'en','help_search',6),('users',8,'en','help_search',4),('users',12,'en','help_search',1.87313),('users',18,'en','help_search',4.86555),('users',21,'en','help_search',2),('users',23,'en','help_search',7),('users',24,'en','help_search',1),('users',26,'en','help_search',1),('users',27,'en','help_search',20.9729),('users',29,'en','help_search',1),('users',30,'en','help_search',6.53343),('users',34,'en','help_search',1),('users',42,'en','help_search',8),('users',44,'en','help_search',8),('users',46,'en','help_search',1),('users',50,'en','help_search',3.77902),('users',55,'en','help_search',1),('users',56,'en','help_search',1),('users',58,'en','help_search',1),('users',59,'en','help_search',2.85934),('users',60,'en','help_search',2),('users',65,'en','help_search',3),('users',66,'en','help_search',1),('users',67,'en','help_search',2),('users',71,'en','help_search',3.85439),('users',76,'en','help_search',1),('users',77,'en','help_search',1),('users',78,'en','help_search',1),('users',79,'en','help_search',4),('users',80,'en','help_search',1),('users',81,'en','help_search',2),('uses',1,'en','node_search',13.1403),('uses',19,'en','help_search',1),('uses',29,'en','help_search',1),('using',1,'en','node_search',6.14742),('using',2,'en','help_search',1),('using',8,'en','help_search',20),('using',11,'en','help_search',9.24453),('using',14,'en','help_search',2),('using',16,'en','help_search',1.99731),('using',20,'en','help_search',26),('using',24,'en','help_search',28.8828),('using',25,'en','help_search',5),('using',27,'en','help_search',1),('using',30,'en','help_search',0.873132),('using',36,'en','help_search',1),('using',38,'en','help_search',1),('using',42,'en','help_search',1),('using',55,'en','help_search',1),('using',60,'en','help_search',26),('using',69,'en','help_search',19),('using',71,'en','help_search',0.860547),('using',79,'en','help_search',26),('using',82,'en','help_search',1),('using',85,'en','help_search',1),('usual',1,'en','node_search',2.14652),('usually',64,'en','help_search',1),('uuid',11,'en','help_search',5.2071),('valid',18,'en','help_search',1),('valid',54,'en','help_search',1),('value',11,'en','help_search',0.714225),('value',12,'en','help_search',0.784336),('value',55,'en','help_search',3.78332),('value',61,'en','help_search',4),('value',64,'en','help_search',4),('value',77,'en','help_search',1),('value',85,'en','help_search',2),('values',12,'en','help_search',6.37799),('values',33,'en','help_search',1),('values',45,'en','help_search',1),('values',55,'en','help_search',4.90974),('values',61,'en','help_search',6),('values',64,'en','help_search',6),('values',67,'en','help_search',3),('variables',44,'en','help_search',25),('variations',12,'en','help_search',1),('various',1,'en','node_search',0.738408),('various',24,'en','help_search',0.927431),('various',54,'en','help_search',1),('vary',47,'en','help_search',1),('vary',61,'en','help_search',1),('vary',83,'en','help_search',1),('vegetables',81,'en','help_search',1),('verification',44,'en','help_search',2),('verified',59,'en','help_search',1),('verified',85,'en','help_search',1),('verify',6,'en','help_search',1),('verify',26,'en','help_search',4),('verify',28,'en','help_search',1),('verify',29,'en','help_search',0.896076),('verify',30,'en','help_search',0.860547),('verify',36,'en','help_search',1),('verify',38,'en','help_search',2),('verify',40,'en','help_search',1),('verify',44,'en','help_search',0.98493),('verify',50,'en','help_search',0.797402),('verify',64,'en','help_search',1),('verify',73,'en','help_search',1),('verify',76,'en','help_search',1),('verify',79,'en','help_search',0.997306),('verify',83,'en','help_search',1),('verify',85,'en','help_search',1),('versatile',16,'en','help_search',1),('versions',11,'en','help_search',0.896076),('vertical',66,'en','help_search',1),('very',12,'en','help_search',1.6956),('very',30,'en','help_search',1),('via',1,'en','node_search',10.6996),('via',25,'en','help_search',1),('via',59,'en','help_search',1),('video',1,'en','node_search',37.5154),('videos',1,'en','node_search',2.01663),('videos',16,'en','help_search',1),('view',6,'en','help_search',6),('view',7,'en','help_search',1),('view',11,'en','help_search',1),('view',27,'en','help_search',0.96498),('view',30,'en','help_search',7.26433),('view',46,'en','help_search',5),('view',60,'en','help_search',2),('view',69,'en','help_search',2),('view',71,'en','help_search',51.209),('view',79,'en','help_search',2),('view',82,'en','help_search',32),('view',83,'en','help_search',33.9849),('view',84,'en','help_search',42),('view',85,'en','help_search',29),('viewed',8,'en','help_search',1),('viewed',21,'en','help_search',1),('viewed',27,'en','help_search',1),('viewer',8,'en','help_search',1),('viewing',8,'en','help_search',1),('viewing',27,'en','help_search',1),('viewing',42,'en','help_search',2),('viewing',46,'en','help_search',26),('viewing',62,'en','help_search',1),('viewport',53,'en','help_search',2),('viewports',53,'en','help_search',1),('views',1,'en','node_search',11.6064),('views',11,'en','help_search',1),('views',21,'en','help_search',1),('views',69,'en','help_search',1),('views',71,'en','help_search',54.628),('views',82,'en','help_search',4),('views',83,'en','help_search',29),('views',84,'en','help_search',4),('views',85,'en','help_search',15.572),('visibility',22,'en','help_search',2),('visibility',26,'en','help_search',4),('visibility',47,'en','help_search',4),('visible',12,'en','help_search',1),('visible',26,'en','help_search',2),('visible',54,'en','help_search',0.851346),('visible',55,'en','help_search',0.899454),('visible',57,'en','help_search',1),('visible',58,'en','help_search',1),('visible',60,'en','help_search',2.99731),('visible',61,'en','help_search',1),('visible',62,'en','help_search',1),('visible',64,'en','help_search',1),('visit',13,'en','help_search',3),('visit',20,'en','help_search',1),('visit',30,'en','help_search',1),('visit',33,'en','help_search',1),('visit',38,'en','help_search',1),('visit',60,'en','help_search',1.98902),('visit',65,'en','help_search',1),('visit',78,'en','help_search',1),('visited',69,'en','help_search',28),('visited',76,'en','help_search',1),('visiting',24,'en','help_search',1),('visitor',59,'en','help_search',1),('visitors',8,'en','help_search',1),('visitors',12,'en','help_search',2),('visitors',30,'en','help_search',0.842342),('visitors',34,'en','help_search',1),('visitors',42,'en','help_search',46),('visitors',48,'en','help_search',1),('visitors',59,'en','help_search',0.913226),('visitors',78,'en','help_search',1),('visits',33,'en','help_search',1),('visits',69,'en','help_search',19),('visual',10,'en','help_search',2),('visual',16,'en','help_search',1),('visual',50,'en','help_search',1),('visual',54,'en','help_search',4),('visually',1,'en','node_search',0.645209),('visually',62,'en','help_search',4),('vocabularies',80,'en','help_search',4),('vocabularies',81,'en','help_search',1.9347),('vocabulary',80,'en','help_search',35),('vocabulary',81,'en','help_search',6),('w3c',53,'en','help_search',10.3222),('wait',13,'en','help_search',1),('wait',35,'en','help_search',1),('wait',36,'en','help_search',1),('wait',38,'en','help_search',1),('waiting',29,'en','help_search',0.902857),('walk',30,'en','help_search',1.90318),('walked',30,'en','help_search',0.938382),('walking',30,'en','help_search',0.942091),('want',2,'en','help_search',1),('want',3,'en','help_search',1),('want',4,'en','help_search',2),('want',5,'en','help_search',2),('want',6,'en','help_search',1),('want',7,'en','help_search',1),('want',9,'en','help_search',1),('want',13,'en','help_search',1),('want',20,'en','help_search',2),('want',28,'en','help_search',1),('want',32,'en','help_search',2),('want',35,'en','help_search',2),('want',36,'en','help_search',1),('want',38,'en','help_search',3),('want',39,'en','help_search',1),('want',40,'en','help_search',1),('want',44,'en','help_search',1.99731),('want',45,'en','help_search',2),('want',47,'en','help_search',4),('want',49,'en','help_search',3),('want',50,'en','help_search',0.842342),('want',51,'en','help_search',1),('want',57,'en','help_search',2),('want',60,'en','help_search',1),('want',61,'en','help_search',3),('want',62,'en','help_search',3),('want',63,'en','help_search',2),('want',64,'en','help_search',6),('want',65,'en','help_search',1),('want',66,'en','help_search',1),('want',72,'en','help_search',2),('want',75,'en','help_search',1),('want',79,'en','help_search',1),('want',80,'en','help_search',1),('want',82,'en','help_search',2),('want',83,'en','help_search',1),('want',85,'en','help_search',3.98902),('want',86,'en','help_search',2),('warning',43,'en','help_search',4),('warnings',37,'en','help_search',1),('was',3,'en','help_search',1),('was',4,'en','help_search',1),('was',32,'en','help_search',1),('was',36,'en','help_search',1),('was',39,'en','help_search',1),('was',47,'en','help_search',1),('was',69,'en','help_search',1),('way',10,'en','help_search',1),('way',12,'en','help_search',1.32634),('way',13,'en','help_search',2),('way',18,'en','help_search',0.942091),('way',25,'en','help_search',1),('way',50,'en','help_search',1),('way',53,'en','help_search',1),('way',71,'en','help_search',0.886095),('ways',11,'en','help_search',1),('ways',12,'en','help_search',1),('ways',81,'en','help_search',1),('web',13,'en','help_search',2),('web',17,'en','help_search',1),('web',25,'en','help_search',93),('web',33,'en','help_search',3),('web',48,'en','help_search',1),('web',59,'en','help_search',1),('web',68,'en','help_search',1),('web',78,'en','help_search',2),('webform',1,'en','node_search',23.1749),('website',1,'en','node_search',0.866793),('website',6,'en','help_search',1),('website',12,'en','help_search',1),('website',21,'en','help_search',26),('website',44,'en','help_search',2),('website',58,'en','help_search',2),('website',59,'en','help_search',1),('website',78,'en','help_search',1),('website',81,'en','help_search',3),('websites',1,'en','node_search',0.72066),('week',13,'en','help_search',1),('weekly',13,'en','help_search',1),('weights',23,'en','help_search',5),('well',13,'en','help_search',2),('well',18,'en','help_search',0.860547),('well',20,'en','help_search',1),('well',61,'en','help_search',1),('well',79,'en','help_search',1),('went',31,'en','help_search',1),('were',32,'en','help_search',2),('were',33,'en','help_search',1.84528),('were',35,'en','help_search',2),('were',44,'en','help_search',0.953396),('wget',13,'en','help_search',4),('what',1,'en','node_search',14.9514),('what',5,'en','help_search',19),('what',8,'en','help_search',19),('what',10,'en','help_search',57),('what',11,'en','help_search',74.418),('what',12,'en','help_search',146.382),('what',13,'en','help_search',38),('what',14,'en','help_search',57),('what',16,'en','help_search',57),('what',17,'en','help_search',19),('what',18,'en','help_search',76),('what',19,'en','help_search',38),('what',20,'en','help_search',19),('what',22,'en','help_search',19),('what',24,'en','help_search',38),('what',25,'en','help_search',76),('what',27,'en','help_search',19),('what',29,'en','help_search',19),('what',30,'en','help_search',74.7594),('what',31,'en','help_search',19),('what',32,'en','help_search',1),('what',33,'en','help_search',39),('what',34,'en','help_search',19),('what',42,'en','help_search',57),('what',44,'en','help_search',39.989),('what',45,'en','help_search',1),('what',46,'en','help_search',19),('what',48,'en','help_search',76),('what',50,'en','help_search',38),('what',53,'en','help_search',76),('what',54,'en','help_search',27.8995),('what',59,'en','help_search',57),('what',60,'en','help_search',19),('what',61,'en','help_search',1),('what',68,'en','help_search',38),('what',69,'en','help_search',38),('what',71,'en','help_search',58.4225),('what',78,'en','help_search',57),('what',79,'en','help_search',19),('what',81,'en','help_search',19),('what',85,'en','help_search',1),('when',8,'en','help_search',1),('when',11,'en','help_search',5.92719),('when',12,'en','help_search',1.6112),('when',15,'en','help_search',1),('when',18,'en','help_search',2.9496),('when',19,'en','help_search',1),('when',23,'en','help_search',1),('when',26,'en','help_search',1),('when',27,'en','help_search',3),('when',29,'en','help_search',3),('when',30,'en','help_search',1.8861),('when',31,'en','help_search',4),('when',33,'en','help_search',2),('when',34,'en','help_search',6),('when',36,'en','help_search',1),('when',44,'en','help_search',3),('when',47,'en','help_search',1),('when',48,'en','help_search',1),('when',50,'en','help_search',2),('when',53,'en','help_search',3),('when',54,'en','help_search',1.98902),('when',61,'en','help_search',1),('when',62,'en','help_search',1),('when',63,'en','help_search',1),('when',64,'en','help_search',1),('when',65,'en','help_search',1),('when',69,'en','help_search',1),('when',71,'en','help_search',1),('when',72,'en','help_search',1),('when',73,'en','help_search',3),('when',79,'en','help_search',1),('when',81,'en','help_search',2),('when',85,'en','help_search',2),('whenever',26,'en','help_search',1),('where',10,'en','help_search',1),('where',12,'en','help_search',0.813674),('where',13,'en','help_search',1),('where',27,'en','help_search',19),('where',44,'en','help_search',1),('where',47,'en','help_search',2),('where',49,'en','help_search',1),('where',59,'en','help_search',1),('where',71,'en','help_search',1),('whether',1,'en','node_search',1.66851),('whether',12,'en','help_search',1),('whether',55,'en','help_search',3.95793),('whether',71,'en','help_search',2),('which',6,'en','help_search',2),('which',8,'en','help_search',3),('which',10,'en','help_search',1),('which',11,'en','help_search',2.64632),('which',12,'en','help_search',5.65326),('which',13,'en','help_search',1),('which',16,'en','help_search',1),('which',18,'en','help_search',1),('which',24,'en','help_search',3),('which',27,'en','help_search',1),('which',29,'en','help_search',1),('which',30,'en','help_search',1.9689),('which',36,'en','help_search',1),('which',37,'en','help_search',1),('which',38,'en','help_search',1),('which',42,'en','help_search',1),('which',48,'en','help_search',1),('which',50,'en','help_search',1.78178),('which',51,'en','help_search',1),('which',53,'en','help_search',2),('which',54,'en','help_search',2),('which',56,'en','help_search',1),('which',58,'en','help_search',1),('which',59,'en','help_search',2),('which',60,'en','help_search',1),('which',61,'en','help_search',2),('which',64,'en','help_search',1),('which',65,'en','help_search',1),('which',66,'en','help_search',1),('which',68,'en','help_search',2),('which',69,'en','help_search',28),('which',70,'en','help_search',1),('which',71,'en','help_search',3.85439),('which',73,'en','help_search',1),('which',74,'en','help_search',3),('which',78,'en','help_search',3),('which',79,'en','help_search',2),('which',80,'en','help_search',1),('which',81,'en','help_search',1),('which',83,'en','help_search',1),('which',84,'en','help_search',1),('while',12,'en','help_search',2.22095),('while',17,'en','help_search',1),('while',28,'en','help_search',1),('while',60,'en','help_search',1),('while',81,'en','help_search',1),('white',33,'en','help_search',4),('who',18,'en','help_search',1),('who',20,'en','help_search',19),('who',34,'en','help_search',1),('who',42,'en','help_search',3),('who',46,'en','help_search',19),('who',50,'en','help_search',1),('who',55,'en','help_search',19),('who',56,'en','help_search',19),('who',57,'en','help_search',19),('who',58,'en','help_search',19),('who',65,'en','help_search',19),('who',66,'en','help_search',19),('who',67,'en','help_search',19),('who',71,'en','help_search',0.879565),('who',76,'en','help_search',19),('who',77,'en','help_search',19),('who',80,'en','help_search',19),('who',83,'en','help_search',20),('whose',8,'en','help_search',1),('whose',48,'en','help_search',1),('whose',78,'en','help_search',1),('whose',85,'en','help_search',1),('why',1,'en','node_search',19),('why',35,'en','help_search',1),('widelyused',54,'en','help_search',1),('widget',12,'en','help_search',17.5931),('widget',16,'en','help_search',4),('widget',63,'en','help_search',7),('widgets',63,'en','help_search',5),('width',1,'en','node_search',7.11399),('width',16,'en','help_search',1),('width',53,'en','help_search',30),('width',70,'en','help_search',4),('widths',53,'en','help_search',2),('will',1,'en','node_search',0.511433),('will',3,'en','help_search',2),('will',5,'en','help_search',1),('will',6,'en','help_search',1),('will',7,'en','help_search',1),('will',8,'en','help_search',1),('will',11,'en','help_search',1.67852),('will',12,'en','help_search',0.584241),('will',13,'en','help_search',2),('will',18,'en','help_search',1.86679),('will',19,'en','help_search',1),('will',20,'en','help_search',2),('will',24,'en','help_search',1),('will',27,'en','help_search',2.96109),('will',28,'en','help_search',2),('will',29,'en','help_search',3),('will',30,'en','help_search',5.57006),('will',31,'en','help_search',1),('will',33,'en','help_search',1),('will',34,'en','help_search',5),('will',37,'en','help_search',1),('will',40,'en','help_search',1),('will',42,'en','help_search',1),('will',46,'en','help_search',1),('will',47,'en','help_search',1),('will',49,'en','help_search',2),('will',50,'en','help_search',1.72016),('will',52,'en','help_search',1),('will',53,'en','help_search',1),('will',54,'en','help_search',2.68852),('will',55,'en','help_search',1.98087),('will',56,'en','help_search',2),('will',57,'en','help_search',3),('will',58,'en','help_search',1),('will',60,'en','help_search',2),('will',62,'en','help_search',1),('will',64,'en','help_search',2),('will',65,'en','help_search',2),('will',66,'en','help_search',4),('will',71,'en','help_search',1),('will',72,'en','help_search',1),('will',73,'en','help_search',3),('will',74,'en','help_search',1),('will',76,'en','help_search',1),('will',77,'en','help_search',2),('will',78,'en','help_search',1),('will',79,'en','help_search',1),('will',80,'en','help_search',6),('will',81,'en','help_search',0.989021),('will',82,'en','help_search',3),('will',83,'en','help_search',4.98224),('will',84,'en','help_search',2),('will',86,'en','help_search',1),('wish',30,'en','help_search',0.816452),('wish',62,'en','help_search',1),('wish',63,'en','help_search',1),('with',1,'en','node_search',40.2942),('with',7,'en','help_search',1),('with',8,'en','help_search',1),('with',10,'en','help_search',1),('with',11,'en','help_search',0.757065),('with',12,'en','help_search',8.7836),('with',15,'en','help_search',1),('with',16,'en','help_search',2),('with',18,'en','help_search',1.88882),('with',19,'en','help_search',1),('with',20,'en','help_search',1),('with',22,'en','help_search',45),('with',23,'en','help_search',3),('with',24,'en','help_search',2),('with',25,'en','help_search',1),('with',27,'en','help_search',26.9729),('with',29,'en','help_search',1),('with',30,'en','help_search',3.83051),('with',34,'en','help_search',1),('with',35,'en','help_search',2),('with',36,'en','help_search',1),('with',42,'en','help_search',1),('with',43,'en','help_search',1),('with',44,'en','help_search',2),('with',46,'en','help_search',1),('with',50,'en','help_search',1),('with',53,'en','help_search',12.363),('with',55,'en','help_search',2.97286),('with',56,'en','help_search',1),('with',58,'en','help_search',1),('with',59,'en','help_search',1),('with',60,'en','help_search',3),('with',61,'en','help_search',1),('with',64,'en','help_search',1),('with',65,'en','help_search',2),('with',66,'en','help_search',1),('with',67,'en','help_search',2),('with',71,'en','help_search',10.3981),('with',76,'en','help_search',3),('with',77,'en','help_search',1),('with',78,'en','help_search',1),('with',79,'en','help_search',1),('with',80,'en','help_search',1),('with',81,'en','help_search',1.9381),('with',83,'en','help_search',3),('with',85,'en','help_search',10.6148),('with',86,'en','help_search',1),('within',11,'en','help_search',1),('within',12,'en','help_search',2),('within',27,'en','help_search',1),('within',47,'en','help_search',1),('within',50,'en','help_search',0.997306),('within',54,'en','help_search',0.896076),('without',1,'en','node_search',0.759465),('without',8,'en','help_search',1),('without',44,'en','help_search',1),('without',60,'en','help_search',2),('without',73,'en','help_search',1),('word',29,'en','help_search',4),('word',30,'en','help_search',0.96498),('word',35,'en','help_search',1),('word',36,'en','help_search',1),('word',67,'en','help_search',1),('words',29,'en','help_search',2),('words',30,'en','help_search',0.945829),('work',59,'en','help_search',1),('work',67,'en','help_search',0.976851),('work',83,'en','help_search',1),('workflow',11,'en','help_search',7.45733),('workflow',59,'en','help_search',1),('working',11,'en','help_search',1),('working',22,'en','help_search',45),('working',27,'en','help_search',26),('working',53,'en','help_search',10.4041),('would',14,'en','help_search',1),('would',20,'en','help_search',1),('would',30,'en','help_search',0.957226),('would',31,'en','help_search',1),('would',33,'en','help_search',0.972861),('would',36,'en','help_search',2),('would',53,'en','help_search',1),('would',55,'en','help_search',1),('would',60,'en','help_search',3),('would',65,'en','help_search',1),('would',67,'en','help_search',1),('would',77,'en','help_search',1),('would',78,'en','help_search',1),('would',83,'en','help_search',1),('wraps',10,'en','help_search',1),('write',11,'en','help_search',0.707906),('writing',27,'en','help_search',1),('written',22,'en','help_search',1),('written',53,'en','help_search',1),('wwwexamplecom',78,'en','help_search',4),('wysiwyg',54,'en','help_search',4),('xml',25,'en','help_search',1),('yaml',1,'en','help_search',1),('yaml',4,'en','help_search',1),('yaml',11,'en','help_search',3.56669),('yaml',27,'en','help_search',1),('yaml',53,'en','help_search',0.968904),('yamlformat',4,'en','help_search',1),('yes',1,'en','node_search',0.506102),('yet',14,'en','help_search',1),('yet',21,'en','help_search',1),('yet',58,'en','help_search',1),('yml',11,'en','help_search',0.993146),('you',1,'en','node_search',31.7746),('you',2,'en','help_search',1),('you',3,'en','help_search',2),('you',4,'en','help_search',2),('you',5,'en','help_search',4),('you',6,'en','help_search',1),('you',7,'en','help_search',2),('you',8,'en','help_search',1),('you',9,'en','help_search',1),('you',10,'en','help_search',1.97685),('you',12,'en','help_search',6.57496),('you',13,'en','help_search',10.9946),('you',14,'en','help_search',3),('you',15,'en','help_search',1),('you',16,'en','help_search',1),('you',18,'en','help_search',1.74636),('you',19,'en','help_search',1),('you',20,'en','help_search',5),('you',21,'en','help_search',1),('you',22,'en','help_search',5),('you',23,'en','help_search',1),('you',24,'en','help_search',3),('you',26,'en','help_search',1),('you',27,'en','help_search',1.98902),('you',28,'en','help_search',3),('you',29,'en','help_search',2.83423),('you',30,'en','help_search',6.3893),('you',31,'en','help_search',1),('you',32,'en','help_search',5),('you',33,'en','help_search',6.74314),('you',35,'en','help_search',8),('you',36,'en','help_search',6),('you',37,'en','help_search',5),('you',38,'en','help_search',7),('you',39,'en','help_search',1),('you',40,'en','help_search',3),('you',41,'en','help_search',1),('you',42,'en','help_search',2),('you',44,'en','help_search',7.96229),('you',45,'en','help_search',3),('you',46,'en','help_search',2),('you',47,'en','help_search',6),('you',48,'en','help_search',4),('you',49,'en','help_search',3),('you',50,'en','help_search',4.18461),('you',51,'en','help_search',2),('you',52,'en','help_search',1),('you',53,'en','help_search',0.972861),('you',54,'en','help_search',12.7711),('you',55,'en','help_search',6.91674),('you',56,'en','help_search',2),('you',57,'en','help_search',6),('you',58,'en','help_search',3),('you',59,'en','help_search',3.8894),('you',60,'en','help_search',4.91448),('you',61,'en','help_search',8),('you',62,'en','help_search',6),('you',63,'en','help_search',4),('you',64,'en','help_search',11),('you',65,'en','help_search',3),('you',66,'en','help_search',5),('you',67,'en','help_search',1),('you',68,'en','help_search',3),('you',69,'en','help_search',1),('you',71,'en','help_search',8.4838),('you',72,'en','help_search',2),('you',73,'en','help_search',3),('you',74,'en','help_search',1),('you',75,'en','help_search',1),('you',76,'en','help_search',2),('you',77,'en','help_search',3),('you',78,'en','help_search',5),('you',79,'en','help_search',2),('you',80,'en','help_search',10),('you',81,'en','help_search',6.9394),('you',82,'en','help_search',5),('you',83,'en','help_search',4),('you',85,'en','help_search',6.99731),('you',86,'en','help_search',5),('your',1,'en','help_search',27),('your',1,'en','node_search',50.5075),('your',2,'en','help_search',6),('your',3,'en','help_search',30),('your',4,'en','help_search',5),('your',6,'en','help_search',1),('your',7,'en','help_search',1),('your',8,'en','help_search',1),('your',10,'en','help_search',42.1676),('your',11,'en','help_search',1),('your',12,'en','help_search',8.53008),('your',13,'en','help_search',9),('your',14,'en','help_search',39),('your',15,'en','help_search',32),('your',16,'en','help_search',2),('your',18,'en','help_search',1.98902),('your',19,'en','help_search',29),('your',20,'en','help_search',3),('your',21,'en','help_search',27),('your',22,'en','help_search',22),('your',24,'en','help_search',3),('your',25,'en','help_search',1),('your',26,'en','help_search',2),('your',27,'en','help_search',1),('your',28,'en','help_search',1),('your',29,'en','help_search',2),('your',30,'en','help_search',1.80822),('your',31,'en','help_search',4),('your',32,'en','help_search',4),('your',33,'en','help_search',5.96178),('your',34,'en','help_search',5),('your',35,'en','help_search',2),('your',36,'en','help_search',1),('your',37,'en','help_search',32),('your',38,'en','help_search',3),('your',41,'en','help_search',1),('your',42,'en','help_search',2),('your',44,'en','help_search',4.99731),('your',47,'en','help_search',1),('your',48,'en','help_search',2),('your',51,'en','help_search',3),('your',52,'en','help_search',3),('your',53,'en','help_search',1),('your',54,'en','help_search',2),('your',59,'en','help_search',2),('your',60,'en','help_search',4.95373),('your',61,'en','help_search',1),('your',62,'en','help_search',2),('your',63,'en','help_search',2),('your',64,'en','help_search',0.997306),('your',65,'en','help_search',2),('your',66,'en','help_search',1),('your',68,'en','help_search',1),('your',70,'en','help_search',1),('your',71,'en','help_search',1),('your',73,'en','help_search',1),('your',74,'en','help_search',1),('your',75,'en','help_search',1),('your',77,'en','help_search',1),('your',78,'en','help_search',4),('your',79,'en','help_search',5.99731),('your',80,'en','help_search',2),('your',81,'en','help_search',0.997306),('your',82,'en','help_search',2),('your',84,'en','help_search',3),('your',85,'en','help_search',4.98493),('your',86,'en','help_search',6),('zindex',1,'en','node_search',3),('zone',32,'en','help_search',2);
/*!40000 ALTER TABLE `search_index` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `search_total`
--

DROP TABLE IF EXISTS `search_total`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `search_total` (
  `word` varchar(50) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique word in the search index.',
  `count` float DEFAULT NULL COMMENT 'The count of the word in the index using Zipf''s law to equalize the probability distribution.',
  PRIMARY KEY (`word`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores search totals for words.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `search_total`
--

LOCK TABLES `search_total` WRITE;
/*!40000 ALTER TABLE `search_total` DISABLE KEYS */;
INSERT INTO `search_total` VALUES ('0a5987',0.30103),('0d77b5',0.206754),('1',0.0575084),('100',0.0754789),('10062024',0.30103),('100vw',0.0703298),('10px',0.30103),('15',0.30103),('2',0.0817947),('200',0.30103),('202410',0.30103),('2024104950565daf4845efbe68c27550a02da9webp',0.30103),('2024108af0c4402152467886c795ee5c055211jpg',0.30103),('20px',0.0226308),('2123',0.30103),('238556',0.30103),('25',0.283045),('255',0.30103),('3',0.30103),('300px',0.133476),('30e30',0.258166),('30px',0.213834),('333',0.30103),('400px',0.236014),('403',0.0184834),('403404',0.0157943),('404',0.0177455),('40em',0.0791812),('40px',0.0269917),('5',0.0297248),('50',0.0706061),('50vw',0.0705754),('6',0.124939),('60px',0.30103),('640px',0.0901195),('7',0.0321847),('721320',0.30103),('768px',0.233715),('9',0.30103),('960px',0.0714291),('999',0.30103),('abbreviation',0.30103),('ability',0.0591189),('able',0.0977625),('about',0.0101432),('aboutus',0.0791812),('above',0.0719533),('absolute',0.30103),('access',0.0124533),('accessed',0.30103),('accessibility',0.00895484),('accessible',0.124939),('accessing',0.176091),('accomplish',0.30103),('accordion',0.0339028),('account',0.00400315),('accountname',0.30103),('accounts',0.00509979),('action',0.0119132),('actions',0.0298577),('active',0.0188459),('activity',0.30103),('acts',0.30103),('add',0.00247306),('added',0.0287454),('adding',0.00186852),('addition',0.0818822),('additional',0.00078275),('address',0.0457575),('addresses',0.188552),('adds',0.30103),('adjust',0.111585),('admin',0.021746),('administer',0.00706588),('administering',0.30103),('administration',0.0263289),('administrative',0.00181142),('administrator',0.125187),('administrators',0.0347621),('advanced',0.0291605),('advisories',0.0211893),('advisory',0.0299632),('affected',0.30103),('after',0.039576),('afterwards',0.30103),('again',0.124939),('against',0.176091),('aggregation',0.0203441),('alias',0.0050208),('aliases',0.00363428),('aliasing',0.30103),('all',0.0107875),('allow',0.0381864),('allowed',0.0187831),('allows',0.0166107),('along',0.176091),('already',0.0321847),('alreadyconfigured',0.30103),('alreadyrendered',0.30103),('also',0.00838762),('alter',0.30103),('alternative',0.30103),('alternatively',0.176091),('always',0.09691),('american',0.30103),('anchor',0.09691),('and',0.000378888),('animations',0.30103),('announcement',0.0347621),('announcements',0.00464491),('anonymous',0.0224828),('another',0.0273551),('any',0.0148021),('anyone',0.176091),('apache',0.0347621),('api',0.0122479),('appear',0.09691),('appearance',0.00686246),('applications',0.124939),('applied',0.124939),('applies',0.30103),('apply',0.0203789),('appropriate',0.176091),('appropriately',0.30103),('approval',0.30103),('approved',0.30103),('archive',0.0430226),('are',0.00049563),('area',0.0512188),('areas',0.30103),('arrows',0.176091),('article',0.0321847),('articles',0.176091),('aspect',0.30103),('aspects',0.30103),('asset',0.30103),('assign',0.179531),('assigned',0.124939),('assistive',0.30103),('associate',0.133055),('associated',0.30103),('associates',0.30103),('association',0.176091),('assume',0.30103),('assuming',0.30103),('assumptions',0.30103),('attach',0.102045),('attached',0.0669468),('attention',0.30103),('attribute',0.30103),('audio',0.30103),('authenticated',0.0378911),('authenticating',0.30103),('authentication',0.0125891),('authoring',0.0520117),('authorized',0.30103),('auto',0.0508067),('automated',0.0971766),('automatic',0.176091),('automatically',0.0727549),('automaticallygenerated',0.176091),('available',0.00299572),('avoid',0.30103),('aware',0.30103),('away',0.176091),('back',0.30103),('background',0.0633686),('backgroundcolor',0.0997825),('backgroundposition',0.169466),('backgroundsize',0.138633),('bad',0.30103),('ban',0.176091),('bar',0.30103),('base',0.0143783),('based',0.30103),('basic',0.00418536),('beautifully',0.30103),('because',0.124939),('become',0.30103),('becomes',0.30103),('been',0.0313976),('before',0.0806055),('behaves',0.30103),('behaving',0.30103),('behavior',0.0687641),('behind',0.30103),('being',0.0477268),('believe',0.30103),('belong',0.30103),('below',0.0151435),('besides',0.207766),('best',0.09691),('between',0.0398561),('bgimage1webp',0.30103),('big',0.30103),('bigpipe',0.0446591),('blank',0.30103),('block',0.0014331),('blocked',0.30103),('blocks',0.00368495),('blog',0.0579919),('blogs',0.30103),('body',0.0687564),('boolean',0.30103),('bootstrap',0.0355887),('border',0.256232),('both',0.0415108),('bottom',0.0622775),('box',0.0358284),('boxes',0.09691),('brackets',0.30103),('break',0.176091),('breakpoint',0.00793195),('breakpointenabled',0.30103),('breakpoints',0.00497197),('breaks',0.09691),('browse',0.30103),('browser',0.0807971),('bugs',0.09691),('buider',0.0157943),('build',0.0396093),('builder',0.142212),('building',0.176091),('builtin',0.176091),('bulk',0.00719509),('bunch',0.0312337),('but',0.0303403),('butter',0.30103),('button',0.0110579),('buttons',0.0369925),('bypass',0.0511525),('cache',0.00512147),('cacheable',0.30103),('cached',0.0457575),('caches',0.0672286),('caching',0.0202034),('calc',0.0705446),('calculated',0.179818),('calculation',0.30103),('calculations',0.124939),('calendar',0.30103),('call',0.033993),('called',0.0474577),('can',0.000809703),('cancel',0.0324435),('canceled',0.0670605),('cannot',0.0669468),('captcha',0.30103),('carefully',0.30103),('carousel',0.0340154),('case',0.30103),('categorize',0.30103),('center',0.0826454),('certain',0.176091),('challenge',0.30103),('change',0.0142797),('changed',0.0460568),('changes',0.0349665),('changing',0.00599036),('channel',0.30103),('character',0.201523),('characteristics',0.232926),('characters',0.30103),('check',0.017203),('checkbox',0.176091),('checked',0.0579919),('checking',0.176091),('child',0.30103),('children',0.30103),('chinese',0.30103),('choice',0.176091),('choices',0.13934),('choose',0.0130297),('choosing',0.124939),('chose',0.176091),('chosen',0.107547),('cjk',0.097509),('ckeditor',0.0319098),('claro',0.125337),('classified',0.30103),('classify',0.0669747),('clean',0.30103),('clear',0.0321847),('cleared',0.30103),('clearing',0.01524),('cli',0.30103),('click',0.002717),('clicked',0.30103),('clicking',0.0512436),('clicks',0.30103),('clipboard',0.124939),('cloned',0.30103),('clones',0.30103),('cloning',0.30103),('closed',0.0534271),('club',0.30103),('code',0.0829375),('codebase',0.30103),('codes',0.0304214),('collected',0.30103),('collection',0.178078),('collectively',0.30103),('color',0.0597806),('column',0.0310199),('column1',0.183382),('column2',0.183514),('columns',0.0356271),('combination',0.30103),('combinations',0.30103),('come',0.141471),('comes',0.30103),('comma',0.30103),('command',0.146288),('commandline',0.30103),('comment',0.00238964),('commentary',0.30103),('commented',0.30103),('commenters',0.30103),('commenting',0.0418868),('comments',0.00161753),('common',0.124939),('commonly',0.176091),('commonlyused',0.176091),('community',0.30103),('communitymembers',0.30103),('communityprovided',0.176091),('compares',0.30103),('comparison',0.0377886),('complete',0.0073217),('completely',0.30103),('complex',0.128947),('compliance',0.30103),('compliant',0.30103),('component',0.154379),('components',0.0102851),('composed',0.30103),('composer',0.0564867),('compressed',0.30103),('computer',0.176091),('concept',0.00465218),('concepts',0.30103),('conditions',0.176091),('config',0.0511525),('configurable',0.30103),('configuration',0.000845453),('configure',0.00346591),('configured',0.0428044),('configuring',0.00108637),('confirm',0.30103),('confirmation',0.176091),('confused',0.30103),('connect',0.30103),('connected',0.30103),('connecting',0.0163904),('consist',0.30103),('consume',0.30103),('contact',0.00154776),('contain',0.0881532),('container',0.0680027),('containing',0.0799177),('contains',0.100868),('content',0.000448325),('context',0.0850083),('contextual',0.00541456),('continue',0.0413927),('contributed',0.0107169),('control',0.0419254),('convert',0.176091),('converted',0.30103),('converting',0.176091),('converts',0.30103),('cookies',0.30103),('cooking',0.30103),('cool',0.0503713),('copied',0.187562),('copy',0.124939),('core',0.00309549),('corner',0.176091),('correct',0.0352981),('corresponding',0.186677),('corresponds',0.30103),('corrupted',0.30103),('could',0.052231),('countdown',0.0357036),('counter',0.0340821),('counterparts',0.30103),('country',0.176091),('cover',0.0889154),('covered',0.176091),('create',0.00315156),('created',0.0100152),('creates',0.176091),('creating',0.00134754),('creatingneweptmodule',0.0724328),('creation',0.0222764),('creators',0.30103),('criteria',0.0224299),('critical',0.176091),('cron',0.00295015),('crop',0.0791812),('cropping',0.30103),('css',0.10025),('curated',0.30103),('current',0.0381109),('currently',0.0855755),('custom',0.07448),('customizable',0.30103),('customize',0.177487),('customizing',0.0199788),('data',0.00429412),('database',0.0477659),('date',0.0173936),('dates',0.187061),('datetime',0.199796),('death',0.09691),('decide',0.30103),('decimalplaces',0.30103),('default',0.00334057),('defaults',0.30103),('defend',0.30103),('define',0.0348417),('defined',0.0791812),('defines',0.124939),('defining',0.014864),('delete',0.0284002),('deleted',0.0142404),('deleting',0.0153447),('deletion',0.0222764),('demo',0.30103),('demonstrate',0.0511525),('dependencies',0.220409),('dependent',0.30103),('depending',0.07144),('depends',0.30103),('deploying',0.013364),('derived',0.30103),('described',0.194576),('describes',0.124939),('description',0.0102192),('descriptive',0.30103),('deserialization',0.09691),('design',0.150207),('desired',0.0172676),('destination',0.212504),('details',0.0695619),('determine',0.30103),('determines',0.30103),('dev',0.188552),('development',0.0078777),('device',0.09691),('deviceindependent',0.0377886),('devices',0.30103),('diagnose',0.176091),('dialog',0.176091),('did',0.176091),('differences',0.30103),('different',0.0275807),('differentsized',0.30103),('difficult',0.30103),('direct',0.30103),('directly',0.0979327),('directories',0.30103),('directory',0.0626339),('disable',0.0170333),('disabled',0.0303538),('disabling',0.00526424),('discard',0.30103),('discovery',0.177487),('discussed',0.30103),('discussion',0.30103),('display',0.00246491),('displayed',0.00916872),('displaying',0.30103),('displayname',0.30103),('displays',0.0193052),('distributed',0.30103),('divided',0.0791812),('divisions',0.30103),('documentation',0.00477159),('documented',0.30103),('documents',0.30103),('does',0.0178018),('dom',0.30103),('don',0.30103),('done',0.0601132),('down',0.30103),('download',0.00474819),('downloaded',0.0542872),('downloads',0.30103),('drag',0.0360685),('draganddrop',0.124939),('dragging',0.185009),('drastic',0.30103),('dropdown',0.0791812),('dropped',0.30103),('drupal',0.000986489),('drupalbook',0.0757182),('drupalbookorg',0.0722952),('drupalorg',0.00833095),('drush',0.0486845),('due',0.30103),('duration',0.30103),('during',0.176091),('dynamic',0.0205082),('each',0.00736806),('ease',0.042716),('easier',0.0791812),('easy',0.30103),('ebt',0.00252425),('edit',0.00178171),('edited',0.30103),('editing',0.00244791),('editor',0.0105939),('editors',0.00955747),('edits',0.176091),('eeeeee',0.30103),('effect',0.0377886),('effects',0.0511525),('efficiently',0.30103),('either',0.0555492),('element',0.30103),('elements',0.30103),('else',0.30103),('email',0.0116858),('embed',0.30103),('embrace',0.30103),('empower',0.0428659),('enable',0.080613),('enabled',0.0247114),('enables',0.176091),('enablescrollspy',0.30103),('enabling',0.00796893),('enclosed',0.30103),('encode',0.30103),('end',0.0690913),('enforces',0.30103),('enforcing',0.30103),('engaging',0.30103),('engines',0.30103),('english',0.0975029),('enhances',0.205543),('ensure',0.184484),('ensures',0.30103),('enter',0.0104952),('entered',0.176091),('entering',0.30103),('enters',0.30103),('entities',0.013564),('entity',0.00198948),('entries',0.176091),('ept',0.0013075),('eptbasicbutton',0.115566),('eptbasicbutton2',0.115566),('eptcontainer',0.0454635),('eptdemolocal',0.167679),('eptedgetoedge',0.13046),('eptherocontainer',0.0791812),('eptparagraphctacontent',0.0882156),('epttabs',0.30103),('eptwidthdefault',0.0714291),('eptwidthsmall',0.233249),('eptwidthxsmall',0.287394),('error',0.010809),('errors',0.0123697),('etc',0.0588093),('events',0.30103),('every',0.0982369),('exact',0.176091),('example',0.010034),('examplecom',0.017852),('examples',0.0841362),('exceed',0.30103),('except',0.30103),('exchanged',0.176091),('exist',0.202653),('existing',0.00626166),('exists',0.176091),('expand',0.30103),('expanded',0.09691),('expect',0.30103),('expected',0.30103),('experience',0.114512),('experimental',0.0170333),('expiring',0.30103),('explaining',0.30103),('export',0.0255328),('exported',0.0398026),('exporting',0.00773452),('expose',0.30103),('exposed',0.0440728),('exposes',0.176091),('extend',0.0080826),('extended',0.30103),('extending',0.00593291),('extends',0.30103),('extension',0.0836586),('external',0.30103),('extra',0.00773065),('facilitate',0.30103),('factors',0.176091),('false',0.30103),('faq',0.019082),('far',0.30103),('faster',0.124939),('faulty',0.30103),('feature',0.30103),('features',0.09691),('feed',0.0669468),('feedback',0.0522572),('feel',0.30103),('few',0.30103),('fewer',0.30103),('ffffff',0.0911877),('field',0.00139453),('fields',0.00213546),('file',0.0142686),('files',0.0268903),('fill',0.0806641),('filling',0.30103),('filter',0.009974),('filtering',0.129075),('filters',0.0049671),('finally',0.30103),('find',0.00780692),('finish',0.30103),('finished',0.176091),('first',0.0362397),('fix',0.30103),('fixed',0.134502),('fixing',0.0377886),('flag',0.30103),('flat',0.176091),('flexdirection',0.207431),('flexibility',0.30103),('flexible',0.152993),('focusing',0.30103),('follow',0.0281802),('following',0.037344),('footer',0.089464),('for',0.000610586),('force',0.30103),('forcing',0.30103),('form',0.00168832),('formal',0.30103),('format',0.00533348),('formats',0.00399671),('formatted',0.0266232),('formatter',0.0228134),('formatters',0.0636519),('formatting',0.30103),('forms',0.00298439),('found',0.30103),('four',0.30103),('framework',0.176091),('free',0.30103),('from',0.00660153),('front',0.0669468),('full',0.0791812),('fullexport',0.30103),('fully',0.0834463),('function',0.124939),('functionality',0.0107813),('functions',0.30103),('further',0.0908076),('future',0.181508),('galleries',0.30103),('gallery',0.0178402),('gap',0.207431),('gear',0.176091),('generally',0.30103),('generate',0.146338),('generated',0.0871708),('generating',0.30103),('generic',0.176091),('get',0.0808654),('getting',0.0157943),('give',0.0595632),('given',0.30103),('glightbox',0.0149421),('goal',0.000387244),('goals',0.30103),('goes',0.176091),('good',0.30103),('governance',0.30103),('granting',0.30103),('green',0.30103),('grid',0.0669468),('group',0.0151048),('grouped',0.176091),('groups',0.0181544),('guide',0.00145328),('handles',0.30103),('handling',0.0978732),('happen',0.30103),('happens',0.097149),('has',0.00522709),('have',0.00438757),('haven',0.30103),('having',0.30103),('header',0.0739314),('heading',0.124939),('health',0.176091),('height',0.012965),('help',0.00187366),('helps',0.30103),('helptopics',0.0511525),('here',0.0128028),('herocol1',0.176091),('herocol2',0.176091),('hidden',0.0183663),('hide',0.138466),('hiding',0.30103),('hierarchical',0.30103),('hierarchy',0.176091),('highly',0.176091),('hints',0.30103),('history',0.176091),('hockey',0.30103),('holds',0.30103),('home',0.0970591),('horizontal',0.30103),('hour',0.30103),('hourly',0.30103),('hover',0.115566),('hovering',0.127893),('hovers',0.30103),('how',0.00329206),('however',0.176091),('html',0.0164933),('http',0.00931495),('https',0.0145361),('human',0.30103),('humanreadable',0.30103),('icon',0.124939),('idea',0.0523561),('identification',0.30103),('identifier',0.0892115),('identifiers',0.30103),('identifies',0.18527),('image',0.00325323),('images',0.0257384),('immediately',0.30103),('impact',0.30103),('implementation',0.176091),('implemented',0.30103),('implications',0.0791812),('import',0.0193052),('important',0.00985811),('imported',0.0679688),('importing',0.00802071),('improper',0.11041),('improve',0.0202034),('improved',0.30103),('include',0.061714),('includes',0.176091),('including',0.0116291),('incorrect',0.30103),('increasing',0.30103),('index',0.00655471),('indexed',0.0834923),('indexing',0.0171016),('indicating',0.0689701),('individual',0.0584738),('influence',0.30103),('information',0.00716827),('informational',0.30103),('ingredients',0.0791812),('inline',0.0142475),('inplace',0.176091),('input',0.206239),('insert',0.30103),('install',0.00729412),('installation',0.176091),('installed',0.00844105),('installing',0.00568143),('instance',0.0430167),('instances',0.107823),('instead',0.0487089),('instructions',0.0981008),('integer',0.125963),('integers',0.30103),('integration',0.30103),('interactions',0.30103),('interactive',0.30103),('interest',0.09691),('interests',0.30103),('interface',0.0036333),('interfaces',0.30103),('internal',0.018932),('into',0.0103325),('invalid',0.30103),('item',0.00181357),('items',0.00532561),('its',0.0195548),('itself',0.30103),('japanese',0.30103),('javascript',0.0599608),('jobs',0.30103),('json',0.0115819),('just',0.109372),('keep',0.128426),('keeping',0.176091),('kept',0.30103),('key',0.19672),('keyboardonly',0.30103),('keys',0.0997059),('keyword',0.176091),('keywords',0.124939),('kinds',0.0222764),('knowing',0.30103),('known',0.09691),('korean',0.30103),('label',0.0100639),('labeled',0.124939),('labels',0.081504),('landing',0.30103),('language',0.0177337),('languages',0.00730688),('languagespecific',0.30103),('large',0.137029),('larger',0.30103),('last',0.0377886),('later',0.0687802),('layout',0.0114104),('layouts',0.0233255),('leading',0.30103),('leads',0.30103),('learn',0.124939),('learning',0.30103),('least',0.176091),('leave',0.176091),('left',0.0399791),('length',0.0791812),('less',0.30103),('let',0.0827086),('lets',0.30103),('letting',0.30103),('level',0.30103),('library',0.0157943),('lifetime',0.081253),('lightbox',0.30103),('like',0.0349754),('limit',0.0550801),('limitations',0.0211893),('limited',0.30103),('limits',0.176091),('line',0.0791812),('link',0.00450618),('linkedin',0.0754457),('links',0.00268144),('linuxlike',0.30103),('list',0.0048015),('listed',0.00977448),('listing',0.125782),('listings',0.00911297),('lists',0.101808),('live',0.1031),('load',0.30103),('loads',0.30103),('locate',0.0347621),('located',0.09691),('location',0.144709),('locations',0.30103),('locator',0.30103),('log',0.0457575),('logged',0.0792203),('loggedin',0.30103),('logging',0.060091),('loginurl',0.30103),('long',0.0454152),('longer',0.176091),('look',0.124939),('looks',0.124939),('machine',0.0669468),('machinereadable',0.30103),('made',0.30103),('mail',0.30103),('main',0.0443459),('maintaining',0.00934003),('maintenance',0.00344715),('make',0.0126852),('makes',0.178372),('making',0.0119051),('malicious',0.30103),('manage',0.00125407),('managed',0.0791812),('management',0.0086537),('manager',0.135476),('managers',0.30103),('manages',0.30103),('managing',0.000693661),('manner',0.30103),('manually',0.0669468),('many',0.0727736),('mapped',0.30103),('mapping',0.0511525),('margin',0.0473326),('marginbottom',0.0613339),('marginleft',0.130896),('marginright',0.131323),('mark',0.30103),('marked',0.09691),('marker',0.30103),('markup',0.09691),('match',0.0875758),('matched',0.30103),('matches',0.30103),('matching',0.30103),('matter',0.30103),('maximum',0.1302),('maxwidth',0.0296037),('may',0.0251936),('meaning',0.176091),('means',0.127485),('meant',0.124939),('measure',0.30103),('mechanisms',0.09691),('media',0.00200687),('mediarelated',0.30103),('medium',0.30103),('members',0.30103),('mentioned',0.30103),('menu',0.00153096),('menus',0.00695232),('merged',0.30103),('message',0.00890035),('messages',0.0286464),('metadata',0.0193052),('method',0.124939),('micromodal',0.0357418),('might',0.0693384),('minimum',0.09691),('minwidth',0.30103),('misbehaving',0.30103),('mistakes',0.30103),('mix',0.30103),('modal',0.176091),('mode',0.00532883),('moderate',0.0211893),('moderating',0.0113174),('moderation',0.0170568),('modern',0.30103),('modify',0.0791812),('modifying',0.00553249),('module',0.00106231),('modules',0.00168464),('month',0.176091),('more',0.00591306),('most',0.0247658),('mostcommonlyused',0.30103),('mouse',0.30103),('move',0.30103),('much',0.30103),('multiple',0.09691),('multiplevalued',0.30103),('multiplier',0.30103),('multipliers',0.0185231),('must',0.0512436),('name',0.00548878),('names',0.30103),('navigate',0.00569264),('navigating',0.176091),('navigation',0.30103),('near',0.30103),('necessary',0.128817),('need',0.012529),('needed',0.0690178),('needing',0.30103),('needs',0.1309),('never',0.30103),('new',0.00189812),('newly',0.30103),('news',0.176091),('next',0.0299632),('node',0.0180067),('nolink',0.09691),('nonadministration',0.30103),('nonadministrative',0.09691),('noncacheable',0.30103),('nondefault',0.30103),('none',0.104012),('nonenglish',0.30103),('nonerror',0.30103),('nontoplevel',0.30103),('norepeat',0.169274),('normal',0.124939),('normally',0.124939),('not',0.00804117),('note',0.0457575),('noted',0.30103),('notfound',0.0524957),('notice',0.30103),('notify',0.09691),('notifying',0.30103),('now',0.0596503),('number',0.0124584),('numbers',0.109372),('numerical',0.30103),('objectfit',0.100758),('occasionally',0.30103),('occur',0.0211893),('off',0.09691),('offer',0.155997),('offering',0.30103),('official',0.09691),('often',0.176091),('older',0.30103),('once',0.0702755),('one',0.0082542),('onetimeloginurl',0.30103),('online',0.00545524),('only',0.0245256),('open',0.0358537),('operation',0.30103),('operations',0.00478587),('optimizing',0.0163904),('option',0.205335),('optional',0.0522058),('optionally',0.0142507),('options',0.00968394),('order',0.00970192),('ordered',0.30103),('ordering',0.176091),('organize',0.30103),('organized',0.30103),('organizes',0.30103),('original',0.30103),('other',0.00542517),('out',0.080246),('outline',0.30103),('output',0.0458695),('outreach',0.30103),('outside',0.0511688),('over',0.0804053),('overall',0.184765),('overflow',0.13057),('overflowx',0.131533),('override',0.0803525),('overview',0.00112363),('own',0.0192692),('owned',0.30103),('owners',0.176091),('padding',0.30103),('paddingbottom',0.0563479),('paddingleft',0.0502859),('paddingright',0.050259),('paddingtop',0.0563284),('page',0.00147955),('pagelevel',0.176091),('pager',0.0824479),('pages',0.00287076),('paginate',0.30103),('paragraph',0.00709109),('paragraphid1',0.0321847),('paragraphid10',0.30103),('paragraphid11',0.053407),('paragraphid12',0.30103),('paragraphid2',0.30103),('paragraphid23',0.30103),('paragraphid26',0.30103),('paragraphid30',0.30103),('paragraphid33',0.30103),('paragraphid36',0.30103),('paragraphid6',0.30103),('paragraphid9',0.30103),('paragraphs',0.0238824),('parent',0.0511525),('part',0.0579919),('particular',0.0250746),('parts',0.187855),('pass',0.30103),('passoptionstojavascript',0.30103),('password',0.0579919),('past',0.0822022),('paste',0.0669468),('path',0.012476),('pathauto',0.0377886),('paths',0.0137883),('patterns',0.09691),('paying',0.30103),('pencil',0.176091),('pending',0.30103),('people',0.0123866),('per',0.0413927),('perform',0.0669468),('performance',0.00580152),('performing',0.129203),('periodically',0.09691),('periods',0.30103),('permanent',0.30103),('permission',0.00557694),('permissions',0.00483939),('personal',0.00742402),('personalized',0.30103),('php',0.0299632),('physical',0.30103),('piece',0.124939),('pieces',0.30103),('pipe',0.30103),('pixel',0.0347621),('place',0.0116406),('placed',0.0511525),('placeholders',0.185457),('placing',0.01524),('plain',0.0382693),('plaintext',0.30103),('planning',0.063656),('plugin',0.0657273),('pluginbased',0.30103),('plugins',0.117352),('point',0.176091),('policy',0.0299632),('pop',0.176091),('popup',0.0332162),('popups',0.0321184),('porter',0.0383419),('portfolios',0.30103),('position',0.09691),('positions',0.30103),('possibility',0.30103),('possible',0.0754469),('post',0.176091),('posted',0.124939),('posting',0.30103),('posts',0.124939),('potentiallydangerous',0.30103),('powerful',0.22987),('practice',0.176091),('practices',0.30103),('predefined',0.141044),('prefer',0.30103),('preferred',0.176091),('prefix',0.30103),('preindex',0.30103),('presentation',0.30103),('presents',0.30103),('prevent',0.30103),('preventing',0.0377886),('preview',0.0324458),('previewing',0.30103),('previous',0.140099),('previously',0.09691),('previouslyplaced',0.0157943),('printers',0.30103),('problem',0.124939),('problems',0.0299774),('process',0.0249474),('processed',0.198979),('processing',0.0743237),('production',0.18123),('profile',0.0579919),('profiles',0.09691),('programs',0.30103),('progress',0.057808),('project',0.0588093),('projects',0.30103),('promote',0.30103),('provide',0.00713191),('provided',0.00895819),('provides',0.0152187),('providing',0.137888),('public',0.30103),('publish',0.0348386),('published',0.030789),('publishes',0.30103),('publishing',0.30103),('pull',0.30103),('purpose',0.30103),('purposes',0.0979142),('put',0.0347621),('putting',0.30103),('queries',0.0132653),('query',0.30103),('quick',0.00768683),('quickly',0.128688),('quote',0.0341583),('radio',0.143522),('ran',0.30103),('range',0.136589),('ranging',0.30103),('ranking',0.0791812),('rather',0.30103),('ratio',0.30103),('reach',0.30103),('read',0.199973),('readers',0.176091),('ready',0.30103),('really',0.30103),('rearrange',0.0791812),('reasons',0.176091),('rebuild',0.09691),('recalculated',0.30103),('recalculation',0.30103),('receive',0.176091),('recent',0.0791812),('recently',0.176091),('recipe',0.124939),('recipes',0.124939),('recipient',0.30103),('recipients',0.0791812),('recommended',0.124939),('records',0.30103),('red',0.30103),('redirected',0.30103),('reduce',0.126931),('reference',0.00403647),('referenced',0.124939),('references',0.30103),('refers',0.30103),('refine',0.176091),('region',0.0170333),('regional',0.09691),('regions',0.0377886),('register',0.09691),('registered',0.124939),('regular',0.127995),('regularlength',0.30103),('reindex',0.101856),('reindexed',0.30103),('related',0.00598603),('relationship',0.187564),('relationships',0.106869),('relative',0.176091),('released',0.30103),('releases',0.176091),('relevant',0.30103),('relying',0.30103),('remain',0.183419),('remote',0.30103),('remove',0.0976765),('removing',0.30103),('render',0.30103),('rendered',0.30103),('rendering',0.30103),('renders',0.30103),('reordering',0.0157943),('repeat',0.082512),('replacement',0.09691),('replacements',0.30103),('reply',0.0382057),('report',0.0413927),('reported',0.30103),('reports',0.00983967),('reproduced',0.30103),('request',0.176091),('requested',0.179818),('requests',0.30103),('require',0.112477),('required',0.0267297),('requires',0.0835812),('requiring',0.30103),('reset',0.176091),('resides',0.30103),('resized',0.30103),('resolution',0.00896416),('resource',0.30103),('resources',0.000809978),('respective',0.30103),('respectively',0.30103),('respond',0.124939),('response',0.0669468),('responses',0.00895484),('responsive',0.0646226),('rest',0.0348708),('restful',0.0184834),('restrict',0.186044),('restrictions',0.30103),('restrictive',0.30103),('restricts',0.191184),('result',0.179531),('results',0.0473965),('retrieved',0.30103),('return',0.0612521),('returned',0.0350127),('reusable',0.135649),('reuse',0.30103),('reusing',0.30103),('reverse',0.176091),('review',0.176091),('reviews',0.30103),('rgba',0.30103),('rich',0.0327589),('right',0.0426937),('righttoleft',0.0513167),('rigid',0.30103),('risk',0.110762),('role',0.00459601),('roles',0.0136974),('row',0.0377886),('rows',0.30103),('rss',0.30103),('run',0.0131008),('running',0.00540085),('runs',0.0970591),('runtime',0.30103),('safe',0.30103),('same',0.0318414),('save',0.00196941),('saved',0.0691786),('saves',0.30103),('saving',0.30103),('say',0.30103),('saying',0.176091),('says',0.30103),('scaffolding',0.30103),('scaling',0.30103),('scan',0.176091),('scenes',0.30103),('schedule',0.0792806),('screen',0.0275456),('screens',0.124939),('scripts',0.30103),('scroll',0.176091),('scrollspydelay',0.30103),('scrollspyonce',0.30103),('seamless',0.202653),('search',0.00103629),('searchable',0.30103),('searches',0.185009),('searching',0.047278),('second',0.176091),('section',0.0195223),('sections',0.0193052),('secure',0.01524),('security',0.00317636),('see',0.00301068),('seen',0.30103),('sees',0.30103),('select',0.00808519),('selected',0.022374),('selecting',0.176091),('selects',0.30103),('send',0.0443169),('sending',0.30103),('sends',0.30103),('sent',0.129993),('seofriendly',0.30103),('separate',0.30103),('separately',0.176091),('separates',0.30103),('separator',0.30103),('sequence',0.30103),('serialization',0.0170434),('serialized',0.30103),('serve',0.177189),('server',0.124939),('servers',0.30103),('service',0.0211893),('services',0.00599036),('serving',0.30103),('session',0.09691),('set',0.00725715),('sets',0.0791812),('setting',0.00542214),('settings',0.00128365),('settingsphp',0.0679777),('several',0.0509907),('severity',0.09691),('share',0.30103),('shared',0.176091),('shield',0.30103),('shift',0.30103),('short',0.109149),('shortcut',0.00783464),('shortcuts',0.0087851),('should',0.0117584),('show',0.0211893),('showing',0.204837),('shown',0.018654),('shows',0.102136),('side',0.0669468),('similar',0.0795761),('simple',0.0458095),('since',0.30103),('single',0.00663058),('singleitem',0.30103),('singleline',0.248161),('singlevalued',0.210151),('site',0.000581456),('sites',0.0311403),('sitewide',0.0579919),('situations',0.30103),('size',0.124939),('sized',0.177487),('sizes',0.30103),('sizing',0.30103),('slack',0.075582),('sleek',0.30103),('slick',0.0341244),('slider',0.0341282),('slideshow',0.0357798),('slogan',0.176091),('smaller',0.0669468),('smarteasingamount',0.30103),('smarteasingthreshold',0.30103),('smooth',0.30103),('social',0.30103),('software',0.0193319),('solr',0.0347621),('some',0.0137214),('someone',0.30103),('sometimes',0.176091),('soon',0.30103),('sort',0.0669468),('sorting',0.176091),('sorts',0.30103),('source',0.0422192),('sources',0.176091),('spaces',0.30103),('spam',0.182335),('spamreduction',0.30103),('special',0.30103),('specific',0.021454),('specifically',0.30103),('specification',0.0377886),('specify',0.176091),('specifying',0.180387),('speed',0.30103),('sphinx',0.0377886),('square',0.30103),('stable',0.124939),('staging',0.30103),('standard',0.30103),('standards',0.0196872),('star',0.30103),('start',0.017615),('started',0.0152649),('starting',0.30103),('starts',0.176091),('startval',0.30103),('state',0.0579919),('statistics',0.30103),('stats',0.0358178),('status',0.0237782),('stemmer',0.0384937),('stemming',0.30103),('step',0.125487),('stepbystep',0.30103),('steps',0.000378631),('still',0.30103),('storage',0.176091),('store',0.0791812),('stored',0.0560289),('stores',0.0352647),('strategic',0.30103),('streamed',0.30103),('string',0.0791812),('strings',0.102946),('striptags',0.30103),('structure',0.00247525),('structures',0.30103),('style',0.00683942),('styles',0.0480516),('styling',0.30103),('subdirectory',0.30103),('subject',0.0347621),('submission',0.30103),('submit',0.176091),('submitting',0.30103),('subset',0.30103),('substituted',0.30103),('subterm',0.30103),('subtype',0.00328042),('subtypes',0.0299859),('such',0.0106934),('sufficient',0.30103),('suffix',0.30103),('suggested',0.30103),('suit',0.30103),('summarizes',0.30103),('summary',0.0545088),('sun',0.30103),('supercharge',0.0163904),('supplied',0.30103),('support',0.13267),('supports',0.30103),('sure',0.0319755),('sustainability',0.30103),('switch',0.127058),('switcher',0.09691),('sync',0.0864771),('synchronization',0.0108913),('synchronize',0.0791812),('synchronized',0.30103),('synchronizing',0.30103),('syslog',0.30103),('system',0.00974223),('systems',0.30103),('tab',0.09691),('table',0.0282891),('tables',0.176091),('tablestyle',0.30103),('tabs',0.031713),('tag',0.190003),('tagging',0.30103),('tags',0.0365968),('take',0.0360035),('taken',0.30103),('takes',0.176091),('target',0.09691),('task',0.0588466),('tasks',0.00451582),('taste',0.30103),('taxonomy',0.00273808),('team',0.0205822),('technically',0.30103),('technologies',0.30103),('technology',0.176091),('telephone',0.151968),('template',0.196086),('templates',0.30103),('temporarily',0.30103),('temporary',0.176091),('term',0.0323619),('terms',0.0204346),('test',0.127071),('text',0.00109827),('than',0.0396293),('that',0.00212164),('the',0.000217399),('their',0.0221045),('them',0.0223138),('theme',0.00284869),('themes',0.00612104),('theming',0.0410633),('themselves',0.30103),('then',0.0468011),('there',0.00908846),('thereby',0.30103),('these',0.0143224),('they',0.0226736),('thirdparty',0.176091),('this',0.00529746),('threading',0.09691),('threads',0.30103),('three',0.176091),('throttle',0.09691),('through',0.0738368),('tiles',0.0341895),('time',0.021409),('timeline',0.0358556),('timeout',0.30103),('times',0.195673),('timestamp',0.30103),('title',0.00643964),('titlewrapper',0.30103),('together',0.30103),('toggle',0.30103),('tomatoes',0.124939),('tool',0.30103),('toolbar',0.0103021),('tooltip',0.30103),('top',0.079634),('topic',0.0121327),('topics',0.00289902),('topleft',0.30103),('toplevel',0.30103),('topright',0.30103),('totally',0.30103),('track',0.30103),('tracked',0.0222764),('tracking',0.00474644),('tracks',0.176091),('traditional',0.30103),('transferred',0.30103),('transform',0.30103),('translatable',0.124939),('translate',0.30103),('translated',0.0102192),('translation',0.0579919),('translations',0.0142404),('transmission',0.30103),('transported',0.30103),('tray',0.124939),('triggers',0.30103),('troubleshooting',0.00934003),('true',0.30103),('trusted',0.09691),('try',0.30103),('trying',0.176091),('turn',0.100179),('turning',0.176091),('turns',0.30103),('twice',0.30103),('twig',0.30103),('twigfilebased',0.30103),('two',0.0426965),('twocolumns',0.30103),('type',0.00112188),('types',0.00180795),('typically',0.0669468),('typing',0.30103),('unapproved',0.09691),('uncacheable',0.30103),('uncheck',0.0669468),('under',0.0191323),('underlying',0.30103),('understand',0.176091),('understandable',0.30103),('unformatted',0.0467698),('uniform',0.30103),('uninstall',0.0113013),('uninstalled',0.0377886),('uninstalling',0.00590886),('unique',0.0812964),('unlimited',0.176091),('unpacked',0.30103),('unpublish',0.0791812),('unpublished',0.09691),('unpublishing',0.30103),('until',0.0511525),('untrusted',0.188816),('unused',0.0163904),('unwanted',0.30103),('upcoming',0.30103),('update',0.0194147),('updated',0.0299632),('updates',0.0143266),('updating',0.0875392),('upload',0.09691),('uploaded',0.176091),('upper',0.176091),('url',0.00279107),('urls',0.00654752),('usage',0.30103),('use',0.00488328),('used',0.0164064),('useeasing',0.30103),('useful',0.30103),('usegrouping',0.30103),('user',0.000718162),('userdefined',0.30103),('userinterface',0.30103),('username',0.09691),('users',0.00401244),('uses',0.027777),('using',0.00240599),('usual',0.166096),('usually',0.30103),('uuid',0.0762928),('valid',0.176091),('value',0.0258864),('values',0.0150876),('variables',0.0170333),('variations',0.30103),('various',0.138339),('vary',0.124939),('vegetables',0.30103),('verification',0.176091),('verified',0.176091),('verify',0.0216799),('versatile',0.30103),('versions',0.30103),('vertical',0.30103),('very',0.137029),('via',0.0329178),('video',0.0114248),('videos',0.12434),('view',0.00201134),('viewed',0.124939),('viewer',0.30103),('viewing',0.0137883),('viewport',0.176091),('viewports',0.30103),('views',0.00355089),('visibility',0.0413927),('visible',0.0327972),('visit',0.0378247),('visited',0.0147233),('visiting',0.30103),('visitor',0.30103),('visitors',0.00800483),('visits',0.0211893),('visual',0.0511525),('visually',0.0846748),('vocabularies',0.0676289),('vocabulary',0.0104654),('w3c',0.0401585),('wait',0.09691),('waiting',0.30103),('walk',0.183394),('walked',0.30103),('walking',0.30103),('want',0.00626439),('warning',0.09691),('warnings',0.30103),('was',0.0579919),('way',0.0450238),('ways',0.124939),('web',0.00415596),('webform',0.0183468),('website',0.0113202),('websites',0.30103),('week',0.30103),('weekly',0.30103),('weights',0.0791812),('well',0.0684206),('went',0.30103),('were',0.0595965),('wget',0.09691),('what',0.00027121),('when',0.00669569),('whenever',0.30103),('where',0.0153403),('whether',0.0476341),('which',0.00460039),('while',0.0647376),('white',0.09691),('who',0.00170059),('whose',0.09691),('why',0.0211893),('widelyused',0.30103),('widget',0.0149292),('widgets',0.0791812),('width',0.0101918),('widths',0.176091),('will',0.00438539),('wish',0.131957),('with',0.00201703),('within',0.0588308),('without',0.0695302),('word',0.0513646),('words',0.126931),('work',0.125782),('workflow',0.0485353),('working',0.00523858),('would',0.0249232),('wraps',0.30103),('write',0.30103),('writing',0.30103),('written',0.176091),('wwwexamplecom',0.09691),('wysiwyg',0.09691),('xml',0.30103),('yaml',0.0541162),('yamlformat',0.30103),('yes',0.30103),('yet',0.124939),('yml',0.30103),('you',0.00131384),('your',0.000905928),('zindex',0.124939),('zone',0.176091);
/*!40000 ALTER TABLE `search_total` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `semaphore`
--

DROP TABLE IF EXISTS `semaphore`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `semaphore` (
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique name.',
  `value` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A value for the semaphore.',
  `expire` double NOT NULL COMMENT 'A Unix timestamp with microseconds indicating when the semaphore should expire.',
  PRIMARY KEY (`name`),
  KEY `value` (`value`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Table for holding semaphores, locks, flags, etc. that…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `semaphore`
--

LOCK TABLES `semaphore` WRITE;
/*!40000 ALTER TABLE `semaphore` DISABLE KEYS */;
/*!40000 ALTER TABLE `semaphore` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sequences`
--

DROP TABLE IF EXISTS `sequences`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `sequences` (
  `value` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'The value of the sequence.',
  PRIMARY KEY (`value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores IDs.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sequences`
--

LOCK TABLES `sequences` WRITE;
/*!40000 ALTER TABLE `sequences` DISABLE KEYS */;
/*!40000 ALTER TABLE `sequences` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `sessions`
--

DROP TABLE IF EXISTS `sessions`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `sessions` (
  `uid` int unsigned NOT NULL COMMENT 'The "users".uid corresponding to a session, or 0 for anonymous user.',
  `sid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'A session ID (hashed). The value is generated by Drupal''s session handlers.',
  `hostname` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The IP address that last used this session ID (sid).',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when this session last requested a page. Old records are purged by PHP automatically.',
  `session` longblob COMMENT 'The serialized contents of the user''s session, an array of name/value pairs that persists across page requests by this session ID. Drupal loads the user''s session from here   at the start of each request and saves it at the end.',
  PRIMARY KEY (`sid`),
  KEY `timestamp` (`timestamp`),
  KEY `uid` (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Drupal''s session handlers read and write into the sessions…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `sessions`
--

LOCK TABLES `sessions` WRITE;
/*!40000 ALTER TABLE `sessions` DISABLE KEYS */;
INSERT INTO `sessions` VALUES (1,'1dj2FDgLy0CeBE1gbQbVHebh0B2UPCYZwLQTmi_5-Ms','127.0.0.1',1729067328,_binary '_sf2_attributes|a:1:{s:3:\"uid\";s:1:\"1\";}_sf2_meta|a:4:{s:1:\"u\";i:1729067329;s:1:\"c\";i:1728225698;s:1:\"l\";i:2000000;s:1:\"s\";s:43:\"gINuL4UrvX8Iu44MoeuUjOTazW29nEoGiSJaUkQuyXQ\";}');
/*!40000 ALTER TABLE `sessions` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `shortcut`
--

DROP TABLE IF EXISTS `shortcut`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `shortcut` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `shortcut_set` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `shortcut_field__uuid__value` (`uuid`),
  KEY `shortcut_field__shortcut_set__target_id` (`shortcut_set`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for shortcut entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `shortcut`
--

LOCK TABLES `shortcut` WRITE;
/*!40000 ALTER TABLE `shortcut` DISABLE KEYS */;
INSERT INTO `shortcut` VALUES (1,'default','058f69d6-9706-4edf-b105-fa8fe49752de','en'),(2,'default','41d418df-6cba-4cbc-ab6d-de19dec6233b','en');
/*!40000 ALTER TABLE `shortcut` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `shortcut_field_data`
--

DROP TABLE IF EXISTS `shortcut_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `shortcut_field_data` (
  `id` int unsigned NOT NULL,
  `shortcut_set` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `weight` int DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `shortcut__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `shortcut_field__shortcut_set__target_id` (`shortcut_set`),
  KEY `shortcut_field__link__uri` (`link__uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for shortcut entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `shortcut_field_data`
--

LOCK TABLES `shortcut_field_data` WRITE;
/*!40000 ALTER TABLE `shortcut_field_data` DISABLE KEYS */;
INSERT INTO `shortcut_field_data` VALUES (1,'default','en','Add content',-20,'internal:/node/add',NULL,_binary 'a:0:{}',1),(2,'default','en','All content',-19,'internal:/admin/content',NULL,_binary 'a:0:{}',1);
/*!40000 ALTER TABLE `shortcut_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `shortcut_set_users`
--

DROP TABLE IF EXISTS `shortcut_set_users`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `shortcut_set_users` (
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "users".uid for this set.',
  `set_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "shortcut_set".set_name that will be displayed for this user.',
  PRIMARY KEY (`uid`),
  KEY `set_name` (`set_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maps users to shortcut sets.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `shortcut_set_users`
--

LOCK TABLES `shortcut_set_users` WRITE;
/*!40000 ALTER TABLE `shortcut_set_users` DISABLE KEYS */;
/*!40000 ALTER TABLE `shortcut_set_users` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_index`
--

DROP TABLE IF EXISTS `taxonomy_index`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_index` (
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "node".nid this record tracks.',
  `tid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The term ID.',
  `status` int NOT NULL DEFAULT '1' COMMENT 'Boolean indicating whether the node is published (visible to non-administrators).',
  `sticky` tinyint DEFAULT '0' COMMENT 'Boolean indicating whether the node is sticky.',
  `created` int NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when the node was created.',
  PRIMARY KEY (`nid`,`tid`),
  KEY `term_node` (`tid`,`status`,`sticky`,`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maintains denormalized information about node/term…';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_index`
--

LOCK TABLES `taxonomy_index` WRITE;
/*!40000 ALTER TABLE `taxonomy_index` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_index` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term__parent`
--

DROP TABLE IF EXISTS `taxonomy_term__parent`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term__parent` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `parent_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `revision_id` (`revision_id`),
  KEY `parent_target_id` (`parent_target_id`),
  KEY `bundle_delta_target_id` (`bundle`,`delta`,`parent_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for taxonomy_term field parent.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term__parent`
--

LOCK TABLES `taxonomy_term__parent` WRITE;
/*!40000 ALTER TABLE `taxonomy_term__parent` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_term__parent` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_data`
--

DROP TABLE IF EXISTS `taxonomy_term_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_data` (
  `tid` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `vid` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`tid`),
  UNIQUE KEY `taxonomy_term_field__uuid__value` (`uuid`),
  UNIQUE KEY `taxonomy_term__revision_id` (`revision_id`),
  KEY `taxonomy_term_field__vid__target_id` (`vid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for taxonomy_term entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_data`
--

LOCK TABLES `taxonomy_term_data` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_term_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_field_data`
--

DROP TABLE IF EXISTS `taxonomy_term_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_field_data` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `vid` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `name` varchar(255) NOT NULL,
  `description__value` longtext,
  `description__format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `weight` int NOT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`tid`,`langcode`),
  KEY `taxonomy_term__id__default_langcode__langcode` (`tid`,`default_langcode`,`langcode`),
  KEY `taxonomy_term__revision_id` (`revision_id`),
  KEY `taxonomy_term_field__name` (`name`(191)),
  KEY `taxonomy_term__status_vid` (`status`,`vid`,`tid`),
  KEY `taxonomy_term__tree` (`vid`,`weight`,`name`(191)),
  KEY `taxonomy_term__vid_name` (`vid`,`name`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for taxonomy_term entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_field_data`
--

LOCK TABLES `taxonomy_term_field_data` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_field_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_term_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_field_revision`
--

DROP TABLE IF EXISTS `taxonomy_term_field_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_field_revision` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `name` varchar(255) DEFAULT NULL,
  `description__value` longtext,
  `description__format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `taxonomy_term__id__default_langcode__langcode` (`tid`,`default_langcode`,`langcode`),
  KEY `taxonomy_term_field__description__format` (`description__format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for taxonomy_term entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_field_revision`
--

LOCK TABLES `taxonomy_term_field_revision` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_field_revision` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_term_field_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_revision`
--

DROP TABLE IF EXISTS `taxonomy_term_revision`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_revision` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log_message` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `taxonomy_term__tid` (`tid`),
  KEY `taxonomy_term_field__revision_user__target_id` (`revision_user`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for taxonomy_term entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_revision`
--

LOCK TABLES `taxonomy_term_revision` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_revision` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_term_revision` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `taxonomy_term_revision__parent`
--

DROP TABLE IF EXISTS `taxonomy_term_revision__parent`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `taxonomy_term_revision__parent` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `parent_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `parent_target_id` (`parent_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for taxonomy_term field parent.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `taxonomy_term_revision__parent`
--

LOCK TABLES `taxonomy_term_revision__parent` WRITE;
/*!40000 ALTER TABLE `taxonomy_term_revision__parent` DISABLE KEYS */;
/*!40000 ALTER TABLE `taxonomy_term_revision__parent` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `user__roles`
--

DROP TABLE IF EXISTS `user__roles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `user__roles` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `roles_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `roles_target_id` (`roles_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for user field roles.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `user__roles`
--

LOCK TABLES `user__roles` WRITE;
/*!40000 ALTER TABLE `user__roles` DISABLE KEYS */;
INSERT INTO `user__roles` VALUES ('user',0,1,1,'en',0,'administrator');
/*!40000 ALTER TABLE `user__roles` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `user__user_picture`
--

DROP TABLE IF EXISTS `user__user_picture`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `user__user_picture` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `user_picture_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `user_picture_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `user_picture_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `user_picture_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `user_picture_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `user_picture_target_id` (`user_picture_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for user field user_picture.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `user__user_picture`
--

LOCK TABLES `user__user_picture` WRITE;
/*!40000 ALTER TABLE `user__user_picture` DISABLE KEYS */;
/*!40000 ALTER TABLE `user__user_picture` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `users`
--

DROP TABLE IF EXISTS `users`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `users` (
  `uid` int unsigned NOT NULL AUTO_INCREMENT,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`uid`),
  UNIQUE KEY `user_field__uuid__value` (`uuid`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for user entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `users`
--

LOCK TABLES `users` WRITE;
/*!40000 ALTER TABLE `users` DISABLE KEYS */;
INSERT INTO `users` VALUES (0,'995f9b83-5f2a-499f-8700-1ff5fb7cb3ec','en'),(1,'7faa4afd-eb0d-4de9-8f53-f303a3bac462','en');
/*!40000 ALTER TABLE `users` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `users_data`
--

DROP TABLE IF EXISTS `users_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `users_data` (
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "users".uid this record affects.',
  `module` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the module declaring the variable.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The identifier of the data.',
  `value` longblob COMMENT 'The value.',
  `serialized` tinyint unsigned DEFAULT '0' COMMENT 'Whether value is serialized.',
  PRIMARY KEY (`uid`,`module`,`name`),
  KEY `module` (`module`),
  KEY `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores module data as key/value pairs per user.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `users_data`
--

LOCK TABLES `users_data` WRITE;
/*!40000 ALTER TABLE `users_data` DISABLE KEYS */;
/*!40000 ALTER TABLE `users_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `users_field_data`
--

DROP TABLE IF EXISTS `users_field_data`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `users_field_data` (
  `uid` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `preferred_langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `preferred_admin_langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `name` varchar(60) NOT NULL,
  `pass` varchar(255) DEFAULT NULL,
  `mail` varchar(254) DEFAULT NULL,
  `timezone` varchar(32) DEFAULT NULL,
  `status` tinyint DEFAULT NULL,
  `created` int NOT NULL,
  `changed` int DEFAULT NULL,
  `access` int NOT NULL,
  `login` int DEFAULT NULL,
  `init` varchar(254) DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`uid`,`langcode`),
  UNIQUE KEY `user__name` (`name`,`langcode`),
  KEY `user__id__default_langcode__langcode` (`uid`,`default_langcode`,`langcode`),
  KEY `user_field__mail` (`mail`(191)),
  KEY `user_field__created` (`created`),
  KEY `user_field__access` (`access`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for user entities.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `users_field_data`
--

LOCK TABLES `users_field_data` WRITE;
/*!40000 ALTER TABLE `users_field_data` DISABLE KEYS */;
INSERT INTO `users_field_data` VALUES (0,'en','en',NULL,'',NULL,NULL,NULL,0,1728225213,1728225213,0,0,NULL,1),(1,'en','en',NULL,'admin','$2y$10$VeOI3DQW97.sTCGsRA4gfO6FSHJ3S.8cFaM9hVA7jLtwbklv/1VGS','admin@example.com','Europe/Belgrade',1,1728225213,1728225671,1729067328,1728225671,'admin@example.com',1);
/*!40000 ALTER TABLE `users_field_data` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `watchdog`
--

DROP TABLE IF EXISTS `watchdog`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!50503 SET character_set_client = utf8mb4 */;
CREATE TABLE `watchdog` (
  `wid` bigint NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique watchdog event ID.',
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "users".uid of the user who triggered the event.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Type of log message, for example "user" or "page not found."',
  `message` longtext NOT NULL COMMENT 'Text of log message to be passed into the t() function.',
  `variables` longblob NOT NULL COMMENT 'Serialized array of variables that match the message string and that is passed into the t() function.',
  `severity` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'The severity level of the event. ranges from 0 (Emergency) to 7 (Debug)',
  `link` text COMMENT 'Link to view the result of the event.',
  `location` text NOT NULL COMMENT 'URL of the origin of the event.',
  `referer` text COMMENT 'URL of referring page.',
  `hostname` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Hostname of the user who triggered the event.',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'Unix timestamp of when event occurred.',
  PRIMARY KEY (`wid`),
  KEY `type` (`type`),
  KEY `uid` (`uid`),
  KEY `severity` (`severity`)
) ENGINE=InnoDB AUTO_INCREMENT=440 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Table that contains logs of all system events.';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `watchdog`
--

LOCK TABLES `watchdog` WRITE;
/*!40000 ALTER TABLE `watchdog` DISABLE KEYS */;
INSERT INTO `watchdog` VALUES (1,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:5:\"dblog\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225280),(2,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:6:\"search\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225290),(3,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:14:\"automated_cron\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225300),(4,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225310),(5,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:5:\"block\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225320),(6,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:5:\"field\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225328),(7,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:6:\"filter\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225338),(8,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:4:\"text\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225349),(9,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:13:\"block_content\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225361),(10,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:10:\"breakpoint\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225371),(11,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:4:\"file\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225381),(12,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:6:\"editor\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225392),(13,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:9:\"ckeditor5\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225400),(14,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:7:\"comment\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225410),(15,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:10:\"contextual\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225420),(16,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:8:\"datetime\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225430),(17,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:8:\"field_ui\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225439),(18,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:4:\"node\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225450),(19,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:7:\"history\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225462),(20,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:5:\"image\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225471),(21,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:4:\"link\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225482),(22,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:5:\"views\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225491),(23,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:17:\"menu_link_content\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225502),(24,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:7:\"menu_ui\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225512),(25,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:7:\"options\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225523),(26,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:4:\"path\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225533),(27,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:7:\"toolbar\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225542),(28,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:8:\"shortcut\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225551),(29,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:8:\"taxonomy\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225563),(30,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:8:\"views_ui\";}',6,'','http://ept-demo.local/core/install.php/?_format=json&id=1&langcode=en&op=do&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225573),(31,0,'system','%theme theme installed.',_binary 'a:1:{s:6:\"%theme\";s:7:\"olivero\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225585),(32,0,'system','%theme theme installed.',_binary 'a:1:{s:6:\"%theme\";s:5:\"claro\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225585),(33,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:8:\"standard\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard&id=1&op=start','127.0.0.1',1728225592),(34,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:6:\"update\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225678),(35,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225679),(36,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:8:\"815.11ms\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225680),(37,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:6:\"8.85ms\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225680),(38,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"0.62ms\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225680),(39,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"0.67ms\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225680),(40,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:6:\"2.78ms\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225680),(41,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"0.96ms\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225680),(42,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"17.58ms\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225680),(43,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:10:\"17451.91ms\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225698),(44,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:8:\"226.52ms\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225698),(45,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:8:\"406.36ms\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225698),(46,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225698),(47,1,'user','Session opened for %name.',_binary 'a:1:{s:5:\"%name\";s:5:\"admin\";}',6,'','http://ept-demo.local/core/install.php/?langcode=en&profile=standard','http://ept-demo.local/core/install.php?langcode=en&profile=standard','127.0.0.1',1728225698),(48,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:5:\"media\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225801),(49,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:13:\"media_library\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225804),(50,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:13:\"admin_toolbar\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225806),(51,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:19:\"admin_toolbar_tools\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225808),(52,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:21:\"ckeditor5_plugin_pack\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225810),(53,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:32:\"ckeditor5_plugin_pack_auto_image\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225811),(54,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:38:\"ckeditor5_plugin_pack_find_and_replace\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225813),(55,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:26:\"ckeditor5_plugin_pack_font\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225815),(56,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:31:\"ckeditor5_plugin_pack_highlight\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225817),(57,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:34:\"ckeditor5_plugin_pack_indent_block\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225819),(58,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:37:\"ckeditor5_plugin_pack_link_attributes\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225820),(59,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:32:\"ckeditor5_plugin_pack_page_break\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225822),(60,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:32:\"ckeditor5_plugin_pack_select_all\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225824),(61,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:31:\"ckeditor5_plugin_pack_templates\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225826),(62,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:41:\"ckeditor5_plugin_pack_text_transformation\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225828),(63,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:40:\"ckeditor5_plugin_pack_todo_document_list\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225830),(64,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:37:\"ckeditor5_premium_features_fullscreen\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728225832),(65,1,'system','%theme theme installed.',_binary 'a:1:{s:6:\"%theme\";s:3:\"gin\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=gin&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','http://ept-demo.local/admin/appearance','127.0.0.1',1728225962),(66,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:11:\"gin_toolbar\";}',6,'','http://ept-demo.local/admin/modules?check_logged_in=1','http://ept-demo.local/admin/modules?check_logged_in=1','127.0.0.1',1728226034),(67,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:11:\"block_field\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226691),(68,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:26:\"entity_reference_revisions\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226694),(69,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:10:\"paragraphs\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226697),(70,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:11:\"field_group\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226699),(71,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:26:\"media_library_form_element\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226702),(72,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:8:\"ept_core\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226704),(73,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:9:\"jquery_ui\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226706),(74,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:19:\"jquery_ui_accordion\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226707),(75,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:13:\"ept_accordion\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226713),(76,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:16:\"ept_basic_button\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226717),(77,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:9:\"ept_block\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226721),(78,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:20:\"ept_bootstrap_button\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226725),(79,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:12:\"ept_carousel\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226730),(80,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:11:\"ept_columns\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226734),(81,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:19:\"ept_core_starterkit\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226736),(82,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:13:\"ept_countdown\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226740),(83,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:11:\"ept_counter\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226745),(84,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:7:\"ept_cta\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226750),(85,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:8:\"ept_hero\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226755),(86,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:9:\"glightbox\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226757),(87,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:9:\"ept_image\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226762),(88,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:17:\"ept_image_gallery\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226766),(89,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:14:\"ept_micromodal\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226770),(90,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:9:\"ept_quote\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226775),(91,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:16:\"ept_slick_slider\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226781),(92,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:13:\"ept_slideshow\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226787),(93,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:9:\"ept_stats\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226793),(94,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:14:\"jquery_ui_tabs\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226795),(95,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:14:\"viewsreference\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226797),(96,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:8:\"ept_tabs\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226804),(97,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:8:\"ept_text\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226808),(98,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:9:\"ept_tiles\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226815),(99,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:21:\"glightbox_media_video\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226816),(100,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:9:\"ept_video\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226821),(101,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:27:\"ept_video_and_image_gallery\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226826),(102,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:9:\"ept_views\";}',6,'','http://ept-demo.local/admin/modules/list/confirm','http://ept-demo.local/admin/modules/list/confirm','127.0.0.1',1728226830),(103,1,'system','%theme theme installed.',_binary 'a:1:{s:6:\"%theme\";s:16:\"bootstrap_barrio\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','http://ept-demo.local/admin/appearance','127.0.0.1',1728229011),(104,1,'php','%type: @message in %function (line %line of %file).',_binary 'a:6:{s:5:\"%type\";s:14:\"LogicException\";s:8:\"@message\";s:118:\"The configuration name \"block.block.bootstrap_barrio_subtheme_page_title\" does not match the ID \"ept_light_page_title\"\";s:9:\"%function\";s:57:\"Drupal\\Core\\Config\\ConfigInstaller->createConfiguration()\";s:5:\"%file\";s:83:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Config\\ConfigInstaller.php\";s:5:\"%line\";i:391;s:17:\"@backtrace_string\";s:4712:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Config\\ConfigInstaller.php(260): Drupal\\Core\\Config\\ConfigInstaller->createConfiguration(\'\', Array)\n#1 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Config\\ConfigInstaller.php(164): Drupal\\Core\\Config\\ConfigInstaller->installOptionalConfig(Object(Drupal\\Core\\Config\\FileStorage), \'\')\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\ProxyClass\\Config\\ConfigInstaller.php(75): Drupal\\Core\\Config\\ConfigInstaller->installDefaultConfig(\'theme\', \'ept_light\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\ThemeInstaller.php(242): Drupal\\Core\\ProxyClass\\Config\\ConfigInstaller->installDefaultConfig(\'theme\', \'ept_light\')\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\system\\src\\Controller\\ThemeController.php(128): Drupal\\Core\\Extension\\ThemeInstaller->install(Array)\n#5 [internal function]: Drupal\\system\\Controller\\ThemeController->install(Object(Symfony\\Component\\HttpFoundation\\Request))\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(123): call_user_func_array(Array, Array)\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(121): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(97): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->wrapControllerExecutionInRenderContext(Array, Array)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(183): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#24 {main}\";}',3,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','http://ept-demo.local/admin/appearance','127.0.0.1',1728229011),(105,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','','127.0.0.1',1728240457),(106,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:6:\"1.41ms\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','','127.0.0.1',1728240457),(107,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:7:\"26.35ms\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','','127.0.0.1',1728240457),(108,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"1.34ms\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','','127.0.0.1',1728240457),(109,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"3.63ms\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','','127.0.0.1',1728240457),(110,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:7:\"18.47ms\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','','127.0.0.1',1728240457),(111,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"0.52ms\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','','127.0.0.1',1728240457),(112,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"22.38ms\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','','127.0.0.1',1728240457),(113,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:9:\"19831.4ms\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','','127.0.0.1',1728240477),(114,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:7:\"98.79ms\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','','127.0.0.1',1728240477),(115,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:9:\"4027.25ms\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','','127.0.0.1',1728240481),(116,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','','127.0.0.1',1728240481),(117,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:115:\"file_get_contents(libraries/bootstrap/dist/css/bootstrap.min.css): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:60:\"Drupal\\Core\\Asset\\CssCollectionOptimizerLazy->generateHash()\";s:5:\"%file\";s:89:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php\";s:5:\"%line\";i:43;s:17:\"@backtrace_string\";s:5675:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php(43): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\CssCollectionOptimizerLazy.php(120): Drupal\\Core\\Asset\\CssCollectionOptimizerLazy->generateHash(Array)\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetResolver.php(191): Drupal\\Core\\Asset\\CssCollectionOptimizerLazy->optimize(Array, Array, Object(Drupal\\Core\\Language\\Language))\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(279): Drupal\\Core\\Asset\\AssetResolver->getCssAssets(Object(Drupal\\Core\\Asset\\AttachedAssets), true, Object(Drupal\\Core\\Language\\Language))\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(123): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAssetLibraries(Object(Drupal\\Core\\Asset\\AttachedAssets), Array)\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\Render\\BigPipeResponseAttachmentsProcessor.php(97): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber.php(45): Drupal\\big_pipe\\Render\\BigPipeResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber->onRespond(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.response\', Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent))\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(216): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\')\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(204): Symfony\\Component\\HttpKernel\\HttpKernel->filterResponse(Object(Drupal\\Core\\Render\\HtmlResponse), Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#27 {main}\";}',4,'','http://ept-demo.local/','http://ept-demo.local/admin/appearance','127.0.0.1',1728241592),(118,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:120:\"file_get_contents(libraries/bootstrap/dist/js/bootstrap.bundle.min.js): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:59:\"Drupal\\Core\\Asset\\JsCollectionOptimizerLazy->generateHash()\";s:5:\"%file\";s:89:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php\";s:5:\"%line\";i:43;s:17:\"@backtrace_string\";s:5632:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php(43): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\JsCollectionOptimizerLazy.php(134): Drupal\\Core\\Asset\\JsCollectionOptimizerLazy->generateHash(Array)\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetResolver.php(334): Drupal\\Core\\Asset\\JsCollectionOptimizerLazy->optimize(Array, Array)\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(286): Drupal\\Core\\Asset\\AssetResolver->getJsAssets(Object(Drupal\\Core\\Asset\\AttachedAssets), true, Object(Drupal\\Core\\Language\\Language))\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(123): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAssetLibraries(Object(Drupal\\Core\\Asset\\AttachedAssets), Array)\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\Render\\BigPipeResponseAttachmentsProcessor.php(97): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber.php(45): Drupal\\big_pipe\\Render\\BigPipeResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber->onRespond(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.response\', Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent))\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(216): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\')\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(204): Symfony\\Component\\HttpKernel\\HttpKernel->filterResponse(Object(Drupal\\Core\\Render\\HtmlResponse), Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#27 {main}\";}',4,'','http://ept-demo.local/','http://ept-demo.local/admin/appearance','127.0.0.1',1728241592),(119,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:115:\"file_get_contents(libraries/bootstrap/dist/css/bootstrap.min.css): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:59:\"Drupal\\system\\Controller\\CssAssetController->generateHash()\";s:5:\"%file\";s:89:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php\";s:5:\"%line\";i:43;s:17:\"@backtrace_string\";s:4423:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php(43): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\system\\src\\Controller\\AssetControllerBase.php(184): Drupal\\system\\Controller\\CssAssetController->generateHash(Array)\n#4 [internal function]: Drupal\\system\\Controller\\AssetControllerBase->deliver(Object(Symfony\\Component\\HttpFoundation\\Request), \'css_GIPvcw4OvSM...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(123): call_user_func_array(Array, Array)\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(121): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(97): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->wrapControllerExecutionInRenderContext(Array, Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(183): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#23 {main}\";}',4,'','http://ept-demo.local/sites/default/files/css/css_GIPvcw4OvSMnTE-L_EksXnUi0ui7cAZERKyXxGV4_VU.css?delta=3&include=eJx9UNFuAyEM-yF2PO17EISIi44jiIR1_fvRU7l2a7UXwCZ2LMOGkZTbp6u5JyquetgclYhFXcgMm30GBrgofmv32cbWq8_Lg_nIVDYxchXF3QYvaAKzijZfXfCtEduUOYxJ0esYTgarukxpVfuYhFie-D-CEdHeYh7uE3iAkfCEkL0IgVPmPNaaL8KL2ONcdo49v8l1Eq9fO4r4hOIuKymau6ud7l2wzS5u74VGI_J_UVPr4z7y3tFxy_Q9bIys3BS6To-JfytPjTbEH-n0uBs&language=en&theme=ept_light','http://ept-demo.local/','127.0.0.1',1728241593),(120,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:120:\"file_get_contents(libraries/bootstrap/dist/js/bootstrap.bundle.min.js): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:58:\"Drupal\\system\\Controller\\JsAssetController->generateHash()\";s:5:\"%file\";s:89:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php\";s:5:\"%line\";i:43;s:17:\"@backtrace_string\";s:4422:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php(43): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\system\\src\\Controller\\AssetControllerBase.php(184): Drupal\\system\\Controller\\JsAssetController->generateHash(Array)\n#4 [internal function]: Drupal\\system\\Controller\\AssetControllerBase->deliver(Object(Symfony\\Component\\HttpFoundation\\Request), \'js_A9h_4YVHNXBD...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(123): call_user_func_array(Array, Array)\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(121): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(97): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->wrapControllerExecutionInRenderContext(Array, Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(183): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#23 {main}\";}',4,'','http://ept-demo.local/sites/default/files/js/js_A9h_4YVHNXBDUHJOpE__4IrbGsDGK7peY6Vu4zbjh9I.js?delta=2&include=eJx9j2EOwiAMhS-E4wyehJSuYY1ICXSL3l40wsxM9oOEvn6P90BJSg9dIdq5rBnihEO5RE63aryIVi2QnYdSWGyI4tu26rMBwVBWFzksancS5_SjHwwohXoaoPJGnyQTONl2HCBS0jFy4n3ACLUyOhWJrc5_uSGYL2I7imdf7RDM95ZysE5aiE5W0yIbFW6PtdpHgCpCpuvbbDwHlzmT7ZcXIRGWYw&language=en&scope=footer&theme=ept_light','http://ept-demo.local/','127.0.0.1',1728241593),(121,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:120:\"file_get_contents(libraries/bootstrap/dist/js/bootstrap.bundle.min.js): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:60:\"Drupal\\Core\\Asset\\JsCollectionOptimizerLazy->optimizeGroup()\";s:5:\"%file\";s:92:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\JsCollectionOptimizerLazy.php\";s:5:\"%line\";i:167;s:17:\"@backtrace_string\";s:4430:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 167)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 167)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\JsCollectionOptimizerLazy.php(167): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\system\\src\\Controller\\AssetControllerBase.php(185): Drupal\\Core\\Asset\\JsCollectionOptimizerLazy->optimizeGroup(Array)\n#4 [internal function]: Drupal\\system\\Controller\\AssetControllerBase->deliver(Object(Symfony\\Component\\HttpFoundation\\Request), \'js_A9h_4YVHNXBD...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(123): call_user_func_array(Array, Array)\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(121): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(97): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->wrapControllerExecutionInRenderContext(Array, Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(183): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#23 {main}\";}',4,'','http://ept-demo.local/sites/default/files/js/js_A9h_4YVHNXBDUHJOpE__4IrbGsDGK7peY6Vu4zbjh9I.js?delta=2&include=eJx9j2EOwiAMhS-E4wyehJSuYY1ICXSL3l40wsxM9oOEvn6P90BJSg9dIdq5rBnihEO5RE63aryIVi2QnYdSWGyI4tu26rMBwVBWFzksancS5_SjHwwohXoaoPJGnyQTONl2HCBS0jFy4n3ACLUyOhWJrc5_uSGYL2I7imdf7RDM95ZysE5aiE5W0yIbFW6PtdpHgCpCpuvbbDwHlzmT7ZcXIRGWYw&language=en&scope=footer&theme=ept_light','http://ept-demo.local/','127.0.0.1',1728241594),(122,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:115:\"file_get_contents(libraries/bootstrap/dist/css/bootstrap.min.css): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:60:\"Drupal\\Core\\Asset\\CssCollectionOptimizerLazy->generateHash()\";s:5:\"%file\";s:89:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php\";s:5:\"%line\";i:43;s:17:\"@backtrace_string\";s:5675:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php(43): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\CssCollectionOptimizerLazy.php(120): Drupal\\Core\\Asset\\CssCollectionOptimizerLazy->generateHash(Array)\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetResolver.php(191): Drupal\\Core\\Asset\\CssCollectionOptimizerLazy->optimize(Array, Array, Object(Drupal\\Core\\Language\\Language))\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(279): Drupal\\Core\\Asset\\AssetResolver->getCssAssets(Object(Drupal\\Core\\Asset\\AttachedAssets), true, Object(Drupal\\Core\\Language\\Language))\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(123): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAssetLibraries(Object(Drupal\\Core\\Asset\\AttachedAssets), Array)\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\Render\\BigPipeResponseAttachmentsProcessor.php(97): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber.php(45): Drupal\\big_pipe\\Render\\BigPipeResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber->onRespond(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.response\', Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent))\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(216): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\')\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(204): Symfony\\Component\\HttpKernel\\HttpKernel->filterResponse(Object(Drupal\\Core\\Render\\HtmlResponse), Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#27 {main}\";}',4,'','http://ept-demo.local/','http://ept-demo.local/','127.0.0.1',1728241627),(123,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:120:\"file_get_contents(libraries/bootstrap/dist/js/bootstrap.bundle.min.js): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:59:\"Drupal\\Core\\Asset\\JsCollectionOptimizerLazy->generateHash()\";s:5:\"%file\";s:89:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php\";s:5:\"%line\";i:43;s:17:\"@backtrace_string\";s:5632:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php(43): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\JsCollectionOptimizerLazy.php(134): Drupal\\Core\\Asset\\JsCollectionOptimizerLazy->generateHash(Array)\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetResolver.php(334): Drupal\\Core\\Asset\\JsCollectionOptimizerLazy->optimize(Array, Array)\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(286): Drupal\\Core\\Asset\\AssetResolver->getJsAssets(Object(Drupal\\Core\\Asset\\AttachedAssets), true, Object(Drupal\\Core\\Language\\Language))\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(123): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAssetLibraries(Object(Drupal\\Core\\Asset\\AttachedAssets), Array)\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\Render\\BigPipeResponseAttachmentsProcessor.php(97): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber.php(45): Drupal\\big_pipe\\Render\\BigPipeResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber->onRespond(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.response\', Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent))\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(216): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\')\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(204): Symfony\\Component\\HttpKernel\\HttpKernel->filterResponse(Object(Drupal\\Core\\Render\\HtmlResponse), Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#27 {main}\";}',4,'','http://ept-demo.local/','http://ept-demo.local/','127.0.0.1',1728241627),(124,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:115:\"file_get_contents(libraries/bootstrap/dist/css/bootstrap.min.css): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:60:\"Drupal\\Core\\Asset\\CssCollectionOptimizerLazy->generateHash()\";s:5:\"%file\";s:89:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php\";s:5:\"%line\";i:43;s:17:\"@backtrace_string\";s:5675:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php(43): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\CssCollectionOptimizerLazy.php(120): Drupal\\Core\\Asset\\CssCollectionOptimizerLazy->generateHash(Array)\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetResolver.php(191): Drupal\\Core\\Asset\\CssCollectionOptimizerLazy->optimize(Array, Array, Object(Drupal\\Core\\Language\\Language))\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(279): Drupal\\Core\\Asset\\AssetResolver->getCssAssets(Object(Drupal\\Core\\Asset\\AttachedAssets), true, Object(Drupal\\Core\\Language\\Language))\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(123): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAssetLibraries(Object(Drupal\\Core\\Asset\\AttachedAssets), Array)\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\Render\\BigPipeResponseAttachmentsProcessor.php(97): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber.php(45): Drupal\\big_pipe\\Render\\BigPipeResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber->onRespond(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.response\', Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent))\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(216): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\')\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(204): Symfony\\Component\\HttpKernel\\HttpKernel->filterResponse(Object(Drupal\\Core\\Render\\HtmlResponse), Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#27 {main}\";}',4,'','http://ept-demo.local/node/add','http://ept-demo.local/','127.0.0.1',1728242584),(125,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:115:\"file_get_contents(libraries/bootstrap/dist/css/bootstrap.min.css): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:59:\"Drupal\\system\\Controller\\CssAssetController->generateHash()\";s:5:\"%file\";s:89:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php\";s:5:\"%line\";i:43;s:17:\"@backtrace_string\";s:4423:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php(43): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\system\\src\\Controller\\AssetControllerBase.php(184): Drupal\\system\\Controller\\CssAssetController->generateHash(Array)\n#4 [internal function]: Drupal\\system\\Controller\\AssetControllerBase->deliver(Object(Symfony\\Component\\HttpFoundation\\Request), \'css_GIPvcw4OvSM...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(123): call_user_func_array(Array, Array)\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(121): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(97): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->wrapControllerExecutionInRenderContext(Array, Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(183): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#23 {main}\";}',4,'','http://ept-demo.local/sites/default/files/css/css_GIPvcw4OvSMnTE-L_EksXnUi0ui7cAZERKyXxGV4_VU.css?delta=3&include=eJx9UFGuAiEMvBDKl-chpTQsWZYSWqLeXtzI6nsmfsEMM9MpuFJIyu3iau4xFVcBV5dKoKLOZ8bVfgKDXJRu2iHb0HqFfH4zp5zKKkbuorRZD0LGM6tog-o8tJbYxsx-KEXvQxwNVXU5xUXtW4mhfPD_DKOifdbc0ycAxNHwgJhBJKFT5jzGfpc4iO-njUQgkrjrkpTMK8LOqC7U5uLP-zmN9eX3r0wvhG2Ue6H9lJm7xxhZuCl2nRkT_3UeHm1ED5-qsLA&language=en&theme=ept_light','http://ept-demo.local/node/add','127.0.0.1',1728242585),(126,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:115:\"file_get_contents(libraries/bootstrap/dist/css/bootstrap.min.css): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:60:\"Drupal\\Core\\Asset\\CssCollectionOptimizerLazy->generateHash()\";s:5:\"%file\";s:89:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php\";s:5:\"%line\";i:43;s:17:\"@backtrace_string\";s:5675:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php(43): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\CssCollectionOptimizerLazy.php(120): Drupal\\Core\\Asset\\CssCollectionOptimizerLazy->generateHash(Array)\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetResolver.php(191): Drupal\\Core\\Asset\\CssCollectionOptimizerLazy->optimize(Array, Array, Object(Drupal\\Core\\Language\\Language))\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(279): Drupal\\Core\\Asset\\AssetResolver->getCssAssets(Object(Drupal\\Core\\Asset\\AttachedAssets), true, Object(Drupal\\Core\\Language\\Language))\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(123): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAssetLibraries(Object(Drupal\\Core\\Asset\\AttachedAssets), Array)\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\Render\\BigPipeResponseAttachmentsProcessor.php(97): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber.php(45): Drupal\\big_pipe\\Render\\BigPipeResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber->onRespond(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.response\', Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent))\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(216): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\')\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(204): Symfony\\Component\\HttpKernel\\HttpKernel->filterResponse(Object(Drupal\\Core\\Render\\HtmlResponse), Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#27 {main}\";}',4,'','http://ept-demo.local/node/add/page','http://ept-demo.local/node/add','127.0.0.1',1728242593),(127,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:120:\"file_get_contents(libraries/bootstrap/dist/js/bootstrap.bundle.min.js): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:59:\"Drupal\\Core\\Asset\\JsCollectionOptimizerLazy->generateHash()\";s:5:\"%file\";s:89:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php\";s:5:\"%line\";i:43;s:17:\"@backtrace_string\";s:5632:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php(43): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\JsCollectionOptimizerLazy.php(134): Drupal\\Core\\Asset\\JsCollectionOptimizerLazy->generateHash(Array)\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetResolver.php(334): Drupal\\Core\\Asset\\JsCollectionOptimizerLazy->optimize(Array, Array)\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(286): Drupal\\Core\\Asset\\AssetResolver->getJsAssets(Object(Drupal\\Core\\Asset\\AttachedAssets), true, Object(Drupal\\Core\\Language\\Language))\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(123): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAssetLibraries(Object(Drupal\\Core\\Asset\\AttachedAssets), Array)\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\Render\\BigPipeResponseAttachmentsProcessor.php(97): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber.php(45): Drupal\\big_pipe\\Render\\BigPipeResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber->onRespond(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.response\', Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent))\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(216): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\')\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(204): Symfony\\Component\\HttpKernel\\HttpKernel->filterResponse(Object(Drupal\\Core\\Render\\HtmlResponse), Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#27 {main}\";}',4,'','http://ept-demo.local/node/add/page','http://ept-demo.local/node/add','127.0.0.1',1728242593),(128,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:115:\"file_get_contents(libraries/bootstrap/dist/css/bootstrap.min.css): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:59:\"Drupal\\system\\Controller\\CssAssetController->generateHash()\";s:5:\"%file\";s:89:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php\";s:5:\"%line\";i:43;s:17:\"@backtrace_string\";s:4423:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php(43): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\system\\src\\Controller\\AssetControllerBase.php(184): Drupal\\system\\Controller\\CssAssetController->generateHash(Array)\n#4 [internal function]: Drupal\\system\\Controller\\AssetControllerBase->deliver(Object(Symfony\\Component\\HttpFoundation\\Request), \'css_fRA1PRa5Mna...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(123): call_user_func_array(Array, Array)\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(121): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(97): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->wrapControllerExecutionInRenderContext(Array, Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(183): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#23 {main}\";}',4,'','http://ept-demo.local/sites/default/files/css/css_fRA1PRa5Mna6N_hwAlLA1tJZ9lvSoT-4z72VY-TDDq4.css?delta=3&include=eJyNUtlywyAM_CFqnvo9DIdqM8aIkUTT_H1lN-RoOp08Ia1Wq4u4QsqC9O5a6XOurvm4ulwTVHGhYFztvWMiVoEv6b7YRL35Mt2Qt5LryobPLLDZ4BlMQBQW8s0FT5TRzgWDMlnOSp4NNHElz4vYGzOmeof_StAW7d7moT4cH6N2eHVj8cw5OkEsWtZUTGA_kLbndg40IsGY5hNIctSC4gP_ZF4iu_1A9V0w4tYKCJjmyc8qvPAI35DplNMM8lw9EbbQRbCaOO6g6xagqgJjvyPyCmfKm5_hJaYOWP440BV4Dm3ArOrsTkvWkS_rtWPNnYHG8Ls9Zf0a_P-PGbk-bXq4i3e8PHQPGcMLksQuQ2P4j5nXHCGAbw3HHkc&language=en&theme=ept_light','http://ept-demo.local/node/add/page','127.0.0.1',1728242594),(129,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:120:\"file_get_contents(libraries/bootstrap/dist/js/bootstrap.bundle.min.js): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:58:\"Drupal\\system\\Controller\\JsAssetController->generateHash()\";s:5:\"%file\";s:89:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php\";s:5:\"%line\";i:43;s:17:\"@backtrace_string\";s:4422:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 43)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetGroupSetHashTrait.php(43): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\system\\src\\Controller\\AssetControllerBase.php(184): Drupal\\system\\Controller\\JsAssetController->generateHash(Array)\n#4 [internal function]: Drupal\\system\\Controller\\AssetControllerBase->deliver(Object(Symfony\\Component\\HttpFoundation\\Request), \'js_hxkgGZDiFl38...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(123): call_user_func_array(Array, Array)\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(121): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(97): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->wrapControllerExecutionInRenderContext(Array, Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(183): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#23 {main}\";}',4,'','http://ept-demo.local/sites/default/files/js/js_hxkgGZDiFl38G39kp7aRcdxw54RXC07PCLlWFYMaC14.js?delta=4&include=eJyNVFuO2zAMvJBqf_UALbD7VaBHEGiZsdnIolais01PX8qJ7LWzWOTDgDgzpMSXHQfBvzKDb_s0R_CNW5FvnsI5m45ZsiSItoOUiNvBc6dslqsKBoNRrKdhlHZTuj58wA8OjhPW28AJXXC5yQwUWv0sOIdBVpMCbYbzkDM5K8xen7OLdcEk5PQigS7vGMfeQ8xoAvcrWM77t8zCjqfoUdBEkLES5bxTZgHBbCYMs52pondTXRMMWoUxbwEq0rxTP6DcopFWOgXl_7zNmK7NidO0u0cT8ZgwRw5Zy2RO5NWjsjfLuDP2JJy-b_Fq2pV5RtPgFEfIlJ8SjzL5l6AdwafkNMHwQWmjn0s3I7jzPRsb-V1T7W13_Vxny1Rana6QS51AiEP7CWahh7jUpRRye0Lp7k10ZDrP7vw2s-CRWcbyAcsPESJkwdfE0-_TidxDmMxzcvii1jr-G-l0DH-WFxyJpflHcORE_3RDwf9aar9nE058wddblqU26yDp-XGRV8Dc16nd1uqL30IVQT9pbw6ujSTELyjNQPe0TIqu-FGA2UHEH8XZdDTYSBHbevgPwv3PVQ&language=en&scope=footer&theme=ept_light','http://ept-demo.local/node/add/page','127.0.0.1',1728242596),(130,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:120:\"file_get_contents(libraries/bootstrap/dist/js/bootstrap.bundle.min.js): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:60:\"Drupal\\Core\\Asset\\JsCollectionOptimizerLazy->optimizeGroup()\";s:5:\"%file\";s:92:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\JsCollectionOptimizerLazy.php\";s:5:\"%line\";i:167;s:17:\"@backtrace_string\";s:4430:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 167)\n#1 [internal function]: _drupal_error_handler(2, \'file_get_conten...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 167)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\JsCollectionOptimizerLazy.php(167): file_get_contents(\'libraries/boots...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\system\\src\\Controller\\AssetControllerBase.php(185): Drupal\\Core\\Asset\\JsCollectionOptimizerLazy->optimizeGroup(Array)\n#4 [internal function]: Drupal\\system\\Controller\\AssetControllerBase->deliver(Object(Symfony\\Component\\HttpFoundation\\Request), \'js_hxkgGZDiFl38...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(123): call_user_func_array(Array, Array)\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(121): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber.php(97): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->wrapControllerExecutionInRenderContext(Array, Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(183): Drupal\\Core\\EventSubscriber\\EarlyRenderingControllerWrapperSubscriber->Drupal\\Core\\EventSubscriber\\{closure}()\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#23 {main}\";}',4,'','http://ept-demo.local/sites/default/files/js/js_hxkgGZDiFl38G39kp7aRcdxw54RXC07PCLlWFYMaC14.js?delta=4&include=eJyNVFuO2zAMvJBqf_UALbD7VaBHEGiZsdnIolais01PX8qJ7LWzWOTDgDgzpMSXHQfBvzKDb_s0R_CNW5FvnsI5m45ZsiSItoOUiNvBc6dslqsKBoNRrKdhlHZTuj58wA8OjhPW28AJXXC5yQwUWv0sOIdBVpMCbYbzkDM5K8xen7OLdcEk5PQigS7vGMfeQ8xoAvcrWM77t8zCjqfoUdBEkLES5bxTZgHBbCYMs52pondTXRMMWoUxbwEq0rxTP6DcopFWOgXl_7zNmK7NidO0u0cT8ZgwRw5Zy2RO5NWjsjfLuDP2JJy-b_Fq2pV5RtPgFEfIlJ8SjzL5l6AdwafkNMHwQWmjn0s3I7jzPRsb-V1T7W13_Vxny1Rana6QS51AiEP7CWahh7jUpRRye0Lp7k10ZDrP7vw2s-CRWcbyAcsPESJkwdfE0-_TidxDmMxzcvii1jr-G-l0DH-WFxyJpflHcORE_3RDwf9aar9nE058wddblqU26yDp-XGRV8Dc16nd1uqL30IVQT9pbw6ujSTELyjNQPe0TIqu-FGA2UHEH8XZdDTYSBHbevgPwv3PVQ&language=en&scope=footer&theme=ept_light','http://ept-demo.local/node/add/page','127.0.0.1',1728242597),(131,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/page','http://ept-demo.local/node/add/page','127.0.0.1',1728242895),(132,1,'system','%theme theme installed.',_binary 'a:1:{s:6:\"%theme\";s:7:\"stable9\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','http://ept-demo.local/admin/appearance','127.0.0.1',1728243821),(133,1,'system','%theme theme installed.',_binary 'a:1:{s:6:\"%theme\";s:9:\"ept_light\";}',6,'','http://ept-demo.local/admin/appearance/install?theme=ept_light&token=Iq-n9WAL-DT6iE1Z114JbVF_DRGYf4A_h0mKc_1ZQNg','http://ept-demo.local/admin/appearance','127.0.0.1',1728243821),(134,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:154:\"include_once(C:\\Repos\\X2\\home\\ept-demo.local\\web/themes/contrib/bootstrap_barrio/bootstrap_barrio.theme): Failed to open stream: No such file or directory\";}s:9:\"%function\";s:14:\"include_once()\";s:5:\"%file\";s:80:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\Extension.php\";s:5:\"%line\";i:153;s:17:\"@backtrace_string\";s:5942:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'include_once(C:...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 153)\n#1 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\Extension.php(153): _drupal_error_handler(2, \'include_once(C:...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 153)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\Extension.php(153): include_once(\'C:\\\\Repos\\\\X2\\\\hom...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeInitialization.php(135): Drupal\\Core\\Extension\\Extension->load()\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeInitialization.php(74): Drupal\\Core\\Theme\\ThemeInitialization->loadActiveTheme(Object(Drupal\\Core\\Theme\\ActiveTheme))\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(415): Drupal\\Core\\Theme\\ThemeInitialization->initTheme(\'ept_light\')\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(95): Drupal\\Core\\Theme\\ThemeManager->initTheme(Object(Drupal\\Core\\Routing\\RouteMatch))\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\Context\\ThemeCacheContext.php(43): Drupal\\Core\\Theme\\ThemeManager->getActiveTheme()\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\Context\\CacheContextsManager.php(123): Drupal\\Core\\Cache\\Context\\ThemeCacheContext->getContext(NULL)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\VariationCache.php(242): Drupal\\Core\\Cache\\Context\\CacheContextsManager->convertTokensToKeys(Array)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\VariationCache.php(177): Drupal\\Core\\Cache\\VariationCache->createCacheIdFast(Array, Object(Drupal\\Core\\Cache\\CacheRedirect))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\VariationCache.php(35): Drupal\\Core\\Cache\\VariationCache->getRedirectChain(Array, Object(Drupal\\Core\\Cache\\CacheableMetadata))\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\dynamic_page_cache\\src\\EventSubscriber\\DynamicPageCacheSubscriber.php(142): Drupal\\Core\\Cache\\VariationCache->get(Array, Object(Drupal\\Core\\Cache\\CacheableMetadata))\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\dynamic_page_cache\\EventSubscriber\\DynamicPageCacheSubscriber->onRequest(Object(Symfony\\Component\\HttpKernel\\Event\\RequestEvent), \'kernel.request\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\RequestEvent), \'kernel.request\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.request\', Object(Symfony\\Component\\HttpKernel\\Event\\RequestEvent))\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(159): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\RequestEvent), \'kernel.request\')\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#28 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#30 {main}\";}',4,'','http://ept-demo.local/','http://ept-demo.local/admin/appearance','127.0.0.1',1728243903),(135,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:443:\"include_once(): Failed opening \'C:\\Repos\\X2\\home\\ept-demo.local\\web/themes/contrib/bootstrap_barrio/bootstrap_barrio.theme\' for inclusion (include_path=\'C:\\Repos\\X2\\home\\ept-demo.local\\vendor/pear/archive_tar;C:\\Repos\\X2\\home\\ept-demo.local\\vendor/pear/console_getopt;C:\\Repos\\X2\\home\\ept-demo.local\\vendor/pear/pear-core-minimal/src;C:\\Repos\\X2\\home\\ept-demo.local\\vendor/pear/pear_exception;.;C:/Repos/X2/data/PHP-8.3-FCGI/default/composer\')\";}s:9:\"%function\";s:14:\"include_once()\";s:5:\"%file\";s:80:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\Extension.php\";s:5:\"%line\";i:153;s:17:\"@backtrace_string\";s:5942:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'include_once():...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 153)\n#1 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\Extension.php(153): _drupal_error_handler(2, \'include_once():...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 153)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\Extension.php(153): include_once(\'C:\\\\Repos\\\\X2\\\\hom...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeInitialization.php(135): Drupal\\Core\\Extension\\Extension->load()\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeInitialization.php(74): Drupal\\Core\\Theme\\ThemeInitialization->loadActiveTheme(Object(Drupal\\Core\\Theme\\ActiveTheme))\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(415): Drupal\\Core\\Theme\\ThemeInitialization->initTheme(\'ept_light\')\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(95): Drupal\\Core\\Theme\\ThemeManager->initTheme(Object(Drupal\\Core\\Routing\\RouteMatch))\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\Context\\ThemeCacheContext.php(43): Drupal\\Core\\Theme\\ThemeManager->getActiveTheme()\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\Context\\CacheContextsManager.php(123): Drupal\\Core\\Cache\\Context\\ThemeCacheContext->getContext(NULL)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\VariationCache.php(242): Drupal\\Core\\Cache\\Context\\CacheContextsManager->convertTokensToKeys(Array)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\VariationCache.php(177): Drupal\\Core\\Cache\\VariationCache->createCacheIdFast(Array, Object(Drupal\\Core\\Cache\\CacheRedirect))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\VariationCache.php(35): Drupal\\Core\\Cache\\VariationCache->getRedirectChain(Array, Object(Drupal\\Core\\Cache\\CacheableMetadata))\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\dynamic_page_cache\\src\\EventSubscriber\\DynamicPageCacheSubscriber.php(142): Drupal\\Core\\Cache\\VariationCache->get(Array, Object(Drupal\\Core\\Cache\\CacheableMetadata))\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\dynamic_page_cache\\EventSubscriber\\DynamicPageCacheSubscriber->onRequest(Object(Symfony\\Component\\HttpKernel\\Event\\RequestEvent), \'kernel.request\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\RequestEvent), \'kernel.request\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.request\', Object(Symfony\\Component\\HttpKernel\\Event\\RequestEvent))\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(159): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\RequestEvent), \'kernel.request\')\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#28 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#30 {main}\";}',4,'','http://ept-demo.local/','http://ept-demo.local/admin/appearance','127.0.0.1',1728243903),(136,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:12:\"User warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:69:\"The following theme is missing from the file system: bootstrap_barrio\";}s:9:\"%function\";s:58:\"Drupal\\Core\\Extension\\ExtensionPathResolver->getPathname()\";s:5:\"%file\";s:92:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\ExtensionPathResolver.php\";s:5:\"%line\";i:63;s:17:\"@backtrace_string\";s:8313:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(512, \'The following t...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 63)\n#1 [internal function]: _drupal_error_handler(512, \'The following t...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 63)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\ExtensionPathResolver.php(63): trigger_error(\'The following t...\', 512)\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\ExtensionPathResolver.php(85): Drupal\\Core\\Extension\\ExtensionPathResolver->getPathname(\'theme\', \'bootstrap_barri...\')\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryParser.php(150): Drupal\\Core\\Extension\\ExtensionPathResolver->getPath(\'theme\', \'bootstrap_barri...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryCollector.php(87): Drupal\\Core\\Asset\\LibraryDiscoveryParser->buildByExtension(\'bootstrap_barri...\')\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryCollector.php(66): Drupal\\Core\\Asset\\LibraryDiscoveryCollector->getLibraryDefinitions(\'bootstrap_barri...\')\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\CacheCollector.php(148): Drupal\\Core\\Asset\\LibraryDiscoveryCollector->resolveCacheMiss(\'bootstrap_barri...\')\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryCollector.php(150): Drupal\\Core\\Cache\\CacheCollector->get(\'bootstrap_barri...\')\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryCollector.php(111): Drupal\\Core\\Asset\\LibraryDiscoveryCollector->applyLibrariesExtend(\'core\', \'drupal.dropbutt...\', Array)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryCollector.php(66): Drupal\\Core\\Asset\\LibraryDiscoveryCollector->getLibraryDefinitions(\'core\')\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\CacheCollector.php(148): Drupal\\Core\\Asset\\LibraryDiscoveryCollector->resolveCacheMiss(\'core\')\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscovery.php(44): Drupal\\Core\\Cache\\CacheCollector->get(\'core\')\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscovery.php(58): Drupal\\Core\\Asset\\LibraryDiscovery->getLibrariesByExtension(\'core\')\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDependencyResolver.php(68): Drupal\\Core\\Asset\\LibraryDiscovery->getLibraryByName(\'core\', \'jquery\')\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDependencyResolver.php(70): Drupal\\Core\\Asset\\LibraryDependencyResolver->doGetDependencies(Array, Array)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDependencyResolver.php(41): Drupal\\Core\\Asset\\LibraryDependencyResolver->doGetDependencies(Array)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDependencyResolver.php(87): Drupal\\Core\\Asset\\LibraryDependencyResolver->getLibrariesWithDependencies(Array)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetResolver.php(113): Drupal\\Core\\Asset\\LibraryDependencyResolver->getMinimalRepresentativeSubset(Array)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetResolver.php(128): Drupal\\Core\\Asset\\AssetResolver->getLibrariesToLoad(Object(Drupal\\Core\\Asset\\AttachedAssets))\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(279): Drupal\\Core\\Asset\\AssetResolver->getCssAssets(Object(Drupal\\Core\\Asset\\AttachedAssets), false, Object(Drupal\\Core\\Language\\Language))\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(123): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAssetLibraries(Object(Drupal\\Core\\Asset\\AttachedAssets), Array)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\Render\\BigPipeResponseAttachmentsProcessor.php(97): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber.php(45): Drupal\\big_pipe\\Render\\BigPipeResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber->onRespond(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.response\', Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent))\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(216): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\')\n#28 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(204): Symfony\\Component\\HttpKernel\\HttpKernel->filterResponse(Object(Drupal\\Core\\Render\\HtmlResponse), Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#31 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#32 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#33 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#34 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#35 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#36 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#37 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#38 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#39 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#40 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#41 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#42 {main}\";}',4,'','http://ept-demo.local/','http://ept-demo.local/admin/appearance','127.0.0.1',1728243905),(137,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:19:\"Deprecated function\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:76:\"dirname(): Passing null to parameter #1 ($path) of type string is deprecated\";}s:9:\"%function\";s:54:\"Drupal\\Core\\Extension\\ExtensionPathResolver->getPath()\";s:5:\"%file\";s:92:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\ExtensionPathResolver.php\";s:5:\"%line\";i:85;s:17:\"@backtrace_string\";s:8098:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(8192, \'dirname(): Pass...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 85)\n#1 [internal function]: _drupal_error_handler(8192, \'dirname(): Pass...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 85)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\ExtensionPathResolver.php(85): dirname(NULL)\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryParser.php(150): Drupal\\Core\\Extension\\ExtensionPathResolver->getPath(\'theme\', \'bootstrap_barri...\')\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryCollector.php(87): Drupal\\Core\\Asset\\LibraryDiscoveryParser->buildByExtension(\'bootstrap_barri...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryCollector.php(66): Drupal\\Core\\Asset\\LibraryDiscoveryCollector->getLibraryDefinitions(\'bootstrap_barri...\')\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\CacheCollector.php(148): Drupal\\Core\\Asset\\LibraryDiscoveryCollector->resolveCacheMiss(\'bootstrap_barri...\')\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryCollector.php(150): Drupal\\Core\\Cache\\CacheCollector->get(\'bootstrap_barri...\')\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryCollector.php(111): Drupal\\Core\\Asset\\LibraryDiscoveryCollector->applyLibrariesExtend(\'core\', \'drupal.dropbutt...\', Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryCollector.php(66): Drupal\\Core\\Asset\\LibraryDiscoveryCollector->getLibraryDefinitions(\'core\')\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\CacheCollector.php(148): Drupal\\Core\\Asset\\LibraryDiscoveryCollector->resolveCacheMiss(\'core\')\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscovery.php(44): Drupal\\Core\\Cache\\CacheCollector->get(\'core\')\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscovery.php(58): Drupal\\Core\\Asset\\LibraryDiscovery->getLibrariesByExtension(\'core\')\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDependencyResolver.php(68): Drupal\\Core\\Asset\\LibraryDiscovery->getLibraryByName(\'core\', \'jquery\')\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDependencyResolver.php(70): Drupal\\Core\\Asset\\LibraryDependencyResolver->doGetDependencies(Array, Array)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDependencyResolver.php(41): Drupal\\Core\\Asset\\LibraryDependencyResolver->doGetDependencies(Array)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDependencyResolver.php(87): Drupal\\Core\\Asset\\LibraryDependencyResolver->getLibrariesWithDependencies(Array)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetResolver.php(113): Drupal\\Core\\Asset\\LibraryDependencyResolver->getMinimalRepresentativeSubset(Array)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetResolver.php(128): Drupal\\Core\\Asset\\AssetResolver->getLibrariesToLoad(Object(Drupal\\Core\\Asset\\AttachedAssets))\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(279): Drupal\\Core\\Asset\\AssetResolver->getCssAssets(Object(Drupal\\Core\\Asset\\AttachedAssets), false, Object(Drupal\\Core\\Language\\Language))\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(123): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAssetLibraries(Object(Drupal\\Core\\Asset\\AttachedAssets), Array)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\Render\\BigPipeResponseAttachmentsProcessor.php(97): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber.php(45): Drupal\\big_pipe\\Render\\BigPipeResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber->onRespond(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.response\', Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent))\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(216): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\')\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(204): Symfony\\Component\\HttpKernel\\HttpKernel->filterResponse(Object(Drupal\\Core\\Render\\HtmlResponse), Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#28 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#31 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#32 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#33 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#34 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#35 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#36 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#37 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#38 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#39 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#40 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#41 {main}\";}',7,'','http://ept-demo.local/','http://ept-demo.local/admin/appearance','127.0.0.1',1728243905),(138,1,'php','%type: @message in %function (line %line of %file).',_binary 'a:6:{s:5:\"%type\";s:72:\"Drupal\\Core\\Asset\\Exception\\InvalidLibrariesExtendSpecificationException\";s:8:\"@message\";s:67:\"The specified library \"bootstrap_barrio/dropbutton\" does not exist.\";s:9:\"%function\";s:67:\"Drupal\\Core\\Asset\\LibraryDiscoveryCollector->applyLibrariesExtend()\";s:5:\"%file\";s:92:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryCollector.php\";s:5:\"%line\";i:155;s:17:\"@backtrace_string\";s:6823:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryCollector.php(111): Drupal\\Core\\Asset\\LibraryDiscoveryCollector->applyLibrariesExtend(\'core\', \'drupal.dropbutt...\', Array)\n#1 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscoveryCollector.php(66): Drupal\\Core\\Asset\\LibraryDiscoveryCollector->getLibraryDefinitions(\'core\')\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cache\\CacheCollector.php(148): Drupal\\Core\\Asset\\LibraryDiscoveryCollector->resolveCacheMiss(\'core\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscovery.php(44): Drupal\\Core\\Cache\\CacheCollector->get(\'core\')\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDiscovery.php(58): Drupal\\Core\\Asset\\LibraryDiscovery->getLibrariesByExtension(\'core\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDependencyResolver.php(68): Drupal\\Core\\Asset\\LibraryDiscovery->getLibraryByName(\'core\', \'jquery\')\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDependencyResolver.php(70): Drupal\\Core\\Asset\\LibraryDependencyResolver->doGetDependencies(Array, Array)\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDependencyResolver.php(41): Drupal\\Core\\Asset\\LibraryDependencyResolver->doGetDependencies(Array)\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\LibraryDependencyResolver.php(87): Drupal\\Core\\Asset\\LibraryDependencyResolver->getLibrariesWithDependencies(Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetResolver.php(113): Drupal\\Core\\Asset\\LibraryDependencyResolver->getMinimalRepresentativeSubset(Array)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Asset\\AssetResolver.php(128): Drupal\\Core\\Asset\\AssetResolver->getLibrariesToLoad(Object(Drupal\\Core\\Asset\\AttachedAssets))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(279): Drupal\\Core\\Asset\\AssetResolver->getCssAssets(Object(Drupal\\Core\\Asset\\AttachedAssets), false, Object(Drupal\\Core\\Language\\Language))\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(123): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAssetLibraries(Object(Drupal\\Core\\Asset\\AttachedAssets), Array)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\Render\\BigPipeResponseAttachmentsProcessor.php(97): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber.php(45): Drupal\\big_pipe\\Render\\BigPipeResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber->onRespond(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.response\', Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent))\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(216): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\')\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(204): Symfony\\Component\\HttpKernel\\HttpKernel->filterResponse(Object(Drupal\\Core\\Render\\HtmlResponse), Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#28 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#31 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#32 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#33 {main}\";}',3,'','http://ept-demo.local/','http://ept-demo.local/admin/appearance','127.0.0.1',1728243905),(139,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:10:\"twig_tweak\";}',6,'','http://default/','','127.0.0.1',1728244251),(140,1,'block','The @entity-type %label has been deleted.',_binary 'a:2:{s:12:\"@entity-type\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"%label\";s:17:\"Powered by Drupal\";}',6,'','http://ept-demo.local/admin/structure/block/manage/ept_light_powered/delete?destination=%2Fnode%2F1','http://ept-demo.local/admin/structure/block/manage/ept_light_powered/delete?destination=/node/1','127.0.0.1',1728244605),(141,1,'block','The @entity-type %label has been deleted.',_binary 'a:2:{s:12:\"@entity-type\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"%label\";s:8:\"RSS feed\";}',6,'','http://ept-demo.local/admin/structure/block/manage/ept_light_syndicate/delete?destination=%2Fnode%2F1','http://ept-demo.local/admin/structure/block/manage/ept_light_syndicate/delete?destination=/node/1','127.0.0.1',1728244676),(142,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728552918),(143,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:8:\"796.62ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728552918),(144,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:7:\"26.84ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728552918),(145,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"3.76ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728552918),(146,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"6.92ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728552918),(147,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:8:\"346.98ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728552919),(148,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"4.78ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728552919),(149,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"30.72ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728552919),(150,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/contextual/render','http://ept-demo.local/','127.0.0.1',1728552919),(151,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:10:\"51531.69ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728552970),(152,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:8:\"746.17ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728552971),(153,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:9:\"7472.54ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728552979),(154,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/','','127.0.0.1',1728552979),(155,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:11:\"tb_megamenu\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728554495),(156,1,'menu','Menu %label has been updated.',_binary 'a:1:{s:6:\"%label\";s:15:\"Main navigation\";}',5,'<a href=\"/admin/structure/menu/manage/main\">Edit</a>','http://ept-demo.local/admin/structure/menu/manage/main','http://ept-demo.local/admin/structure/menu/manage/main','127.0.0.1',1728554734),(157,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:15:\"link_attributes\";}',6,'','http://default/','','127.0.0.1',1728554839),(158,1,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:33:\"link_attributes_menu_link_content\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/modules','127.0.0.1',1728554937),(159,1,'menu','Menu %label has been updated.',_binary 'a:1:{s:6:\"%label\";s:15:\"Main navigation\";}',5,'<a href=\"/admin/structure/menu/manage/main\">Edit</a>','http://ept-demo.local/admin/structure/menu/manage/main','http://ept-demo.local/admin/structure/menu/manage/main','127.0.0.1',1728555051),(160,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728569686),(161,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:6:\"6.69ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728569686),(162,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:7:\"44.92ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728569686),(163,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"7.18ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728569686),(164,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:7:\"13.32ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728569686),(165,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:8:\"153.02ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728569686),(166,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"4.31ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728569686),(167,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"34.18ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728569687),(168,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/contextual/render','http://ept-demo.local/','127.0.0.1',1728569688),(169,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:10:\"34341.78ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728569721),(170,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:8:\"288.66ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728569721),(171,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:9:\"8620.91ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728569730),(172,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/','','127.0.0.1',1728569730),(173,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/structure/types/manage/page/form-display','127.0.0.1',1728595612),(174,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:9:\"1205.35ms\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/structure/types/manage/page/form-display','127.0.0.1',1728595613),(175,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:7:\"12.93ms\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/structure/types/manage/page/form-display','127.0.0.1',1728595613),(176,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"1.36ms\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/structure/types/manage/page/form-display','127.0.0.1',1728595613),(177,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"3.11ms\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/structure/types/manage/page/form-display','127.0.0.1',1728595613),(178,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:7:\"10.16ms\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/structure/types/manage/page/form-display','127.0.0.1',1728595613),(179,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"1.13ms\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/structure/types/manage/page/form-display','127.0.0.1',1728595613),(180,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"19.91ms\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/structure/types/manage/page/form-display','127.0.0.1',1728595613),(181,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:8:\"640.99ms\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/structure/types/manage/page/form-display','127.0.0.1',1728595614),(182,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:8:\"235.83ms\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/structure/types/manage/page/form-display','127.0.0.1',1728595614),(183,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:7:\"96.41ms\";}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/structure/types/manage/page/form-display','127.0.0.1',1728595614),(184,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/admin/modules','http://ept-demo.local/admin/structure/types/manage/page/form-display','127.0.0.1',1728595614),(185,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:16:\"layout_discovery\";}',6,'','http://default/','','127.0.0.1',1728595666),(186,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:17:\"layout_paragraphs\";}',6,'','http://default/','','127.0.0.1',1728595667),(187,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/admin/structure/tb-megamenu','http://ept-demo.local/node/1/edit','127.0.0.1',1728630386),(188,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:8:\"831.66ms\";}',6,'','http://ept-demo.local/admin/structure/tb-megamenu','http://ept-demo.local/node/1/edit','127.0.0.1',1728630387),(189,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:6:\"9.74ms\";}',6,'','http://ept-demo.local/admin/structure/tb-megamenu','http://ept-demo.local/node/1/edit','127.0.0.1',1728630387),(190,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"0.51ms\";}',6,'','http://ept-demo.local/admin/structure/tb-megamenu','http://ept-demo.local/node/1/edit','127.0.0.1',1728630387),(191,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"1.61ms\";}',6,'','http://ept-demo.local/admin/structure/tb-megamenu','http://ept-demo.local/node/1/edit','127.0.0.1',1728630387),(192,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:6:\"5.95ms\";}',6,'','http://ept-demo.local/admin/structure/tb-megamenu','http://ept-demo.local/node/1/edit','127.0.0.1',1728630387),(193,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"0.47ms\";}',6,'','http://ept-demo.local/admin/structure/tb-megamenu','http://ept-demo.local/node/1/edit','127.0.0.1',1728630387),(194,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"12.74ms\";}',6,'','http://ept-demo.local/admin/structure/tb-megamenu','http://ept-demo.local/node/1/edit','127.0.0.1',1728630387),(195,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/admin/structure/tb-megamenu/main__ept_light?destination=%2Fadmin%2Fstructure%2Ftb-megamenu','http://ept-demo.local/admin/structure/tb-megamenu','127.0.0.1',1728630392),(196,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:10:\"20164.05ms\";}',6,'','http://ept-demo.local/admin/structure/tb-megamenu','http://ept-demo.local/node/1/edit','127.0.0.1',1728630407),(197,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:7:\"219.6ms\";}',6,'','http://ept-demo.local/admin/structure/tb-megamenu','http://ept-demo.local/node/1/edit','127.0.0.1',1728630407),(198,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:8:\"150.97ms\";}',6,'','http://ept-demo.local/admin/structure/tb-megamenu','http://ept-demo.local/node/1/edit','127.0.0.1',1728630408),(199,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/admin/structure/tb-megamenu','http://ept-demo.local/node/1/edit','127.0.0.1',1728630408),(200,1,'block','The @entity-type %label has been deleted.',_binary 'a:2:{s:12:\"@entity-type\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"%label\";s:15:\"Main navigation\";}',6,'','http://ept-demo.local/admin/structure/block/manage/ept_light_main_navigation/delete?destination=%2Fadmin%2Fstructure%2Fblock','http://ept-demo.local/admin/structure/block','127.0.0.1',1728632165),(201,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728749413),(202,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:8:\"943.85ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728749414),(203,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:7:\"29.64ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728749414),(204,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"6.99ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728749414),(205,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"4.34ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728749414),(206,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:7:\"39.34ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728749414),(207,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"4.26ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728749414),(208,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"21.29ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728749414),(209,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:7:\"98.79ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728749415),(210,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/contextual/render','http://ept-demo.local/','127.0.0.1',1728749415),(211,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:8:\"319.26ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728749415),(212,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:9:\"5490.84ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728749420),(213,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/','','127.0.0.1',1728749420),(214,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728749524),(215,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728751273),(216,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728751459),(217,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762001),(218,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762001),(219,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:6:\"1.47ms\";}',6,'','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762001),(220,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:7:\"12.21ms\";}',6,'','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762001),(221,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"0.96ms\";}',6,'','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762001),(222,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"2.34ms\";}',6,'','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762001),(223,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:6:\"4.46ms\";}',6,'','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762001),(224,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"0.63ms\";}',6,'','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762001),(225,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"10.92ms\";}',6,'','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762001),(226,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:8:\"719.57ms\";}',6,'','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762002),(227,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:7:\"33.22ms\";}',6,'','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762002),(228,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:9:\"1431.17ms\";}',6,'','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762004),(229,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762004),(230,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762440),(231,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728762686),(232,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728807998),(233,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:9:\"1086.51ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728808000),(234,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:7:\"15.63ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728808000),(235,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"7.24ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728808000),(236,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"5.42ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728808000),(237,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:7:\"26.52ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728808000),(238,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"0.44ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728808000),(239,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"13.14ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728808000),(240,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:9:\"1139.43ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728808001),(241,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:7:\"235.4ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728808001),(242,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:9:\"1742.04ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728808003),(243,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728808003),(244,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit?destination=%2Fnode%2F1','http://ept-demo.local/node/1/edit?destination=/node/1','127.0.0.1',1728808801),(245,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728809720),(246,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728809816),(247,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728809850),(248,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:225:\"rename(sites/default/files/php/twig/.NvzpGw_4UpCslG4VpGO2Wpacqtg,sites/default/files/php/twig/670b8dc79d9c8_html.html.twig_STfUYk_wqEmmXg1taaVVwzvlP/6av9lPpU0_YqzOnfcBdJMi2s4vMgXm-8ZncIm9hLsdM.php): Access is denied (code: 5)\";}s:9:\"%function\";s:65:\"Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save()\";s:5:\"%file\";s:106:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php\";s:5:\"%line\";i:88;s:17:\"@backtrace_string\";s:6035:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#1 [internal function]: _drupal_error_handler(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php(88): rename(\'sites/default/f...\', \'sites/default/f...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigPhpStorageCache.php(112): Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save(\'670b8dc79d9c8_h...\', \'<?php\\n\\nuse Twig...\')\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(382): Drupal\\Core\\Template\\TwigPhpStorageCache->write(\'670b8dc79d9c8_h...\', \'<?php\\n\\nuse Twig...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(343): Twig\\Environment->loadTemplate(\'__TwigTemplate_...\', \'themes/contrib/...\')\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\Environment->load(\'themes/contrib/...\')\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'html\', Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(158): Drupal\\Core\\Render\\Renderer->render(Array)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->Drupal\\Core\\Render\\MainContent\\{closure}()\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(153): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber.php(90): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->renderResponse(Array, Object(Symfony\\Component\\HttpFoundation\\Request), Object(Drupal\\Core\\Routing\\CurrentRouteMatch))\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber->onViewRenderArray(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.view\', Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent))\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(188): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\')\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#28 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#31 {main}\";}',4,'','http://ept-demo.local/admin/config/content/ept-core','http://ept-demo.local/admin/config/content','127.0.0.1',1728810757),(249,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:226:\"rename(sites/default/files/php/twig/.fCxym4Hjukr12hg5m9h7ZZ_o5BE,sites/default/files/php/twig/670b8dc79d9c8_block.html.twig_axg2PmldJU9mvXtmAZpb8FwqW/chKlS4hS0-8rRZX51nOmt1NqT7CK6dA4Zq5dkF_IbLs.php): Access is denied (code: 5)\";}s:9:\"%function\";s:65:\"Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save()\";s:5:\"%file\";s:106:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php\";s:5:\"%line\";i:88;s:17:\"@backtrace_string\";s:9070:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#1 [internal function]: _drupal_error_handler(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php(88): rename(\'sites/default/f...\', \'sites/default/f...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigPhpStorageCache.php(112): Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save(\'670b8dc79d9c8_b...\', \'<?php\\n\\nuse Twig...\')\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(382): Drupal\\Core\\Template\\TwigPhpStorageCache->write(\'670b8dc79d9c8_b...\', \'<?php\\n\\nuse Twig...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(343): Twig\\Environment->loadTemplate(\'__TwigTemplate_...\', \'core/themes/cla...\')\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\Environment->load(\'core/themes/cla...\')\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'core/themes/cla...\', Array)\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'block\', Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(459): Drupal\\Core\\Render\\Renderer->doRender(Array)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_page.html.twig_G8WkXEivMOLIwnuERzVVPKxTG\\ijutJ0sxMXEIGnFyfOuNZ6g_cXYsApNYPLRdEeJwTdk.php(91): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_3119f91b22ea3b4f7cb6a9d676bdea3a->doDisplay(Array, Array)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'page\', Array)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_html.html.twig_STfUYk_wqEmmXg1taaVVwzvlP\\6av9lPpU0_YqzOnfcBdJMi2s4vMgXm-8ZncIm9hLsdM.php(92): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_c7c650c3373035d0d83fc87b7705077b->doDisplay(Array, Array)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#28 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'html\', Array)\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#31 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(158): Drupal\\Core\\Render\\Renderer->render(Array)\n#32 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->Drupal\\Core\\Render\\MainContent\\{closure}()\n#33 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(153): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#34 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber.php(90): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->renderResponse(Array, Object(Symfony\\Component\\HttpFoundation\\Request), Object(Drupal\\Core\\Routing\\CurrentRouteMatch))\n#35 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber->onViewRenderArray(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#36 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#37 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.view\', Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent))\n#38 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(188): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\')\n#39 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#40 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#41 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#42 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#43 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#44 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#45 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#46 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#47 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#48 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#49 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#50 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#51 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#52 {main}\";}',4,'','http://ept-demo.local/admin/config/content/paragraphs','http://ept-demo.local/admin/config/content','127.0.0.1',1728810758),(250,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:231:\"rename(sites/default/files/php/twig/.0T9VZ8tN6_7sSTv14c9zGRCGV1M,sites/default/files/php/twig/670b8dc79d9c8_breadcrumb.html.twig_CASsrwQSnv42Rs3RPN0jgmAEk/7RdkMMTYe_zUl5p8YbC0uSGHBCrqzu9mrN9MwV_gL24.php): Access is denied (code: 5)\";}s:9:\"%function\";s:65:\"Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save()\";s:5:\"%file\";s:106:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php\";s:5:\"%line\";i:88;s:17:\"@backtrace_string\";s:10910:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#1 [internal function]: _drupal_error_handler(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php(88): rename(\'sites/default/f...\', \'sites/default/f...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigPhpStorageCache.php(112): Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save(\'670b8dc79d9c8_b...\', \'<?php\\n\\nuse Twig...\')\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(382): Drupal\\Core\\Template\\TwigPhpStorageCache->write(\'670b8dc79d9c8_b...\', \'<?php\\n\\nuse Twig...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(343): Twig\\Environment->loadTemplate(\'__TwigTemplate_...\', \'themes/contrib/...\')\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\Environment->load(\'themes/contrib/...\')\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'breadcrumb\', Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_block.html.twig_axg2PmldJU9mvXtmAZpb8FwqW\\chKlS4hS0-8rRZX51nOmt1NqT7CK6dA4Zq5dkF_IbLs.php(90): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(437): __TwigTemplate_af012c9c8bbdf04bf0829cdea1762705->block_content(Array, Array)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_block.html.twig_axg2PmldJU9mvXtmAZpb8FwqW\\chKlS4hS0-8rRZX51nOmt1NqT7CK6dA4Zq5dkF_IbLs.php(73): Twig\\Template->yieldBlock(\'content\', Array, Array)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_af012c9c8bbdf04bf0829cdea1762705->doDisplay(Array, Array)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'core/themes/cla...\', Array)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'block\', Array)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(459): Drupal\\Core\\Render\\Renderer->doRender(Array)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_page.html.twig_G8WkXEivMOLIwnuERzVVPKxTG\\ijutJ0sxMXEIGnFyfOuNZ6g_cXYsApNYPLRdEeJwTdk.php(91): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_3119f91b22ea3b4f7cb6a9d676bdea3a->doDisplay(Array, Array)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#28 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#31 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'page\', Array)\n#32 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#33 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#34 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_html.html.twig_STfUYk_wqEmmXg1taaVVwzvlP\\6av9lPpU0_YqzOnfcBdJMi2s4vMgXm-8ZncIm9hLsdM.php(92): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#35 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_c7c650c3373035d0d83fc87b7705077b->doDisplay(Array, Array)\n#36 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#37 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#38 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#39 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#40 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#41 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'html\', Array)\n#42 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#43 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(158): Drupal\\Core\\Render\\Renderer->render(Array)\n#44 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->Drupal\\Core\\Render\\MainContent\\{closure}()\n#45 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(153): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#46 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber.php(90): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->renderResponse(Array, Object(Symfony\\Component\\HttpFoundation\\Request), Object(Drupal\\Core\\Routing\\CurrentRouteMatch))\n#47 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber->onViewRenderArray(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#48 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#49 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.view\', Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent))\n#50 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(188): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\')\n#51 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#52 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#53 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#54 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#55 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#56 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#57 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#58 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#59 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#60 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#61 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#62 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#63 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#64 {main}\";}',4,'','http://ept-demo.local/admin/config/content/ept-core','http://ept-demo.local/admin/config/content','127.0.0.1',1728810758),(251,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:236:\"rename(sites/default/files/php/twig/.PWt2nc3N3t6OcWCnq7xnNVU9GaE,sites/default/files/php/twig/670b8dc79d9c8_region--breadcrumb.html.t_hamet15t4X56WZdnJXxc5Xhg1/bK2P_0qC7fwnIpyWwVhw4Pt6MhslZcMl1BWCafssmvM.php): Access is denied (code: 5)\";}s:9:\"%function\";s:65:\"Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save()\";s:5:\"%file\";s:106:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php\";s:5:\"%line\";i:88;s:17:\"@backtrace_string\";s:8939:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#1 [internal function]: _drupal_error_handler(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php(88): rename(\'sites/default/f...\', \'sites/default/f...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigPhpStorageCache.php(112): Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save(\'670b8dc79d9c8_r...\', \'<?php\\n\\nuse Twig...\')\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(382): Drupal\\Core\\Template\\TwigPhpStorageCache->write(\'670b8dc79d9c8_r...\', \'<?php\\n\\nuse Twig...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(343): Twig\\Environment->loadTemplate(\'__TwigTemplate_...\', \'core/themes/cla...\')\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\Environment->load(\'core/themes/cla...\')\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'core/themes/cla...\', Array)\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(502): Drupal\\Core\\Theme\\ThemeManager->render(\'region\', Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_page.html.twig_G8WkXEivMOLIwnuERzVVPKxTG\\ijutJ0sxMXEIGnFyfOuNZ6g_cXYsApNYPLRdEeJwTdk.php(91): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_3119f91b22ea3b4f7cb6a9d676bdea3a->doDisplay(Array, Array)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'page\', Array)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_html.html.twig_STfUYk_wqEmmXg1taaVVwzvlP\\6av9lPpU0_YqzOnfcBdJMi2s4vMgXm-8ZncIm9hLsdM.php(92): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_c7c650c3373035d0d83fc87b7705077b->doDisplay(Array, Array)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#28 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'html\', Array)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(158): Drupal\\Core\\Render\\Renderer->render(Array)\n#31 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->Drupal\\Core\\Render\\MainContent\\{closure}()\n#32 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(153): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#33 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber.php(90): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->renderResponse(Array, Object(Symfony\\Component\\HttpFoundation\\Request), Object(Drupal\\Core\\Routing\\CurrentRouteMatch))\n#34 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber->onViewRenderArray(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#35 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#36 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.view\', Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent))\n#37 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(188): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\')\n#38 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#39 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#40 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#41 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#42 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#43 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#44 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#45 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#46 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#47 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#48 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#49 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#50 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#51 {main}\";}',4,'','http://ept-demo.local/admin/config/content/ept-core','http://ept-demo.local/admin/config/content','127.0.0.1',1728810758),(252,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:231:\"rename(sites/default/files/php/twig/.0_8AkYNS5eQO2kXjFRAa3m3rrKY,sites/default/files/php/twig/670b8dc79d9c8_page-title.html.twig_cgOOOamk5V67GnOsNJvLFG-76/E0C2EIpDG6Kf9cw6ATU4dzTVh40xwNytx3i2PYkEhUE.php): Access is denied (code: 5)\";}s:9:\"%function\";s:65:\"Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save()\";s:5:\"%file\";s:106:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php\";s:5:\"%line\";i:88;s:17:\"@backtrace_string\";s:10779:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#1 [internal function]: _drupal_error_handler(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php(88): rename(\'sites/default/f...\', \'sites/default/f...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigPhpStorageCache.php(112): Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save(\'670b8dc79d9c8_p...\', \'<?php\\n\\nuse Twig...\')\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(382): Drupal\\Core\\Template\\TwigPhpStorageCache->write(\'670b8dc79d9c8_p...\', \'<?php\\n\\nuse Twig...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(343): Twig\\Environment->loadTemplate(\'__TwigTemplate_...\', \'core/themes/cla...\')\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\Environment->load(\'core/themes/cla...\')\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'core/themes/cla...\', Array)\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'page_title\', Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_block.html.twig_axg2PmldJU9mvXtmAZpb8FwqW\\chKlS4hS0-8rRZX51nOmt1NqT7CK6dA4Zq5dkF_IbLs.php(90): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(437): __TwigTemplate_af012c9c8bbdf04bf0829cdea1762705->block_content(Array, Array)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_block.html.twig_axg2PmldJU9mvXtmAZpb8FwqW\\chKlS4hS0-8rRZX51nOmt1NqT7CK6dA4Zq5dkF_IbLs.php(73): Twig\\Template->yieldBlock(\'content\', Array, Array)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_af012c9c8bbdf04bf0829cdea1762705->doDisplay(Array, Array)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'core/themes/cla...\', Array)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'block\', Array)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_page.html.twig_G8WkXEivMOLIwnuERzVVPKxTG\\ijutJ0sxMXEIGnFyfOuNZ6g_cXYsApNYPLRdEeJwTdk.php(113): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_3119f91b22ea3b4f7cb6a9d676bdea3a->doDisplay(Array, Array)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#28 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'page\', Array)\n#31 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#32 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#33 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_html.html.twig_STfUYk_wqEmmXg1taaVVwzvlP\\6av9lPpU0_YqzOnfcBdJMi2s4vMgXm-8ZncIm9hLsdM.php(92): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#34 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_c7c650c3373035d0d83fc87b7705077b->doDisplay(Array, Array)\n#35 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#36 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#37 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#38 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#39 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#40 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'html\', Array)\n#41 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#42 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(158): Drupal\\Core\\Render\\Renderer->render(Array)\n#43 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->Drupal\\Core\\Render\\MainContent\\{closure}()\n#44 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(153): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#45 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber.php(90): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->renderResponse(Array, Object(Symfony\\Component\\HttpFoundation\\Request), Object(Drupal\\Core\\Routing\\CurrentRouteMatch))\n#46 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber->onViewRenderArray(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#47 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#48 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.view\', Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent))\n#49 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(188): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\')\n#50 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#51 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#52 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#53 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#54 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#55 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#56 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#57 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#58 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#59 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#60 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#61 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#62 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#63 {main}\";}',4,'','http://ept-demo.local/admin/config/content/paragraphs','http://ept-demo.local/admin/config/content','127.0.0.1',1728810758),(253,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:227:\"rename(sites/default/files/php/twig/.o-789RxQJxOF7FkjloN8N6G_kHg,sites/default/files/php/twig/670b8dc79d9c8_region.html.twig_xNqZovJKSJlEiSLCVC0L-eiJv/gQHkWHCaRFhRsHUa-vuYsQQv5-Zr1O_725xgpQMA_fo.php): Access is denied (code: 5)\";}s:9:\"%function\";s:65:\"Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save()\";s:5:\"%file\";s:106:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php\";s:5:\"%line\";i:88;s:17:\"@backtrace_string\";s:8940:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#1 [internal function]: _drupal_error_handler(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php(88): rename(\'sites/default/f...\', \'sites/default/f...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigPhpStorageCache.php(112): Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save(\'670b8dc79d9c8_r...\', \'<?php\\n\\nuse Twig...\')\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(382): Drupal\\Core\\Template\\TwigPhpStorageCache->write(\'670b8dc79d9c8_r...\', \'<?php\\n\\nuse Twig...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(343): Twig\\Environment->loadTemplate(\'__TwigTemplate_...\', \'themes/contrib/...\')\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\Environment->load(\'themes/contrib/...\')\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(502): Drupal\\Core\\Theme\\ThemeManager->render(\'region\', Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_page.html.twig_G8WkXEivMOLIwnuERzVVPKxTG\\ijutJ0sxMXEIGnFyfOuNZ6g_cXYsApNYPLRdEeJwTdk.php(133): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_3119f91b22ea3b4f7cb6a9d676bdea3a->doDisplay(Array, Array)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'page\', Array)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_html.html.twig_STfUYk_wqEmmXg1taaVVwzvlP\\6av9lPpU0_YqzOnfcBdJMi2s4vMgXm-8ZncIm9hLsdM.php(92): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_c7c650c3373035d0d83fc87b7705077b->doDisplay(Array, Array)\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#28 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'html\', Array)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(158): Drupal\\Core\\Render\\Renderer->render(Array)\n#31 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->Drupal\\Core\\Render\\MainContent\\{closure}()\n#32 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(153): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#33 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber.php(90): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->renderResponse(Array, Object(Symfony\\Component\\HttpFoundation\\Request), Object(Drupal\\Core\\Routing\\CurrentRouteMatch))\n#34 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber->onViewRenderArray(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#35 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#36 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.view\', Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent))\n#37 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(188): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\')\n#38 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#39 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#40 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#41 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#42 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#43 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#44 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#45 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#46 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#47 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#48 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#49 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#50 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#51 {main}\";}',4,'','http://ept-demo.local/admin/config/content/paragraphs','http://ept-demo.local/admin/config/content','127.0.0.1',1728810758),(254,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:236:\"rename(sites/default/files/php/twig/.uvVFvp5l-28Ju0zLnX7wDBMgRuk,sites/default/files/php/twig/670b8dc79d9c8_off-canvas-page-wrapper.h_cavG12lSadZP1h1J4UZTVf7yY/7Y7FcGvLSheJeRBiAhgPEfW_TfUABHNB8H8vyctQ9sk.php): Access is denied (code: 5)\";}s:9:\"%function\";s:65:\"Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save()\";s:5:\"%file\";s:106:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php\";s:5:\"%line\";i:88;s:17:\"@backtrace_string\";s:7500:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#1 [internal function]: _drupal_error_handler(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php(88): rename(\'sites/default/f...\', \'sites/default/f...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigPhpStorageCache.php(112): Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save(\'670b8dc79d9c8_o...\', \'<?php\\n\\nuse Twig...\')\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(382): Drupal\\Core\\Template\\TwigPhpStorageCache->write(\'670b8dc79d9c8_o...\', \'<?php\\n\\nuse Twig...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(343): Twig\\Environment->loadTemplate(\'__TwigTemplate_...\', \'core/themes/cla...\')\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\Environment->load(\'core/themes/cla...\')\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'core/themes/cla...\', Array)\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(502): Drupal\\Core\\Theme\\ThemeManager->render(\'off_canvas_page...\', Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670b8dc79d9c8_html.html.twig_STfUYk_wqEmmXg1taaVVwzvlP\\6av9lPpU0_YqzOnfcBdJMi2s4vMgXm-8ZncIm9hLsdM.php(92): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_c7c650c3373035d0d83fc87b7705077b->doDisplay(Array, Array)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'html\', Array)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(158): Drupal\\Core\\Render\\Renderer->render(Array)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->Drupal\\Core\\Render\\MainContent\\{closure}()\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(153): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber.php(90): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->renderResponse(Array, Object(Symfony\\Component\\HttpFoundation\\Request), Object(Drupal\\Core\\Routing\\CurrentRouteMatch))\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber->onViewRenderArray(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.view\', Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent))\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(188): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\')\n#28 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#31 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#32 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#33 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#34 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#35 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#36 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#37 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#38 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#39 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#40 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#41 {main}\";}',4,'','http://ept-demo.local/admin/config/content/paragraphs','http://ept-demo.local/admin/config/content','127.0.0.1',1728810758),(255,1,'php','%type: @message in %function (line %line of %file) @backtrace_string.',_binary 'a:6:{s:5:\"%type\";s:7:\"Warning\";s:8:\"@message\";O:25:\"Drupal\\Core\\Render\\Markup\":1:{s:9:\"\0*\0string\";s:236:\"rename(sites/default/files/php/twig/.72FIeBngr9JmwTSpIFDsHTxV2NA,sites/default/files/php/twig/670b8dc79d9c8_big-pipe-interface-previe_SPZNrXHrKg6-DqjMpDh94PF2t/MaLx46nuFbb0fdpGmCR9XioSTU0FtguCxoYTAHEsTug.php): Access is denied (code: 5)\";}s:9:\"%function\";s:65:\"Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save()\";s:5:\"%file\";s:106:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php\";s:5:\"%line\";i:88;s:17:\"@backtrace_string\";s:7956:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\includes\\bootstrap.inc(108): _drupal_error_handler_real(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#1 [internal function]: _drupal_error_handler(2, \'rename(sites/de...\', \'C:\\\\Repos\\\\X2\\\\hom...\', 88)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage.php(88): rename(\'sites/default/f...\', \'sites/default/f...\')\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigPhpStorageCache.php(112): Drupal\\Component\\PhpStorage\\MTimeProtectedFastFileStorage->save(\'670b8dc79d9c8_b...\', \'<?php\\n\\nuse Twig...\')\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(382): Drupal\\Core\\Template\\TwigPhpStorageCache->write(\'670b8dc79d9c8_b...\', \'<?php\\n\\nuse Twig...\')\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Environment.php(343): Twig\\Environment->loadTemplate(\'__TwigTemplate_...\', \'core/modules/bi...\')\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\Environment->load(\'core/modules/bi...\')\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'core/modules/bi...\', Array)\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'big_pipe_interf...\', Array)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(459): Drupal\\Core\\Render\\Renderer->doRender(Array)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, true)\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(120): Drupal\\Core\\Render\\Renderer->render(Array, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\Render\\Renderer->Drupal\\Core\\Render\\{closure}()\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(119): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(146): Drupal\\Core\\Render\\Renderer->renderInIsolation(Array)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(678): Drupal\\Core\\Render\\Renderer->doRenderPlaceholder(Array)\n#16 [internal function]: Drupal\\Core\\Render\\Renderer->Drupal\\Core\\Render\\{closure}()\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(686): Fiber->start()\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(563): Drupal\\Core\\Render\\Renderer->replacePlaceholders(Array)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, true)\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(108): Drupal\\Core\\Render\\Renderer->render(Array, true)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\Render\\Renderer->Drupal\\Core\\Render\\{closure}()\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(107): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor.php(244): Drupal\\Core\\Render\\Renderer->renderRoot(Array)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\Render\\BigPipeResponseAttachmentsProcessor.php(74): Drupal\\Core\\Render\\HtmlResponseAttachmentsProcessor->renderPlaceholders(Object(Drupal\\Core\\Render\\HtmlResponse))\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber.php(45): Drupal\\big_pipe\\Render\\BigPipeResponseAttachmentsProcessor->processAttachments(Object(Drupal\\Core\\Render\\HtmlResponse))\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\HtmlResponseSubscriber->onRespond(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#28 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.response\', Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent))\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(216): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ResponseEvent), \'kernel.response\')\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(204): Symfony\\Component\\HttpKernel\\HttpKernel->filterResponse(Object(Drupal\\Core\\Render\\HtmlResponse), Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#31 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#32 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#33 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#34 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#35 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#36 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#37 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#38 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#39 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#40 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#41 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#42 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#43 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#44 {main}\";}',4,'','http://ept-demo.local/admin/config/content/paragraphs','http://ept-demo.local/admin/config/content','127.0.0.1',1728810758),(256,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728817648),(257,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit','127.0.0.1',1728818843),(258,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:6:\"4.13ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit','127.0.0.1',1728818843),(259,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:7:\"26.24ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit','127.0.0.1',1728818843),(260,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"4.84ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit','127.0.0.1',1728818843),(261,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"8.99ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit','127.0.0.1',1728818843),(262,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:7:\"38.55ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit','127.0.0.1',1728818843),(263,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"1.62ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit','127.0.0.1',1728818843),(264,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"31.65ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit','127.0.0.1',1728818843),(265,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:10:\"22957.63ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit','127.0.0.1',1728818866),(266,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:7:\"59.47ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit','127.0.0.1',1728818866),(267,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:7:\"25.76ms\";}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit','127.0.0.1',1728818866),(268,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/node/1','http://ept-demo.local/node/1/edit','127.0.0.1',1728818866),(269,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728819417),(270,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728819463),(271,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728819684),(272,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728819953),(273,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728820015),(274,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728833000),(275,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:8:\"928.98ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728833001),(276,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:6:\"12.1ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728833001),(277,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"1.48ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728833001),(278,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"2.44ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728833001),(279,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:7:\"13.98ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728833001),(280,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"0.74ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728833001),(281,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"12.12ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728833001),(282,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/contextual/render','http://ept-demo.local/','127.0.0.1',1728833002),(283,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:9:\"1290.46ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728833003),(284,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:8:\"248.19ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728833003),(285,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:9:\"2518.52ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728833005),(286,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/','','127.0.0.1',1728833005),(287,1,'php','%type: @message in %function (line %line of %file).',_binary 'a:6:{s:5:\"%type\";s:57:\"Drupal\\Core\\Extension\\Exception\\UnknownExtensionException\";s:8:\"@message\";s:35:\"The module ept_core does not exist.\";s:9:\"%function\";s:42:\"Drupal\\Core\\Extension\\ExtensionList->get()\";s:5:\"%file\";s:84:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\ExtensionList.php\";s:5:\"%line\";i:266;s:17:\"@backtrace_string\";s:11028:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\ExtensionList.php(244): Drupal\\Core\\Extension\\ExtensionList->get(\'ept_core\')\n#1 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\PermissionHandler.php(234): Drupal\\Core\\Extension\\ExtensionList->getName(\'ept_core\')\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\PermissionHandler.php(212): Drupal\\user\\PermissionHandler->getModuleNames()\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\PermissionHandler.php(118): Drupal\\user\\PermissionHandler->sortPermissions(Array)\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\Form\\EntityPermissionsForm.php(104): Drupal\\user\\PermissionHandler->getPermissions()\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\Form\\EntityPermissionsForm.php(184): Drupal\\user\\Form\\EntityPermissionsForm->permissionsByProvider()\n#6 [internal function]: Drupal\\user\\Form\\EntityPermissionsForm->access(Object(Symfony\\Component\\Routing\\Route), Object(Drupal\\Core\\Routing\\RouteMatch), NULL)\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Access\\CustomAccessCheck.php(66): call_user_func_array(Array, Array)\n#8 [internal function]: Drupal\\Core\\Access\\CustomAccessCheck->access(Object(Symfony\\Component\\Routing\\Route), Object(Drupal\\Core\\Routing\\RouteMatch), Object(Drupal\\Core\\Session\\AccountProxy), NULL)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Access\\AccessManager.php(160): call_user_func_array(Array, Array)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Access\\AccessManager.php(136): Drupal\\Core\\Access\\AccessManager->performCheck(\'access_check.cu...\', Object(Drupal\\Component\\Utility\\ArgumentsResolver))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Access\\AccessManager.php(93): Drupal\\Core\\Access\\AccessManager->check(Object(Drupal\\Core\\Routing\\RouteMatch), Object(Drupal\\Core\\Session\\AccountProxy), NULL, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(187): Drupal\\Core\\Access\\AccessManager->checkNamedRoute(\'entity.comment_...\', Array, Object(Drupal\\Core\\Session\\AccountProxy), true)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(76): Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->menuLinkCheckAccess(Object(Drupal\\Core\\Menu\\MenuLinkDefault))\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(80): Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->checkAccess(Array)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(80): Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->checkAccess(Array)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(80): Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->checkAccess(Array)\n#17 [internal function]: Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->checkAccess(Array)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\MenuLinkTree.php(114): call_user_func(Array, Array)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\modules\\contrib\\gin_toolbar\\src\\Render\\Element\\GinToolbar.php(60): Drupal\\Core\\Menu\\MenuLinkTree->transform(Array, Array)\n#20 [internal function]: Drupal\\gin_toolbar\\Render\\Element\\GinToolbar::preRenderTray(Array)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Security\\DoTrustedCallbackTrait.php(107): call_user_func_array(Array, Array)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(825): Drupal\\Core\\Render\\Renderer->doTrustedCallback(Array, Array, \'Render #pre_ren...\', \'exception\', \'Drupal\\\\Core\\\\Ren...\')\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(387): Drupal\\Core\\Render\\Renderer->doCallback(\'#pre_render\', Array, Array)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(459): Drupal\\Core\\Render\\Renderer->doRender(Array)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(459): Drupal\\Core\\Render\\Renderer->doRender(Array)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\toolbar\\toolbar.module(94): Drupal\\Core\\Render\\Renderer->render(Array)\n#28 [internal function]: template_preprocess_toolbar(Array, \'toolbar\', Array)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(261): call_user_func_array(\'template_prepro...\', Array)\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'toolbar\', Array)\n#31 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(459): Drupal\\Core\\Render\\Renderer->doRender(Array)\n#32 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#33 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#34 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670be6b82aaff_html.html.twig_STfUYk_wqEmmXg1taaVVwzvlP\\sF-Ph6-wpO7AqPBEpncenbslf1fUcf87Z5HZQ3FGhPU.php(88): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#35 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_c7c650c3373035d0d83fc87b7705077b->doDisplay(Array, Array)\n#36 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#37 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#38 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#39 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#40 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#41 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'html\', Array)\n#42 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#43 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(158): Drupal\\Core\\Render\\Renderer->render(Array)\n#44 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->Drupal\\Core\\Render\\MainContent\\{closure}()\n#45 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(153): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#46 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber.php(90): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->renderResponse(Array, Object(Symfony\\Component\\HttpFoundation\\Request), Object(Drupal\\Core\\Routing\\CurrentRouteMatch))\n#47 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber->onViewRenderArray(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#48 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#49 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.view\', Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent))\n#50 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(188): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\')\n#51 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#52 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#53 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#54 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#55 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#56 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#57 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#58 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#59 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#60 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#61 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#62 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#63 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#64 {main}\";}',3,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849880),(288,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849880),(289,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:6:\"0.95ms\";}',6,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849880),(290,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:7:\"24.62ms\";}',6,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849880),(291,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"2.33ms\";}',6,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849880),(292,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"5.22ms\";}',6,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849880),(293,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:6:\"4.62ms\";}',6,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849880),(294,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"2.16ms\";}',6,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849880),(295,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"35.45ms\";}',6,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849880),(296,1,'php','%type: @message in %function (line %line of %file).',_binary 'a:6:{s:5:\"%type\";s:57:\"Drupal\\Core\\Extension\\Exception\\UnknownExtensionException\";s:8:\"@message\";s:35:\"The module ept_core does not exist.\";s:9:\"%function\";s:42:\"Drupal\\Core\\Extension\\ExtensionList->get()\";s:5:\"%file\";s:84:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\ExtensionList.php\";s:5:\"%line\";i:266;s:17:\"@backtrace_string\";s:11028:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\ExtensionList.php(244): Drupal\\Core\\Extension\\ExtensionList->get(\'ept_core\')\n#1 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\PermissionHandler.php(234): Drupal\\Core\\Extension\\ExtensionList->getName(\'ept_core\')\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\PermissionHandler.php(212): Drupal\\user\\PermissionHandler->getModuleNames()\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\PermissionHandler.php(118): Drupal\\user\\PermissionHandler->sortPermissions(Array)\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\Form\\EntityPermissionsForm.php(104): Drupal\\user\\PermissionHandler->getPermissions()\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\Form\\EntityPermissionsForm.php(184): Drupal\\user\\Form\\EntityPermissionsForm->permissionsByProvider()\n#6 [internal function]: Drupal\\user\\Form\\EntityPermissionsForm->access(Object(Symfony\\Component\\Routing\\Route), Object(Drupal\\Core\\Routing\\RouteMatch), NULL)\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Access\\CustomAccessCheck.php(66): call_user_func_array(Array, Array)\n#8 [internal function]: Drupal\\Core\\Access\\CustomAccessCheck->access(Object(Symfony\\Component\\Routing\\Route), Object(Drupal\\Core\\Routing\\RouteMatch), Object(Drupal\\Core\\Session\\AccountProxy), NULL)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Access\\AccessManager.php(160): call_user_func_array(Array, Array)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Access\\AccessManager.php(136): Drupal\\Core\\Access\\AccessManager->performCheck(\'access_check.cu...\', Object(Drupal\\Component\\Utility\\ArgumentsResolver))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Access\\AccessManager.php(93): Drupal\\Core\\Access\\AccessManager->check(Object(Drupal\\Core\\Routing\\RouteMatch), Object(Drupal\\Core\\Session\\AccountProxy), NULL, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(187): Drupal\\Core\\Access\\AccessManager->checkNamedRoute(\'entity.comment_...\', Array, Object(Drupal\\Core\\Session\\AccountProxy), true)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(76): Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->menuLinkCheckAccess(Object(Drupal\\Core\\Menu\\MenuLinkDefault))\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(80): Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->checkAccess(Array)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(80): Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->checkAccess(Array)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(80): Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->checkAccess(Array)\n#17 [internal function]: Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->checkAccess(Array)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\MenuLinkTree.php(114): call_user_func(Array, Array)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\modules\\contrib\\gin_toolbar\\src\\Render\\Element\\GinToolbar.php(60): Drupal\\Core\\Menu\\MenuLinkTree->transform(Array, Array)\n#20 [internal function]: Drupal\\gin_toolbar\\Render\\Element\\GinToolbar::preRenderTray(Array)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Security\\DoTrustedCallbackTrait.php(107): call_user_func_array(Array, Array)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(825): Drupal\\Core\\Render\\Renderer->doTrustedCallback(Array, Array, \'Render #pre_ren...\', \'exception\', \'Drupal\\\\Core\\\\Ren...\')\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(387): Drupal\\Core\\Render\\Renderer->doCallback(\'#pre_render\', Array, Array)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(459): Drupal\\Core\\Render\\Renderer->doRender(Array)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(459): Drupal\\Core\\Render\\Renderer->doRender(Array)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\toolbar\\toolbar.module(94): Drupal\\Core\\Render\\Renderer->render(Array)\n#28 [internal function]: template_preprocess_toolbar(Array, \'toolbar\', Array)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(261): call_user_func_array(\'template_prepro...\', Array)\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'toolbar\', Array)\n#31 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(459): Drupal\\Core\\Render\\Renderer->doRender(Array)\n#32 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#33 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#34 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670be6b82aaff_html.html.twig_STfUYk_wqEmmXg1taaVVwzvlP\\sF-Ph6-wpO7AqPBEpncenbslf1fUcf87Z5HZQ3FGhPU.php(88): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#35 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_c7c650c3373035d0d83fc87b7705077b->doDisplay(Array, Array)\n#36 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#37 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#38 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#39 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#40 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#41 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'html\', Array)\n#42 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#43 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(158): Drupal\\Core\\Render\\Renderer->render(Array)\n#44 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->Drupal\\Core\\Render\\MainContent\\{closure}()\n#45 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(153): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#46 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber.php(90): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->renderResponse(Array, Object(Symfony\\Component\\HttpFoundation\\Request), Object(Drupal\\Core\\Routing\\CurrentRouteMatch))\n#47 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber->onViewRenderArray(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#48 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#49 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.view\', Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent))\n#50 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(188): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\')\n#51 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#52 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#53 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#54 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#55 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#56 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#57 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#58 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#59 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#60 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#61 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#62 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#63 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#64 {main}\";}',3,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849892),(297,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849893),(298,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/favicon.ico','http://ept-demo.local/node/1/edit','127.0.0.1',1728849898),(299,0,'cron','%type: @message in %function (line %line of %file).',_binary 'a:6:{s:5:\"%type\";s:23:\"Twig\\Error\\RuntimeError\";s:8:\"@message\";s:104:\"An exception has been thrown during the rendering of a template (\"The module ept_core does not exist.\").\";s:9:\"%function\";s:22:\"Twig\\Template->yield()\";s:5:\"%file\";s:117:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\announcements_feed\\help_topics\\announcements_feed.overview.html.twig\";s:5:\"%line\";i:12;s:17:\"@backtrace_string\";s:3699:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#1 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\help\\src\\HelpTopicTwig.php(55): Twig\\TemplateWrapper->render()\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\help\\HelpTopicTwig->getBody()\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\help\\src\\Plugin\\HelpSection\\HelpTopicSection.php(200): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Array)\n#6 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\help\\src\\Plugin\\Search\\HelpSearch.php(362): Drupal\\help\\Plugin\\HelpSection\\HelpTopicSection->renderTopicForSearch(\'announcements_f...\', Object(Drupal\\Core\\Language\\Language))\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\search\\search.module(80): Drupal\\help\\Plugin\\Search\\HelpSearch->updateIndex()\n#8 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cron.php(275): search_cron()\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\ModuleHandler.php(395): Drupal\\Core\\Cron->Drupal\\Core\\{closure}(Object(Closure), \'search\')\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cron.php(258): Drupal\\Core\\Extension\\ModuleHandler->invokeAllWith(\'cron\', Object(Closure))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Cron.php(97): Drupal\\Core\\Cron->invokeCronHandlers()\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\ProxyClass\\Cron.php(75): Drupal\\Core\\Cron->run()\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\automated_cron\\src\\EventSubscriber\\AutomatedCron.php(65): Drupal\\Core\\ProxyClass\\Cron->run()\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\automated_cron\\EventSubscriber\\AutomatedCron->onTerminate(Object(Symfony\\Component\\HttpKernel\\Event\\TerminateEvent), \'kernel.terminat...\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\TerminateEvent), \'kernel.terminat...\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.terminat...\', Object(Symfony\\Component\\HttpKernel\\Event\\TerminateEvent))\n#17 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(114): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\TerminateEvent), \'kernel.terminat...\')\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(63): Symfony\\Component\\HttpKernel\\HttpKernel->terminate(Object(Symfony\\Component\\HttpFoundation\\Request), Object(Symfony\\Component\\HttpFoundation\\Response))\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(683): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->terminate(Object(Symfony\\Component\\HttpFoundation\\Request), Object(Symfony\\Component\\HttpFoundation\\Response))\n#20 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(22): Drupal\\Core\\DrupalKernel->terminate(Object(Symfony\\Component\\HttpFoundation\\Request), Object(Symfony\\Component\\HttpFoundation\\Response))\n#21 {main}\";}',3,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849914),(300,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:10:\"33595.17ms\";}',6,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849914),(301,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:8:\"148.55ms\";}',6,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849914),(302,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:9:\"3686.34ms\";}',6,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849918),(303,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728849918),(304,1,'php','%type: @message in %function (line %line of %file).',_binary 'a:6:{s:5:\"%type\";s:57:\"Drupal\\Core\\Extension\\Exception\\UnknownExtensionException\";s:8:\"@message\";s:35:\"The module ept_core does not exist.\";s:9:\"%function\";s:42:\"Drupal\\Core\\Extension\\ExtensionList->get()\";s:5:\"%file\";s:84:\"C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\ExtensionList.php\";s:5:\"%line\";i:266;s:17:\"@backtrace_string\";s:11028:\"#0 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Extension\\ExtensionList.php(244): Drupal\\Core\\Extension\\ExtensionList->get(\'ept_core\')\n#1 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\PermissionHandler.php(234): Drupal\\Core\\Extension\\ExtensionList->getName(\'ept_core\')\n#2 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\PermissionHandler.php(212): Drupal\\user\\PermissionHandler->getModuleNames()\n#3 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\PermissionHandler.php(118): Drupal\\user\\PermissionHandler->sortPermissions(Array)\n#4 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\Form\\EntityPermissionsForm.php(104): Drupal\\user\\PermissionHandler->getPermissions()\n#5 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\user\\src\\Form\\EntityPermissionsForm.php(184): Drupal\\user\\Form\\EntityPermissionsForm->permissionsByProvider()\n#6 [internal function]: Drupal\\user\\Form\\EntityPermissionsForm->access(Object(Symfony\\Component\\Routing\\Route), Object(Drupal\\Core\\Routing\\RouteMatch), NULL)\n#7 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Access\\CustomAccessCheck.php(66): call_user_func_array(Array, Array)\n#8 [internal function]: Drupal\\Core\\Access\\CustomAccessCheck->access(Object(Symfony\\Component\\Routing\\Route), Object(Drupal\\Core\\Routing\\RouteMatch), Object(Drupal\\Core\\Session\\AccountProxy), NULL)\n#9 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Access\\AccessManager.php(160): call_user_func_array(Array, Array)\n#10 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Access\\AccessManager.php(136): Drupal\\Core\\Access\\AccessManager->performCheck(\'access_check.cu...\', Object(Drupal\\Component\\Utility\\ArgumentsResolver))\n#11 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Access\\AccessManager.php(93): Drupal\\Core\\Access\\AccessManager->check(Object(Drupal\\Core\\Routing\\RouteMatch), Object(Drupal\\Core\\Session\\AccountProxy), NULL, true)\n#12 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(187): Drupal\\Core\\Access\\AccessManager->checkNamedRoute(\'entity.comment_...\', Array, Object(Drupal\\Core\\Session\\AccountProxy), true)\n#13 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(76): Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->menuLinkCheckAccess(Object(Drupal\\Core\\Menu\\MenuLinkDefault))\n#14 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(80): Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->checkAccess(Array)\n#15 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(80): Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->checkAccess(Array)\n#16 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators.php(80): Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->checkAccess(Array)\n#17 [internal function]: Drupal\\Core\\Menu\\DefaultMenuLinkTreeManipulators->checkAccess(Array)\n#18 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Menu\\MenuLinkTree.php(114): call_user_func(Array, Array)\n#19 C:\\Repos\\X2\\home\\ept-demo.local\\web\\modules\\contrib\\gin_toolbar\\src\\Render\\Element\\GinToolbar.php(60): Drupal\\Core\\Menu\\MenuLinkTree->transform(Array, Array)\n#20 [internal function]: Drupal\\gin_toolbar\\Render\\Element\\GinToolbar::preRenderTray(Array)\n#21 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Security\\DoTrustedCallbackTrait.php(107): call_user_func_array(Array, Array)\n#22 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(825): Drupal\\Core\\Render\\Renderer->doTrustedCallback(Array, Array, \'Render #pre_ren...\', \'exception\', \'Drupal\\\\Core\\\\Ren...\')\n#23 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(387): Drupal\\Core\\Render\\Renderer->doCallback(\'#pre_render\', Array, Array)\n#24 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(459): Drupal\\Core\\Render\\Renderer->doRender(Array)\n#25 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(459): Drupal\\Core\\Render\\Renderer->doRender(Array)\n#26 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#27 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\toolbar\\toolbar.module(94): Drupal\\Core\\Render\\Renderer->render(Array)\n#28 [internal function]: template_preprocess_toolbar(Array, \'toolbar\', Array)\n#29 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(261): call_user_func_array(\'template_prepro...\', Array)\n#30 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'toolbar\', Array)\n#31 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(459): Drupal\\Core\\Render\\Renderer->doRender(Array)\n#32 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#33 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Template\\TwigExtension.php(476): Drupal\\Core\\Render\\Renderer->render(Array)\n#34 C:\\Repos\\X2\\home\\ept-demo.local\\web\\sites\\default\\files\\php\\twig\\670be6b82aaff_html.html.twig_STfUYk_wqEmmXg1taaVVwzvlP\\sF-Ph6-wpO7AqPBEpncenbslf1fUcf87Z5HZQ3FGhPU.php(88): Drupal\\Core\\Template\\TwigExtension->escapeFilter(Object(Drupal\\Core\\Template\\TwigEnvironment), Array, \'html\', NULL, true)\n#35 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(393): __TwigTemplate_c7c650c3373035d0d83fc87b7705077b->doDisplay(Array, Array)\n#36 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(349): Twig\\Template->yield(Array, Array)\n#37 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\Template.php(364): Twig\\Template->display(Array)\n#38 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\twig\\twig\\src\\TemplateWrapper.php(35): Twig\\Template->render(Array)\n#39 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\themes\\engines\\twig\\twig.engine(33): Twig\\TemplateWrapper->render(Array)\n#40 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Theme\\ThemeManager.php(348): twig_render_template(\'themes/contrib/...\', Array)\n#41 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(446): Drupal\\Core\\Theme\\ThemeManager->render(\'html\', Array)\n#42 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(203): Drupal\\Core\\Render\\Renderer->doRender(Array, false)\n#43 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(158): Drupal\\Core\\Render\\Renderer->render(Array)\n#44 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\Renderer.php(593): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->Drupal\\Core\\Render\\MainContent\\{closure}()\n#45 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\Render\\MainContent\\HtmlRenderer.php(153): Drupal\\Core\\Render\\Renderer->executeInRenderContext(Object(Drupal\\Core\\Render\\RenderContext), Object(Closure))\n#46 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber.php(90): Drupal\\Core\\Render\\MainContent\\HtmlRenderer->renderResponse(Array, Object(Symfony\\Component\\HttpFoundation\\Request), Object(Drupal\\Core\\Routing\\CurrentRouteMatch))\n#47 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(246): Drupal\\Core\\EventSubscriber\\MainContentViewSubscriber->onViewRenderArray(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#48 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(206): Symfony\\Component\\EventDispatcher\\EventDispatcher::Symfony\\Component\\EventDispatcher\\{closure}(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\', Object(Symfony\\Component\\EventDispatcher\\EventDispatcher))\n#49 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\event-dispatcher\\EventDispatcher.php(56): Symfony\\Component\\EventDispatcher\\EventDispatcher->callListeners(Array, \'kernel.view\', Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent))\n#50 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(188): Symfony\\Component\\EventDispatcher\\EventDispatcher->dispatch(Object(Symfony\\Component\\HttpKernel\\Event\\ViewEvent), \'kernel.view\')\n#51 C:\\Repos\\X2\\home\\ept-demo.local\\vendor\\symfony\\http-kernel\\HttpKernel.php(76): Symfony\\Component\\HttpKernel\\HttpKernel->handleRaw(Object(Symfony\\Component\\HttpFoundation\\Request), 1)\n#52 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\Session.php(53): Symfony\\Component\\HttpKernel\\HttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#53 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\KernelPreHandle.php(48): Drupal\\Core\\StackMiddleware\\Session->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#54 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ContentLength.php(28): Drupal\\Core\\StackMiddleware\\KernelPreHandle->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#55 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\big_pipe\\src\\StackMiddleware\\ContentLength.php(32): Drupal\\Core\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#56 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(106): Drupal\\big_pipe\\StackMiddleware\\ContentLength->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#57 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\modules\\page_cache\\src\\StackMiddleware\\PageCache.php(85): Drupal\\page_cache\\StackMiddleware\\PageCache->pass(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#58 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware.php(48): Drupal\\page_cache\\StackMiddleware\\PageCache->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#59 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\NegotiationMiddleware.php(51): Drupal\\Core\\StackMiddleware\\ReverseProxyMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#60 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\AjaxPageState.php(36): Drupal\\Core\\StackMiddleware\\NegotiationMiddleware->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#61 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\StackMiddleware\\StackedHttpKernel.php(51): Drupal\\Core\\StackMiddleware\\AjaxPageState->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#62 C:\\Repos\\X2\\home\\ept-demo.local\\web\\core\\lib\\Drupal\\Core\\DrupalKernel.php(709): Drupal\\Core\\StackMiddleware\\StackedHttpKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request), 1, true)\n#63 C:\\Repos\\X2\\home\\ept-demo.local\\web\\index.php(19): Drupal\\Core\\DrupalKernel->handle(Object(Symfony\\Component\\HttpFoundation\\Request))\n#64 {main}\";}',3,'','http://ept-demo.local/node/1/edit','','127.0.0.1',1728850080),(305,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/history/1/read','http://ept-demo.local/','127.0.0.1',1728882889),(306,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:9:\"5816.62ms\";}',6,'','http://ept-demo.local/history/1/read','http://ept-demo.local/','127.0.0.1',1728882895),(307,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:7:\"16.17ms\";}',6,'','http://ept-demo.local/history/1/read','http://ept-demo.local/','127.0.0.1',1728882895),(308,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"1.34ms\";}',6,'','http://ept-demo.local/history/1/read','http://ept-demo.local/','127.0.0.1',1728882895),(309,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"2.82ms\";}',6,'','http://ept-demo.local/history/1/read','http://ept-demo.local/','127.0.0.1',1728882895),(310,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:7:\"24.63ms\";}',6,'','http://ept-demo.local/history/1/read','http://ept-demo.local/','127.0.0.1',1728882895),(311,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"0.47ms\";}',6,'','http://ept-demo.local/history/1/read','http://ept-demo.local/','127.0.0.1',1728882895),(312,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"11.91ms\";}',6,'','http://ept-demo.local/history/1/read','http://ept-demo.local/','127.0.0.1',1728882895),(313,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/node/1/edit','http://ept-demo.local/','127.0.0.1',1728882919),(314,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/layout-paragraphs-builder/95fe2708534b0147e0e23d777fe2879a/reorder?_wrapper_format=drupal_ajax','http://ept-demo.local/node/1/edit','127.0.0.1',1728882924),(315,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/layout-paragraphs-builder/95fe2708534b0147e0e23d777fe2879a/edit/f427a33f-64f8-4506-99c7-a8605b1df563?_wrapper_format=drupal_dialog','http://ept-demo.local/node/1/edit','127.0.0.1',1728882932),(316,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:10:\"46514.07ms\";}',6,'','http://ept-demo.local/history/1/read','http://ept-demo.local/','127.0.0.1',1728882942),(317,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:9:\"4840.25ms\";}',6,'','http://ept-demo.local/history/1/read','http://ept-demo.local/','127.0.0.1',1728882947),(318,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:9:\"1280.36ms\";}',6,'','http://ept-demo.local/history/1/read','http://ept-demo.local/','127.0.0.1',1728882948),(319,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/history/1/read','http://ept-demo.local/','127.0.0.1',1728882948),(320,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728882973),(321,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728883070),(322,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728883326),(323,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728883775),(324,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728883939),(325,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728884119),(326,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728884895),(327,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:18:\"media_library_edit\";}',6,'','http://default/','','127.0.0.1',1728885071),(328,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728885202),(329,1,'media','@type: updated %label.',_binary 'a:2:{s:5:\"@type\";s:5:\"image\";s:6:\"%label\";s:17:\"fluid_grid_1.webp\";}',6,'<a href=\"/media/4/edit\" hreflang=\"en\">View</a>','http://ept-demo.local/media/4/edit?destination=%2Fnode%2F1','http://ept-demo.local/media/4/edit?destination=/node/1','127.0.0.1',1728885250),(330,1,'media','@type: updated %label.',_binary 'a:2:{s:5:\"@type\";s:5:\"image\";s:6:\"%label\";s:16:\"faq example.webp\";}',6,'<a href=\"/media/5/edit\" hreflang=\"en\">View</a>','http://ept-demo.local/media/5/edit?destination=%2Fnode%2F1','http://ept-demo.local/media/5/edit?destination=/node/1','127.0.0.1',1728885289),(331,1,'media','@type: updated %label.',_binary 'a:2:{s:5:\"@type\";s:5:\"image\";s:6:\"%label\";s:18:\"2 columns CTA.webp\";}',6,'<a href=\"/media/6/edit\" hreflang=\"en\">View</a>','http://ept-demo.local/media/6/edit?destination=%2Fnode%2F1','http://ept-demo.local/media/6/edit?destination=/node/1','127.0.0.1',1728885311),(332,1,'media','@type: updated %label.',_binary 'a:2:{s:5:\"@type\";s:5:\"image\";s:6:\"%label\";s:13:\"EBT Tabs.webp\";}',6,'<a href=\"/media/7/edit\" hreflang=\"en\">View</a>','http://ept-demo.local/media/7/edit?destination=%2Fnode%2F1','http://ept-demo.local/media/7/edit?destination=/node/1','127.0.0.1',1728885332),(333,1,'media','@type: updated %label.',_binary 'a:2:{s:5:\"@type\";s:5:\"image\";s:6:\"%label\";s:17:\"fluid_grid_1.webp\";}',6,'<a href=\"/media/4/edit\" hreflang=\"en\">View</a>','http://ept-demo.local/media/4/edit?destination=%2Fnode%2F1','http://ept-demo.local/media/4/edit?destination=/node/1','127.0.0.1',1728885350),(334,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728885508),(335,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728885679),(336,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728885901),(337,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728888390),(338,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728889244),(339,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728889331),(340,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728932377),(341,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:8:\"1086.7ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728932378),(342,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:7:\"23.13ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728932378),(343,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"9.42ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728932378),(344,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"6.88ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728932378),(345,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:7:\"31.03ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728932378),(346,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"5.15ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728932378),(347,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"27.54ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728932378),(348,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/contextual/render','http://ept-demo.local/','127.0.0.1',1728932379),(349,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:10:\"31499.23ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728932410),(350,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:8:\"392.35ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728932410),(351,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/node/1/edit','http://ept-demo.local/','127.0.0.1',1728932413),(352,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:9:\"2644.03ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1728932413),(353,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/','','127.0.0.1',1728932413),(354,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728933426),(355,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728933475),(356,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728934141),(357,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728934264),(358,1,'media','@type: updated %label.',_binary 'a:2:{s:5:\"@type\";s:5:\"image\";s:6:\"%label\";s:41:\"4950565d-af48-45ef-be68-c27550a02da9.webp\";}',6,'<a href=\"/media/19/edit\" hreflang=\"en\">View</a>','http://ept-demo.local/media/19/edit?destination=%2Fadmin%2Fcontent%2Fmedia-grid','http://ept-demo.local/media/19/edit?destination=/admin/content/media-grid','127.0.0.1',1728935149),(359,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728935840),(360,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728936708),(361,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728936830),(362,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728936890),(363,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728937167),(364,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1728937230),(365,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729018462),(366,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:9:\"1108.69ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729018464),(367,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:7:\"18.02ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729018464),(368,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"6.37ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729018464),(369,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"6.68ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729018464),(370,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:7:\"54.89ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729018464),(371,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"2.93ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729018464),(372,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"30.87ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729018464),(373,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/contextual/render','http://ept-demo.local/','127.0.0.1',1729018464),(374,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:10:\"23330.34ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729018487),(375,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:8:\"431.67ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729018487),(376,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:9:\"4335.07ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729018492),(377,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/','','127.0.0.1',1729018492),(378,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1729020155),(379,1,'menu','Menu %label has been updated.',_binary 'a:1:{s:6:\"%label\";s:6:\"Footer\";}',5,'<a href=\"/admin/structure/menu/manage/footer\">Edit</a>','http://ept-demo.local/admin/structure/menu/manage/footer','http://ept-demo.local/admin/structure/menu/manage/footer','127.0.0.1',1729020379),(380,1,'tb_megamenu','Could not find TB Megamenu configuration for menu: @menu, theme: @theme',_binary 'a:2:{s:5:\"@menu\";s:6:\"footer\";s:6:\"@theme\";s:9:\"ept_light\";}',4,'','http://ept-demo.local/admin/structure/menu/manage/footer','http://ept-demo.local/admin/structure/menu/manage/footer','127.0.0.1',1729020379),(381,1,'menu','Menu %label has been updated.',_binary 'a:1:{s:6:\"%label\";s:6:\"Footer\";}',5,'<a href=\"/admin/structure/menu/manage/footer\">Edit</a>','http://ept-demo.local/admin/structure/menu/manage/footer','http://ept-demo.local/admin/structure/menu/manage/footer','127.0.0.1',1729020529),(382,1,'tb_megamenu','Could not find TB Megamenu configuration for menu: @menu, theme: @theme',_binary 'a:2:{s:5:\"@menu\";s:6:\"footer\";s:6:\"@theme\";s:9:\"ept_light\";}',4,'','http://ept-demo.local/admin/structure/menu/manage/footer','http://ept-demo.local/admin/structure/menu/manage/footer','127.0.0.1',1729020529),(383,1,'menu','Menu %label has been updated.',_binary 'a:1:{s:6:\"%label\";s:6:\"Footer\";}',5,'<a href=\"/admin/structure/menu/manage/footer\">Edit</a>','http://ept-demo.local/admin/structure/menu/manage/footer','http://ept-demo.local/admin/structure/menu/manage/footer','127.0.0.1',1729020556),(384,1,'tb_megamenu','Could not find TB Megamenu configuration for menu: @menu, theme: @theme',_binary 'a:2:{s:5:\"@menu\";s:6:\"footer\";s:6:\"@theme\";s:9:\"ept_light\";}',4,'','http://ept-demo.local/admin/structure/menu/manage/footer','http://ept-demo.local/admin/structure/menu/manage/footer','127.0.0.1',1729020556),(385,1,'menu','Menu %label has been updated.',_binary 'a:1:{s:6:\"%label\";s:17:\"User account menu\";}',5,'<a href=\"/admin/structure/menu/manage/account\">Edit</a>','http://ept-demo.local/admin/structure/menu/manage/account','http://ept-demo.local/admin/structure/menu/manage/account','127.0.0.1',1729020979),(386,1,'tb_megamenu','Could not find TB Megamenu configuration for menu: @menu, theme: @theme',_binary 'a:2:{s:5:\"@menu\";s:7:\"account\";s:6:\"@theme\";s:9:\"ept_light\";}',4,'','http://ept-demo.local/admin/structure/menu/manage/account','http://ept-demo.local/admin/structure/menu/manage/account','127.0.0.1',1729020979),(387,1,'menu','Menu %label has been updated.',_binary 'a:1:{s:6:\"%label\";s:6:\"Footer\";}',5,'<a href=\"/admin/structure/menu/manage/footer\">Edit</a>','http://ept-demo.local/admin/structure/menu/manage/footer','http://ept-demo.local/admin/structure/menu/manage/footer','127.0.0.1',1729021178),(388,1,'tb_megamenu','Could not find TB Megamenu configuration for menu: @menu, theme: @theme',_binary 'a:2:{s:5:\"@menu\";s:6:\"footer\";s:6:\"@theme\";s:9:\"ept_light\";}',4,'','http://ept-demo.local/admin/structure/menu/manage/footer','http://ept-demo.local/admin/structure/menu/manage/footer','127.0.0.1',1729021178),(389,1,'menu_link_content','The @entity-type %label has been deleted.',_binary 'a:2:{s:12:\"@entity-type\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"custom menu link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:6:\"%label\";s:25:\"Demo: EPT Accordion / FAQ\";}',6,'','http://ept-demo.local/admin/structure/menu/item/2/delete?destination=%2Fnode%2F1','http://ept-demo.local/admin/structure/menu/item/2/delete?destination=/node/1','127.0.0.1',1729021335),(390,1,'menu','Menu %label has been updated.',_binary 'a:1:{s:6:\"%label\";s:15:\"Main navigation\";}',5,'<a href=\"/admin/structure/menu/manage/main\">Edit</a>','http://ept-demo.local/admin/structure/menu/manage/main?destination=%2Fnode%2F1','http://ept-demo.local/admin/structure/menu/manage/main?destination=/node/1','127.0.0.1',1729021360),(391,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1729022520),(392,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1729022937),(393,1,'menu','Menu %label has been updated.',_binary 'a:1:{s:6:\"%label\";s:15:\"Main navigation\";}',5,'<a href=\"/admin/structure/menu/manage/main\">Edit</a>','http://ept-demo.local/admin/structure/menu/manage/main?destination=%2Fnode%2F1','http://ept-demo.local/admin/structure/menu/manage/main?destination=/node/1','127.0.0.1',1729023795),(394,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:8:\"file_mdm\";}',6,'','http://default/','','127.0.0.1',1729024210),(395,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:13:\"file_mdm_exif\";}',6,'','http://default/','','127.0.0.1',1729024210),(396,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:13:\"file_mdm_font\";}',6,'','http://default/','','127.0.0.1',1729024211),(397,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:13:\"image_effects\";}',6,'','http://default/','','127.0.0.1',1729024212),(398,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:31:\"Getting Started EPT Page Buider\";}',6,'<a href=\"/node/1\" hreflang=\"en\">View</a>','http://ept-demo.local/node/1/edit','http://ept-demo.local/node/1/edit','127.0.0.1',1729024763),(399,0,'cron','Starting execution of @module_cron().',_binary 'a:1:{s:7:\"@module\";s:18:\"announcements_feed\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729063115),(400,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"comment\";s:16:\"@module_previous\";s:18:\"announcements_feed\";s:5:\"@time\";s:9:\"1058.18ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729063116),(401,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"dblog\";s:16:\"@module_previous\";s:7:\"comment\";s:5:\"@time\";s:7:\"18.59ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729063116),(402,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:5:\"field\";s:16:\"@module_previous\";s:5:\"dblog\";s:5:\"@time\";s:6:\"6.79ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729063116),(403,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"file\";s:16:\"@module_previous\";s:5:\"field\";s:5:\"@time\";s:6:\"5.54ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729063116),(404,0,'cron','Attempting to re-run cron while it is already running.',_binary 'a:0:{}',4,'','http://ept-demo.local/contextual/render','http://ept-demo.local/','127.0.0.1',1729063116),(405,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:7:\"history\";s:16:\"@module_previous\";s:4:\"file\";s:5:\"@time\";s:8:\"107.35ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729063116),(406,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:4:\"node\";s:16:\"@module_previous\";s:7:\"history\";s:5:\"@time\";s:6:\"2.71ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729063116),(407,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"search\";s:16:\"@module_previous\";s:4:\"node\";s:5:\"@time\";s:7:\"34.39ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729063116),(408,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"system\";s:16:\"@module_previous\";s:6:\"search\";s:5:\"@time\";s:10:\"24174.67ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729063140),(409,0,'cron','Starting execution of @module_cron(), execution of @module_previous_cron() took @time.',_binary 'a:3:{s:7:\"@module\";s:6:\"update\";s:16:\"@module_previous\";s:6:\"system\";s:5:\"@time\";s:8:\"358.01ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729063140),(410,0,'cron','Execution of @module_previous_cron() took @time.',_binary 'a:2:{s:16:\"@module_previous\";s:6:\"update\";s:5:\"@time\";s:9:\"2093.28ms\";}',6,'','http://ept-demo.local/','','127.0.0.1',1729063143),(411,0,'cron','Cron run completed.',_binary 'a:0:{}',6,'','http://ept-demo.local/','','127.0.0.1',1729063143),(412,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:39:\"New EPT Video and Image gallery module!\";}',6,'<a href=\"/node/2\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729063269),(413,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:23:\"New EPT Webform module!\";}',6,'<a href=\"/node/3\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729063647),(414,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:29:\"New EPT Webform Popup module!\";}',6,'<a href=\"/node/4\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729063667),(415,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:51:\"EPT (Extra Paragraph Types): Core new release 1.4.0\";}',6,'<a href=\"/node/5\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729063696),(416,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:21:\"New EPT Stats module!\";}',6,'<a href=\"/node/6\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729063724),(417,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:21:\"New EPT Views module!\";}',6,'<a href=\"/node/7\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729063750),(418,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:21:\"New EBT Views module!\";}',6,'<a href=\"/node/8\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729063840),(419,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:48:\"EBT (Extra Block Types): Core new release 1.4.16\";}',6,'<a href=\"/node/9\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729063863),(420,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:51:\"EPT (Extra Paragraph Types): Core new release 1.4.1\";}',6,'<a href=\"/node/10\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729063887),(421,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:21:\"New EPT Block module!\";}',6,'<a href=\"/node/11\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729063907),(422,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:48:\"EBT (Extra Block Types): Core new release 1.4.21\";}',6,'<a href=\"/node/12\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729063939),(423,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:51:\"EPT (Extra Paragraph Types): Core new release 1.4.3\";}',6,'<a href=\"/node/13\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729063958),(424,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:21:\"New EBT Block module!\";}',6,'<a href=\"/node/14\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729063986),(425,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:35:\"New EBT Columns / Container module!\";}',6,'<a href=\"/node/15\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729064009),(426,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:48:\"EBT (Extra Block Types): Core new release 1.4.22\";}',6,'<a href=\"/node/16\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729064047),(427,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:48:\"EBT (Extra Block Types): Core new release 1.4.24\";}',6,'<a href=\"/node/17\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729064068),(428,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:7:\"article\";s:6:\"%title\";s:51:\"EPT (Extra Paragraph Types): Core new release 1.4.7\";}',6,'<a href=\"/node/18\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/article','http://ept-demo.local/node/add/article','127.0.0.1',1729064096),(429,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:17:\"views_year_filter\";}',6,'','http://default/','','127.0.0.1',1729064407),(430,1,'content','@type: added %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:10:\"What\'s New\";}',6,'<a href=\"/whats-new\" hreflang=\"en\">View</a>','http://ept-demo.local/node/add/page','http://ept-demo.local/node/add/page','127.0.0.1',1729064556),(431,1,'menu','Menu %label has been updated.',_binary 'a:1:{s:6:\"%label\";s:15:\"Main navigation\";}',5,'<a href=\"/admin/structure/menu/manage/main\">Edit</a>','http://ept-demo.local/admin/structure/menu/manage/main?destination=%2Fnode%2F19','http://ept-demo.local/admin/structure/menu/manage/main?destination=/node/19','127.0.0.1',1729064672),(432,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:10:\"What\'s New\";}',6,'<a href=\"/whats-new\" hreflang=\"en\">View</a>','http://ept-demo.local/node/19/edit','http://ept-demo.local/node/19/edit','127.0.0.1',1729065354),(433,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:22:\"better_exposed_filters\";}',6,'','http://default/','','127.0.0.1',1729066403),(434,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:10:\"What\'s New\";}',6,'<a href=\"/whats-new\" hreflang=\"en\">View</a>','http://ept-demo.local/node/19/edit','http://ept-demo.local/node/19/edit','127.0.0.1',1729066915),(435,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:10:\"What\'s New\";}',6,'<a href=\"/whats-new\" hreflang=\"en\">View</a>','http://ept-demo.local/node/19/edit?destination=%2Fnode%2F19','http://ept-demo.local/node/19/edit?destination=/node/19','127.0.0.1',1729066955),(436,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:10:\"What\'s New\";}',6,'<a href=\"/whats-new\" hreflang=\"en\">View</a>','http://ept-demo.local/node/19/edit?destination=%2Fnode%2F19','http://ept-demo.local/node/19/edit?destination=/node/19','127.0.0.1',1729067015),(437,1,'content','@type: updated %title.',_binary 'a:2:{s:5:\"@type\";s:4:\"page\";s:6:\"%title\";s:10:\"What\'s New\";}',6,'<a href=\"/whats-new\" hreflang=\"en\">View</a>','http://ept-demo.local/node/19/edit','http://ept-demo.local/node/19/edit','127.0.0.1',1729067293),(438,0,'system','%module module installed.',_binary 'a:1:{s:7:\"%module\";s:16:\"profile_switcher\";}',6,'','http://default/','','127.0.0.1',1729108594),(439,0,'system','%module module uninstalled.',_binary 'a:1:{s:7:\"%module\";s:16:\"profile_switcher\";}',6,'','http://default/','','127.0.0.1',1729108661);
/*!40000 ALTER TABLE `watchdog` ENABLE KEYS */;
UNLOCK TABLES;


-- Dump completed on 2024-10-16 22:01:07
